@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -29,7 +29,7 @@ import net.sf.jasperreports.engine.JRExpression;
 
 /**
  * @author Flavius Sana (flavius_sana@users.sourceforge.net)
- * @version $Id: JRBubblePlot.java 3559 2010-03-10 10:31:16Z shertage $
+ * @version $Id: JRBubblePlot.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public interface JRBubblePlot extends JRChartPlot, JRXAxisFormat, JRYAxisFormat
 {
@@ -44,31 +44,11 @@ public interface JRBubblePlot extends JRChartPlot, JRXAxisFormat, JRYAxisFormat
 	 */
 	public JRExpression getYAxisLabelExpression();
 
-	/**
-	 * @deprecated Replaced by {@link #getScaleTypeValue()}
-	 */
-	public int getScaleType();
-
-	/**
-	 * @deprecated Replaced by {@link #getScaleTypeValue()}
-	 */
-	public Integer getScaleTypeInteger();
-
 	/**
 	 * 
 	 */
 	public ScaleTypeEnum getScaleTypeValue();
 
-	/**
-	 * @deprecated Replaced by {@link #setScaleType(ScaleTypeEnum)}
-	 */
-	public void setScaleType(int scaleType);
-	
-	/**
-	 * @deprecated Replaced by {@link #setScaleType(ScaleTypeEnum)}
-	 */
-	public void setScaleType(Integer scaleType);
-
 	/**
 	 * 
 	 */
