@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -34,32 +34,12 @@ import net.sf.jasperreports.engine.JRCloneable;
  * dataset.
  *
  * @author Barry Klawans (barry@users.sourceforge.net)
- * @version $Id: JRChartAxis.java 3582 2010-03-12 10:28:51Z shertage $
+ * @version $Id: JRChartAxis.java 4595 2011-09-08 15:55:10Z teodord $
  */
 
 
 public interface JRChartAxis extends JRCloneable
 {
-	/**
-	 * @deprecated Replaced by {@link AxisPositionEnum#LEFT_OR_TOP}
-	 */
-	public static final byte POSITION_LEFT_OR_TOP = 1;
-
-	/**
-	 * @deprecated Replaced by {@link AxisPositionEnum#LEFT_OR_TOP}
-	 */
-	public static final byte POSITION_RIGHT_OR_BOTTOM = 2;
-
-	/**
-	 * @deprecated Replaced by {@link #getPositionValue()}
-	 */
-	public byte getPosition();
-
-	/**
-	 * @deprecated Replaced by {@link #getPositionValue()}
-	 */
-	public Byte getPositionByte();
-
 	/**
 	 * Gets the position of this axis.
 	 *
