@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -27,6 +27,7 @@ import java.awt.Color;
 import java.util.List;
 
 import net.sf.jasperreports.charts.type.MeterShapeEnum;
+import net.sf.jasperreports.charts.util.JRMeterInterval;
 import net.sf.jasperreports.engine.JRChartPlot;
 import net.sf.jasperreports.engine.JRFont;
 
@@ -37,30 +38,10 @@ import net.sf.jasperreports.engine.JRFont;
  * can be broken up into shaded regions to highlight portions of the range.
  *
  * @author Barry Klawans (bklawans@users.sourceforge.net)
- * @version $Id: JRMeterPlot.java 3565 2010-03-10 11:41:24Z shertage $
+ * @version $Id: JRMeterPlot.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public interface JRMeterPlot extends JRChartPlot
 {
-	/**
-	 * @deprecated Replaced by {@link MeterShapeEnum#CHORD}
-	 */
-	public static final byte SHAPE_CHORD = 0;
-
-	/**
-	 * @deprecated Replaced by {@link MeterShapeEnum#CIRCLE}
-	 */
-	public static final byte SHAPE_CIRCLE = 1;
-
-	/**
-	 * @deprecated Replaced by {@link MeterShapeEnum#PIE}
-	 */
-	public static final byte SHAPE_PIE = 2;
-
-	/**
-	 * @deprecated Replaced by {@link MeterShapeEnum#DIAL}
-	 */
-	public static final byte SHAPE_DIAL = 3;
-
 	/**
 	 * Returns the range of values that the Meter can display.
 	 *
@@ -77,16 +58,6 @@ public interface JRMeterPlot extends JRChartPlot
 	 */
 	public JRValueDisplay getValueDisplay();
 
-	/**
-	 * @deprecated Replaced by {@link #getShapeValue()}
-	 */
-	public byte getShape();
-
-	/**
-	 * @deprecated Replaced by {@link #getShapeValue()}
-	 */
-	public Byte getShapeByte();
-
 	/**
 	 * Returns the shape of the Meter.  The shape is only relevant if the Meter face is
 	 * over 180 degrees wide, and controls how the portion of the circle described by the
@@ -106,12 +77,7 @@ public interface JRMeterPlot extends JRChartPlot
 	 *
 	 * @return a list of all the intervals contained in this Meter
 	 */
-	public List getIntervals();
-
-	/**
-	 * @deprecated Replaced by {@link #getMeterAngleInteger()}
-	 */
-	public int getMeterAngle();
+	public List<JRMeterInterval> getIntervals();
 
 	/**
 	 * Returns the size of the Meter face in degrees.
@@ -128,11 +94,6 @@ public interface JRMeterPlot extends JRChartPlot
 	 */
 	public String getUnits();
 
-	/**
-	 * @deprecated Replaced by {@link #getTickIntervalDouble()}
-	 */
-	public double getTickInterval();
-
 	/**
 	 * Returns the spacing between the ticks on the face of the meter.  The spacing is relative
 	 * to the range that the meter is displaying - if the range is 0 to 500 and the tick interval
