@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -28,22 +28,23 @@ import net.sf.jasperreports.engine.JRChartPlot;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRPiePlot.java 3032 2009-08-27 11:32:28Z teodord $
+ * @version $Id: JRPiePlot.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public interface JRPiePlot extends JRChartPlot
 {
-	/**
-	 * @deprecated Replaced by {@link #getCircular()}
-	 */
-	public boolean isCircular();
-	
 	/**
 	 * 
 	 */
 	public Boolean getCircular();
 	
+	/**
+	 * 
+	 */
 	public String getLabelFormat();
 	
+	/**
+	 * 
+	 */
 	public String getLegendLabelFormat();
 
 	/**
@@ -51,4 +52,9 @@ public interface JRPiePlot extends JRChartPlot
 	 */
 	public JRItemLabel getItemLabel();
 	
+	/**
+	 * 
+	 */
+	public Boolean getShowLabels();
+	
 }
