@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,30 +35,10 @@ import net.sf.jasperreports.engine.JRChartPlot;
  * and "critical", and the textual display of the value.
  *
  * @author Barry Klawans (bklawans@users.sourceforge.net)
- * @version $Id: JRThermometerPlot.java 3609 2010-03-23 09:01:15Z teodord $
+ * @version $Id: JRThermometerPlot.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public interface JRThermometerPlot extends JRChartPlot
 {
-	/**
-	 * @deprecated Replaced by {@link ValueLocationEnum#NONE}
-	 */
-	public static final byte LOCATION_NONE = 0;
-
-	/**
-	 * @deprecated Replaced by {@link ValueLocationEnum#LEFT}
-	 */
-	public static final byte LOCATION_LEFT = 1;
-
-	/**
-	 * @deprecated Replaced by {@link ValueLocationEnum#RIGHT}
-	 */
-	public static final byte LOCATION_RIGHT = 2;
-
-	/**
-	 * @deprecated Replaced by {@link ValueLocationEnum#BULB}
-	 */
-	public static final byte LOCATION_BULB = 3;
-
 	/**
 	 * Returns the range of values displayed by this thermometer.  This range
 	 * corresponds with the scale on the thermometer.
@@ -79,16 +59,6 @@ public interface JRThermometerPlot extends JRChartPlot
 	 */
 	public boolean isShowValueLines();
 
-	/**
-	 * @deprecated Replaced by {@link #getValueLocationValue()}
-	 */
-	public byte getValueLocation();
-
-	/**
-	 * @deprecated Replaced by {@link #getValueLocationValue()}
-	 */
-	public Byte getValueLocationByte();
-
 	/**
 	 * Returns the location where the value of the thermometer will be shown.  The
 	 * return value will be one of <code>net.sf.jasperreports.charts.type.ValueLocationEnum.NONE</code>,
