@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -27,14 +27,14 @@ import net.sf.jasperreports.engine.JRChartDataset;
 
 /**
  * @author Flavius Sana (flavius_sana@users.sourceforge.net)
- * @version $Id: JRTimeSeriesDataset.java 3032 2009-08-27 11:32:28Z teodord $
+ * @version $Id: JRTimeSeriesDataset.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public interface JRTimeSeriesDataset extends JRChartDataset {
 	
 	public JRTimeSeries[] getSeries();
 	
-	public Class getTimePeriod();
+	public Class<?> getTimePeriod();
 
-	public void setTimePeriod(Class timePeriod);
+	public void setTimePeriod(Class<?> timePeriod);
 
 }
