@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -36,15 +36,15 @@ import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRExpressionCollector;
 import net.sf.jasperreports.engine.JRFont;
 import net.sf.jasperreports.engine.base.JRBaseChartPlot;
-import net.sf.jasperreports.engine.base.JRBaseFont;
 import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 import org.jfree.chart.renderer.category.BarRenderer3D;
 
 /**
  * @author Flavius Sana (flavius_sana@users.sourceforge.net)
- * @version $Id: JRBaseBar3DPlot.java 3715 2010-04-08 18:08:49Z teodord $ 
+ * @version $Id: JRBaseBar3DPlot.java 4595 2011-09-08 15:55:10Z teodord $ 
  */
 public class JRBaseBar3DPlot extends JRBaseChartPlot implements JRBar3DPlot 
 {
@@ -57,33 +57,33 @@ public class JRBaseBar3DPlot extends JRBaseChartPlot implements JRBar3DPlot
 	
 	public static final String PROPERTY_Y_OFFSET = "yOffset";
 	
-	protected JRExpression categoryAxisLabelExpression = null;
-	protected JRFont categoryAxisLabelFont = null;
-	protected Color categoryAxisLabelColor = null;
-	protected JRFont categoryAxisTickLabelFont = null;
-	protected Color categoryAxisTickLabelColor = null;
-	protected String categoryAxisTickLabelMask = null;
-	protected Boolean categoryAxisVerticalTickLabels = null;
-	protected Color categoryAxisLineColor = null;
+	protected JRExpression categoryAxisLabelExpression;
+	protected JRFont categoryAxisLabelFont;
+	protected Color categoryAxisLabelColor;
+	protected JRFont categoryAxisTickLabelFont;
+	protected Color categoryAxisTickLabelColor;
+	protected String categoryAxisTickLabelMask;
+	protected Boolean categoryAxisVerticalTickLabels;
+	protected Color categoryAxisLineColor;
 
-	protected JRExpression valueAxisLabelExpression = null;
-	protected JRExpression rangeAxisMinValueExpression = null;
-	protected JRExpression rangeAxisMaxValueExpression = null;
-	protected JRExpression domainAxisMinValueExpression = null;
-	protected JRExpression domainAxisMaxValueExpression = null;
-	protected JRFont valueAxisLabelFont = null;
-	protected Color valueAxisLabelColor = null;
-	protected JRFont valueAxisTickLabelFont = null;
-	protected Color valueAxisTickLabelColor = null;
-	protected String valueAxisTickLabelMask = null;
-	protected Boolean valueAxisVerticalTickLabels = null;
-	protected Color valueAxisLineColor = null;
+	protected JRExpression valueAxisLabelExpression;
+	protected JRExpression rangeAxisMinValueExpression;
+	protected JRExpression rangeAxisMaxValueExpression;
+	protected JRExpression domainAxisMinValueExpression;
+	protected JRExpression domainAxisMaxValueExpression;
+	protected JRFont valueAxisLabelFont;
+	protected Color valueAxisLabelColor;
+	protected JRFont valueAxisTickLabelFont;
+	protected Color valueAxisTickLabelColor;
+	protected String valueAxisTickLabelMask;
+	protected Boolean valueAxisVerticalTickLabels;
+	protected Color valueAxisLineColor;
 
-	protected JRItemLabel itemLabel = null;
+	protected JRItemLabel itemLabel;
 	
-	private Double xOffsetDouble = null;
-	private Double yOffsetDouble = null;
-	private Boolean showLabels = null;
+	private Double xOffsetDouble;
+	private Double yOffsetDouble;
+	private Boolean showLabels;
 	
 	/**
 	 * 
@@ -95,18 +95,14 @@ public class JRBaseBar3DPlot extends JRBaseChartPlot implements JRBar3DPlot
 		JRBar3DPlot barPlot = plot instanceof JRBar3DPlot ? (JRBar3DPlot)plot : null;
 		if (barPlot == null)
 		{
-			categoryAxisLabelFont = new JRBaseFont(chart, null);
-			categoryAxisTickLabelFont = new JRBaseFont(chart, null);
-			valueAxisLabelFont = new JRBaseFont(chart, null);
-			valueAxisTickLabelFont = new JRBaseFont(chart, null);
 			itemLabel = new JRBaseItemLabel(null, chart);
 		}
 		else
 		{
-			categoryAxisLabelFont = new JRBaseFont(chart, barPlot.getCategoryAxisLabelFont());
-			categoryAxisTickLabelFont = new JRBaseFont(chart, barPlot.getCategoryAxisTickLabelFont());
-			valueAxisLabelFont = new JRBaseFont(chart, barPlot.getValueAxisLabelFont());
-			valueAxisTickLabelFont = new JRBaseFont(chart, barPlot.getValueAxisTickLabelFont());
+			categoryAxisLabelFont = barPlot.getCategoryAxisLabelFont();
+			categoryAxisTickLabelFont = getCategoryAxisTickLabelFont();
+			valueAxisLabelFont = barPlot.getValueAxisLabelFont();
+			valueAxisTickLabelFont = barPlot.getValueAxisTickLabelFont();
 			itemLabel = new JRBaseItemLabel(barPlot.getItemLabel(), chart);
 		}
 	}
@@ -124,9 +120,9 @@ public class JRBaseBar3DPlot extends JRBaseChartPlot implements JRBar3DPlot
 		showLabels = barPlot.getShowLabels();
 		
 		categoryAxisLabelExpression = factory.getExpression( barPlot.getCategoryAxisLabelExpression() );
-		categoryAxisLabelFont = new JRBaseFont(barPlot.getChart(), barPlot.getCategoryAxisLabelFont());
+		categoryAxisLabelFont = factory.getFont(barPlot.getChart(), barPlot.getCategoryAxisLabelFont());
 		categoryAxisLabelColor = barPlot.getOwnCategoryAxisLabelColor();
-		categoryAxisTickLabelFont = new JRBaseFont(barPlot.getChart(), barPlot.getCategoryAxisTickLabelFont());
+		categoryAxisTickLabelFont = factory.getFont(barPlot.getChart(), barPlot.getCategoryAxisTickLabelFont());
 		categoryAxisTickLabelColor = barPlot.getOwnCategoryAxisTickLabelColor();
 		categoryAxisTickLabelMask = barPlot.getCategoryAxisTickLabelMask();
 		categoryAxisVerticalTickLabels = barPlot.getCategoryAxisVerticalTickLabels();
@@ -138,9 +134,9 @@ public class JRBaseBar3DPlot extends JRBaseChartPlot implements JRBar3DPlot
 		domainAxisMaxValueExpression = factory.getExpression( barPlot.getDomainAxisMaxValueExpression() );
 		rangeAxisMinValueExpression = factory.getExpression( barPlot.getRangeAxisMinValueExpression() );
 		rangeAxisMaxValueExpression = factory.getExpression( barPlot.getRangeAxisMaxValueExpression() );
-		valueAxisLabelFont = new JRBaseFont(barPlot.getChart(), barPlot.getValueAxisLabelFont());
+		valueAxisLabelFont = factory.getFont(barPlot.getChart(), barPlot.getValueAxisLabelFont());
 		valueAxisLabelColor = barPlot.getOwnValueAxisLabelColor();
-		valueAxisTickLabelFont = new JRBaseFont(barPlot.getChart(), barPlot.getValueAxisTickLabelFont());
+		valueAxisTickLabelFont = factory.getFont(barPlot.getChart(), barPlot.getValueAxisTickLabelFont());
 		valueAxisTickLabelColor = barPlot.getOwnValueAxisTickLabelColor();
 		valueAxisTickLabelMask = barPlot.getValueAxisTickLabelMask();
 		valueAxisVerticalTickLabels = barPlot.getValueAxisVerticalTickLabels();
@@ -368,13 +364,6 @@ public class JRBaseBar3DPlot extends JRBaseChartPlot implements JRBar3DPlot
 		return valueAxisLineColor;
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #getXOffsetDouble()}
-	 */
-	public double getXOffset(){
-		return getXOffsetDouble() == null ? BarRenderer3D.DEFAULT_X_OFFSET : getXOffsetDouble().doubleValue();
-	}
-	
 	/**
 	 * 
 	 */
@@ -382,13 +371,6 @@ public class JRBaseBar3DPlot extends JRBaseChartPlot implements JRBar3DPlot
 		return xOffsetDouble;
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #setXOffset(Double)}
-	 */
-	public void setXOffset( double xOffset ){
-		setXOffset(new Double(xOffset));
-	}
-	
 	/**
 	 *
 	 */
@@ -406,13 +388,6 @@ public class JRBaseBar3DPlot extends JRBaseChartPlot implements JRBar3DPlot
 		getEventSupport().firePropertyChange(PROPERTY_X_OFFSET, old, this.xOffsetDouble);
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #getYOffsetDouble()}
-	 */
-	public double getYOffset(){
-		return getYOffsetDouble() == null ? BarRenderer3D.DEFAULT_Y_OFFSET : getYOffsetDouble().doubleValue();
-	}
-	
 	/**
 	 * 
 	 */
@@ -420,13 +395,6 @@ public class JRBaseBar3DPlot extends JRBaseChartPlot implements JRBar3DPlot
 		return yOffsetDouble;
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #setYOffset(Double)}
-	 */
-	public void setYOffset( double yOffset ){
-		setYOffset(new Double(yOffset));
-	}
-	
 	/**
 	 * 
 	 */
@@ -436,13 +404,6 @@ public class JRBaseBar3DPlot extends JRBaseChartPlot implements JRBar3DPlot
 		getEventSupport().firePropertyChange(PROPERTY_Y_OFFSET, old, this.yOffsetDouble);
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #getShowLabels()} 
-	 */
-	public boolean isShowLabels(){
-		return showLabels == null ? false : showLabels.booleanValue();
-	}
-	
 	/**
 	 * 
 	 */
@@ -450,13 +411,6 @@ public class JRBaseBar3DPlot extends JRBaseChartPlot implements JRBar3DPlot
 		return showLabels;
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #setShowLabels(Boolean)} 
-	 */
-	public void setShowLabels( boolean isShowLabels ){
-		setShowLabels(Boolean.valueOf(isShowLabels));
-	}
-
 	/**
 	 * 
 	 */
@@ -480,35 +434,13 @@ public class JRBaseBar3DPlot extends JRBaseChartPlot implements JRBar3DPlot
 	public Object clone(JRChart parentChart) 
 	{
 		JRBaseBar3DPlot clone = (JRBaseBar3DPlot)super.clone(parentChart);
-		if (categoryAxisLabelExpression != null)
-		{
-			clone.categoryAxisLabelExpression = (JRExpression)categoryAxisLabelExpression.clone();
-		}
-		if (valueAxisLabelExpression != null)
-		{
-			clone.valueAxisLabelExpression = (JRExpression)valueAxisLabelExpression.clone();
-		}
-		if (domainAxisMinValueExpression != null)
-		{
-			clone.domainAxisMinValueExpression = (JRExpression)domainAxisMinValueExpression.clone();
-		}
-		if (domainAxisMaxValueExpression != null)
-		{
-			clone.domainAxisMaxValueExpression = (JRExpression)domainAxisMaxValueExpression.clone();
-		}
-		if (rangeAxisMinValueExpression != null)
-		{
-			clone.rangeAxisMinValueExpression = (JRExpression)rangeAxisMinValueExpression.clone();
-		}
-		if (rangeAxisMaxValueExpression != null)
-		{
-			clone.rangeAxisMaxValueExpression = (JRExpression)rangeAxisMaxValueExpression.clone();
-		}
-		if (itemLabel != null)
-		{
-			clone.itemLabel = (JRItemLabel)itemLabel.clone();
-		}
-		
+		clone.categoryAxisLabelExpression = JRCloneUtils.nullSafeClone(categoryAxisLabelExpression);
+		clone.valueAxisLabelExpression = JRCloneUtils.nullSafeClone(valueAxisLabelExpression);
+		clone.domainAxisMinValueExpression = JRCloneUtils.nullSafeClone(domainAxisMinValueExpression);
+		clone.domainAxisMaxValueExpression = JRCloneUtils.nullSafeClone(domainAxisMaxValueExpression);
+		clone.rangeAxisMinValueExpression = JRCloneUtils.nullSafeClone(rangeAxisMinValueExpression);
+		clone.rangeAxisMaxValueExpression = JRCloneUtils.nullSafeClone(rangeAxisMaxValueExpression);
+		clone.itemLabel = JRCloneUtils.nullSafeClone(itemLabel);
 		return clone;
 	}
 
@@ -528,7 +460,7 @@ public class JRBaseBar3DPlot extends JRBaseChartPlot implements JRBar3DPlot
 	/**
 	 * @deprecated
 	 */
-	private boolean isShowLabels = false;
+	private boolean isShowLabels;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
