@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -36,14 +36,14 @@ import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRExpressionCollector;
 import net.sf.jasperreports.engine.JRFont;
 import net.sf.jasperreports.engine.base.JRBaseChartPlot;
-import net.sf.jasperreports.engine.base.JRBaseFont;
 import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseBarPlot.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBaseBarPlot.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseBarPlot extends JRBaseChartPlot implements JRBarPlot
 {
@@ -60,33 +60,33 @@ public class JRBaseBarPlot extends JRBaseChartPlot implements JRBarPlot
 
 	public static final String PROPERTY_SHOW_TICK_MARKS = "showTickMarks";
 
-	protected JRExpression categoryAxisLabelExpression = null;
-	protected JRFont categoryAxisLabelFont = null;
-	protected Color categoryAxisLabelColor = null;
-	protected JRFont categoryAxisTickLabelFont = null;
-	protected Color categoryAxisTickLabelColor = null;
-	protected String categoryAxisTickLabelMask = null;
-	protected Boolean categoryAxisVerticalTickLabels = null;
-	protected Color categoryAxisLineColor = null;
+	protected JRExpression categoryAxisLabelExpression;
+	protected JRFont categoryAxisLabelFont;
+	protected Color categoryAxisLabelColor;
+	protected JRFont categoryAxisTickLabelFont;
+	protected Color categoryAxisTickLabelColor;
+	protected String categoryAxisTickLabelMask;
+	protected Boolean categoryAxisVerticalTickLabels;
+	protected Color categoryAxisLineColor;
 
-	protected JRExpression valueAxisLabelExpression = null;
-	protected JRExpression rangeAxisMinValueExpression = null;
-	protected JRExpression rangeAxisMaxValueExpression = null;
-	protected JRExpression domainAxisMinValueExpression = null;
-	protected JRExpression domainAxisMaxValueExpression = null;
-	protected JRFont valueAxisLabelFont = null;
-	protected Color valueAxisLabelColor = null;
-	protected JRFont valueAxisTickLabelFont = null;
-	protected Color valueAxisTickLabelColor = null;
-	protected String valueAxisTickLabelMask = null;
-	protected Boolean valueAxisVerticalTickLabels = null;
-	protected Color valueAxisLineColor = null;
+	protected JRExpression valueAxisLabelExpression;
+	protected JRExpression rangeAxisMinValueExpression;
+	protected JRExpression rangeAxisMaxValueExpression;
+	protected JRExpression domainAxisMinValueExpression;
+	protected JRExpression domainAxisMaxValueExpression;
+	protected JRFont valueAxisLabelFont;
+	protected Color valueAxisLabelColor;
+	protected JRFont valueAxisTickLabelFont;
+	protected Color valueAxisTickLabelColor;
+	protected String valueAxisTickLabelMask;
+	protected Boolean valueAxisVerticalTickLabels;
+	protected Color valueAxisLineColor;
 
-	protected Boolean showTickMarks = null;
-	protected Boolean showTickLabels = null;
-	protected Boolean showLabels = null;
+	protected Boolean showTickMarks;
+	protected Boolean showTickLabels;
+	protected Boolean showLabels;
 	
-	protected JRItemLabel itemLabel = null;
+	protected JRItemLabel itemLabel;
 
 
 	/**
@@ -99,18 +99,14 @@ public class JRBaseBarPlot extends JRBaseChartPlot implements JRBarPlot
 		JRBarPlot barPlot = plot instanceof JRBarPlot ? (JRBarPlot)plot : null;
 		if (barPlot == null)
 		{
-			categoryAxisLabelFont = new JRBaseFont(chart, null);
-			categoryAxisTickLabelFont = new JRBaseFont(chart, null);
-			valueAxisLabelFont = new JRBaseFont(chart, null);
-			valueAxisTickLabelFont = new JRBaseFont(chart, null);
 			itemLabel = new JRBaseItemLabel(null, chart);
 		}
 		else
 		{
-			categoryAxisLabelFont = new JRBaseFont(chart, barPlot.getCategoryAxisLabelFont());
-			categoryAxisTickLabelFont = new JRBaseFont(chart, barPlot.getCategoryAxisTickLabelFont());
-			valueAxisLabelFont = new JRBaseFont(chart, barPlot.getValueAxisLabelFont());
-			valueAxisTickLabelFont = new JRBaseFont(chart, barPlot.getValueAxisTickLabelFont());
+			categoryAxisLabelFont = barPlot.getCategoryAxisLabelFont();
+			categoryAxisTickLabelFont = barPlot.getCategoryAxisTickLabelFont();
+			valueAxisLabelFont = barPlot.getValueAxisLabelFont();
+			valueAxisTickLabelFont = barPlot.getValueAxisTickLabelFont();
 			itemLabel = new JRBaseItemLabel(barPlot.getItemLabel(), chart);
 		}
 	}
@@ -127,9 +123,9 @@ public class JRBaseBarPlot extends JRBaseChartPlot implements JRBarPlot
 		showLabels = barPlot.getShowLabels();
 
 		categoryAxisLabelExpression = factory.getExpression( barPlot.getCategoryAxisLabelExpression() );
-		categoryAxisLabelFont = new JRBaseFont(barPlot.getChart(), barPlot.getCategoryAxisLabelFont());
+		categoryAxisLabelFont = factory.getFont(barPlot.getChart(), barPlot.getCategoryAxisLabelFont());
 		categoryAxisLabelColor = barPlot.getOwnCategoryAxisLabelColor();
-		categoryAxisTickLabelFont = new JRBaseFont(barPlot.getChart(), barPlot.getCategoryAxisTickLabelFont());
+		categoryAxisTickLabelFont = factory.getFont(barPlot.getChart(), barPlot.getCategoryAxisTickLabelFont());
 		categoryAxisTickLabelColor = barPlot.getOwnCategoryAxisTickLabelColor();
 		categoryAxisTickLabelMask = barPlot.getCategoryAxisTickLabelMask();
 		categoryAxisVerticalTickLabels = barPlot.getCategoryAxisVerticalTickLabels();
@@ -141,9 +137,9 @@ public class JRBaseBarPlot extends JRBaseChartPlot implements JRBarPlot
 		domainAxisMaxValueExpression = factory.getExpression( barPlot.getDomainAxisMaxValueExpression() );
 		rangeAxisMinValueExpression = factory.getExpression( barPlot.getRangeAxisMinValueExpression() );
 		rangeAxisMaxValueExpression = factory.getExpression( barPlot.getRangeAxisMaxValueExpression() );
-		valueAxisLabelFont = new JRBaseFont(barPlot.getChart(), barPlot.getValueAxisLabelFont());
+		valueAxisLabelFont = factory.getFont(barPlot.getChart(), barPlot.getValueAxisLabelFont());
 		valueAxisLabelColor = barPlot.getOwnValueAxisLabelColor();
-		valueAxisTickLabelFont = new JRBaseFont(barPlot.getChart(), barPlot.getValueAxisTickLabelFont());
+		valueAxisTickLabelFont = factory.getFont(barPlot.getChart(), barPlot.getValueAxisTickLabelFont());
 		valueAxisTickLabelColor = barPlot.getOwnValueAxisTickLabelColor();
 		valueAxisTickLabelMask = barPlot.getValueAxisTickLabelMask();
 		valueAxisVerticalTickLabels = barPlot.getValueAxisVerticalTickLabels();
@@ -372,13 +368,6 @@ public class JRBaseBarPlot extends JRBaseChartPlot implements JRBarPlot
 		return valueAxisLineColor;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getShowLabels()}
-	 */
-	public boolean isShowLabels(){
-		return showLabels == null ? false : showLabels.booleanValue();
-	}
-
 	/**
 	 *
 	 */
@@ -394,13 +383,6 @@ public class JRBaseBarPlot extends JRBaseChartPlot implements JRBarPlot
 		return itemLabel;
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #setShowLabels(Boolean)}
-	 */
-	public void setShowLabels( boolean isShowLabels ){
-		setShowLabels(Boolean.valueOf(isShowLabels));
-	}
-
 	/**
 	 *
 	 */
@@ -411,14 +393,6 @@ public class JRBaseBarPlot extends JRBaseChartPlot implements JRBarPlot
 	}
 
 
-	/**
-	 * @deprecated Replaced by {@link #getShowTickMarks()}
-	 */
-	public boolean isShowTickMarks()
-	{
-		return showTickMarks == null ? true : showTickMarks.booleanValue();
-	}
-
 	/**
 	 *
 	 */
@@ -427,14 +401,6 @@ public class JRBaseBarPlot extends JRBaseChartPlot implements JRBarPlot
 		return showTickMarks;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setShowTickMarks(Boolean)}
-	 */
-	public void setShowTickMarks(boolean isShowTickMarks)
-	{
-		setShowTickMarks(Boolean.valueOf(isShowTickMarks));
-	}
-
 	/**
 	 *
 	 */
@@ -445,14 +411,6 @@ public class JRBaseBarPlot extends JRBaseChartPlot implements JRBarPlot
 		getEventSupport().firePropertyChange(PROPERTY_SHOW_TICK_MARKS, old, this.showTickMarks);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getShowTickLabels()}
-	 */
-	public boolean isShowTickLabels()
-	{
-		return showTickLabels == null ? true : showTickLabels.booleanValue();
-	}
-
 	/**
 	 *
 	 */
@@ -461,14 +419,6 @@ public class JRBaseBarPlot extends JRBaseChartPlot implements JRBarPlot
 		return showTickLabels;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setShowTickLabels(Boolean)}
-	 */
-	public void setShowTickLabels(boolean isShowTickLabels)
-	{
-		setShowTickLabels(Boolean.valueOf(isShowTickLabels));
-	}
-
 	/**
 	 *
 	 */
@@ -493,35 +443,13 @@ public class JRBaseBarPlot extends JRBaseChartPlot implements JRBarPlot
 	public Object clone(JRChart parentChart)
 	{
 		JRBaseBarPlot clone = (JRBaseBarPlot)super.clone(parentChart);
-		if (categoryAxisLabelExpression != null)
-		{
-			clone.categoryAxisLabelExpression = (JRExpression)categoryAxisLabelExpression.clone();
-		}
-		if (valueAxisLabelExpression != null)
-		{
-			clone.valueAxisLabelExpression = (JRExpression)valueAxisLabelExpression.clone();
-		}
-		if (domainAxisMinValueExpression != null)
-		{
-			clone.domainAxisMinValueExpression = (JRExpression)domainAxisMinValueExpression.clone();
-		}
-		if (domainAxisMaxValueExpression != null)
-		{
-			clone.domainAxisMaxValueExpression = (JRExpression)domainAxisMaxValueExpression.clone();
-		}
-		if (rangeAxisMinValueExpression != null)
-		{
-			clone.rangeAxisMinValueExpression = (JRExpression)rangeAxisMinValueExpression.clone();
-		}
-		if (rangeAxisMaxValueExpression != null)
-		{
-			clone.rangeAxisMaxValueExpression = (JRExpression)rangeAxisMaxValueExpression.clone();
-		}
-		if (itemLabel != null)
-		{
-			clone.itemLabel = (JRItemLabel)itemLabel.clone();
-		}
-		
+		clone.categoryAxisLabelExpression = JRCloneUtils.nullSafeClone(categoryAxisLabelExpression);
+		clone.valueAxisLabelExpression = JRCloneUtils.nullSafeClone(valueAxisLabelExpression);
+		clone.domainAxisMinValueExpression = JRCloneUtils.nullSafeClone(domainAxisMinValueExpression);
+		clone.domainAxisMaxValueExpression = JRCloneUtils.nullSafeClone(domainAxisMaxValueExpression);
+		clone.rangeAxisMinValueExpression = JRCloneUtils.nullSafeClone(rangeAxisMinValueExpression);
+		clone.rangeAxisMaxValueExpression = JRCloneUtils.nullSafeClone(rangeAxisMaxValueExpression);
+		clone.itemLabel = JRCloneUtils.nullSafeClone(itemLabel);
 		return clone;
 	}
 
@@ -532,7 +460,7 @@ public class JRBaseBarPlot extends JRBaseChartPlot implements JRBarPlot
 	/**
 	 * @deprecated
 	 */
-	private boolean isShowTickMarks = false;
+	private boolean isShowTickMarks;
 	/**
 	 * @deprecated
 	 */
