@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,14 +35,14 @@ import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRExpressionCollector;
 import net.sf.jasperreports.engine.JRFont;
 import net.sf.jasperreports.engine.base.JRBaseChartPlot;
-import net.sf.jasperreports.engine.base.JRBaseFont;
 import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 
 /**
  * @author Ionut Nedelcu (ionutned@users.sourceforge.net)
- * @version $Id: JRBaseCandlestickPlot.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBaseCandlestickPlot.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseCandlestickPlot extends JRBaseChartPlot implements JRCandlestickPlot
 {
@@ -53,29 +53,29 @@ public class JRBaseCandlestickPlot extends JRBaseChartPlot implements JRCandlest
 	
 	public static final String PROPERTY_SHOW_VOLUME = "showVolume";
 
-	protected JRExpression timeAxisLabelExpression = null;
-	protected JRFont timeAxisLabelFont = null;
-	protected Color timeAxisLabelColor = null;
-	protected JRFont timeAxisTickLabelFont = null;
-	protected Color timeAxisTickLabelColor = null;
-	protected String timeAxisTickLabelMask = null;
-	protected Boolean timeAxisVerticalTickLabels = null;
-	protected Color timeAxisLineColor = null;
+	protected JRExpression timeAxisLabelExpression;
+	protected JRFont timeAxisLabelFont;
+	protected Color timeAxisLabelColor;
+	protected JRFont timeAxisTickLabelFont;
+	protected Color timeAxisTickLabelColor;
+	protected String timeAxisTickLabelMask;
+	protected Boolean timeAxisVerticalTickLabels;
+	protected Color timeAxisLineColor;
 
-	protected JRExpression valueAxisLabelExpression = null;
-	protected JRExpression rangeAxisMinValueExpression = null;
-	protected JRExpression rangeAxisMaxValueExpression = null;
-	protected JRExpression domainAxisMinValueExpression = null;
-	protected JRExpression domainAxisMaxValueExpression = null;
-	protected JRFont valueAxisLabelFont = null;
-	protected Color valueAxisLabelColor = null;
-	protected JRFont valueAxisTickLabelFont = null;
-	protected Color valueAxisTickLabelColor = null;
-	protected String valueAxisTickLabelMask = null;
-	protected Boolean valueAxisVerticalTickLabels = null;
-	protected Color valueAxisLineColor = null;
+	protected JRExpression valueAxisLabelExpression;
+	protected JRExpression rangeAxisMinValueExpression;
+	protected JRExpression rangeAxisMaxValueExpression;
+	protected JRExpression domainAxisMinValueExpression;
+	protected JRExpression domainAxisMaxValueExpression;
+	protected JRFont valueAxisLabelFont;
+	protected Color valueAxisLabelColor;
+	protected JRFont valueAxisTickLabelFont;
+	protected Color valueAxisTickLabelColor;
+	protected String valueAxisTickLabelMask;
+	protected Boolean valueAxisVerticalTickLabels;
+	protected Color valueAxisLineColor;
 
-	protected Boolean showVolume = null;
+	protected Boolean showVolume;
 
 	/**
 	 *
@@ -85,19 +85,12 @@ public class JRBaseCandlestickPlot extends JRBaseChartPlot implements JRCandlest
 		super(plot, chart);
 		
 		JRCandlestickPlot candlestickPlot = plot instanceof JRCandlestickPlot ? (JRCandlestickPlot)plot : null;
-		if (candlestickPlot == null)
+		if (candlestickPlot != null)
 		{
-			timeAxisLabelFont = new JRBaseFont(chart, null);
-			timeAxisTickLabelFont = new JRBaseFont(chart, null);
-			valueAxisLabelFont = new JRBaseFont(chart, null);
-			valueAxisTickLabelFont = new JRBaseFont(chart, null);
-		}
-		else
-		{
-			timeAxisLabelFont = new JRBaseFont(chart, candlestickPlot.getTimeAxisLabelFont());
-			timeAxisTickLabelFont = new JRBaseFont(chart, candlestickPlot.getTimeAxisTickLabelFont());
-			valueAxisLabelFont = new JRBaseFont(chart, candlestickPlot.getValueAxisLabelFont());
-			valueAxisTickLabelFont = new JRBaseFont(chart, candlestickPlot.getValueAxisTickLabelFont());
+			timeAxisLabelFont = candlestickPlot.getTimeAxisLabelFont();
+			timeAxisTickLabelFont = candlestickPlot.getTimeAxisTickLabelFont();
+			valueAxisLabelFont = candlestickPlot.getValueAxisLabelFont();
+			valueAxisTickLabelFont = candlestickPlot.getValueAxisTickLabelFont();
 		}
 	}
 
@@ -112,9 +105,9 @@ public class JRBaseCandlestickPlot extends JRBaseChartPlot implements JRCandlest
 		showVolume = candlestickPlot.getShowVolume();
 
 		timeAxisLabelExpression = factory.getExpression( candlestickPlot.getTimeAxisLabelExpression() );
-		timeAxisLabelFont = new JRBaseFont(candlestickPlot.getChart(), candlestickPlot.getTimeAxisLabelFont());
+		timeAxisLabelFont = factory.getFont(candlestickPlot.getChart(), candlestickPlot.getTimeAxisLabelFont());
 		timeAxisLabelColor = candlestickPlot.getOwnTimeAxisLabelColor();
-		timeAxisTickLabelFont = new JRBaseFont(candlestickPlot.getChart(), candlestickPlot.getTimeAxisTickLabelFont());
+		timeAxisTickLabelFont = factory.getFont(candlestickPlot.getChart(), candlestickPlot.getTimeAxisTickLabelFont());
 		timeAxisTickLabelColor = candlestickPlot.getOwnTimeAxisTickLabelColor();
 		timeAxisTickLabelMask = candlestickPlot.getTimeAxisTickLabelMask();
 		timeAxisVerticalTickLabels = candlestickPlot.getTimeAxisVerticalTickLabels();
@@ -125,9 +118,9 @@ public class JRBaseCandlestickPlot extends JRBaseChartPlot implements JRCandlest
 		domainAxisMaxValueExpression = factory.getExpression( candlestickPlot.getDomainAxisMaxValueExpression() );
 		rangeAxisMinValueExpression = factory.getExpression( candlestickPlot.getRangeAxisMinValueExpression() );
 		rangeAxisMaxValueExpression = factory.getExpression( candlestickPlot.getRangeAxisMaxValueExpression() );
-		valueAxisLabelFont = new JRBaseFont(candlestickPlot.getChart(), candlestickPlot.getValueAxisLabelFont());
+		valueAxisLabelFont = factory.getFont(candlestickPlot.getChart(), candlestickPlot.getValueAxisLabelFont());
 		valueAxisLabelColor = candlestickPlot.getOwnValueAxisLabelColor();
-		valueAxisTickLabelFont = new JRBaseFont(candlestickPlot.getChart(), candlestickPlot.getValueAxisTickLabelFont());
+		valueAxisTickLabelFont = factory.getFont(candlestickPlot.getChart(), candlestickPlot.getValueAxisTickLabelFont());
 		valueAxisTickLabelColor = candlestickPlot.getOwnValueAxisTickLabelColor();
 		valueAxisTickLabelMask = candlestickPlot.getValueAxisTickLabelMask();
 		valueAxisVerticalTickLabels = candlestickPlot.getValueAxisVerticalTickLabels();
@@ -337,14 +330,6 @@ public class JRBaseCandlestickPlot extends JRBaseChartPlot implements JRCandlest
 		return valueAxisLineColor;
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #getShowVolume()}
-	 */
-	public boolean isShowVolume()
-	{
-		return showVolume == null ? true : showVolume.booleanValue();
-	}
-
 	/**
 	 * 
 	 */
@@ -354,14 +339,6 @@ public class JRBaseCandlestickPlot extends JRBaseChartPlot implements JRCandlest
 	}
 
 
-	/**
-	 * @deprecated Replaced by {@link #setShowVolume(Boolean)}
-	 */
-	public void setShowVolume(boolean isShowVolume)
-	{
-		setShowVolume(Boolean.valueOf(isShowVolume));
-	}
-
 	/**
 	 * 
 	 */
@@ -386,30 +363,12 @@ public class JRBaseCandlestickPlot extends JRBaseChartPlot implements JRCandlest
 	public Object clone(JRChart parentChart) 
 	{
 		JRBaseCandlestickPlot clone = (JRBaseCandlestickPlot)super.clone(parentChart);
-		if (timeAxisLabelExpression != null)
-		{
-			clone.timeAxisLabelExpression = (JRExpression)timeAxisLabelExpression.clone();
-		}
-		if (valueAxisLabelExpression != null)
-		{
-			clone.valueAxisLabelExpression = (JRExpression)valueAxisLabelExpression.clone();
-		}
-		if (domainAxisMinValueExpression != null)
-		{
-			clone.domainAxisMinValueExpression = (JRExpression)domainAxisMinValueExpression.clone();
-		}
-		if (domainAxisMaxValueExpression != null)
-		{
-			clone.domainAxisMaxValueExpression = (JRExpression)domainAxisMaxValueExpression.clone();
-		}
-		if (rangeAxisMinValueExpression != null)
-		{
-			clone.rangeAxisMinValueExpression = (JRExpression)rangeAxisMinValueExpression.clone();
-		}
-		if (rangeAxisMaxValueExpression != null)
-		{
-			clone.rangeAxisMaxValueExpression = (JRExpression)rangeAxisMaxValueExpression.clone();
-		}
+		clone.timeAxisLabelExpression = JRCloneUtils.nullSafeClone(timeAxisLabelExpression);
+		clone.valueAxisLabelExpression = JRCloneUtils.nullSafeClone(valueAxisLabelExpression);
+		clone.domainAxisMinValueExpression = JRCloneUtils.nullSafeClone(domainAxisMinValueExpression);
+		clone.domainAxisMaxValueExpression = JRCloneUtils.nullSafeClone(domainAxisMaxValueExpression);
+		clone.rangeAxisMinValueExpression = JRCloneUtils.nullSafeClone(rangeAxisMinValueExpression);
+		clone.rangeAxisMaxValueExpression = JRCloneUtils.nullSafeClone(rangeAxisMaxValueExpression);
 		return clone;
 	}
 	
