@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -31,11 +31,12 @@ import net.sf.jasperreports.engine.JRExpressionCollector;
 import net.sf.jasperreports.engine.base.JRBaseChartDataset;
 import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
 import net.sf.jasperreports.engine.design.JRVerifier;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseCategoryDataset.java 3734 2010-04-12 14:24:34Z lucianc $
+ * @version $Id: JRBaseCategoryDataset.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseCategoryDataset extends JRBaseChartDataset implements JRCategoryDataset
 {
@@ -46,7 +47,7 @@ public class JRBaseCategoryDataset extends JRBaseChartDataset implements JRCateg
 	 */
 	private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 
-	protected JRCategorySeries[] categorySeries = null;
+	protected JRCategorySeries[] categorySeries;
 
 	
 	/**
@@ -117,16 +118,7 @@ public class JRBaseCategoryDataset extends JRBaseChartDataset implements JRCateg
 	public Object clone() 
 	{
 		JRBaseCategoryDataset clone = (JRBaseCategoryDataset)super.clone();
-		
-		if (categorySeries != null)
-		{
-			clone.categorySeries = new JRCategorySeries[categorySeries.length];
-			for(int i = 0; i < categorySeries.length; i++)
-			{
-				clone.categorySeries[i] = (JRCategorySeries)categorySeries[i].clone();
-			}
-		}
-		
+		clone.categorySeries = JRCloneUtils.cloneArray(categorySeries);
 		return clone;
 	}
 
