@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -38,7 +38,7 @@ import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
  * Base read-only implementation of {@link JRChartAxis JRChartAxis}.
  *
  * @author Barry Klawans (barry@users.sourceforge.net)
- * @version $Id: JRBaseChartAxis.java 3932 2010-08-04 12:17:40Z teodord $
+ * @version $Id: JRBaseChartAxis.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseChartAxis implements JRChartAxis, Serializable
 {
@@ -70,22 +70,6 @@ public class JRBaseChartAxis implements JRChartAxis, Serializable
 		this.chart = (JRChart)factory.getVisitResult(axis.getChart());
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getPositionValue()}
-	 */
-	public byte getPosition()
-	{
-		return getPositionValue() == null ? AxisPositionEnum.LEFT_OR_TOP.getValue() : getPositionValue().getValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getPositionValue()}
-	 */
-	public Byte getPositionByte()
-	{
-		return getPositionValue() == null ? null : getPositionValue().getValueByte();
-	}
-
 	/**
 	 * Returns the position of this axis.
 	 *
