@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -31,13 +31,14 @@ import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRExpressionCollector;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 
 /**
  * An immutable instantiation of a <code>JRDataRange</code>, suitable for holding
  * a range.
  *
  * @author Barry Klawans (bklawans@users.sourceforge.net)
- * @version $Id: JRBaseDataRange.java 3032 2009-08-27 11:32:28Z teodord $
+ * @version $Id: JRBaseDataRange.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseDataRange implements JRDataRange, Serializable
 {
@@ -49,12 +50,12 @@ public class JRBaseDataRange implements JRDataRange, Serializable
 	/**
 	 * The expression used to calculate the lower bound of the range.
 	 */
-	protected JRExpression lowExpression = null;
+	protected JRExpression lowExpression;
 
 	/**
 	 * The expression used to calculate the upper bound of the range.
 	 */
-	protected JRExpression highExpression = null;
+	protected JRExpression highExpression;
 
 
 	/**
@@ -132,14 +133,8 @@ public class JRBaseDataRange implements JRDataRange, Serializable
 			throw new JRRuntimeException(e);
 		}
 
-		if (lowExpression != null)
-		{
-			clone.lowExpression = (JRExpression)lowExpression.clone();
-		}
-		if (highExpression != null)
-		{
-			clone.highExpression = (JRExpression)highExpression.clone();
-		}
+		clone.lowExpression = JRCloneUtils.nullSafeClone(lowExpression);
+		clone.highExpression = JRCloneUtils.nullSafeClone(highExpression);
 		
 		return clone;
 	}
