@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -34,7 +34,7 @@ import net.sf.jasperreports.engine.design.JRVerifier;
 
 /**
  * @author Peter Risko (peter@risko.hu)
- * @version $Id: JRBaseGanttDataset.java 3739 2010-04-15 17:07:33Z lucianc $
+ * @version $Id: JRBaseGanttDataset.java 4595 2011-09-08 15:55:10Z teodord $
  */
 //FIXME clone
 public class JRBaseGanttDataset extends JRBaseChartDataset implements JRGanttDataset {
@@ -44,7 +44,7 @@ public class JRBaseGanttDataset extends JRBaseChartDataset implements JRGanttDat
 	 */
 	private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 
-	protected JRGanttSeries[] ganttSeries = null;
+	protected JRGanttSeries[] ganttSeries;
 
 	/**
 	 *
