@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,14 +35,14 @@ import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRExpressionCollector;
 import net.sf.jasperreports.engine.JRFont;
 import net.sf.jasperreports.engine.base.JRBaseChartPlot;
-import net.sf.jasperreports.engine.base.JRBaseFont;
 import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 
 /**
  * @author Ionut Nedelcu (ionutned@users.sourceforge.net)
- * @version $Id: JRBaseHighLowPlot.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBaseHighLowPlot.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseHighLowPlot extends JRBaseChartPlot implements JRHighLowPlot
 {
@@ -56,30 +56,30 @@ public class JRBaseHighLowPlot extends JRBaseChartPlot implements JRHighLowPlot
 	
 	public static final String PROPERTY_SHOW_OPEN_TICKS = "showOpenTicks";
 
-	protected JRExpression timeAxisLabelExpression = null;
-	protected JRFont timeAxisLabelFont = null;
-	protected Color timeAxisLabelColor = null;
-	protected JRFont timeAxisTickLabelFont = null;
-	protected Color timeAxisTickLabelColor = null;
-	protected String timeAxisTickLabelMask = null;
-	protected Boolean timeAxisVerticalTickLabels = null;
-	protected Color timeAxisLineColor = null;
+	protected JRExpression timeAxisLabelExpression;
+	protected JRFont timeAxisLabelFont;
+	protected Color timeAxisLabelColor;
+	protected JRFont timeAxisTickLabelFont;
+	protected Color timeAxisTickLabelColor;
+	protected String timeAxisTickLabelMask;
+	protected Boolean timeAxisVerticalTickLabels;
+	protected Color timeAxisLineColor;
 
-	protected JRExpression valueAxisLabelExpression = null;
-	protected JRExpression rangeAxisMinValueExpression = null;
-	protected JRExpression rangeAxisMaxValueExpression = null;
-	protected JRExpression domainAxisMinValueExpression = null;
-	protected JRExpression domainAxisMaxValueExpression = null;
-	protected JRFont valueAxisLabelFont = null;
-	protected Color valueAxisLabelColor = null;
-	protected JRFont valueAxisTickLabelFont = null;
-	protected Color valueAxisTickLabelColor = null;
-	protected String valueAxisTickLabelMask = null;
-	protected Boolean valueAxisVerticalTickLabels = null;
-	protected Color valueAxisLineColor = null;
+	protected JRExpression valueAxisLabelExpression;
+	protected JRExpression rangeAxisMinValueExpression;
+	protected JRExpression rangeAxisMaxValueExpression;
+	protected JRExpression domainAxisMinValueExpression;
+	protected JRExpression domainAxisMaxValueExpression;
+	protected JRFont valueAxisLabelFont;
+	protected Color valueAxisLabelColor;
+	protected JRFont valueAxisTickLabelFont;
+	protected Color valueAxisTickLabelColor;
+	protected String valueAxisTickLabelMask;
+	protected Boolean valueAxisVerticalTickLabels;
+	protected Color valueAxisLineColor;
 
-	protected Boolean showOpenTicks = null;
-	protected Boolean showCloseTicks = null;
+	protected Boolean showOpenTicks;
+	protected Boolean showCloseTicks;
 
 
 	/**
@@ -90,19 +90,12 @@ public class JRBaseHighLowPlot extends JRBaseChartPlot implements JRHighLowPlot
 		super(plot, chart);
 		
 		JRHighLowPlot highLowPlot = plot instanceof JRHighLowPlot ? (JRHighLowPlot)plot : null;
-		if (highLowPlot == null)
+		if (highLowPlot != null)
 		{
-			timeAxisLabelFont = new JRBaseFont(chart, null);
-			timeAxisTickLabelFont = new JRBaseFont(chart, null);
-			valueAxisLabelFont = new JRBaseFont(chart, null);
-			valueAxisTickLabelFont = new JRBaseFont(chart, null);
-		}
-		else
-		{
-			timeAxisLabelFont = new JRBaseFont(chart, highLowPlot.getTimeAxisLabelFont());
-			timeAxisTickLabelFont = new JRBaseFont(chart, highLowPlot.getTimeAxisTickLabelFont());
-			valueAxisLabelFont = new JRBaseFont(chart, highLowPlot.getValueAxisLabelFont());
-			valueAxisTickLabelFont = new JRBaseFont(chart, highLowPlot.getValueAxisTickLabelFont());
+			timeAxisLabelFont = highLowPlot.getTimeAxisLabelFont();
+			timeAxisTickLabelFont = highLowPlot.getTimeAxisTickLabelFont();
+			valueAxisLabelFont = highLowPlot.getValueAxisLabelFont();
+			valueAxisTickLabelFont = highLowPlot.getValueAxisTickLabelFont();
 		}
 	}
 
@@ -118,9 +111,9 @@ public class JRBaseHighLowPlot extends JRBaseChartPlot implements JRHighLowPlot
 		showCloseTicks = highLowPlot.getShowCloseTicks();
 
 		timeAxisLabelExpression = factory.getExpression( highLowPlot.getTimeAxisLabelExpression() );
-		timeAxisLabelFont = new JRBaseFont(highLowPlot.getChart(), highLowPlot.getTimeAxisLabelFont());
+		timeAxisLabelFont = factory.getFont(highLowPlot.getChart(), highLowPlot.getTimeAxisLabelFont());
 		timeAxisLabelColor = highLowPlot.getOwnTimeAxisLabelColor();
-		timeAxisTickLabelFont = new JRBaseFont(highLowPlot.getChart(), highLowPlot.getTimeAxisTickLabelFont());
+		timeAxisTickLabelFont = factory.getFont(highLowPlot.getChart(), highLowPlot.getTimeAxisTickLabelFont());
 		timeAxisTickLabelColor = highLowPlot.getOwnTimeAxisTickLabelColor();
 		timeAxisTickLabelMask = highLowPlot.getTimeAxisTickLabelMask();
 		timeAxisVerticalTickLabels = highLowPlot.getTimeAxisVerticalTickLabels();
@@ -131,9 +124,9 @@ public class JRBaseHighLowPlot extends JRBaseChartPlot implements JRHighLowPlot
 		domainAxisMaxValueExpression = factory.getExpression( highLowPlot.getDomainAxisMaxValueExpression() );
 		rangeAxisMinValueExpression = factory.getExpression( highLowPlot.getRangeAxisMinValueExpression() );
 		rangeAxisMaxValueExpression = factory.getExpression( highLowPlot.getRangeAxisMaxValueExpression() );
-		valueAxisLabelFont = new JRBaseFont(highLowPlot.getChart(), highLowPlot.getValueAxisLabelFont());
+		valueAxisLabelFont = factory.getFont(highLowPlot.getChart(), highLowPlot.getValueAxisLabelFont());
 		valueAxisLabelColor = highLowPlot.getOwnValueAxisLabelColor();
-		valueAxisTickLabelFont = new JRBaseFont(highLowPlot.getChart(), highLowPlot.getValueAxisTickLabelFont());
+		valueAxisTickLabelFont = factory.getFont(highLowPlot.getChart(), highLowPlot.getValueAxisTickLabelFont());
 		valueAxisTickLabelColor = highLowPlot.getOwnValueAxisTickLabelColor();
 		valueAxisTickLabelMask = highLowPlot.getValueAxisTickLabelMask();
 		valueAxisVerticalTickLabels = highLowPlot.getValueAxisVerticalTickLabels();
@@ -342,14 +335,6 @@ public class JRBaseHighLowPlot extends JRBaseChartPlot implements JRHighLowPlot
 		return valueAxisLineColor;
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #getShowOpenTicks()}
-	 */
-	public boolean isShowOpenTicks()
-	{
-		return showOpenTicks == null ? false : showOpenTicks.booleanValue();
-	}
-
 	/**
 	 * 
 	 */
@@ -359,14 +344,6 @@ public class JRBaseHighLowPlot extends JRBaseChartPlot implements JRHighLowPlot
 	}
 
 
-	/**
-	 * @deprecated Replaced by {@link #setShowOpenTicks(Boolean)}
-	 */
-	public void setShowOpenTicks(boolean showOpenTicks)
-	{
-		setShowOpenTicks(Boolean.valueOf(showOpenTicks));
-	}
-
 	/**
 	 * 
 	 */
@@ -377,14 +354,6 @@ public class JRBaseHighLowPlot extends JRBaseChartPlot implements JRHighLowPlot
 		getEventSupport().firePropertyChange(PROPERTY_SHOW_OPEN_TICKS, old, this.showOpenTicks);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getShowCloseTicks()}
-	 */
-	public boolean isShowCloseTicks()
-	{
-		return showCloseTicks == null ? false : showCloseTicks.booleanValue();
-	}
-
 	/**
 	 * 
 	 */
@@ -393,14 +362,6 @@ public class JRBaseHighLowPlot extends JRBaseChartPlot implements JRHighLowPlot
 		return showCloseTicks;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setShowCloseTicks(Boolean)}
-	 */
-	public void setShowCloseTicks(boolean showCloseTicks)
-	{
-		setShowCloseTicks(Boolean.valueOf(showCloseTicks));
-	}
-
 	/**
 	 * 
 	 */
@@ -425,30 +386,12 @@ public class JRBaseHighLowPlot extends JRBaseChartPlot implements JRHighLowPlot
 	public Object clone(JRChart parentChart) 
 	{
 		JRBaseHighLowPlot clone = (JRBaseHighLowPlot)super.clone(parentChart);
-		if (timeAxisLabelExpression != null)
-		{
-			clone.timeAxisLabelExpression = (JRExpression)timeAxisLabelExpression.clone();
-		}
-		if (valueAxisLabelExpression != null)
-		{
-			clone.valueAxisLabelExpression = (JRExpression)valueAxisLabelExpression.clone();
-		}
-		if (domainAxisMinValueExpression != null)
-		{
-			clone.domainAxisMinValueExpression = (JRExpression)domainAxisMinValueExpression.clone();
-		}
-		if (domainAxisMaxValueExpression != null)
-		{
-			clone.domainAxisMaxValueExpression = (JRExpression)domainAxisMaxValueExpression.clone();
-		}
-		if (rangeAxisMinValueExpression != null)
-		{
-			clone.rangeAxisMinValueExpression = (JRExpression)rangeAxisMinValueExpression.clone();
-		}
-		if (rangeAxisMaxValueExpression != null)
-		{
-			clone.rangeAxisMaxValueExpression = (JRExpression)rangeAxisMaxValueExpression.clone();
-		}
+		clone.timeAxisLabelExpression = JRCloneUtils.nullSafeClone(timeAxisLabelExpression);
+		clone.valueAxisLabelExpression = JRCloneUtils.nullSafeClone(valueAxisLabelExpression);
+		clone.domainAxisMinValueExpression = JRCloneUtils.nullSafeClone(domainAxisMinValueExpression);
+		clone.domainAxisMaxValueExpression = JRCloneUtils.nullSafeClone(domainAxisMaxValueExpression);
+		clone.rangeAxisMinValueExpression = JRCloneUtils.nullSafeClone(rangeAxisMinValueExpression);
+		clone.rangeAxisMaxValueExpression = JRCloneUtils.nullSafeClone(rangeAxisMaxValueExpression);
 		return clone;
 	}
 	
@@ -459,11 +402,11 @@ public class JRBaseHighLowPlot extends JRBaseChartPlot implements JRHighLowPlot
 	/**
 	 * @deprecated
 	 */
-	private boolean isShowOpenTicks = false;
+	private boolean isShowOpenTicks;
 	/**
 	 * @deprecated
 	 */
-	private boolean isShowCloseTicks = false;
+	private boolean isShowCloseTicks;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
