@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -32,7 +32,6 @@ import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRExpressionCollector;
 import net.sf.jasperreports.engine.JRFont;
 import net.sf.jasperreports.engine.JRRuntimeException;
-import net.sf.jasperreports.engine.base.JRBaseFont;
 import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
 
 /**
@@ -40,7 +39,7 @@ import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
  * item labels in a category plot.
  *
  * @author sanda zaharia (shertage@users.sourceforge.net)
- * @version $Id: JRBaseItemLabel.java 3032 2009-08-27 11:32:28Z teodord $
+ * @version $Id: JRBaseItemLabel.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseItemLabel implements JRItemLabel, Serializable
 {
@@ -51,28 +50,28 @@ public class JRBaseItemLabel implements JRItemLabel, Serializable
 	 */
 	private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 
-	protected JRChart chart = null;
+	protected JRChart chart;
 
 	/**
 	 * The item label text color.
 	 */
-	protected Color color = null;
+	protected Color color;
 
 	/**
 	 * The item label background color.
 	 */
-	protected Color backgroundColor = null;
+	protected Color backgroundColor;
 
 	/**
 	 * The formatting mask to use when writing the value.  Must a pattern
 	 * that is accepted by a code>java.text.DecimalFormat</code> object.
 	 */
-//	protected String mask = null;
+//	protected String mask;
 
 	/**
 	 * The item label text font.
 	 */
-	protected JRFont font = null;
+	protected JRFont font;
 
 
 	/**
@@ -85,18 +84,12 @@ public class JRBaseItemLabel implements JRItemLabel, Serializable
 	{
 		this.chart = chart;
 		
-		if (itemLabel == null)
-		{
-			font = new JRBaseFont(chart, null);
-			color = chart.getForecolor();
-			backgroundColor = chart.getBackcolor();
-		}
-		else
+		if (itemLabel != null)
 		{
 			color = itemLabel.getColor();
 			backgroundColor = itemLabel.getBackgroundColor();
 //			mask = itemLabel.getMask();
-			font = new JRBaseFont(itemLabel.getChart(), itemLabel.getFont());
+			font = itemLabel.getFont();
 		}
 	}
 
@@ -116,7 +109,7 @@ public class JRBaseItemLabel implements JRItemLabel, Serializable
 		color = itemLabel.getColor();
 		backgroundColor = itemLabel.getBackgroundColor();
 //		mask = itemLabel.getMask();
-		font = new JRBaseFont(itemLabel.getChart(), itemLabel.getFont());
+		font = factory.getFont(itemLabel.getChart(), itemLabel.getFont());
 	}
 
 
