@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -34,11 +34,12 @@ import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRExpressionCollector;
 import net.sf.jasperreports.engine.base.JRBaseChartPlot;
 import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBasePiePlot.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBasePiePlot.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBasePiePlot extends JRBaseChartPlot implements JRPiePlot
 {
@@ -50,32 +51,36 @@ public class JRBasePiePlot extends JRBaseChartPlot implements JRPiePlot
 	public static final String PROPERTY_LEGEND_LABEL_FORMAT = "legendLabelFormat";
 	public static final String PROPERTY_ITEM_LABEL = "itemLabel";
 
+	public static final String PROPERTY_SHOW_LABELS = "showLabels";
 	/*
 	 * README
 	 * 
 	 * Make sure that all fields are read in readObject().
 	 */
-	protected Boolean circular = null;
-	protected String labelFormat = null;
-	protected String legendLabelFormat = null;
+	protected Boolean circular;
+	protected String labelFormat;
+	protected String legendLabelFormat;
 	
-	protected JRItemLabel itemLabel = null;
+	protected JRItemLabel itemLabel;
+	protected Boolean showLabels;
 
 	/**
 	 *
 	 */
-	public JRBasePiePlot(JRChartPlot piePlot, JRChart chart)
+	public JRBasePiePlot(JRChartPlot chartPlot, JRChart chart)
 	{
-		super(piePlot, chart);
+		super(chartPlot, chart);
+		
+		JRPiePlot piePlot = chartPlot instanceof JRPiePlot ? (JRPiePlot)chartPlot : null;
+		
 		if (piePlot == null)
 		{
 			itemLabel = new JRBaseItemLabel(null, chart);
 		}
 		else
 		{
-			itemLabel = new JRBaseItemLabel(((JRPiePlot)piePlot).getItemLabel(), chart);
+			itemLabel = new JRBaseItemLabel(piePlot.getItemLabel(), chart);
 		}
-		
 	}
 
 
@@ -89,6 +94,7 @@ public class JRBasePiePlot extends JRBaseChartPlot implements JRPiePlot
 		labelFormat = piePlot.getLabelFormat();
 		legendLabelFormat = piePlot.getLegendLabelFormat();
 		itemLabel = new JRBaseItemLabel(piePlot.getItemLabel(), factory);
+		showLabels = piePlot.getShowLabels();
 	}
 	
 	/**
@@ -99,13 +105,6 @@ public class JRBasePiePlot extends JRBaseChartPlot implements JRPiePlot
 	}
 
 
-	/**
-	 * @deprecated Replaced by {@link #getCircular()}
-	 */
-	public boolean isCircular() {
-		return circular == null ? true : circular.booleanValue();
-	}
-
 	/**
 	 * @return the circular
 	 */
@@ -113,13 +112,6 @@ public class JRBasePiePlot extends JRBaseChartPlot implements JRPiePlot
 		return circular;
 	}
 
-	/**
-	 * @param isCircular the isCircular to set
-	 */
-	public void setCircular(boolean isCircular) {
-		setCircular(Boolean.valueOf(isCircular));
-	}
-
 	/**
 	 * @param isCircular the isCircular to set
 	 */
@@ -181,17 +173,29 @@ public class JRBasePiePlot extends JRBaseChartPlot implements JRPiePlot
 		getEventSupport().firePropertyChange(PROPERTY_ITEM_LABEL, old, this.itemLabel);
 	}
 
+	/**
+	 *
+	 */
+	public Boolean getShowLabels(){
+		return showLabels;
+	}
+
+	/**
+	 *
+	 */
+	public void setShowLabels( Boolean showLabels ){
+		Boolean old = this.showLabels;
+		this.showLabels = showLabels;
+		getEventSupport().firePropertyChange(PROPERTY_SHOW_LABELS, old, this.showLabels);
+	}
+
 	/**
 	 *
 	 */
 	public Object clone(JRChart parentChart) 
 	{
 		JRBasePiePlot clone = (JRBasePiePlot)super.clone(parentChart);
-		if (itemLabel != null)
-		{
-			clone.itemLabel = (JRItemLabel)itemLabel.clone();
-		}
-		
+		clone.itemLabel = JRCloneUtils.nullSafeClone(itemLabel);
 		return clone;
 	}
 
