@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -31,11 +31,12 @@ import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRHyperlink;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBasePieSeries.java 3938 2010-08-19 14:59:36Z teodord $
+ * @version $Id: JRBasePieSeries.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBasePieSeries implements JRPieSeries, Serializable
 {
@@ -120,22 +121,10 @@ public class JRBasePieSeries implements JRPieSeries, Serializable
 			throw new JRRuntimeException(e);
 		}
 		
-		if (keyExpression != null)
-		{
-			clone.keyExpression = (JRExpression)keyExpression.clone();
-		}
-		if (valueExpression != null)
-		{
-			clone.valueExpression = (JRExpression)valueExpression.clone();
-		}
-		if (labelExpression != null)
-		{
-			clone.labelExpression = (JRExpression)labelExpression.clone();
-		}
-		if (sectionHyperlink != null)
-		{
-			clone.sectionHyperlink = (JRHyperlink)sectionHyperlink.clone();
-		}
+		clone.keyExpression = JRCloneUtils.nullSafeClone(keyExpression);
+		clone.valueExpression = JRCloneUtils.nullSafeClone(valueExpression);
+		clone.labelExpression = JRCloneUtils.nullSafeClone(labelExpression);
+		clone.sectionHyperlink = JRCloneUtils.nullSafeClone(sectionHyperlink);
 		
 		return clone;
 	}
