@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,13 +35,13 @@ import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRExpressionCollector;
 import net.sf.jasperreports.engine.JRFont;
 import net.sf.jasperreports.engine.base.JRBaseChartPlot;
-import net.sf.jasperreports.engine.base.JRBaseFont;
 import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseScatterPlot.java 3715 2010-04-08 18:08:49Z teodord $ 
+ * @version $Id: JRBaseScatterPlot.java 4595 2011-09-08 15:55:10Z teodord $ 
  */
 public class JRBaseScatterPlot extends JRBaseChartPlot implements JRScatterPlot {
 	
@@ -51,31 +51,31 @@ public class JRBaseScatterPlot extends JRBaseChartPlot implements JRScatterPlot
 	
 	public static final String PROPERTY_SHOW_SHAPES = "showShapes";
 	
-	protected JRExpression xAxisLabelExpression = null;
-	protected JRFont xAxisLabelFont = null;
-	protected Color xAxisLabelColor = null;
-	protected JRFont xAxisTickLabelFont = null;
-	protected Color xAxisTickLabelColor = null;
-	protected String xAxisTickLabelMask = null;
-	protected Boolean xAxisVerticalTickLabels = null;
-	protected Color xAxisLineColor = null;
+	protected JRExpression xAxisLabelExpression;
+	protected JRFont xAxisLabelFont;
+	protected Color xAxisLabelColor;
+	protected JRFont xAxisTickLabelFont;
+	protected Color xAxisTickLabelColor;
+	protected String xAxisTickLabelMask;
+	protected Boolean xAxisVerticalTickLabels;
+	protected Color xAxisLineColor;
 
-	protected JRExpression yAxisLabelExpression = null;
-	protected JRFont yAxisLabelFont = null;
-	protected Color yAxisLabelColor = null;
-	protected JRFont yAxisTickLabelFont = null;
-	protected Color yAxisTickLabelColor = null;
-	protected String yAxisTickLabelMask = null;
-	protected Boolean yAxisVerticalTickLabels = null;
-	protected Color yAxisLineColor = null;
+	protected JRExpression yAxisLabelExpression;
+	protected JRFont yAxisLabelFont;
+	protected Color yAxisLabelColor;
+	protected JRFont yAxisTickLabelFont;
+	protected Color yAxisTickLabelColor;
+	protected String yAxisTickLabelMask;
+	protected Boolean yAxisVerticalTickLabels;
+	protected Color yAxisLineColor;
 	
-	protected JRExpression domainAxisMinValueExpression = null;
-	protected JRExpression domainAxisMaxValueExpression = null;
-	protected JRExpression rangeAxisMinValueExpression = null;
-	protected JRExpression rangeAxisMaxValueExpression = null;
+	protected JRExpression domainAxisMinValueExpression;
+	protected JRExpression domainAxisMaxValueExpression;
+	protected JRExpression rangeAxisMinValueExpression;
+	protected JRExpression rangeAxisMaxValueExpression;
 	
-	Boolean showShapes = null;
-	Boolean showLines = null;
+	Boolean showShapes;
+	Boolean showLines;
 	
 	
 	/**
@@ -86,19 +86,12 @@ public class JRBaseScatterPlot extends JRBaseChartPlot implements JRScatterPlot
 		super(plot, chart);
 		
 		JRScatterPlot scatterPlot = plot instanceof JRScatterPlot ? (JRScatterPlot)plot : null;
-		if (scatterPlot == null)
+		if (scatterPlot != null)
 		{
-			xAxisLabelFont = new JRBaseFont(chart, null);
-			xAxisTickLabelFont = new JRBaseFont(chart, null);
-			yAxisLabelFont = new JRBaseFont(chart, null);
-			yAxisTickLabelFont = new JRBaseFont(chart, null);
-		}
-		else
-		{
-			xAxisLabelFont = new JRBaseFont(chart, scatterPlot.getXAxisLabelFont());
-			xAxisTickLabelFont = new JRBaseFont(chart, scatterPlot.getXAxisTickLabelFont());
-			yAxisLabelFont = new JRBaseFont(chart, scatterPlot.getYAxisLabelFont());
-			yAxisTickLabelFont = new JRBaseFont(chart, scatterPlot.getYAxisTickLabelFont());
+			xAxisLabelFont = scatterPlot.getXAxisLabelFont();
+			xAxisTickLabelFont = scatterPlot.getXAxisTickLabelFont();
+			yAxisLabelFont = scatterPlot.getYAxisLabelFont();
+			yAxisTickLabelFont = scatterPlot.getYAxisTickLabelFont();
 		}
 	}
 
@@ -113,18 +106,18 @@ public class JRBaseScatterPlot extends JRBaseChartPlot implements JRScatterPlot
 		showLines = scatterPlot.getShowLines();
 		
 		xAxisLabelExpression = factory.getExpression( scatterPlot.getXAxisLabelExpression() );
-		xAxisLabelFont = new JRBaseFont(scatterPlot.getChart(), scatterPlot.getXAxisLabelFont());
+		xAxisLabelFont = factory.getFont(scatterPlot.getChart(), scatterPlot.getXAxisLabelFont());
 		xAxisLabelColor = scatterPlot.getOwnXAxisLabelColor();
-		xAxisTickLabelFont = new JRBaseFont(scatterPlot.getChart(), scatterPlot.getXAxisTickLabelFont());
+		xAxisTickLabelFont = factory.getFont(scatterPlot.getChart(), scatterPlot.getXAxisTickLabelFont());
 		xAxisTickLabelColor = scatterPlot.getOwnXAxisTickLabelColor();
 		xAxisTickLabelMask = scatterPlot.getXAxisTickLabelMask();
 		xAxisVerticalTickLabels = scatterPlot.getXAxisVerticalTickLabels();
 		xAxisLineColor = scatterPlot.getOwnXAxisLineColor();
 		
 		yAxisLabelExpression = factory.getExpression( scatterPlot.getYAxisLabelExpression() );
-		yAxisLabelFont = new JRBaseFont(scatterPlot.getChart(), scatterPlot.getYAxisLabelFont());
+		yAxisLabelFont = factory.getFont(scatterPlot.getChart(), scatterPlot.getYAxisLabelFont());
 		yAxisLabelColor = scatterPlot.getOwnYAxisLabelColor();
-		yAxisTickLabelFont = new JRBaseFont(scatterPlot.getChart(), scatterPlot.getYAxisTickLabelFont());
+		yAxisTickLabelFont = factory.getFont(scatterPlot.getChart(), scatterPlot.getYAxisTickLabelFont());
 		yAxisTickLabelColor = scatterPlot.getOwnYAxisTickLabelColor();
 		yAxisTickLabelMask = scatterPlot.getYAxisTickLabelMask();
 		yAxisVerticalTickLabels = scatterPlot.getYAxisVerticalTickLabels();
@@ -310,13 +303,6 @@ public class JRBaseScatterPlot extends JRBaseChartPlot implements JRScatterPlot
 		return yAxisLineColor;
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #getShowShapes()}
-	 */
-	public boolean isShowShapes(){
-		return showShapes == null ? true : showShapes.booleanValue();
-	}
-	
 	/**
 	 * 
 	 */
@@ -324,13 +310,6 @@ public class JRBaseScatterPlot extends JRBaseChartPlot implements JRScatterPlot
 		return showShapes;
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #getShowLines()}
-	 */
-	public boolean isShowLines(){
-		return showLines == null ? true : showLines.booleanValue();
-	}
-	
 	/**
 	 * 
 	 */
@@ -338,13 +317,6 @@ public class JRBaseScatterPlot extends JRBaseChartPlot implements JRScatterPlot
 		return showLines;
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #setShowShapes(Boolean)}
-	 */
-	public void setShowShapes( boolean value ){
-		setShowShapes(Boolean.valueOf(value));
-	}
-	
 	/**
 	 * 
 	 */
@@ -382,13 +354,6 @@ public class JRBaseScatterPlot extends JRBaseChartPlot implements JRScatterPlot
 		getEventSupport().firePropertyChange(PROPERTY_SHOW_SHAPES, old, this.showShapes);
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #setShowLines(Boolean)}
-	 */
-	public void setShowLines( boolean value ){
-		setShowLines(Boolean.valueOf(value));
-	}
-
 	/**
 	 * 
 	 */
@@ -412,30 +377,12 @@ public class JRBaseScatterPlot extends JRBaseChartPlot implements JRScatterPlot
 	public Object clone(JRChart parentChart) 
 	{
 		JRBaseScatterPlot clone = (JRBaseScatterPlot)super.clone(parentChart);
-		if (xAxisLabelExpression != null)
-		{
-			clone.xAxisLabelExpression = (JRExpression)xAxisLabelExpression.clone();
-		}
-		if (yAxisLabelExpression != null)
-		{
-			clone.yAxisLabelExpression = (JRExpression)yAxisLabelExpression.clone();
-		}
-		if (domainAxisMinValueExpression != null)
-		{
-			clone.domainAxisMinValueExpression = (JRExpression)domainAxisMinValueExpression.clone();
-		}
-		if (domainAxisMaxValueExpression != null)
-		{
-			clone.domainAxisMaxValueExpression = (JRExpression)domainAxisMaxValueExpression.clone();
-		}
-		if (rangeAxisMinValueExpression != null)
-		{
-			clone.rangeAxisMinValueExpression = (JRExpression)rangeAxisMinValueExpression.clone();
-		}
-		if (rangeAxisMaxValueExpression != null)
-		{
-			clone.rangeAxisMaxValueExpression = (JRExpression)rangeAxisMaxValueExpression.clone();
-		}
+		clone.xAxisLabelExpression = JRCloneUtils.nullSafeClone(xAxisLabelExpression);
+		clone.yAxisLabelExpression = JRCloneUtils.nullSafeClone(yAxisLabelExpression);
+		clone.domainAxisMinValueExpression = JRCloneUtils.nullSafeClone(domainAxisMinValueExpression);
+		clone.domainAxisMaxValueExpression = JRCloneUtils.nullSafeClone(domainAxisMaxValueExpression);
+		clone.rangeAxisMinValueExpression = JRCloneUtils.nullSafeClone(rangeAxisMinValueExpression);
+		clone.rangeAxisMaxValueExpression = JRCloneUtils.nullSafeClone(rangeAxisMaxValueExpression);
 		return clone;
 	}
 
