@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -31,10 +31,11 @@ import net.sf.jasperreports.engine.JRExpressionCollector;
 import net.sf.jasperreports.engine.base.JRBaseChartDataset;
 import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
 import net.sf.jasperreports.engine.design.JRVerifier;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 
 /**
  * @author Flavius Sana (flavius_sana@users.sourceforge.net)
- * @version $Id: JRBaseTimePeriodDataset.java 3734 2010-04-12 14:24:34Z lucianc $
+ * @version $Id: JRBaseTimePeriodDataset.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseTimePeriodDataset extends JRBaseChartDataset implements JRTimePeriodDataset {
 	
@@ -43,7 +44,7 @@ public class JRBaseTimePeriodDataset extends JRBaseChartDataset implements JRTim
 	 */
 	private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 	
-	private JRTimePeriodSeries[] timePeriodSeries = null;
+	private JRTimePeriodSeries[] timePeriodSeries;
 	
 	protected JRBaseTimePeriodDataset( JRTimePeriodDataset dataset ){
 		super( dataset );
@@ -93,16 +94,7 @@ public class JRBaseTimePeriodDataset extends JRBaseChartDataset implements JRTim
 	public Object clone() 
 	{
 		JRBaseTimePeriodDataset clone = (JRBaseTimePeriodDataset)super.clone();
-		
-		if (timePeriodSeries != null)
-		{
-			clone.timePeriodSeries = new JRTimePeriodSeries[timePeriodSeries.length];
-			for(int i = 0; i < timePeriodSeries.length; i++)
-			{
-				clone.timePeriodSeries[i] = (JRTimePeriodSeries)timePeriodSeries[i].clone();
-			}
-		}
-		
+		clone.timePeriodSeries = JRCloneUtils.cloneArray(timePeriodSeries);
 		return clone;
 	}
 }
