@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,13 +35,13 @@ import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRExpressionCollector;
 import net.sf.jasperreports.engine.JRFont;
 import net.sf.jasperreports.engine.base.JRBaseChartPlot;
-import net.sf.jasperreports.engine.base.JRBaseFont;
 import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 /**
  * @author Flavius Sana (flavius_sana@users.sourceforge.net)
- * @version $Id: JRBaseTimeSeriesPlot.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBaseTimeSeriesPlot.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseTimeSeriesPlot extends JRBaseChartPlot implements JRTimeSeriesPlot 
 {
@@ -52,30 +52,30 @@ public class JRBaseTimeSeriesPlot extends JRBaseChartPlot implements JRTimeSerie
 	
 	public static final String PROPERTY_SHOW_SHAPES = "showShapes";
 	
-	protected JRExpression timeAxisLabelExpression = null;
-	protected JRFont timeAxisLabelFont = null;
-	protected Color timeAxisLabelColor = null;
-	protected JRFont timeAxisTickLabelFont = null;
-	protected Color timeAxisTickLabelColor = null;
-	protected String timeAxisTickLabelMask = null;
-	protected Boolean timeAxisVerticalTickLabels = null;
-	protected Color timeAxisLineColor = null;
+	protected JRExpression timeAxisLabelExpression;
+	protected JRFont timeAxisLabelFont;
+	protected Color timeAxisLabelColor;
+	protected JRFont timeAxisTickLabelFont;
+	protected Color timeAxisTickLabelColor;
+	protected String timeAxisTickLabelMask;
+	protected Boolean timeAxisVerticalTickLabels;
+	protected Color timeAxisLineColor;
 
-	protected JRExpression valueAxisLabelExpression = null;
-	protected JRExpression rangeAxisMinValueExpression = null;
-	protected JRExpression rangeAxisMaxValueExpression = null;
-	protected JRExpression domainAxisMinValueExpression = null;
-	protected JRExpression domainAxisMaxValueExpression = null;
-	protected JRFont valueAxisLabelFont = null;
-	protected Color valueAxisLabelColor = null;
-	protected JRFont valueAxisTickLabelFont = null;
-	protected Color valueAxisTickLabelColor = null;
-	protected String valueAxisTickLabelMask = null;
-	protected Boolean valueAxisVerticalTickLabels = null;
-	protected Color valueAxisLineColor = null;
+	protected JRExpression valueAxisLabelExpression;
+	protected JRExpression rangeAxisMinValueExpression;
+	protected JRExpression rangeAxisMaxValueExpression;
+	protected JRExpression domainAxisMinValueExpression;
+	protected JRExpression domainAxisMaxValueExpression;
+	protected JRFont valueAxisLabelFont;
+	protected Color valueAxisLabelColor;
+	protected JRFont valueAxisTickLabelFont;
+	protected Color valueAxisTickLabelColor;
+	protected String valueAxisTickLabelMask;
+	protected Boolean valueAxisVerticalTickLabels;
+	protected Color valueAxisLineColor;
 	
-	Boolean showShapes = null;
-	Boolean showLines = null;
+	Boolean showShapes;
+	Boolean showLines;
 	
 	/**
 	 * 
@@ -85,19 +85,12 @@ public class JRBaseTimeSeriesPlot extends JRBaseChartPlot implements JRTimeSerie
 		super(plot, chart);
 		
 		JRTimeSeriesPlot timeSeriesPlot = plot instanceof JRTimeSeriesPlot ? (JRTimeSeriesPlot)plot : null;
-		if (timeSeriesPlot == null)
-		{
-			timeAxisLabelFont = new JRBaseFont(chart, null);
-			timeAxisTickLabelFont = new JRBaseFont(chart, null);
-			valueAxisLabelFont = new JRBaseFont(chart, null);
-			valueAxisTickLabelFont = new JRBaseFont(chart, null);
-		}
-		else
+		if (timeSeriesPlot != null)
 		{//FIXMETHEME you could copy more things
-			timeAxisLabelFont = new JRBaseFont(chart, timeSeriesPlot.getTimeAxisLabelFont());
-			timeAxisTickLabelFont = new JRBaseFont(chart, timeSeriesPlot.getTimeAxisTickLabelFont());
-			valueAxisLabelFont = new JRBaseFont(chart, timeSeriesPlot.getValueAxisLabelFont());
-			valueAxisTickLabelFont = new JRBaseFont(chart, timeSeriesPlot.getValueAxisTickLabelFont());
+			timeAxisLabelFont = timeSeriesPlot.getTimeAxisLabelFont();
+			timeAxisTickLabelFont = timeSeriesPlot.getTimeAxisTickLabelFont();
+			valueAxisLabelFont = timeSeriesPlot.getValueAxisLabelFont();
+			valueAxisTickLabelFont = timeSeriesPlot.getValueAxisTickLabelFont();
 		}
 	}
 	
@@ -112,9 +105,9 @@ public class JRBaseTimeSeriesPlot extends JRBaseChartPlot implements JRTimeSerie
 		showShapes = plot.getShowShapes();
 		
 		timeAxisLabelExpression = factory.getExpression( plot.getTimeAxisLabelExpression() );
-		timeAxisLabelFont = new JRBaseFont(plot.getChart(), plot.getTimeAxisLabelFont());//FIXMETHEME check this plot.getChart(); don't we get the design chart?
+		timeAxisLabelFont = factory.getFont(plot.getChart(), plot.getTimeAxisLabelFont());//FIXMETHEME check this plot.getChart(); don't we get the design chart?
 		timeAxisLabelColor = plot.getOwnTimeAxisLabelColor();
-		timeAxisTickLabelFont = new JRBaseFont(plot.getChart(), plot.getTimeAxisTickLabelFont());
+		timeAxisTickLabelFont = factory.getFont(plot.getChart(), plot.getTimeAxisTickLabelFont());
 		timeAxisTickLabelColor = plot.getOwnTimeAxisTickLabelColor();
 		timeAxisTickLabelMask = plot.getTimeAxisTickLabelMask();
 		timeAxisVerticalTickLabels = plot.getTimeAxisVerticalTickLabels();
@@ -125,9 +118,9 @@ public class JRBaseTimeSeriesPlot extends JRBaseChartPlot implements JRTimeSerie
 		domainAxisMaxValueExpression = factory.getExpression( plot.getDomainAxisMaxValueExpression() );
 		rangeAxisMinValueExpression = factory.getExpression( plot.getRangeAxisMinValueExpression() );
 		rangeAxisMaxValueExpression = factory.getExpression( plot.getRangeAxisMaxValueExpression() );
-		valueAxisLabelFont = new JRBaseFont(plot.getChart(), plot.getValueAxisLabelFont());
+		valueAxisLabelFont = factory.getFont(plot.getChart(), plot.getValueAxisLabelFont());
 		valueAxisLabelColor = plot.getOwnValueAxisLabelColor();
-		valueAxisTickLabelFont = new JRBaseFont(plot.getChart(), plot.getValueAxisTickLabelFont());
+		valueAxisTickLabelFont = factory.getFont(plot.getChart(), plot.getValueAxisTickLabelFont());
 		valueAxisTickLabelColor = plot.getOwnValueAxisTickLabelColor();
 		valueAxisTickLabelMask = plot.getValueAxisTickLabelMask();
 		valueAxisVerticalTickLabels = plot.getValueAxisVerticalTickLabels();
@@ -336,34 +329,6 @@ public class JRBaseTimeSeriesPlot extends JRBaseChartPlot implements JRTimeSerie
 		return valueAxisLineColor;
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #getShowLines()}
-	 */
-	public boolean isShowLines(){
-		return showLines == null ? true : showLines.booleanValue();
-	}
-	
-	/**
-	 * @deprecated Replaced by {@link #getShowShapes()}
-	 */
-	public boolean isShowShapes(){
-		return showShapes == null ? true : showShapes.booleanValue();
-	}
-	
-	/**
-	 * @deprecated Replaced by {@link #setShowLines(Boolean)}
-	 */
-	public void setShowLines( boolean val ){
-		setShowLines(Boolean.valueOf(val));
-	}
-	
-	/**
-	 * @deprecated Replaced by {@link #setShowShapes(Boolean)}
-	 */
-	public void setShowShapes( boolean val ){
-		setShowShapes(Boolean.valueOf(val));
-	}
-
 	/**
 	 * 
 	 */
@@ -410,30 +375,12 @@ public class JRBaseTimeSeriesPlot extends JRBaseChartPlot implements JRTimeSerie
 	public Object clone(JRChart parentChart) 
 	{
 		JRBaseTimeSeriesPlot clone = (JRBaseTimeSeriesPlot)super.clone(parentChart);
-		if (timeAxisLabelExpression != null)
-		{
-			clone.timeAxisLabelExpression = (JRExpression)timeAxisLabelExpression.clone();
-		}
-		if (valueAxisLabelExpression != null)
-		{
-			clone.valueAxisLabelExpression = (JRExpression)valueAxisLabelExpression.clone();
-		}
-		if (domainAxisMinValueExpression != null)
-		{
-			clone.domainAxisMinValueExpression = (JRExpression)domainAxisMinValueExpression.clone();
-		}
-		if (domainAxisMaxValueExpression != null)
-		{
-			clone.domainAxisMaxValueExpression = (JRExpression)domainAxisMaxValueExpression.clone();
-		}
-		if (rangeAxisMinValueExpression != null)
-		{
-			clone.rangeAxisMinValueExpression = (JRExpression)rangeAxisMinValueExpression.clone();
-		}
-		if (rangeAxisMaxValueExpression != null)
-		{
-			clone.rangeAxisMaxValueExpression = (JRExpression)rangeAxisMaxValueExpression.clone();
-		}
+		clone.timeAxisLabelExpression = JRCloneUtils.nullSafeClone(timeAxisLabelExpression);
+		clone.valueAxisLabelExpression = JRCloneUtils.nullSafeClone(valueAxisLabelExpression);
+		clone.domainAxisMinValueExpression = JRCloneUtils.nullSafeClone(domainAxisMinValueExpression);
+		clone.domainAxisMaxValueExpression = JRCloneUtils.nullSafeClone(domainAxisMaxValueExpression);
+		clone.rangeAxisMinValueExpression = JRCloneUtils.nullSafeClone(rangeAxisMinValueExpression);
+		clone.rangeAxisMaxValueExpression = JRCloneUtils.nullSafeClone(rangeAxisMaxValueExpression);
 		return clone;
 	}
 	
