@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -36,7 +36,7 @@ import net.sf.jasperreports.engine.design.events.JRPropertyChangeSupport;
  * {@link JRChartAxis JRChartAxis} implementation to be used for report design.
  *
  * @author Barry Klawans (barry@users.sourceforge.net)
- * @version $Id: JRDesignChartAxis.java 3938 2010-08-19 14:59:36Z teodord $
+ * @version $Id: JRDesignChartAxis.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRDesignChartAxis extends JRBaseChartAxis implements JRChangeEventsSupport
 {
@@ -62,22 +62,6 @@ public class JRDesignChartAxis extends JRBaseChartAxis implements JRChangeEvents
 		this.parentChart = parentChart;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setPosition(AxisPositionEnum)}
-	 */
-	public void setPosition(byte position)
-	{
-		setPosition(AxisPositionEnum.getByValue(position));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setPosition(AxisPositionEnum)}
-	 */
-	public void setPosition(Byte position)
-	{
-		setPosition(AxisPositionEnum.getByValue(position));
-	}
-
 	/**
 	 * Sets the position of this axis' value line relative to the multiple
 	 * axis chart.
@@ -135,6 +119,16 @@ public class JRDesignChartAxis extends JRBaseChartAxis implements JRChangeEvents
 		setChart((JRDesignChart)element);
 	}
 	
+	/**
+	 * 
+	 */
+	public Object clone() 
+	{
+		JRDesignChartAxis clone = (JRDesignChartAxis)super.clone();
+		clone.eventSupport = null;
+		return clone;
+	}
+	
 	private transient JRPropertyChangeSupport eventSupport;
 	
 	public JRPropertyChangeSupport getEventSupport()
