@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -31,18 +31,20 @@ import java.util.List;
 import net.sf.jasperreports.charts.JRPieDataset;
 import net.sf.jasperreports.charts.JRPieSeries;
 import net.sf.jasperreports.engine.JRChartDataset;
+import net.sf.jasperreports.engine.JRCloneable;
 import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRExpressionCollector;
 import net.sf.jasperreports.engine.JRHyperlink;
 import net.sf.jasperreports.engine.design.JRDesignChartDataset;
 import net.sf.jasperreports.engine.design.JRVerifier;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRDesignPieDataset.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRDesignPieDataset.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRDesignPieDataset extends JRDesignChartDataset implements JRPieDataset
 {
@@ -64,14 +66,14 @@ public class JRDesignPieDataset extends JRDesignChartDataset implements JRPieDat
 	public static final String PROPERTY_OTHER_LABEL_EXPRESSION = "otherLabelExpression";
 	public static final String PROPERTY_OTHER_SECTION_HYPERLINK = "otherSectionHyperlink";
 
-	private Float minPercentage = null;
-	private Integer maxCount = null;
+	private Float minPercentage;
+	private Integer maxCount;
 	
-	private List pieSeriesList = new ArrayList();
+	private List<JRPieSeries> pieSeriesList = new ArrayList<JRPieSeries>();
 
-	protected JRExpression otherKeyExpression = null;
-	protected JRExpression otherLabelExpression = null;
-	private JRHyperlink otherSectionHyperlink = null;
+	protected JRExpression otherKeyExpression;
+	protected JRExpression otherLabelExpression;
+	private JRHyperlink otherSectionHyperlink;
 
 
 	/**
@@ -135,7 +137,7 @@ public class JRDesignPieDataset extends JRDesignChartDataset implements JRPieDat
 	/**
 	 * 
 	 */
-	public List getSeriesList()
+	public List<JRPieSeries> getSeriesList()
 	{
 		return pieSeriesList;
 	}
@@ -151,6 +153,15 @@ public class JRDesignPieDataset extends JRDesignChartDataset implements JRPieDat
 				pieSeries, pieSeriesList.size() - 1);
 	}
 	
+	/**
+	 *
+	 */
+	public void addPieSeries(int index, JRPieSeries pieSeries)
+	{
+		pieSeriesList.add(index, pieSeries);
+		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_PIE_SERIES, 
+				pieSeries, index);
+	}
 
 	/**
 	 *
@@ -177,7 +188,7 @@ public class JRDesignPieDataset extends JRDesignChartDataset implements JRPieDat
 	 */
 	public JRExpression getKeyExpression()
 	{
-		return pieSeriesList.size() > 0 ? ((JRPieSeries)pieSeriesList.get(0)).getKeyExpression() : null;
+		return pieSeriesList.size() > 0 ? (pieSeriesList.get(0)).getKeyExpression() : null;
 	}
 		
 	/**
@@ -197,7 +208,7 @@ public class JRDesignPieDataset extends JRDesignChartDataset implements JRPieDat
 	 */
 	public JRExpression getValueExpression()
 	{
-		return pieSeriesList.size() > 0 ? ((JRPieSeries)pieSeriesList.get(0)).getValueExpression() : null;
+		return pieSeriesList.size() > 0 ? (pieSeriesList.get(0)).getValueExpression() : null;
 	}
 		
 	/**
@@ -217,7 +228,7 @@ public class JRDesignPieDataset extends JRDesignChartDataset implements JRPieDat
 	 */
 	public JRExpression getLabelExpression()
 	{
-		return pieSeriesList.size() > 0 ? ((JRPieSeries)pieSeriesList.get(0)).getLabelExpression() : null;
+		return pieSeriesList.size() > 0 ? (pieSeriesList.get(0)).getLabelExpression() : null;
 	}
 		
 	/**
@@ -237,7 +248,7 @@ public class JRDesignPieDataset extends JRDesignChartDataset implements JRPieDat
 	 */
 	public JRHyperlink getSectionHyperlink()
 	{
-		return pieSeriesList.size() > 0 ? ((JRPieSeries)pieSeriesList.get(0)).getSectionHyperlink() : null;
+		return pieSeriesList.size() > 0 ? (pieSeriesList.get(0)).getSectionHyperlink() : null;
 	}
 
 
@@ -338,29 +349,10 @@ public class JRDesignPieDataset extends JRDesignChartDataset implements JRPieDat
 	public Object clone() 
 	{
 		JRDesignPieDataset clone = (JRDesignPieDataset)super.clone();
-		
-		if (pieSeriesList != null)
-		{
-			clone.pieSeriesList = new ArrayList(pieSeriesList.size());
-			for(int i = 0; i < pieSeriesList.size(); i++)
-			{
-				clone.pieSeriesList.add(((JRPieSeries)pieSeriesList.get(i)).clone());
-			}
-		}
-		
-		if (otherKeyExpression != null)
-		{
-			clone.otherKeyExpression = (JRExpression)otherKeyExpression.clone();
-		}
-		if (otherLabelExpression != null)
-		{
-			clone.otherLabelExpression = (JRExpression)otherLabelExpression.clone();
-		}
-		if (otherSectionHyperlink != null)
-		{
-			clone.otherSectionHyperlink = (JRHyperlink)otherSectionHyperlink.clone();
-		}
-		
+		clone.pieSeriesList = JRCloneUtils.cloneList(pieSeriesList);
+		clone.otherKeyExpression = JRCloneUtils.nullSafeClone(otherKeyExpression);
+		clone.otherLabelExpression = JRCloneUtils.nullSafeClone(otherLabelExpression);
+		clone.otherSectionHyperlink = JRCloneUtils.nullSafeClone(otherSectionHyperlink);
 		return clone;
 	}
 
@@ -370,19 +362,19 @@ public class JRDesignPieDataset extends JRDesignChartDataset implements JRPieDat
 	/**
 	 * @deprecated
 	 */
-	private JRExpression keyExpression = null;
+	private JRExpression keyExpression;
 	/**
 	 * @deprecated
 	 */
-	private JRExpression valueExpression = null;
+	private JRExpression valueExpression;
 	/**
 	 * @deprecated
 	 */
-	private JRExpression labelExpression = null;
+	private JRExpression labelExpression;
 	/**
 	 * @deprecated
 	 */
-	private JRHyperlink sectionHyperlink = null;
+	private JRHyperlink sectionHyperlink;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
@@ -390,7 +382,7 @@ public class JRDesignPieDataset extends JRDesignChartDataset implements JRPieDat
 		
 		if (pieSeriesList == null)
 		{
-			pieSeriesList = new ArrayList();
+			pieSeriesList = new ArrayList<JRPieSeries>();
 			
 			JRDesignPieSeries ps = new JRDesignPieSeries();
 			ps.setKeyExpression(keyExpression);
