@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -31,6 +31,7 @@ import net.sf.jasperreports.charts.JRCategorySeries;
 import net.sf.jasperreports.charts.util.CategoryLabelGenerator;
 import net.sf.jasperreports.engine.JRChartDataset;
 import net.sf.jasperreports.engine.JRExpressionCollector;
+import net.sf.jasperreports.engine.JRPrintHyperlink;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.design.JRVerifier;
 import net.sf.jasperreports.engine.fill.JRCalculator;
@@ -44,7 +45,7 @@ import org.jfree.data.general.Dataset;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillCategoryDataset.java 3032 2009-08-27 11:32:28Z teodord $
+ * @version $Id: JRFillCategoryDataset.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRFillCategoryDataset extends JRFillChartDataset implements JRCategoryDataset
 {
@@ -52,12 +53,12 @@ public class JRFillCategoryDataset extends JRFillChartDataset implements JRCateg
 	/**
 	 *
 	 */
-	protected JRFillCategorySeries[] categorySeries = null;
+	protected JRFillCategorySeries[] categorySeries;
 
-	private DefaultCategoryDataset dataset = null;
-	private Map labelsMap = null;
+	private DefaultCategoryDataset dataset;
+	private Map<Comparable<?>, Map<Comparable<?>, String>> labelsMap;
 	
-	private Map itemHyperlinks;
+	private Map<Comparable<?>, Map<Comparable<?>, JRPrintHyperlink>> itemHyperlinks;
 
 	
 	/**
@@ -126,15 +127,15 @@ public class JRFillCategoryDataset extends JRFillChartDataset implements JRCateg
 			if (dataset == null)
 			{
 				dataset = new DefaultCategoryDataset();
-				labelsMap = new HashMap();
-				itemHyperlinks = new HashMap();
+				labelsMap = new HashMap<Comparable<?>, Map<Comparable<?>, String>>();
+				itemHyperlinks = new HashMap<Comparable<?>, Map<Comparable<?>, JRPrintHyperlink>>();
 			}
 			
 			for(int i = 0; i < categorySeries.length; i++)
 			{
 				JRFillCategorySeries crtCategorySeries = categorySeries[i];
 				
-				Comparable seriesName = crtCategorySeries.getSeries();
+				Comparable<?> seriesName = crtCategorySeries.getSeries();
 				if (seriesName == null)
 				{
 					throw new JRRuntimeException("Category series name is null.");
@@ -148,10 +149,10 @@ public class JRFillCategoryDataset extends JRFillChartDataset implements JRCateg
 
 				if (crtCategorySeries.getLabelExpression() != null)
 				{
-					Map seriesLabels = (Map)labelsMap.get(seriesName);
+					Map<Comparable<?>, String> seriesLabels = labelsMap.get(seriesName);
 					if (seriesLabels == null)
 					{
-						seriesLabels = new HashMap();
+						seriesLabels = new HashMap<Comparable<?>, String>();
 						labelsMap.put(seriesName, seriesLabels);
 					}
 					
@@ -160,10 +161,10 @@ public class JRFillCategoryDataset extends JRFillChartDataset implements JRCateg
 				
 				if (crtCategorySeries.hasItemHyperlinks())
 				{
-					Map seriesLinks = (Map) itemHyperlinks.get(seriesName);
+					Map<Comparable<?>, JRPrintHyperlink> seriesLinks = itemHyperlinks.get(seriesName);
 					if (seriesLinks == null)
 					{
-						seriesLinks = new HashMap();
+						seriesLinks = new HashMap<Comparable<?>, JRPrintHyperlink>();
 						itemHyperlinks.put(seriesName, seriesLinks);
 					}
 					seriesLinks.put(crtCategorySeries.getCategory(), crtCategorySeries.getPrintItemHyperlink());
@@ -207,7 +208,7 @@ public class JRFillCategoryDataset extends JRFillChartDataset implements JRCateg
 	}
 
 	
-	public Map getItemHyperlinks()
+	public Map<Comparable<?>, Map<Comparable<?>, JRPrintHyperlink>> getItemHyperlinks()
 	{
 		return itemHyperlinks;
 	}
