@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -37,7 +37,7 @@ import net.sf.jasperreports.engine.fill.JRFillObjectFactory;
  * dataset.
  *
  * @author Barry Klawans (barry@users.sourceforge.net)
- * @version $Id: JRFillChartAxis.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRFillChartAxis.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRFillChartAxis implements JRChartAxis
 {
@@ -48,7 +48,7 @@ public class JRFillChartAxis implements JRChartAxis
 	 * The filled version of the <code>chart</code> field.  Contains evaluated
 	 * expressions and data.
 	 */
-	protected JRFillChart fillChart = null;
+	protected JRFillChart fillChart;
 
 	private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 
@@ -78,22 +78,6 @@ public class JRFillChartAxis implements JRChartAxis
 		return parent.getChart();
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getPositionValue()}
-	 */
-	public byte getPosition()
-	{
-		return getPositionValue() == null ? AxisPositionEnum.LEFT_OR_TOP.getValue() : getPositionValue().getValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getPositionValue()}
-	 */
-	public Byte getPositionByte()
-	{
-		return getPositionValue() == null ? null : getPositionValue().getValueByte();
-	}
-
 	public AxisPositionEnum getPositionValue()
 	{
 		return parent.getPositionValue();
