@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -49,7 +49,7 @@ import org.jfree.data.xy.DefaultHighLowDataset;
 
 /**
  * @author Ionut Nedelcu (ionutned@users.sourceforge.net)
- * @version $Id: JRFillHighLowDataset.java 3667 2010-03-31 14:40:11Z shertage $
+ * @version $Id: JRFillHighLowDataset.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRFillHighLowDataset extends JRFillChartDataset implements JRHighLowDataset
 {
@@ -57,17 +57,17 @@ public class JRFillHighLowDataset extends JRFillChartDataset implements JRHighLo
 	/**
 	 *
 	 */
-	private String series = null;
-	private List elements = new ArrayList();
-	private Date date = null;
-	private Number high = null;
-	private Number low = null;
-	private Number open = null;
-	private Number close = null;
-	private Number volume = null;
+	private String series;
+	private List<HighLowElement> elements = new ArrayList<HighLowElement>();
+	private Date date;
+	private Number high;
+	private Number low;
+	private Number open;
+	private Number close;
+	private Number volume;
 	
 	private JRPrintHyperlink itemHyperlink;
-	private List itemHyperlinks;
+	private List<JRPrintHyperlink> itemHyperlinks;
 
 	
 	/**
@@ -81,8 +81,8 @@ public class JRFillHighLowDataset extends JRFillChartDataset implements JRHighLo
 
 	protected void customInitialize()
 	{
-		elements = new ArrayList();
-		itemHyperlinks = new ArrayList();
+		elements = new ArrayList<HighLowElement>();
+		itemHyperlinks = new ArrayList<JRPrintHyperlink>();
 	}
 
 
@@ -144,7 +144,7 @@ public class JRFillHighLowDataset extends JRFillChartDataset implements JRHighLo
 			double[] volumeArray = new double[size];
 
 			for (int i = 0; i < elements.size(); i++) {
-				HighLowElement bean = (HighLowElement) elements.get(i);
+				HighLowElement bean = elements.get(i);
 				dateArray[i] = new Date(bean.getDate().getTime());
 				highArray[i] = bean.getHigh().doubleValue();
 				lowArray[i] = bean.getLow().doubleValue();
@@ -327,7 +327,7 @@ public class JRFillHighLowDataset extends JRFillChartDataset implements JRHighLo
 	}
 
 	
-	public List getItemHyperlinks()
+	public List<JRPrintHyperlink> getItemHyperlinks()
 	{
 		return itemHyperlinks;
 	}
