@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -28,14 +28,13 @@ import java.awt.Color;
 import net.sf.jasperreports.charts.JRLinePlot;
 import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRFont;
-import net.sf.jasperreports.engine.base.JRBaseFont;
 import net.sf.jasperreports.engine.fill.JRFillChartPlot;
 import net.sf.jasperreports.engine.fill.JRFillObjectFactory;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 /**
  * @author Flavius Sana (flavius_sana@users.sourceforge.net)
- * @version $Id: JRFillLinePlot.java 3938 2010-08-19 14:59:36Z teodord $
+ * @version $Id: JRFillLinePlot.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRFillLinePlot extends JRFillChartPlot implements JRLinePlot 
 {
@@ -63,15 +62,15 @@ public class JRFillLinePlot extends JRFillChartPlot implements JRLinePlot
 	{
 		super( plot, factory );
 
-		categoryAxisLabelFont = new JRBaseFont(plot.getChart(), plot.getCategoryAxisLabelFont()); 
+		categoryAxisLabelFont = factory.getFont(plot.getChart(), plot.getCategoryAxisLabelFont()); 
 		categoryAxisLabelColor = plot.getOwnCategoryAxisLabelColor();
-		categoryAxisTickLabelFont = new JRBaseFont(plot.getChart(), plot.getCategoryAxisTickLabelFont());
+		categoryAxisTickLabelFont = factory.getFont(plot.getChart(), plot.getCategoryAxisTickLabelFont());
 		categoryAxisTickLabelColor = plot.getOwnCategoryAxisTickLabelColor();
 		categoryAxisLineColor = plot.getOwnCategoryAxisLineColor();
 		
-		valueAxisLabelFont = new JRBaseFont(plot.getChart(), plot.getValueAxisLabelFont());
+		valueAxisLabelFont = factory.getFont(plot.getChart(), plot.getValueAxisLabelFont());
 		valueAxisLabelColor = plot.getOwnValueAxisLabelColor();
-		valueAxisTickLabelFont = new JRBaseFont(plot.getChart(), plot.getValueAxisTickLabelFont());
+		valueAxisTickLabelFont = factory.getFont(plot.getChart(), plot.getValueAxisTickLabelFont());
 		valueAxisTickLabelColor = plot.getOwnValueAxisTickLabelColor();
 		valueAxisLineColor = plot.getOwnValueAxisLineColor();
 	}
@@ -341,13 +340,6 @@ public class JRFillLinePlot extends JRFillChartPlot implements JRLinePlot
 	{
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getShowShapes()}
-	 */
-	public boolean isShowShapes(){
-		return ((JRLinePlot)parent).isShowShapes();
-	}
-	
 	/**
 	 *
 	 */
@@ -355,25 +347,12 @@ public class JRFillLinePlot extends JRFillChartPlot implements JRLinePlot
 		return ((JRLinePlot)parent).getShowShapes();
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #setShowShapes(Boolean)}
-	 */
-	public void setShowShapes( boolean value ){
-	}
-	
 	/**
 	 *
 	 */
 	public void setShowShapes( Boolean value ){
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #getShowLines()}
-	 */
-	public boolean isShowLines(){
-		return ((JRLinePlot)parent).isShowLines();
-	}
-	
 	/**
 	 *
 	 */
@@ -381,12 +360,6 @@ public class JRFillLinePlot extends JRFillChartPlot implements JRLinePlot
 		return ((JRLinePlot)parent).getShowLines();
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #setShowLines(Boolean)}
-	 */
-	public void setShowLines( boolean value ){
-	}
-	
 	/**
 	 *
 	 */
