@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -38,7 +38,7 @@ import net.sf.jasperreports.engine.fill.JRFillObjectFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillPieSeries.java 3938 2010-08-19 14:59:36Z teodord $
+ * @version $Id: JRFillPieSeries.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRFillPieSeries implements JRPieSeries
 {
@@ -48,7 +48,7 @@ public class JRFillPieSeries implements JRPieSeries
 	 */
 	protected JRPieSeries parent;
 
-	private Comparable key;
+	private Comparable<?> key;
 	private Number value;
 	private String label;
 	private JRPrintHyperlink sectionHyperlink;
@@ -96,7 +96,7 @@ public class JRFillPieSeries implements JRPieSeries
 	/**
 	 *
 	 */
-	protected Comparable getKey()
+	protected Comparable<?> getKey()
 	{
 		return key;
 	}
@@ -131,7 +131,7 @@ public class JRFillPieSeries implements JRPieSeries
 	 */
 	protected void evaluate(JRCalculator calculator) throws JRExpressionEvalException
 	{
-		key = (Comparable)calculator.evaluate(getKeyExpression()); 
+		key = (Comparable<?>)calculator.evaluate(getKeyExpression()); 
 		value = (Number)calculator.evaluate(getValueExpression());
 		label = (String)calculator.evaluate(getLabelExpression());
 		
