@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -40,7 +40,7 @@ import net.sf.jasperreports.engine.fill.JRFillObjectFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillTimeSeries.java 3032 2009-08-27 11:32:28Z teodord $
+ * @version $Id: JRFillTimeSeries.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRFillTimeSeries implements JRTimeSeries
 {
@@ -48,12 +48,12 @@ public class JRFillTimeSeries implements JRTimeSeries
 	/**
 	 *
 	 */
-	protected JRTimeSeries parent = null;
+	protected JRTimeSeries parent;
 
-	private Comparable series = null;
-	private Date timePeriod = null;
-	private Number value = null;
-	private String label = null;
+	private Comparable<?> series;
+	private Date timePeriod;
+	private Number value;
+	private String label;
 	private JRPrintHyperlink itemHyperlink;
 	
 	
@@ -107,7 +107,7 @@ public class JRFillTimeSeries implements JRTimeSeries
 	/**
 	 *
 	 */
-	protected Comparable getSeries()
+	protected Comparable<?> getSeries()
 	{
 		return series;
 	}
@@ -142,7 +142,7 @@ public class JRFillTimeSeries implements JRTimeSeries
 	 */
 	protected void evaluate(JRCalculator calculator) throws JRExpressionEvalException
 	{
-		series = (Comparable)calculator.evaluate(getSeriesExpression()); 
+		series = (Comparable<?>)calculator.evaluate(getSeriesExpression()); 
 		timePeriod = (Date)calculator.evaluate(getTimePeriodExpression()); 
 		value = (Number)calculator.evaluate(getValueExpression());
 		label = (String)calculator.evaluate(getLabelExpression());
