@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -28,14 +28,13 @@ import java.awt.Color;
 import net.sf.jasperreports.charts.JRTimeSeriesPlot;
 import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRFont;
-import net.sf.jasperreports.engine.base.JRBaseFont;
 import net.sf.jasperreports.engine.fill.JRFillChartPlot;
 import net.sf.jasperreports.engine.fill.JRFillObjectFactory;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 /**
  * @author Flavius Sana (flavius_sana@users.sourceforge.net)
- * @version $Id: JRFillTimeSeriesPlot.java 3179 2009-10-30 10:03:01Z teodord $
+ * @version $Id: JRFillTimeSeriesPlot.java 4595 2011-09-08 15:55:10Z teodord $
  */
 
 public class JRFillTimeSeriesPlot extends JRFillChartPlot implements JRTimeSeriesPlot {
@@ -43,34 +42,35 @@ public class JRFillTimeSeriesPlot extends JRFillChartPlot implements JRTimeSerie
 	/**
 	 *
 	 */
-	protected JRFont timeAxisLabelFont = null;
-	protected Color timeAxisLabelColor = null;
-	protected JRFont timeAxisTickLabelFont = null;
-	protected Color timeAxisTickLabelColor = null;
-	protected Color timeAxisLineColor = null;
+	protected JRFont timeAxisLabelFont;
+	protected Color timeAxisLabelColor;
+	protected JRFont timeAxisTickLabelFont;
+	protected Color timeAxisTickLabelColor;
+	protected Color timeAxisLineColor;
 
-	protected JRFont valueAxisLabelFont = null;
-	protected Color valueAxisLabelColor = null;
-	protected JRFont valueAxisTickLabelFont = null;
-	protected Color valueAxisTickLabelColor = null;
-	protected Color valueAxisLineColor = null;
+	protected JRFont valueAxisLabelFont;
+	protected Color valueAxisLabelColor;
+	protected JRFont valueAxisTickLabelFont;
+	protected Color valueAxisTickLabelColor;
+	protected Color valueAxisLineColor;
 
 	
 	/**
 	 *
 	 */
-	public JRFillTimeSeriesPlot( JRTimeSeriesPlot plot, JRFillObjectFactory factory ){
-		super( plot, factory );
+	public JRFillTimeSeriesPlot( JRTimeSeriesPlot plot, JRFillObjectFactory factory )
+	{
+		super(plot, factory);
 
-		timeAxisLabelFont = new JRBaseFont(plot.getChart(), plot.getTimeAxisLabelFont());
+		timeAxisLabelFont = factory.getFont(plot.getChart(), plot.getTimeAxisLabelFont());
 		timeAxisLabelColor = plot.getOwnTimeAxisLabelColor();
-		timeAxisTickLabelFont = new JRBaseFont(plot.getChart(), plot.getTimeAxisTickLabelFont());
+		timeAxisTickLabelFont = factory.getFont(plot.getChart(), plot.getTimeAxisTickLabelFont());
 		timeAxisTickLabelColor = plot.getOwnTimeAxisTickLabelColor();
 		timeAxisLineColor = plot.getOwnTimeAxisLineColor();
 		
-		valueAxisLabelFont = new JRBaseFont(plot.getChart(), plot.getValueAxisLabelFont());
+		valueAxisLabelFont = factory.getFont(plot.getChart(), plot.getValueAxisLabelFont());
 		valueAxisLabelColor = plot.getOwnValueAxisLabelColor();
-		valueAxisTickLabelFont = new JRBaseFont(plot.getChart(), plot.getValueAxisTickLabelFont());
+		valueAxisTickLabelFont = factory.getFont(plot.getChart(), plot.getValueAxisTickLabelFont());
 		valueAxisTickLabelColor = plot.getOwnValueAxisTickLabelColor();
 		valueAxisLineColor = plot.getOwnValueAxisTickLabelColor();
 	}
@@ -318,31 +318,6 @@ public class JRFillTimeSeriesPlot extends JRFillChartPlot implements JRTimeSerie
 		return valueAxisLineColor;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getShowLines()}
-	 */
-	public boolean isShowLines(){
-		return ((JRTimeSeriesPlot)parent).isShowLines();
-	}
-	
-	/**
-	 * @deprecated Replaced by {@link #setShowLines(Boolean)}
-	 */
-	public void setShowLines(){
-	}
-	
-	/**
-	 * @deprecated Replaced by {@link #getShowShapes()}
-	 */
-	public boolean isShowShapes(){
-		return ((JRTimeSeriesPlot)parent).isShowShapes();
-	}
-	
-	/**
-	 * @deprecated Replaced by {@link #setShowShapes(Boolean)}
-	 */
-	public void setShowShapes(){
-	}
 	/**
 	 * 
 	 */
