@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -37,16 +37,16 @@ import net.sf.jasperreports.engine.fill.JRFillObjectFactory;
 
 /**
  * @author Flavius Sana (flavius_sana@users.sourceforge.net)
- * @version $Id: JRFillXyzSeries.java 3032 2009-08-27 11:32:28Z teodord $
+ * @version $Id: JRFillXyzSeries.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRFillXyzSeries implements JRXyzSeries {
 	
-	JRXyzSeries parent = null;
+	JRXyzSeries parent;
 	
-	private Comparable series = null;
-	private Number xValue = null;
-	private Number yValue = null;
-	private Number zValue = null;
+	private Comparable<?> series;
+	private Number xValue;
+	private Number yValue;
+	private Number zValue;
 	private JRPrintHyperlink itemHyperlink;
 	
 	public JRFillXyzSeries( JRXyzSeries xyzSeries, JRFillObjectFactory factory ){
@@ -71,7 +71,7 @@ public class JRFillXyzSeries implements JRXyzSeries {
 	}
 	
 	
-	protected Comparable getSeries(){
+	protected Comparable<?> getSeries(){
 		return series;
 	}
 	
@@ -93,7 +93,7 @@ public class JRFillXyzSeries implements JRXyzSeries {
 	}
 	
 	protected void evaluate( JRCalculator calculator ) throws JRExpressionEvalException {
-		series = (Comparable)calculator.evaluate( getSeriesExpression() );
+		series = (Comparable<?>)calculator.evaluate( getSeriesExpression() );
 		xValue = (Number)calculator.evaluate( getXValueExpression() );
 		yValue = (Number)calculator.evaluate( getYValueExpression() );
 		zValue = (Number)calculator.evaluate( getZValueExpression() );
