@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -28,32 +28,33 @@ import java.util.Map;
 import net.sf.jasperreports.engine.JRConstants;
 
 import org.jfree.chart.labels.StandardXYItemLabelGenerator;
+import org.jfree.data.time.TimePeriod;
 import org.jfree.data.time.TimePeriodValuesCollection;
 import org.jfree.data.xy.XYDataset;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: TimePeriodDatasetLabelGenerator.java 3032 2009-08-27 11:32:28Z teodord $
+ * @version $Id: TimePeriodDatasetLabelGenerator.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class TimePeriodDatasetLabelGenerator extends StandardXYItemLabelGenerator 
 {
 	private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 	
-	private Map labelsMap = null;
+	private Map<Comparable<?>, Map<TimePeriod, String>> labelsMap;
 	
-	public TimePeriodDatasetLabelGenerator(Map labelsMap)
+	public TimePeriodDatasetLabelGenerator(Map<Comparable<?>, Map<TimePeriod, String>> labelsMap)
 	{
 		this.labelsMap = labelsMap;
 	}
 	
 	public String generateLabel(XYDataset dataset, int series, int item)
 	{
-		Comparable seriesName = dataset.getSeriesKey(series);
-		Map labels = (Map)labelsMap.get(seriesName);
+		Comparable<?> seriesName = dataset.getSeriesKey(series);
+		Map<TimePeriod, String> labels = labelsMap.get(seriesName);
 		if(labels != null)
 		{
-			return (String)labels.get(((TimePeriodValuesCollection)dataset).getSeries(series).getTimePeriod(item));
+			return labels.get(((TimePeriodValuesCollection)dataset).getSeries(series).getTimePeriod(item));
 		}
 		return super.generateLabel( dataset, series, item );
 	}
