@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -33,7 +33,6 @@ import groovyjarjarasm.asm.ClassWriter;
 
 import java.io.ByteArrayInputStream;
 import java.io.File;
-import java.io.Serializable;
 import java.io.UnsupportedEncodingException;
 import java.util.HashMap;
 import java.util.Map;
@@ -57,7 +56,7 @@ import org.codehaus.groovy.control.Phases;
  * Calculator compiler that uses groovy to compile expressions.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net), Peter Severin (peter_p_s@users.sourceforge.net)
- * @version $Id: JRGroovyCompiler.java 3837 2010-05-31 06:55:21Z lucianc $
+ * @version $Id: JRGroovyCompiler.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRGroovyCompiler extends JRAbstractJavaCompiler 
 {
@@ -119,7 +118,7 @@ public class JRGroovyCompiler extends JRAbstractJavaCompiler
 		
 		for (int i = 0; i < units.length; i++)
 		{
-			units[i].setCompileData((Serializable) collector.classes.get(units[i].getName()));
+			units[i].setCompileData(collector.classes.get(units[i].getName()));
 		}
 		
 		return null;
@@ -131,7 +130,7 @@ public class JRGroovyCompiler extends JRAbstractJavaCompiler
 	 */
 	private static class ClassCollector extends CompilationUnit.ClassgenCallback 
 	{
-		public Map classes = new HashMap();
+		public Map<String, byte[]> classes = new HashMap<String, byte[]>();
 		public int classCount;
 	
 		/**
