@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -48,7 +48,7 @@ import org.mozilla.javascript.ScriptableObject;
  * JavaScript expression evaluator.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JavaScriptEvaluator.java 3717 2010-04-09 10:01:33Z teodord $
+ * @version $Id: JavaScriptEvaluator.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JavaScriptEvaluator extends JREvaluator
 {
@@ -199,8 +199,7 @@ public class JavaScriptEvaluator extends JREvaluator
 			}
 		}
 		
-		return new JavaScriptCompileData.Expression(expression.getValueClassName(),
-				defaultExpr.toString(), estimatedExpr.toString(), oldExpr.toString());
+		return new JavaScriptCompileData.Expression(defaultExpr.toString(), estimatedExpr.toString(), oldExpr.toString());
 	}
 
 	protected static String getParameterVar(String name)
@@ -221,8 +220,8 @@ public class JavaScriptEvaluator extends JREvaluator
 	private final JavaScriptCompileData compileData;
 	private Context context;
 	private ScriptableObject scope;
-	private Map loadedTypes = new HashMap();
-	private Map compiledExpressions = new HashMap();
+	private Map<String, Class<?>> loadedTypes = new HashMap<String, Class<?>>();
+	private Map<String, Script> compiledExpressions = new HashMap<String, Script>();
 
 	/**
 	 * Create a JavaScript expression evaluator.
@@ -234,38 +233,41 @@ public class JavaScriptEvaluator extends JREvaluator
 		this.compileData = compileData;
 	}
 
-	protected void customizedInit(Map parametersMap, Map fieldsMap,
-			Map variablesMap) throws JRException
+	protected void customizedInit(
+			Map<String, JRFillParameter> parametersMap, 
+			Map<String, JRFillField> fieldsMap,
+			Map<String, JRFillVariable> variablesMap
+			) throws JRException
 	{
 		context = ContextFactory.getGlobal().enterContext();//TODO exit context
 		context.getWrapFactory().setJavaPrimitiveWrap(false);
 		scope = context.initStandardObjects();
 		
-		for (Iterator it = parametersMap.entrySet().iterator(); it.hasNext();)
+		for (Iterator<Map.Entry<String, JRFillParameter>> it = parametersMap.entrySet().iterator(); it.hasNext();)
 		{
-			Map.Entry entry = (Map.Entry) it.next();
-			String name = (String) entry.getKey();
-			JRFillParameter param = (JRFillParameter) entry.getValue();
+			Map.Entry<String, JRFillParameter> entry = it.next();
+			String name = entry.getKey();
+			JRFillParameter param = entry.getValue();
 			JSParameter jsParam = new JSParameter(param, scope);
 			scope.put(getParameterVar(name), scope, jsParam);
 		}
 
-		for (Iterator it = variablesMap.entrySet().iterator(); it.hasNext();)
+		for (Iterator<Map.Entry<String, JRFillVariable>> it = variablesMap.entrySet().iterator(); it.hasNext();)
 		{
-			Map.Entry entry = (Map.Entry) it.next();
-			String name = (String) entry.getKey();
-			JRFillVariable var = (JRFillVariable) entry.getValue();
+			Map.Entry<String, JRFillVariable> entry = it.next();
+			String name = entry.getKey();
+			JRFillVariable var = entry.getValue();
 			JSVariable jsVar = new JSVariable(var, scope);
 			scope.put(getVariableVar(name), scope, jsVar);
 		}
 
 		if (fieldsMap != null)
 		{
-			for (Iterator it = fieldsMap.entrySet().iterator(); it.hasNext();)
+			for (Iterator<Map.Entry<String, JRFillField>> it = fieldsMap.entrySet().iterator(); it.hasNext();)
 			{
-				Map.Entry entry = (Map.Entry) it.next();
-				String name = (String) entry.getKey();
-				JRFillField field = (JRFillField) entry.getValue();
+				Map.Entry<String, JRFillField> entry = it.next();
+				String name = entry.getKey();
+				JRFillField field = entry.getValue();
 				JSField jsField = new JSField(field, scope);
 				scope.put(getFieldVar(name), scope, jsField);
 			}
@@ -275,22 +277,19 @@ public class JavaScriptEvaluator extends JREvaluator
 	protected Object evaluate(int id) throws Throwable //NOSONAR
 	{
 		JavaScriptCompileData.Expression expression = getExpression(id);
-		return evaluateExpression(expression.getJavaType(), 
-				expression.getDefaultExpression());
+		return evaluateExpression(expression.getDefaultExpression());
 	}
 
 	protected Object evaluateEstimated(int id) throws Throwable //NOSONAR
 	{
 		JavaScriptCompileData.Expression expression = getExpression(id);
-		return evaluateExpression(expression.getJavaType(), 
-				expression.getEstimatedExpression());
+		return evaluateExpression(expression.getEstimatedExpression());
 	}
 
 	protected Object evaluateOld(int id) throws Throwable //NOSONAR
 	{
 		JavaScriptCompileData.Expression expression = getExpression(id);
-		return evaluateExpression(expression.getJavaType(), 
-				expression.getOldExpression());
+		return evaluateExpression(expression.getOldExpression());
 	}
 
 	protected JavaScriptCompileData.Expression getExpression(int id)
@@ -298,16 +297,23 @@ public class JavaScriptEvaluator extends JREvaluator
 		return compileData.getExpression(id);
 	}
 	
+	/**
+	 * @deprecated Replaced by {@link #evaluateExpression(String)}.
+	 */
 	protected Object evaluateExpression(String type, String expression)
+	{
+		return evaluateExpression(expression);
+	}
+	
+	protected Object evaluateExpression(String expression)
 	{
 		Script compiledExpression = getCompiledExpression(expression);
 		Object value = compiledExpression.exec(context, scope);
 		
-		Class typeClass = getTypeClass(type);
 		Object javaValue;
 		try
 		{
-			javaValue = Context.jsToJava(value, typeClass);
+			javaValue = Context.jsToJava(value, Object.class);
 		}
 		catch (EvaluatorException e)
 		{
@@ -318,7 +324,7 @@ public class JavaScriptEvaluator extends JREvaluator
 	
 	protected Script getCompiledExpression(String expression)
 	{
-		Script compiledExpression = (Script) compiledExpressions.get(expression);
+		Script compiledExpression = compiledExpressions.get(expression);
 		if (compiledExpression == null)
 		{
 			compiledExpression = context.compileString(expression, "expression", 0, null);
@@ -327,9 +333,12 @@ public class JavaScriptEvaluator extends JREvaluator
 		return compiledExpression;
 	}
 	
-	protected Class getTypeClass(String type)
+	/**
+	 * @deprecated To be removed.
+	 */
+	protected Class<?> getTypeClass(String type)
 	{
-		Class typeClass = (Class) loadedTypes.get(type);
+		Class<?> typeClass = loadedTypes.get(type);
 		if (typeClass == null)
 		{
 			try
@@ -344,4 +353,5 @@ public class JavaScriptEvaluator extends JREvaluator
 		}
 		return typeClass;
 	}
+
 }
