@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,15 +17,13 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
 package net.sf.jasperreports.components;
 
-import java.util.Collections;
 import java.util.HashMap;
-import java.util.List;
 
 import net.sf.jasperreports.components.barbecue.BarbecueCompiler;
 import net.sf.jasperreports.components.barbecue.BarbecueDesignConverter;
@@ -37,18 +35,27 @@ import net.sf.jasperreports.components.list.FillListFactory;
 import net.sf.jasperreports.components.list.ListComponent;
 import net.sf.jasperreports.components.list.ListComponentCompiler;
 import net.sf.jasperreports.components.list.ListDesignConverter;
+import net.sf.jasperreports.components.map.MapCompiler;
+import net.sf.jasperreports.components.map.MapDesignConverter;
+import net.sf.jasperreports.components.map.MapFillFactory;
+import net.sf.jasperreports.components.sort.SortComponentCompiler;
+import net.sf.jasperreports.components.sort.SortComponentDesignConverter;
+import net.sf.jasperreports.components.sort.SortComponentFillFactory;
 import net.sf.jasperreports.components.spiderchart.SpiderChartCompiler;
 import net.sf.jasperreports.components.spiderchart.SpiderChartDesignConverter;
 import net.sf.jasperreports.components.spiderchart.SpiderChartFillFactory;
 import net.sf.jasperreports.components.table.FillTableFactory;
 import net.sf.jasperreports.components.table.TableCompiler;
+import net.sf.jasperreports.components.table.TableDesignConverter;
 import net.sf.jasperreports.engine.JRPropertiesMap;
+import net.sf.jasperreports.engine.component.ComponentManager;
 import net.sf.jasperreports.engine.component.ComponentsBundle;
 import net.sf.jasperreports.engine.component.DefaultComponentManager;
 import net.sf.jasperreports.engine.component.DefaultComponentXmlParser;
 import net.sf.jasperreports.engine.component.DefaultComponentsBundle;
 import net.sf.jasperreports.extensions.ExtensionsRegistry;
 import net.sf.jasperreports.extensions.ExtensionsRegistryFactory;
+import net.sf.jasperreports.extensions.SingletonExtensionRegistry;
 
 /**
  * Extension registry factory that includes built-in component element
@@ -58,7 +65,7 @@ import net.sf.jasperreports.extensions.ExtensionsRegistryFactory;
  * This registry factory is registered by default in JasperReports.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: ComponentsExtensionsRegistryFactory.java 3901 2010-07-19 12:40:55Z shertage $
+ * @version $Id: ComponentsExtensionsRegistryFactory.java 4595 2011-09-08 15:55:10Z teodord $
  * @see ListComponent
  */
 public class ComponentsExtensionsRegistryFactory implements
@@ -80,6 +87,8 @@ public class ComponentsExtensionsRegistryFactory implements
 		"UPCA", "UPCE", "EAN13", "EAN8", "USPSIntelligentMail", "RoyalMailCustomer", 
 		"POSTNET", "PDF417"};
 	protected static final String SPIDERCHART_COMPONENT_NAME = "spiderChart";
+	protected static final String MAP_COMPONENT_NAME = "map";
+	protected static final String SORT_COMPONENT_NAME = "sort";
 	
 	private static final ExtensionsRegistry REGISTRY;
 	
@@ -96,7 +105,7 @@ public class ComponentsExtensionsRegistryFactory implements
 		parser.setDigesterConfigurer(xmlHandler);
 		bundle.setXmlParser(parser);
 		
-		HashMap componentManagers = new HashMap();
+		HashMap<String, ComponentManager> componentManagers = new HashMap<String, ComponentManager>();
 		
 		DefaultComponentManager listManager = new DefaultComponentManager();
 		listManager.setDesignConverter(new ListDesignConverter());
@@ -106,6 +115,7 @@ public class ComponentsExtensionsRegistryFactory implements
 		componentManagers.put(LIST_COMPONENT_NAME, listManager);
 		
 		DefaultComponentManager tableManager = new DefaultComponentManager();
+		tableManager.setDesignConverter(new TableDesignConverter());
 		tableManager.setComponentCompiler(new TableCompiler());
 		tableManager.setComponentXmlWriter(xmlHandler);
 		tableManager.setComponentFillFactory(new FillTableFactory());
@@ -135,20 +145,23 @@ public class ComponentsExtensionsRegistryFactory implements
 		spiderChartManager.setComponentFillFactory(new SpiderChartFillFactory());
 		componentManagers.put(SPIDERCHART_COMPONENT_NAME, spiderChartManager);
 		
+		DefaultComponentManager mapManager = new DefaultComponentManager();
+		mapManager.setDesignConverter(MapDesignConverter.getInstance());
+		mapManager.setComponentCompiler(new MapCompiler());
+		mapManager.setComponentXmlWriter(xmlHandler);
+		mapManager.setComponentFillFactory(new MapFillFactory());
+		componentManagers.put(MAP_COMPONENT_NAME, mapManager);
+
+		DefaultComponentManager sortManager = new DefaultComponentManager();
+		sortManager.setDesignConverter(SortComponentDesignConverter.getInstance());
+		sortManager.setComponentCompiler(new SortComponentCompiler());
+		sortManager.setComponentXmlWriter(xmlHandler);
+		sortManager.setComponentFillFactory(new SortComponentFillFactory());
+		componentManagers.put(SORT_COMPONENT_NAME, sortManager);
+		
 		bundle.setComponentManagers(componentManagers);
 		
-		REGISTRY = new ExtensionsRegistry()
-		{
-			public List getExtensions(Class extensionType)
-			{
-				if (ComponentsBundle.class.equals(extensionType))
-				{
-					return Collections.singletonList(bundle);
-				}
-				
-				return null;
-			}
-		};
+		REGISTRY = new SingletonExtensionRegistry<ComponentsBundle>(ComponentsBundle.class, bundle);
 	}
 	
 	public ExtensionsRegistry createRegistry(String registryId,
