@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -26,8 +26,6 @@ package net.sf.jasperreports.components;
 import java.io.IOException;
 import java.util.List;
 
-import net.sf.jasperreports.charts.design.JRDesignCategorySeries;
-import net.sf.jasperreports.charts.xml.JRCategorySeriesFactory;
 import net.sf.jasperreports.components.barbecue.BarbecueComponent;
 import net.sf.jasperreports.components.barbecue.StandardBarbecueComponent;
 import net.sf.jasperreports.components.barcode4j.BarcodeComponent;
@@ -50,15 +48,14 @@ import net.sf.jasperreports.components.list.DesignListContents;
 import net.sf.jasperreports.components.list.ListComponent;
 import net.sf.jasperreports.components.list.ListContents;
 import net.sf.jasperreports.components.list.StandardListComponent;
-import net.sf.jasperreports.components.spiderchart.ChartSettings;
-import net.sf.jasperreports.components.spiderchart.ChartSettingsXmlFactory;
+import net.sf.jasperreports.components.map.MapComponent;
+import net.sf.jasperreports.components.map.StandardMapComponent;
+import net.sf.jasperreports.components.sort.SortComponent;
+import net.sf.jasperreports.components.sort.SortComponentDigester;
+import net.sf.jasperreports.components.sort.SortComponentXmlWriter;
 import net.sf.jasperreports.components.spiderchart.SpiderChartComponent;
-import net.sf.jasperreports.components.spiderchart.SpiderChartXmlFactory;
+import net.sf.jasperreports.components.spiderchart.SpiderChartDigester;
 import net.sf.jasperreports.components.spiderchart.SpiderChartXmlWriter;
-import net.sf.jasperreports.components.spiderchart.SpiderDataset;
-import net.sf.jasperreports.components.spiderchart.SpiderDatasetXmlFactory;
-import net.sf.jasperreports.components.spiderchart.SpiderPlot;
-import net.sf.jasperreports.components.spiderchart.SpiderPlotXmlFactory;
 import net.sf.jasperreports.components.table.BaseColumn;
 import net.sf.jasperreports.components.table.Cell;
 import net.sf.jasperreports.components.table.Column;
@@ -69,28 +66,26 @@ import net.sf.jasperreports.components.table.GroupCell;
 import net.sf.jasperreports.components.table.StandardColumn;
 import net.sf.jasperreports.components.table.StandardColumnGroup;
 import net.sf.jasperreports.components.table.StandardGroupCell;
-import net.sf.jasperreports.components.table.StandardTable;
+import net.sf.jasperreports.components.table.StandardTableFactory;
 import net.sf.jasperreports.components.table.TableComponent;
 import net.sf.jasperreports.components.table.TableReportContextXmlRule;
+import net.sf.jasperreports.components.table.WhenNoDataTypeTableEnum;
 import net.sf.jasperreports.engine.JRExpression;
-import net.sf.jasperreports.engine.JRFont;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.component.Component;
 import net.sf.jasperreports.engine.component.ComponentKey;
 import net.sf.jasperreports.engine.component.ComponentXmlWriter;
 import net.sf.jasperreports.engine.component.XmlDigesterConfigurer;
-import net.sf.jasperreports.engine.design.JRDesignExpression;
 import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
 import net.sf.jasperreports.engine.type.PrintOrderEnum;
+import net.sf.jasperreports.engine.type.RotationEnum;
 import net.sf.jasperreports.engine.util.JRXmlWriteHelper;
 import net.sf.jasperreports.engine.util.XmlNamespace;
-import net.sf.jasperreports.engine.xml.JRElementDatasetFactory;
 import net.sf.jasperreports.engine.xml.JRExpressionFactory;
-import net.sf.jasperreports.engine.xml.JRFontFactory;
+import net.sf.jasperreports.engine.xml.JRXmlConstants;
 import net.sf.jasperreports.engine.xml.JRXmlWriter;
 import net.sf.jasperreports.engine.xml.StyleContainerRule;
 import net.sf.jasperreports.engine.xml.XmlConstantPropertyRule;
-import net.sf.jasperreports.engine.xml.JRXmlConstants;
 
 import org.apache.commons.digester.Digester;
 
@@ -98,7 +93,7 @@ import org.apache.commons.digester.Digester;
  * XML handler (digester + writer) for built-in component implementations.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: ComponentsXmlHandler.java 3901 2010-07-19 12:40:55Z shertage $
+ * @version $Id: ComponentsXmlHandler.java 4595 2011-09-08 15:55:10Z teodord $
  * @see ComponentsExtensionsRegistryFactory
  */
 public class ComponentsXmlHandler implements XmlDigesterConfigurer, ComponentXmlWriter
@@ -110,7 +105,9 @@ public class ComponentsXmlHandler implements XmlDigesterConfigurer, ComponentXml
 		addBarbecueRules(digester);
 		addBarcode4jRules(digester);
 		addTableRules(digester);
-		addSpiderChartRules(digester);
+		SpiderChartDigester.addSpiderChartRules(digester);
+		addMapRules(digester);
+		SortComponentDigester.addSortComponentRules(digester);
 	}
 
 	protected void addListRules(Digester digester)
@@ -136,12 +133,16 @@ public class ComponentsXmlHandler implements XmlDigesterConfigurer, ComponentXml
 		digester.addObjectCreate(barcodePattern, StandardBarbecueComponent.class);
 		digester.addSetProperties(barcodePattern,
 				//properties to be ignored by this rule
-				new String[]{JRXmlConstants.ATTRIBUTE_evaluationTime}, 
+				new String[]{JRXmlConstants.ATTRIBUTE_evaluationTime, StandardBarbecueComponent.PROPERTY_ROTATION}, 
 				new String[0]);
 		digester.addRule(barcodePattern, 
 				new XmlConstantPropertyRule(
 						JRXmlConstants.ATTRIBUTE_evaluationTime, "evaluationTimeValue",
 						EvaluationTimeEnum.values()));
+		digester.addRule(barcodePattern, 
+				new XmlConstantPropertyRule(
+						StandardBarbecueComponent.PROPERTY_ROTATION,
+						RotationEnum.values()));
 
 		String barcodeExpressionPattern = barcodePattern + "/codeExpression";
 		digester.addFactoryCreate(barcodeExpressionPattern, 
@@ -198,8 +199,8 @@ public class ComponentsXmlHandler implements XmlDigesterConfigurer, ComponentXml
 				"*/componentElement/PDF417", PDF417Component.class);
 	}
 	
-	protected void addBaseBarcode4jRules(Digester digester, 
-			String barcodePattern, Class barcodeComponentClass)
+	protected <T> void addBaseBarcode4jRules(Digester digester, 
+			String barcodePattern, Class<T> barcodeComponentClass)
 	{
 		digester.addObjectCreate(barcodePattern, barcodeComponentClass);
 		digester.addSetProperties(barcodePattern,
@@ -227,10 +228,46 @@ public class ComponentsXmlHandler implements XmlDigesterConfigurer, ComponentXml
 				JRExpression.class.getName());
 	}
 
+	protected void addMapRules(Digester digester)
+	{
+		String mapPattern = "*/componentElement/map";
+		digester.addObjectCreate(mapPattern, StandardMapComponent.class);
+		digester.addSetProperties(mapPattern,
+			//properties to be ignored by this rule
+			new String[]{JRXmlConstants.ATTRIBUTE_evaluationTime}, 
+			new String[0]);
+		digester.addRule(mapPattern, 
+			new XmlConstantPropertyRule(
+				JRXmlConstants.ATTRIBUTE_evaluationTime, "evaluationTime",
+				EvaluationTimeEnum.values()));
+
+		String latitudeExpressionPattern = mapPattern + "/latitudeExpression";
+		digester.addFactoryCreate(latitudeExpressionPattern, 
+				JRExpressionFactory.class.getName());
+		digester.addCallMethod(latitudeExpressionPattern, "setText", 0);
+		digester.addSetNext(latitudeExpressionPattern, "setLatitudeExpression", 
+				JRExpression.class.getName());
+
+		String longitudeExpressionPattern = mapPattern + "/longitudeExpression";
+		digester.addFactoryCreate(longitudeExpressionPattern, 
+				JRExpressionFactory.class.getName());
+		digester.addCallMethod(longitudeExpressionPattern, "setText", 0);
+		digester.addSetNext(longitudeExpressionPattern, "setLongitudeExpression", 
+				JRExpression.class.getName());
+		
+		String zoomExpressionPattern = mapPattern + "/zoomExpression";
+		digester.addFactoryCreate(zoomExpressionPattern, 
+				JRExpressionFactory.class.getName());
+		digester.addCallMethod(zoomExpressionPattern, "setText", 0);
+		digester.addSetNext(zoomExpressionPattern, "setZoomExpression", 
+				JRExpression.class.getName());
+	}
+
 	protected void addTableRules(Digester digester)
 	{
 		String tablePattern = "*/componentElement/table";
-		digester.addObjectCreate(tablePattern, StandardTable.class);
+		//digester.addObjectCreate(tablePattern, StandardTable.class);
+		digester.addFactoryCreate(tablePattern, StandardTableFactory.class.getName());
 		
 		String columnPattern = "*/column";
 		digester.addObjectCreate(columnPattern, StandardColumn.class);
@@ -285,8 +322,8 @@ public class ComponentsXmlHandler implements XmlDigesterConfigurer, ComponentXml
 		digester.addSetNext(pattern, setNextMethod);
 	}
 
-	protected void addExpressionRules(Digester digester, String expressionPattern,
-			Class factoryClass, String setterMethod, boolean jrNamespace)
+	protected <T> void addExpressionRules(Digester digester, String expressionPattern,
+			Class<T> factoryClass, String setterMethod, boolean jrNamespace)
 	{
 		String originalNamespace = digester.getRuleNamespaceURI();
 		if (jrNamespace)
@@ -336,6 +373,17 @@ public class ComponentsXmlHandler implements XmlDigesterConfigurer, ComponentXml
 			SpiderChartXmlWriter spiderChartWriter = new SpiderChartXmlWriter();
 			spiderChartWriter.writeToXml(componentKey, spiderChart, reportWriter);
 		}
+		else if (component instanceof SortComponent)
+		{
+			SortComponentXmlWriter sortWriter = new SortComponentXmlWriter();
+			sortWriter.writeToXml(componentKey, component, reportWriter);
+		}
+		else if (component instanceof MapComponent)
+		{
+			MapComponent map = (MapComponent) component;
+			writeMap(map, componentKey, reportWriter);
+		}
+		
 	}
 
 	protected void writeList(ListComponent list, ComponentKey componentKey,
@@ -380,6 +428,7 @@ public class ComponentsXmlHandler implements XmlDigesterConfigurer, ComponentXml
 		writer.addAttribute("checksumRequired", barcode.isChecksumRequired());
 		writer.addAttribute("barWidth", barcode.getBarWidth());
 		writer.addAttribute("barHeight", barcode.getBarHeight());
+		writer.addAttribute("rotation", barcode.getOwnRotation());
 		if (barcode.getEvaluationTimeValue() != EvaluationTimeEnum.NOW)
 		{
 			writer.addAttribute(JRXmlConstants.ATTRIBUTE_evaluationTime, 
@@ -389,9 +438,39 @@ public class ComponentsXmlHandler implements XmlDigesterConfigurer, ComponentXml
 				barcode.getEvaluationGroup());
 
 		writer.writeExpression("codeExpression", 
-				barcode.getCodeExpression(), false);
+				barcode.getCodeExpression());
 		writer.writeExpression("applicationIdentifierExpression", 
-				barcode.getApplicationIdentifierExpression(), false);
+				barcode.getApplicationIdentifierExpression());
+		
+		writer.closeElement();
+	}
+
+	protected void writeMap(MapComponent map, ComponentKey componentKey,
+			JRXmlWriter reportWriter) throws IOException
+	{
+		JRXmlWriteHelper writer = reportWriter.getXmlWriteHelper();
+		
+		XmlNamespace namespace = new XmlNamespace(
+			ComponentsExtensionsRegistryFactory.NAMESPACE, 
+			componentKey.getNamespacePrefix(),
+			ComponentsExtensionsRegistryFactory.XSD_LOCATION);
+		
+		writer.startElement("map", namespace);
+		
+		if (map.getEvaluationTime() != EvaluationTimeEnum.NOW)
+		{
+			writer.addAttribute(JRXmlConstants.ATTRIBUTE_evaluationTime, 
+				map.getEvaluationTime());
+		}
+		writer.addAttribute(JRXmlConstants.ATTRIBUTE_evaluationGroup, 
+			map.getEvaluationGroup());
+
+		writer.writeExpression("latitudeExpression", 
+			map.getLatitudeExpression());
+		writer.writeExpression("longitudeExpression", 
+				map.getLongitudeExpression());
+		writer.writeExpression("zoomExpression", 
+				map.getZoomExpression());
 		
 		writer.closeElement();
 	}
@@ -407,6 +486,7 @@ public class ComponentsXmlHandler implements XmlDigesterConfigurer, ComponentXml
 				ComponentsExtensionsRegistryFactory.XSD_LOCATION);
 		
 		writer.startElement("table", namespace);
+		writer.addAttribute(JRXmlConstants.ATTRIBUTE_whenNoDataType, table.getWhenNoDataType(), WhenNoDataTypeTableEnum.BLANK);
 		reportWriter.writeDatasetRun(table.getDatasetRun());
 		
 		ColumnVisitor<Void> columnWriter = new ColumnVisitor<Void>()
@@ -419,7 +499,7 @@ public class ComponentsXmlHandler implements XmlDigesterConfigurer, ComponentXml
 					writer.addAttribute("width", column.getWidth());
 					writer.writeExpression(JRXmlConstants.ELEMENT_printWhenExpression, 
 							JRXmlWriter.JASPERREPORTS_NAMESPACE, 
-							column.getPrintWhenExpression(), false);
+							column.getPrintWhenExpression());
 					writeTableCell(column.getTableHeader(), "tableHeader", reportWriter);
 					writeTableCell(column.getTableFooter(), "tableFooter", reportWriter);
 					writeGroupCells(column.getGroupHeaders(), "groupHeader", reportWriter);
@@ -445,7 +525,7 @@ public class ComponentsXmlHandler implements XmlDigesterConfigurer, ComponentXml
 					writer.addAttribute("width", columnGroup.getWidth());
 					writer.writeExpression(JRXmlConstants.ELEMENT_printWhenExpression, 
 							JRXmlWriter.JASPERREPORTS_NAMESPACE, 
-							columnGroup.getPrintWhenExpression(), false);
+							columnGroup.getPrintWhenExpression());
 					writeTableCell(columnGroup.getTableHeader(), "tableHeader", reportWriter);
 					writeTableCell(columnGroup.getTableFooter(), "tableFooter", reportWriter);
 					writeGroupCells(columnGroup.getGroupHeaders(), "groupHeader", reportWriter);
@@ -512,85 +592,4 @@ public class ComponentsXmlHandler implements XmlDigesterConfigurer, ComponentXml
 		}
 	}
 	
-	protected void addSpiderChartRules(Digester digester)
-	{
-		String componentNamespace = digester.getRuleNamespaceURI();
-		String jrNamespace = JRXmlConstants.JASPERREPORTS_NAMESPACE;
-		
-		String spiderChartPattern = "*/componentElement/spiderChart";
-		digester.addFactoryCreate(spiderChartPattern, SpiderChartXmlFactory.class.getName());
-		
-		String chartSettingsPattern = spiderChartPattern + "/chartSettings";
-		digester.addFactoryCreate(chartSettingsPattern, ChartSettingsXmlFactory.class.getName());
-		digester.addSetNext(chartSettingsPattern, "setChartSettings", ChartSettings.class.getName());
-
-		digester.setRuleNamespaceURI(jrNamespace);
-		String chartTitlePattern = chartSettingsPattern + "/chartTitle";
-		digester.addFactoryCreate(chartTitlePattern, ChartSettingsXmlFactory.ChartTitleFactory.class.getName());
-		digester.addFactoryCreate(chartTitlePattern + "/font", JRFontFactory.ChartFontFactory.class.getName());
-		digester.addSetNext(chartTitlePattern + "/font", "setTitleFont", JRFont.class.getName());
-		digester.addFactoryCreate(chartTitlePattern + "/titleExpression", JRExpressionFactory.StringExpressionFactory.class);
-		digester.addSetNext(chartTitlePattern + "/titleExpression", "setTitleExpression", JRDesignExpression.class.getName());
-		digester.addCallMethod(chartTitlePattern + "/titleExpression", "setText", 0);
-		
-		String chartSubtitlePattern = chartSettingsPattern + "/chartSubtitle";
-		digester.addFactoryCreate(chartSubtitlePattern, ChartSettingsXmlFactory.ChartSubtitleFactory.class.getName());
-		digester.addFactoryCreate(chartSubtitlePattern + "/font", JRFontFactory.ChartFontFactory.class.getName());
-		digester.addSetNext(chartSubtitlePattern + "/font", "setSubtitleFont", JRFont.class.getName());
-		digester.addFactoryCreate(chartSubtitlePattern + "/subtitleExpression", JRExpressionFactory.StringExpressionFactory.class);
-		digester.addSetNext(chartSubtitlePattern + "/subtitleExpression", "setSubtitleExpression", JRDesignExpression.class.getName());
-		digester.addCallMethod(chartSubtitlePattern + "/subtitleExpression", "setText", 0);
-		
-		digester.addFactoryCreate(chartSettingsPattern + "/chartLegend", ChartSettingsXmlFactory.ChartLegendFactory.class.getName());
-		digester.addFactoryCreate(chartSettingsPattern + "/chartLegend/font", JRFontFactory.ChartFontFactory.class.getName());
-		digester.addSetNext(chartSettingsPattern + "/chartLegend/font", "setLegendFont", JRFont.class.getName());
-
-		digester.setRuleNamespaceURI(componentNamespace);
-		String spiderDatasetPattern = spiderChartPattern + "/spiderDataset";
-		digester.addFactoryCreate(spiderDatasetPattern, SpiderDatasetXmlFactory.class.getName());
-		digester.addSetNext(spiderDatasetPattern, "setDataset", SpiderDataset.class.getName());
-		
-		digester.setRuleNamespaceURI(jrNamespace);
-		String datasetPattern = spiderDatasetPattern + "/dataset";
-		digester.addFactoryCreate(datasetPattern, JRElementDatasetFactory.class.getName());
-
-		String datasetIncrementWhenExpressionPath = datasetPattern + JRXmlConstants.ELEMENT_incrementWhenExpression;
-		digester.addFactoryCreate(datasetIncrementWhenExpressionPath, JRExpressionFactory.BooleanExpressionFactory.class.getName());
-		digester.addSetNext(datasetIncrementWhenExpressionPath, "setIncrementWhenExpression", JRExpression.class.getName());
-		digester.addCallMethod(datasetIncrementWhenExpressionPath, "setText", 0);
-
-		String seriesPattern = spiderDatasetPattern + "/categorySeries";
-		digester.addFactoryCreate(seriesPattern, JRCategorySeriesFactory.class.getName());
-		digester.addSetNext(seriesPattern, "addCategorySeries", JRDesignCategorySeries.class.getName());
-
-		digester.addFactoryCreate(seriesPattern + "/seriesExpression", JRExpressionFactory.ComparableExpressionFactory.class);
-		digester.addSetNext(seriesPattern + "/seriesExpression", "setSeriesExpression", JRDesignExpression.class.getName());
-		digester.addCallMethod(seriesPattern + "/seriesExpression", "setText", 0);
-		digester.addFactoryCreate(seriesPattern + "/categoryExpression", JRExpressionFactory.ComparableExpressionFactory.class);
-		digester.addSetNext(seriesPattern + "/categoryExpression", "setCategoryExpression", JRDesignExpression.class.getName());
-		digester.addCallMethod(seriesPattern + "/categoryExpression", "setText", 0);
-		digester.addFactoryCreate(seriesPattern + "/labelExpression", JRExpressionFactory.StringExpressionFactory.class);
-		digester.addSetNext(seriesPattern + "/labelExpression", "setLabelExpression", JRDesignExpression.class.getName());
-		digester.addCallMethod(seriesPattern + "/labelExpression", "setText", 0);
-		digester.addFactoryCreate(seriesPattern + "/valueExpression", JRExpressionFactory.NumberExpressionFactory.class);
-		digester.addSetNext(seriesPattern + "/valueExpression", "setValueExpression", JRDesignExpression.class.getName());
-		digester.addCallMethod(seriesPattern + "/valueExpression", "setText", 0);
-		
-		digester.setRuleNamespaceURI(componentNamespace);
-		String plotPattern = spiderChartPattern + "/spiderPlot";
-		digester.addFactoryCreate(plotPattern, SpiderPlotXmlFactory.class.getName());
-		digester.addSetNext(plotPattern, "setPlot", SpiderPlot.class.getName());
-
-		digester.setRuleNamespaceURI(jrNamespace);
-		String labelFontPattern = plotPattern + "/labelFont/font";
-		digester.addFactoryCreate(labelFontPattern, JRFontFactory.ChartFontFactory.class.getName());
-		digester.addSetNext(labelFontPattern, "setLabelFont", JRFont.class.getName());
-
-		digester.setRuleNamespaceURI(componentNamespace);
-		String maxValueExpressionPattern = plotPattern + "/maxValueExpression";
-		digester.addFactoryCreate(maxValueExpressionPattern, JRExpressionFactory.DoubleExpressionFactory.class);
-		digester.addSetNext(maxValueExpressionPattern, "setMaxValueExpression", JRDesignExpression.class.getName() );
-		digester.addCallMethod(maxValueExpressionPattern, "setText", 0 );
-	}
-	
 }
