@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,12 +35,12 @@ import net.sourceforge.barbecue.linear.ean.UCCEAN128Barcode;
 /**
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: BarcodeProviders.java 3717 2010-04-09 10:01:33Z teodord $
+ * @version $Id: BarcodeProviders.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public final class BarcodeProviders
 {
 
-	private static Map providers;
+	private static Map<String, BarcodeProvider> providers;
 
 	private static synchronized void initProviders()
 	{
@@ -49,39 +49,39 @@ public final class BarcodeProviders
 			return;
 		}
 
-		providers = new HashMap();
-        providers.put("2of7", new Barcode2of7Provider());
-        providers.put("3of9", new Barcode3of9Provider());
-        providers.put("Bookland", new BooklandProvider());
-        providers.put("Codabar", new CodabarProvider());
-        providers.put("Code128", new Code128Provider());
-        providers.put("Code128A", new Code128AProvider());
-        providers.put("Code128B", new Code128Provider());
-        providers.put("Code128C", new Code128CProvider());
-        providers.put("Code39", new Code39Provider());
-        providers.put("Code39 (Extended)", 
-        		new Code39ExtendedProvider());
-        providers.put("EAN128", new EAN128Provider());
-        providers.put("EAN13", new EAN13Provider());
-        providers.put("GlobalTradeItemNumber", 
-        		new GlobalTradeItemNumberProvider());
-        providers.put("Int2of5", new Int2of5Provider());
-        providers.put("Monarch", new MonarchProvider());
-        providers.put("NW7", new NW7Provider());
-        providers.put("PDF417", new PDF417Provider());
-        providers.put("PostNet", new PostNetProvider());
-        providers.put("RandomWeightUPCA", new RandomWeightUPCAProvider());
-        providers.put("SCC14ShippingCode", 
-        		new SCC14ShippingCodeProvider());
-        providers.put("ShipmentIdentificationNumber", 
-        		new ShipmentIdentificationNumberProvider());
-        providers.put("SSCC18", new SSCC18Provider());
-        providers.put("Std2of5", new Std2of5Provider());
-        providers.put("UCC128", new UCC128Provider());
-        providers.put("UPCA", new UPCAProvider());
-        providers.put("USD3", new USD3Provider());
-        providers.put("USD4", new USD4Provider());
-        providers.put("USPS", new USPSProvider());
+		providers = new HashMap<String, BarcodeProvider>();
+		providers.put("2of7", new Barcode2of7Provider());
+		providers.put("3of9", new Barcode3of9Provider());
+		providers.put("Bookland", new BooklandProvider());
+		providers.put("Codabar", new CodabarProvider());
+		providers.put("Code128", new Code128Provider());
+		providers.put("Code128A", new Code128AProvider());
+		providers.put("Code128B", new Code128Provider());
+		providers.put("Code128C", new Code128CProvider());
+		providers.put("Code39", new Code39Provider());
+		providers.put("Code39 (Extended)", 
+				new Code39ExtendedProvider());
+		providers.put("EAN128", new EAN128Provider());
+		providers.put("EAN13", new EAN13Provider());
+		providers.put("GlobalTradeItemNumber", 
+				new GlobalTradeItemNumberProvider());
+		providers.put("Int2of5", new Int2of5Provider());
+		providers.put("Monarch", new MonarchProvider());
+		providers.put("NW7", new NW7Provider());
+		providers.put("PDF417", new PDF417Provider());
+		providers.put("PostNet", new PostNetProvider());
+		providers.put("RandomWeightUPCA", new RandomWeightUPCAProvider());
+		providers.put("SCC14ShippingCode", 
+				new SCC14ShippingCodeProvider());
+		providers.put("ShipmentIdentificationNumber", 
+				new ShipmentIdentificationNumberProvider());
+		providers.put("SSCC18", new SSCC18Provider());
+		providers.put("Std2of5", new Std2of5Provider());
+		providers.put("UCC128", new UCC128Provider());
+		providers.put("UPCA", new UPCAProvider());
+		providers.put("USD3", new USD3Provider());
+		providers.put("USD4", new USD4Provider());
+		providers.put("USPS", new USPSProvider());
 	}
 	
 	public static boolean isTypeSupported(String type)
@@ -95,7 +95,7 @@ public final class BarcodeProviders
 	{
 		initProviders();
 		
-		BarcodeProvider provider = (BarcodeProvider) providers.get(
+		BarcodeProvider provider = providers.get(
 				barcodeInfo.getType());
 		if (provider == null)
 		{
