@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -43,14 +43,14 @@ import org.krysalis.barcode4j.impl.AbstractBarcodeBean;
 /**
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: BarcodeFillComponent.java 3505 2010-03-04 14:08:05Z teodord $
+ * @version $Id: BarcodeFillComponent.java 4648 2011-10-10 12:50:53Z lucianc $
  */
 public class BarcodeFillComponent extends BaseFillComponent
 {
 
 	private final BarcodeComponent barcodeComponent;
 	
-	private final Map printTemplates = new HashMap();
+	private final Map<JRStyle, JRTemplateImage> printTemplates = new HashMap<JRStyle, JRTemplateImage>();
 	private AbstractBarcodeBean barcode;
 	private String message;
 	
@@ -101,7 +101,7 @@ public class BarcodeFillComponent extends BaseFillComponent
 	{
 		JRTemplateImage templateImage = getTemplateImage();
 		
-		JRTemplatePrintImage image = new JRTemplatePrintImage(templateImage);
+		JRTemplatePrintImage image = new JRTemplatePrintImage(templateImage, elementId);
 		JRComponentElement element = fillContext.getComponentElement();
 		image.setX(element.getX());
 		image.setY(fillContext.getElementPrintY());
@@ -125,7 +125,7 @@ public class BarcodeFillComponent extends BaseFillComponent
 	protected JRTemplateImage getTemplateImage()
 	{
 		JRStyle elementStyle = fillContext.getElementStyle();
-		JRTemplateImage templateImage = (JRTemplateImage) printTemplates.get(elementStyle);
+		JRTemplateImage templateImage = printTemplates.get(elementStyle);
 		if (templateImage == null)
 		{
 			templateImage = new JRTemplateImage(
@@ -133,7 +133,8 @@ public class BarcodeFillComponent extends BaseFillComponent
 					fillContext.getDefaultStyleProvider());
 			templateImage.setStyle(elementStyle);
 			templateImage.setScaleImage(ScaleImageEnum.RETAIN_SHAPE);
-			
+
+			templateImage = deduplicate(templateImage);
 			printTemplates.put(elementStyle, templateImage);
 		}
 		return templateImage;
