@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,7 +35,7 @@ import org.krysalis.barcode4j.impl.datamatrix.SymbolShapeHint;
 /**
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: BarcodeVerifier.java 3505 2010-03-04 14:08:05Z teodord $
+ * @version $Id: BarcodeVerifier.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class BarcodeVerifier implements BarcodeVisitor
 {
@@ -54,37 +54,6 @@ public class BarcodeVerifier implements BarcodeVisitor
 		{
 			verifier.addBrokenRule("Barcode expression is null", barcode);
 		}
-		else
-		{
-			String valueClass = codeExpression.getValueClassName();
-			if (valueClass == null)
-			{
-				verifier.addBrokenRule("Barcode expression value class not set", codeExpression);
-			}
-			else if (!"java.lang.String".equals(valueClass))
-			{
-				verifier.addBrokenRule("Class " + valueClass 
-						+ " not supported for barcode expression. Use java.lang.String instead.",
-						codeExpression);
-			}
-		}
-		
-		JRExpression patternExpression = barcode.getPatternExpression();
-		if (patternExpression != null)
-		{
-			String valueClass = patternExpression.getValueClassName();
-			if (valueClass == null)
-			{
-				verifier.addBrokenRule("Barcode pattern expression value class not set", 
-						patternExpression);
-			}
-			else if (!"java.lang.String".equals(valueClass))
-			{
-				verifier.addBrokenRule("Class " + valueClass 
-						+ " not supported for barcode pattern expression. Use java.lang.String instead.",
-						patternExpression);
-			}
-		}
 		
 		verifyTextPosition(barcode);
 		verifyOrientation(barcode);
