@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -38,7 +38,7 @@ import org.apache.commons.logging.LogFactory;
  * Horizontal fill list component implementation.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: HorizontalFillList.java 3238 2009-12-28 15:12:33Z lucianc $
+ * @version $Id: HorizontalFillList.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class HorizontalFillList extends BaseFillList
 {
@@ -47,7 +47,7 @@ public class HorizontalFillList extends BaseFillList
 	
 	private final int contentsWidth;
 	private final boolean ignoreWidth;
-	private final List contentsList;
+	private final List<FillListContents> contentsList;
 
 	private int overflowStartPage;
 	private int overflowColumnIndex;
@@ -66,7 +66,7 @@ public class HorizontalFillList extends BaseFillList
 				createDatasetExpressionEvaluator());
 		FillListContents fillContents = new FillListContents(
 				listContents, datasetFactory);
-		this.contentsList = new ArrayList();
+		this.contentsList = new ArrayList<FillListContents>();
 		this.contentsList.add(fillContents);
 	}
 
@@ -227,6 +227,9 @@ public class HorizontalFillList extends BaseFillList
 				if (columnIndex > 0)
 				{
 					fillRow(columnIndex);
+					
+					// reset overflow column index
+					overflowColumnIndex = 0;
 				}
 				
 				if (log.isDebugEnabled())
@@ -269,8 +272,7 @@ public class HorizontalFillList extends BaseFillList
 		int rowHeight = 0;
 		for (int idx = 0; idx < columnCount; ++idx)
 		{
-			FillListContents contents = 
-				(FillListContents) contentsList.get(idx);
+			FillListContents contents = contentsList.get(idx);
 			int cellHeight = contents.getStretchHeight();
 			if (cellHeight > rowHeight)
 			{
@@ -280,8 +282,7 @@ public class HorizontalFillList extends BaseFillList
 		
 		for (int idx = 0; idx < columnCount; ++idx)
 		{
-			FillListContents contents = 
-				(FillListContents) contentsList.get(idx);
+			FillListContents contents = contentsList.get(idx);
 			// stretch all cells to row height
 			contents.stretchTo(rowHeight);
 			contents.finalizeElementPositions();
@@ -296,7 +297,7 @@ public class HorizontalFillList extends BaseFillList
 	{
 		if (columnIndex > 0 && columnIndex >= contentsList.size())
 		{
-			FillListContents template = (FillListContents) contentsList.get(0);
+			FillListContents template = contentsList.get(0);
 			for (int idx = contentsList.size(); idx <= columnIndex; idx++)
 			{
 				if (log.isDebugEnabled())
@@ -308,7 +309,7 @@ public class HorizontalFillList extends BaseFillList
 				contentsList.add(clone);
 			}
 		}
-		return (FillListContents) contentsList.get(columnIndex);
+		return contentsList.get(columnIndex);
 	}
 
 	public void rewind()
