@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,14 +17,12 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
 package net.sf.jasperreports.components.list;
 
-import java.awt.Rectangle;
-import java.awt.geom.Area;
 import java.util.Iterator;
 import java.util.List;
 
@@ -32,7 +30,6 @@ import net.sf.jasperreports.engine.JRChild;
 import net.sf.jasperreports.engine.JRComponentElement;
 import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.base.JRBasePrintFrame;
-import net.sf.jasperreports.engine.base.JRBasePrintImage;
 import net.sf.jasperreports.engine.component.ComponentDesignConverter;
 import net.sf.jasperreports.engine.convert.ConvertVisitor;
 import net.sf.jasperreports.engine.convert.ReportConverter;
@@ -42,7 +39,7 @@ import net.sf.jasperreports.engine.type.ModeEnum;
  * List preview converter.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: ListDesignConverter.java 3420 2010-02-18 09:17:47Z teodord $
+ * @version $Id: ListDesignConverter.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class ListDesignConverter implements ComponentDesignConverter
 {
@@ -71,21 +68,22 @@ public class ListDesignConverter implements ComponentDesignConverter
 			contentsFrame.setHeight(contents.getHeight());
 			contentsFrame.setMode(ModeEnum.TRANSPARENT);
 			
-			List children = contents.getChildren();
+			List<JRChild> children = contents.getChildren();
 			if (children != null)
 			{
 				ConvertVisitor contentsVisitor = new ConvertVisitor(reportConverter, 
 						contentsFrame);
-				for (Iterator it = children.iterator(); it
+				for (Iterator<JRChild> it = children.iterator(); it
 						.hasNext();)
 				{
-					JRChild child = (JRChild) it.next();
+					JRChild child = it.next();
 					child.visit(contentsVisitor);
 				}
 			}
 			
 			frame.addElement(contentsFrame);
 
+			/*
 			Integer width = contents.getWidth();
 			int contentsWidth = width == null ? element.getWidth() 
 					: width.intValue();
@@ -111,6 +109,7 @@ public class ListDesignConverter implements ComponentDesignConverter
 				image.setRenderer(new UnusedSpaceImageRenderer(clip));
 				frame.addElement(image);
 			}
+			*/
 		}
 		
 		return frame;
