@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -40,7 +40,7 @@ import net.sf.jasperreports.engine.util.JRCloneUtils;
  * Standard {@link ListComponent} implementation.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: StandardListComponent.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: StandardListComponent.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class StandardListComponent implements Serializable, ListComponent, JRChangeEventsSupport
 {
@@ -49,6 +49,7 @@ public class StandardListComponent implements Serializable, ListComponent, JRCha
 	
 	public static final String PROPERTY_PRINT_ORDER = "printOrder";
 	public static final String PROPERTY_IGNORE_WIDTH = "ignoreWidth";
+	public static final String PROPERTY_DATASET_RUN = "datasetRun";
 	
 	private JRDatasetRun datasetRun;
 	private ListContents contents;
@@ -80,7 +81,9 @@ public class StandardListComponent implements Serializable, ListComponent, JRCha
 	 */
 	public void setDatasetRun(JRDatasetRun datasetRun)
 	{
+		Object old = this.datasetRun;
 		this.datasetRun = datasetRun;
+		getEventSupport().firePropertyChange(PROPERTY_DATASET_RUN, old, this.datasetRun);
 	}
 	
 	public ListContents getContents()
@@ -101,26 +104,20 @@ public class StandardListComponent implements Serializable, ListComponent, JRCha
 	
 	public Object clone()
 	{
+		StandardListComponent clone = null;
 		try
 		{
-			StandardListComponent clone = (StandardListComponent) super.clone();
-			clone.datasetRun = (JRDatasetRun) JRCloneUtils.nullSafeClone(datasetRun);
-			clone.contents = (ListContents) JRCloneUtils.nullSafeClone(contents);
-			return clone;
+			clone = (StandardListComponent) super.clone();
 		} 
 		catch (CloneNotSupportedException e)
 		{
 			// never
 			throw new JRRuntimeException(e);
 		}
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getPrintOrderValue()}.
-	 */
-	public Byte getPrintOrder()
-	{
-		return getPrintOrderValue().getValueByte();
+		clone.datasetRun = JRCloneUtils.nullSafeClone(datasetRun);
+		clone.contents = JRCloneUtils.nullSafeClone(contents);
+		clone.eventSupport = null;
+		return clone;
 	}
 
 	/**
@@ -131,22 +128,6 @@ public class StandardListComponent implements Serializable, ListComponent, JRCha
 		return printOrderValue;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setPrintOrderValue(PrintOrderEnum)}.
-	 */
-	public void setPrintOrder(Byte printOrder)
-	{
-		setPrintOrderValue(PrintOrderEnum.getByValue(printOrder));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setPrintOrderValue(PrintOrderEnum)}.
-	 */
-	public void setPrintOrder(byte printOrder)
-	{
-		setPrintOrderValue(PrintOrderEnum.getByValue(printOrder));
-	}
-	
 	/**
 	 * Sets the list cell print order.
 	 * 
