@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -31,6 +31,7 @@ import net.sf.jasperreports.charts.fill.JRFillCategorySeries;
 import net.sf.jasperreports.charts.util.CategoryLabelGenerator;
 import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRExpressionCollector;
+import net.sf.jasperreports.engine.JRPrintHyperlink;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.fill.JRCalculator;
 import net.sf.jasperreports.engine.fill.JRExpressionEvalException;
@@ -43,7 +44,7 @@ import org.jfree.data.category.DefaultCategoryDataset;
 
 /**
  * @author sanda zaharia (shertage@users.sourceforge.net)
- * @version $Id: FillSpiderDataset.java 3877 2010-07-14 15:25:08Z shertage $
+ * @version $Id: FillSpiderDataset.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class FillSpiderDataset extends JRFillElementDataset implements SpiderDataset
 {
@@ -59,9 +60,9 @@ public class FillSpiderDataset extends JRFillElementDataset implements SpiderDat
 	protected JRFillCategorySeries[] categorySeries;
 
 	private DefaultCategoryDataset dataset;
-	private Map labelsMap;
+	private Map<Comparable<?>, Map<Comparable<?>, String>> labelsMap;
 	
-	private Map itemHyperlinks;
+	private Map<Comparable<?>,Map<Comparable<?>,JRPrintHyperlink>> itemHyperlinks;
 
 	
 	/**
@@ -130,15 +131,15 @@ public class FillSpiderDataset extends JRFillElementDataset implements SpiderDat
 			if (dataset == null)
 			{
 				dataset = new DefaultCategoryDataset();
-				labelsMap = new HashMap();
-				itemHyperlinks = new HashMap();
+				labelsMap = new HashMap<Comparable<?>, Map<Comparable<?>, String>>();
+				itemHyperlinks = new HashMap<Comparable<?>,Map<Comparable<?>,JRPrintHyperlink>>();
 			}
 			
 			for(int i = 0; i < categorySeries.length; i++)
 			{
 				JRFillCategorySeries crtCategorySeries = categorySeries[i];
 				
-				Comparable seriesName = crtCategorySeries.getSeries();
+				Comparable<?> seriesName = crtCategorySeries.getSeries();
 				if (seriesName == null)
 				{
 					throw new JRRuntimeException("Category series name is null.");
@@ -152,10 +153,10 @@ public class FillSpiderDataset extends JRFillElementDataset implements SpiderDat
 
 				if (crtCategorySeries.getLabelExpression() != null)
 				{
-					Map seriesLabels = (Map)labelsMap.get(seriesName);
+					Map<Comparable<?>, String> seriesLabels = labelsMap.get(seriesName);
 					if (seriesLabels == null)
 					{
-						seriesLabels = new HashMap();
+						seriesLabels = new HashMap<Comparable<?>, String>();
 						labelsMap.put(seriesName, seriesLabels);
 					}
 					
@@ -164,10 +165,10 @@ public class FillSpiderDataset extends JRFillElementDataset implements SpiderDat
 				
 				if (crtCategorySeries.hasItemHyperlinks())
 				{
-					Map seriesLinks = (Map) itemHyperlinks.get(seriesName);
+					Map<Comparable<?>,JRPrintHyperlink> seriesLinks = itemHyperlinks.get(seriesName);
 					if (seriesLinks == null)
 					{
-						seriesLinks = new HashMap();
+						seriesLinks = new HashMap<Comparable<?>,JRPrintHyperlink>();
 						itemHyperlinks.put(seriesName, seriesLinks);
 					}
 					seriesLinks.put(crtCategorySeries.getCategory(), crtCategorySeries.getPrintItemHyperlink());
@@ -202,7 +203,7 @@ public class FillSpiderDataset extends JRFillElementDataset implements SpiderDat
 	}
 
 	
-	public Map getItemHyperlinks()
+	public Map<Comparable<?>,Map<Comparable<?>,JRPrintHyperlink>> getItemHyperlinks()
 	{
 		return itemHyperlinks;
 	}
