@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -41,18 +41,16 @@ import org.apache.commons.digester.Digester;
 /**
  * 
  * @author sanda zaharia (shertage@users.sourceforge.net)
- * @version $Id: SpiderChartDigester.java 3892 2010-07-16 13:43:20Z shertage $
+ * @version $Id: SpiderChartDigester.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class SpiderChartDigester implements XmlDigesterConfigurer
 {
-
 	public void configureDigester(Digester digester)
 	{
 		addSpiderChartRules(digester);
 	}
 	
-	
-	protected void addSpiderChartRules(Digester digester)
+	public static void addSpiderChartRules(Digester digester)
 	{
 		String componentNamespace = digester.getRuleNamespaceURI();
 		String jrNamespace = JRXmlConstants.JASPERREPORTS_NAMESPACE;
@@ -132,4 +130,5 @@ public class SpiderChartDigester implements XmlDigesterConfigurer
 		digester.addSetNext(maxValueExpressionPattern, "setMaxValueExpression", JRDesignExpression.class.getName() );
 		digester.addCallMethod(maxValueExpressionPattern, "setText", 0 );
 	}
+	
 }
