@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -29,6 +29,7 @@ import java.util.List;
 import java.util.ListIterator;
 
 import net.sf.jasperreports.charts.type.EdgeEnum;
+import net.sf.jasperreports.components.charts.ChartSettings;
 import net.sf.jasperreports.engine.JRAnchor;
 import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRExpression;
@@ -42,11 +43,12 @@ import net.sf.jasperreports.engine.design.JRDesignHyperlink;
 import net.sf.jasperreports.engine.design.events.JRChangeEventsSupport;
 import net.sf.jasperreports.engine.design.events.JRPropertyChangeSupport;
 import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 
 
 /**
  * @author sanda zaharia (shertage@users.sourceforge.net)
- * @version $Id: StandardChartSettings.java 3891 2010-07-16 13:15:11Z shertage $
+ * @version $Id: StandardChartSettings.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class StandardChartSettings implements ChartSettings, JRChangeEventsSupport
 {
@@ -117,6 +119,8 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	
 	public static final String PROPERTY_HYPERLINK_PARAMETERS = "hyperlinkParameters";
 	
+	public static final String PROPERTY_CUSTOMIZER_CLASS = "customizerClass";
+	
 	
 	/**
 	 *
@@ -157,7 +161,10 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	protected JRExpression hyperlinkReferenceExpression;
 	protected JRExpression hyperlinkAnchorExpression;
 	protected JRExpression hyperlinkPageExpression;
-	private JRExpression hyperlinkTooltipExpression;
+	protected JRExpression hyperlinkTooltipExpression;
+	
+	protected String customizerClass;
+
 
 	/**
 	 * The bookmark level for the anchor associated with this chart.
@@ -200,7 +207,8 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 		hyperlinkPageExpression = factory.getExpression(chart.getHyperlinkPageExpression());
 		hyperlinkTooltipExpression = factory.getExpression(chart.getHyperlinkTooltipExpression());
 		bookmarkLevel = chart.getBookmarkLevel();
-
+		customizerClass = chart.getCustomizerClass();
+		
 		JRHyperlinkParameter[] hyperlinkParams = chart.getHyperlinkParameters();
 		if (hyperlinkParams != null && hyperlinkParams.length > 0)
 		{
@@ -233,7 +241,7 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	 */
 	public Color getBackcolor()
 	{
-		return backcolor;
+		return this.backcolor;
 	}
 
 	/**
@@ -251,7 +259,7 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	 */
 	public JRFont getTitleFont()
 	{
-		return titleFont;
+		return this.titleFont;
 	}
 
 	/**
@@ -259,7 +267,7 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	 */
 	public EdgeEnum getTitlePosition()
 	{
-		return titlePosition;
+		return this.titlePosition;
 	}
 
 	/**
@@ -277,7 +285,7 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	 */
 	public Color getTitleColor()
 	{
-		return titleColor;
+		return this.titleColor;
 	}
 
 	/**
@@ -295,7 +303,7 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	 */
 	public JRFont getSubtitleFont()
 	{
-		return subtitleFont;
+		return this.subtitleFont;
 	}
 
 	/**
@@ -303,7 +311,7 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	 */
 	public Color getSubtitleColor()
 	{
-		return subtitleColor;
+		return this.subtitleColor;
 	}
 
 	/**
@@ -320,21 +328,21 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	 *
 	 */
 	public Color getLegendBackgroundColor() {
-		return legendBackgroundColor;
+		return this.legendBackgroundColor;
 	}
 
 	/**
 	 *
 	 */
 	public Color getLegendColor() {
-		return legendColor;
+		return this.legendColor;
 	}
 
 	/**
 	 *
 	 */
 	public JRFont getLegendFont() {
-		return legendFont;
+		return this.legendFont;
 	}
 
 	/**
@@ -360,7 +368,7 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	 */
 	public EdgeEnum getLegendPosition()
 	{
-		return legendPosition;
+		return this.legendPosition;
 	}
 
 	/**
@@ -402,7 +410,7 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	 */
 	public JRExpression getTitleExpression()
 	{
-		return titleExpression;
+		return this.titleExpression;
 	}
 
 	/**
@@ -410,7 +418,7 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	 */
 	public JRExpression getSubtitleExpression()
 	{
-		return subtitleExpression;
+		return this.subtitleExpression;
 	}
 
 	/**
@@ -418,7 +426,7 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	 */
 	public JRExpression getAnchorNameExpression()
 	{
-		return anchorNameExpression;
+		return this.anchorNameExpression;
 	}
 
 	/**
@@ -426,7 +434,7 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	 */
 	public JRExpression getHyperlinkReferenceExpression()
 	{
-		return hyperlinkReferenceExpression;
+		return this.hyperlinkReferenceExpression;
 	}
 
 	/**
@@ -434,7 +442,7 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	 */
 	public JRExpression getHyperlinkAnchorExpression()
 	{
-		return hyperlinkAnchorExpression;
+		return this.hyperlinkAnchorExpression;
 	}
 
 	/**
@@ -442,12 +450,12 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	 */
 	public JRExpression getHyperlinkPageExpression()
 	{
-		return hyperlinkPageExpression;
+		return this.hyperlinkPageExpression;
 	}
 	
 	public byte getChartType()
 	{
-		return chartType;
+		return this.chartType;
 	}
 
 	/**
@@ -455,7 +463,7 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	 */
 	public String getRenderType()
 	{
-		return renderType;
+		return this.renderType;
 	}
 
 	/**
@@ -470,7 +478,7 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 
 	public int getBookmarkLevel()
 	{
-		return bookmarkLevel;
+		return this.bookmarkLevel;
 	}
 
 	/**
@@ -486,17 +494,26 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 
 	public String getLinkType()
 	{
-		return linkType;
+		return this.linkType;
 	}
 	
 	public String getLinkTarget()
 	{
-		return linkTarget;
+		return this.linkTarget;
 	}
 
 	public JRExpression getHyperlinkTooltipExpression()
 	{
-		return hyperlinkTooltipExpression;
+		return this.hyperlinkTooltipExpression;
+	}
+
+
+	/**
+	 * @return the customizerClass
+	 */
+	public String getCustomizerClass()
+	{
+		return this.customizerClass;
 	}
 
 
@@ -620,6 +637,17 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 		getEventSupport().firePropertyChange(PROPERTY_HYPERLINK_TOOLTIP_EXPRESSION, old, this.hyperlinkTooltipExpression);
 	}
 
+	/**
+	 * @param customizerClass the customizerClass to set
+	 */
+	public void setCustomizerClass(String customizerClass) 
+	{
+		Object old = this.customizerClass;
+		this.customizerClass = customizerClass;
+		getEventSupport().firePropertyChange(PROPERTY_CUSTOMIZER_CLASS, old, this.customizerClass);
+		
+	}
+	
 	public void collectExpressions(JRExpressionCollector collector)
 	{
 		SpiderChartCompiler.collectExpressions(this, collector);
@@ -627,54 +655,25 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 
 	public Object clone() 
 	{
+		StandardChartSettings clone = null;
 		try
 		{
-			StandardChartSettings clone = (StandardChartSettings)super.clone();
-			
-			if (hyperlinkParameters != null)
-			{
-				clone.hyperlinkParameters = new ArrayList<JRHyperlinkParameter>();
-				for(int i = 0; i < hyperlinkParameters.size(); i++)
-				{
-					clone.hyperlinkParameters.add(i,(JRHyperlinkParameter)hyperlinkParameters.get(i).clone());
-				}
-			}
-	
-			if (titleExpression != null)
-			{
-				clone.titleExpression = (JRExpression)titleExpression.clone();
-			}
-			if (subtitleExpression != null)
-			{
-				clone.subtitleExpression = (JRExpression)subtitleExpression.clone();
-			}
-			if (anchorNameExpression != null)
-			{
-				clone.anchorNameExpression = (JRExpression)anchorNameExpression.clone();
-			}
-			if (hyperlinkReferenceExpression != null)
-			{
-				clone.hyperlinkReferenceExpression = (JRExpression)hyperlinkReferenceExpression.clone();
-			}
-			if (hyperlinkAnchorExpression != null)
-			{
-				clone.hyperlinkAnchorExpression = (JRExpression)hyperlinkAnchorExpression.clone();
-			}
-			if (hyperlinkPageExpression != null)
-			{
-				clone.hyperlinkPageExpression = (JRExpression)hyperlinkPageExpression.clone();
-			}
-			if (hyperlinkTooltipExpression != null)
-			{
-				clone.hyperlinkTooltipExpression = (JRExpression)hyperlinkTooltipExpression.clone();
-			}
-			
-			return clone;
+			clone = (StandardChartSettings)super.clone();
 		}
 		catch (CloneNotSupportedException e)
 		{
 			throw new JRRuntimeException(e);
 		}
+		clone.hyperlinkParameters = JRCloneUtils.cloneList(hyperlinkParameters);
+		clone.titleExpression = JRCloneUtils.nullSafeClone(titleExpression);
+		clone.subtitleExpression = JRCloneUtils.nullSafeClone(subtitleExpression);
+		clone.anchorNameExpression = JRCloneUtils.nullSafeClone(anchorNameExpression);
+		clone.hyperlinkReferenceExpression = JRCloneUtils.nullSafeClone(hyperlinkReferenceExpression);
+		clone.hyperlinkAnchorExpression = JRCloneUtils.nullSafeClone(hyperlinkAnchorExpression);
+		clone.hyperlinkPageExpression = JRCloneUtils.nullSafeClone(hyperlinkPageExpression);
+		clone.hyperlinkTooltipExpression = JRCloneUtils.nullSafeClone(hyperlinkTooltipExpression);
+		clone.eventSupport = null;
+		return clone;
 	}
 
 	private transient JRPropertyChangeSupport eventSupport;
@@ -709,7 +708,7 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	 * 
 	 * @return the list of custom hyperlink parameters
 	 */
-	public List getHyperlinkParametersList()
+	public List<JRHyperlinkParameter> getHyperlinkParametersList()
 	{
 		return hyperlinkParameters;
 	}
@@ -756,9 +755,9 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 	 */
 	public void removeHyperlinkParameter(String parameterName)
 	{
-		for (ListIterator it = hyperlinkParameters.listIterator(); it.hasNext();)
+		for (ListIterator<JRHyperlinkParameter> it = hyperlinkParameters.listIterator(); it.hasNext();)
 		{
-			JRHyperlinkParameter parameter = (JRHyperlinkParameter) it.next();
+			JRHyperlinkParameter parameter = it.next();
 			if (parameter.getName() != null && parameter.getName().equals(parameterName))
 			{
 				it.remove();
@@ -767,7 +766,5 @@ public class StandardChartSettings implements ChartSettings, JRChangeEventsSuppo
 			}
 		}
 	}
-	
-	
-	
+
 }
