@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -32,7 +32,7 @@ import net.sf.jasperreports.engine.component.Component;
 
 /**
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: TableComponent.java 3586 2010-03-12 18:17:13Z lucianc $
+ * @version $Id: TableComponent.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public interface TableComponent extends Component, JRCloneable
 {
@@ -41,4 +41,6 @@ public interface TableComponent extends Component, JRCloneable
 
 	List<BaseColumn> getColumns();
 	
+	WhenNoDataTypeTableEnum getWhenNoDataType();
+	
 }
