@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -36,24 +36,10 @@ import net.sf.jasperreports.engine.type.CalculationEnum;
  * in the crosstab cells.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRCrosstabMeasure.java 3510 2010-03-05 10:38:28Z shertage $
+ * @version $Id: JRCrosstabMeasure.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public interface JRCrosstabMeasure extends JRCloneable
 {
-	/**
-	 * Percentage type indicating that the value will not be calculated
-	 * as a percentage.
-	 * @deprecated Replaced by {@link CrosstabPercentageEnum#NONE}.
-	 */
-	public static final byte PERCENTAGE_TYPE_NONE = 0;
-	
-	/**
-	 * Percentage type indicating that the value will be calculated as percentage
-	 * of the grand total value.
-	 * @deprecated Replaced by {@link CrosstabPercentageEnum#GRAND_TOTAL}.
-	 */
-	public static final byte PERCENTAGE_TYPE_GRAND_TOTAL = 1;
-
 	
 	/**
 	 * Returns the name of the measure.
@@ -77,7 +63,7 @@ public interface JRCrosstabMeasure extends JRCloneable
 	 * 
 	 * @return the value class of this measure
 	 */
-	public Class getValueClass();
+	public Class<?> getValueClass();
 	
 	
 	/**
@@ -88,12 +74,6 @@ public interface JRCrosstabMeasure extends JRCloneable
 	public JRExpression getValueExpression();
 	
 	
-	/**
-	 * @deprecated Replaced by {@link #getCalculationValue()}.
-	 */
-	public byte getCalculation();
-	
-	
 	/**
 	 * Returns the calculation type which will be performed on the measure values.
 	 * <p>
@@ -130,15 +110,9 @@ public interface JRCrosstabMeasure extends JRCloneable
 	 * @return the incrementer factory class
 	 * @see #getIncrementerFactoryClassName()
 	 */
-	public Class getIncrementerFactoryClass();
+	public Class<?> getIncrementerFactoryClass();
 
 	
-	/**
-	 * @deprecated Replaced by {@link #getPercentageType()}.
-	 */
-	public byte getPercentageOfType();
-	
-	
 	/**
 	 * Returns the percentage calculation type performed on this measure.
 	 * <p>
@@ -173,7 +147,7 @@ public interface JRCrosstabMeasure extends JRCloneable
 	 * 
 	 * @return the percentage calculator class
 	 */
-	public Class getPercentageCalculatorClass();
+	public Class<?> getPercentageCalculatorClass();
 	
 	
 	/**
