@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -38,13 +38,12 @@ import net.sf.jasperreports.engine.base.JRBaseLineBox;
 import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
 import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
-import net.sf.jasperreports.engine.util.LineBoxWrapper;
 
 /**
  * Base read-only implementation of {@link net.sf.jasperreports.crosstabs.JRCellContents JRCellContents}.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRBaseCellContents.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBaseCellContents.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseCellContents extends JRBaseElementGroup implements JRCellContents
 {
@@ -79,14 +78,6 @@ public class JRBaseCellContents extends JRBaseElementGroup implements JRCellCont
 		return backcolor;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public JRBox getBox()
-	{
-		return new LineBoxWrapper(getLineBox());
-	}
-
 	public JRLineBox getLineBox()
 	{
 		return lineBox;
@@ -112,14 +103,6 @@ public class JRBaseCellContents extends JRBaseElementGroup implements JRCellCont
 		return style;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getModeValue()}.
-	 */
-	public Byte getMode()
-	{
-		return getModeValue() == null ? null : getModeValue().getValueByte() ;
-	}
-
 	public ModeEnum getModeValue()
 	{
 		return modeValue;
@@ -150,7 +133,7 @@ public class JRBaseCellContents extends JRBaseElementGroup implements JRCellCont
 	/**
 	 * @deprecated
 	 */
-	private JRBox box = null;
+	private JRBox box;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
