@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -54,7 +54,7 @@ import net.sf.jasperreports.engine.util.JRStyleResolver;
  * Base read-only {@link net.sf.jasperreports.crosstabs.JRCrosstab crosstab} implementation.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRBaseCrosstab.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBaseCrosstab.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseCrosstab extends JRBaseElement implements JRCrosstab
 {
@@ -290,10 +290,10 @@ public class JRBaseCrosstab extends JRBaseElement implements JRCrosstab
 		{
 			if (crosstab instanceof JRDesignCrosstab)
 			{
-				List cellsList = ((JRDesignCrosstab) crosstab).getCellsList();
-				for (Iterator it = cellsList.iterator(); element == null && it.hasNext();)
+				List<JRCrosstabCell> cellsList = ((JRDesignCrosstab) crosstab).getCellsList();
+				for (Iterator<JRCrosstabCell> it = cellsList.iterator(); element == null && it.hasNext();)
 				{
-					JRCrosstabCell cell = (JRCrosstabCell) it.next();
+					JRCrosstabCell cell = it.next();
 					element = cell.getContents().getElementByKey(key);
 				}
 			}
@@ -361,23 +361,6 @@ public class JRBaseCrosstab extends JRBaseElement implements JRCrosstab
 	}
 
 	
-	/**
-	 * @deprecated Replaced by {@link #getRunDirectionValue()}.
-	 */
-	public byte getRunDirection()
-	{
-		return getRunDirectionValue().getValue();
-	}
-
-	
-	/**
-	 * @deprecated Replaced by {@link #setRunDirection(RunDirectionEnum)}.
-	 */
-	public void setRunDirection(byte runDirection)
-	{
-		setRunDirection(RunDirectionEnum.getByValue(runDirection));
-	}
-
 	/**
 	 *
 	 */
