@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -33,18 +33,23 @@ import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
 import net.sf.jasperreports.engine.type.SortOrderEnum;
+import net.sf.jasperreports.engine.util.JRClassLoader;
 import net.sf.jasperreports.engine.util.JRCloneUtils;
 
 /**
  * Base read-only implementation of {@link net.sf.jasperreports.crosstabs.JRCrosstabBucket JRCrosstabBucket}.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRBaseCrosstabBucket.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBaseCrosstabBucket.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseCrosstabBucket implements JRCrosstabBucket, Serializable
 {
 	private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 
+	protected String valueClassName;
+	protected String valueClassRealName;
+	protected Class<?> valueClass;
+
 	protected SortOrderEnum orderValue = SortOrderEnum.ASCENDING;
 	protected JRExpression expression;
 	protected JRExpression orderByExpression;
@@ -58,18 +63,16 @@ public class JRBaseCrosstabBucket implements JRCrosstabBucket, Serializable
 	{
 		factory.put(bucket, this);
 		
+		this.valueClassName = bucket.getValueClassName();
 		this.orderValue = bucket.getOrderValue();
 		this.expression = factory.getExpression(bucket.getExpression());
 		this.orderByExpression = factory.getExpression(bucket.getOrderByExpression());
 		this.comparatorExpression = factory.getExpression(bucket.getComparatorExpression());
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getOrderValue()}.
-	 */
-	public byte getOrder()
+	public String getValueClassName()
 	{
-		return getOrderValue().getValue();
+		return valueClassName;
 	}
 
 	public SortOrderEnum getOrderValue()
@@ -92,21 +95,56 @@ public class JRBaseCrosstabBucket implements JRCrosstabBucket, Serializable
 		return comparatorExpression;
 	}
 	
+	public Class<?> getValueClass()
+	{
+		if (valueClass == null)
+		{
+			String className = getValueClassRealName();
+			if (className != null)
+			{
+				try
+				{
+					valueClass = JRClassLoader.loadClassForName(className);
+				}
+				catch (ClassNotFoundException e)
+				{
+					throw new JRRuntimeException("Could not load bucket value class", e);
+				}
+			}
+		}
+		
+		return valueClass;
+	}
+
+	/**
+	 *
+	 */
+	private String getValueClassRealName()
+	{
+		if (valueClassRealName == null)
+		{
+			valueClassRealName = JRClassLoader.getClassRealName(valueClassName);
+		}
+		
+		return valueClassRealName;
+	}
+
 	public Object clone()
 	{
+		JRBaseCrosstabBucket clone = null;
 		try
 		{
-			JRBaseCrosstabBucket clone = (JRBaseCrosstabBucket) super.clone();
-			clone.expression = (JRExpression) JRCloneUtils.nullSafeClone(expression);
-			clone.orderByExpression = (JRExpression) JRCloneUtils.nullSafeClone(orderByExpression);
-			clone.comparatorExpression = (JRExpression) JRCloneUtils.nullSafeClone(comparatorExpression);
-			return clone;
+			clone = (JRBaseCrosstabBucket) super.clone();
 		}
 		catch (CloneNotSupportedException e)
 		{
 			// never
 			throw new JRRuntimeException(e);
 		}
+		clone.expression = JRCloneUtils.nullSafeClone(expression);
+		clone.orderByExpression = JRCloneUtils.nullSafeClone(orderByExpression);
+		clone.comparatorExpression = JRCloneUtils.nullSafeClone(comparatorExpression);
+		return clone;
 	}
 
 
@@ -127,6 +165,12 @@ public class JRBaseCrosstabBucket implements JRCrosstabBucket, Serializable
 		{
 			orderValue = SortOrderEnum.getByValue(order);
 		}
+
+		if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_4_0_3)
+		{
+			//expression can never be null due to verifier
+			valueClassName = getExpression().getValueClassName();//we probably can never remove this method from expression, if we want to preserve backward compatibility
+		}
 	}
 	
 }
