@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -42,7 +42,7 @@ import net.sf.jasperreports.engine.util.JRCloneUtils;
  * Base read-only crosstab measure implementation.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRBaseCrosstabMeasure.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBaseCrosstabMeasure.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseCrosstabMeasure implements JRCrosstabMeasure, Serializable
 {
@@ -50,17 +50,17 @@ public class JRBaseCrosstabMeasure implements JRCrosstabMeasure, Serializable
 
 	protected String name;
 	protected String valueClassName;
-	protected String valueClassRealName = null;
-	protected Class valueClass;
+	protected String valueClassRealName;
+	protected Class<?> valueClass;
 	protected JRExpression expression;
 	protected CalculationEnum calculationValue = CalculationEnum.COUNT;
 	protected String incrementerFactoryClassName;
 	protected String incrementerFactoryClassRealName;
-	protected Class incrementerFactoryClass;
+	protected Class<?> incrementerFactoryClass;
 	protected CrosstabPercentageEnum percentageType = CrosstabPercentageEnum.NONE;
 	protected String percentageCalculatorClassName;
 	protected String percentageCalculatorClassRealName;
-	protected Class percentageCalculatorClass;
+	protected Class<?> percentageCalculatorClass;
 	protected JRVariable variable;
 
 	protected JRBaseCrosstabMeasure()
@@ -96,14 +96,6 @@ public class JRBaseCrosstabMeasure implements JRCrosstabMeasure, Serializable
 		return expression;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getCalculationValue()}.
-	 */
-	public byte getCalculation()
-	{
-		return getCalculationValue().getValue();
-	}
-
 	public CalculationEnum getCalculationValue()
 	{
 		return calculationValue;
@@ -114,20 +106,12 @@ public class JRBaseCrosstabMeasure implements JRCrosstabMeasure, Serializable
 		return incrementerFactoryClassName;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getPercentageType()}.
-	 */
-	public byte getPercentageOfType()
-	{
-		return getPercentageType().getValue();
-	}
-
 	public CrosstabPercentageEnum getPercentageType()
 	{
 		return percentageType;
 	}
 
-	public Class getIncrementerFactoryClass()
+	public Class<?> getIncrementerFactoryClass()
 	{
 		if (incrementerFactoryClass == null)
 		{
@@ -161,7 +145,7 @@ public class JRBaseCrosstabMeasure implements JRCrosstabMeasure, Serializable
 		return incrementerFactoryClassRealName;
 	}
 
-	public Class getValueClass()
+	public Class<?> getValueClass()
 	{
 		if (valueClass == null)
 		{
@@ -174,7 +158,7 @@ public class JRBaseCrosstabMeasure implements JRCrosstabMeasure, Serializable
 				}
 				catch (ClassNotFoundException e)
 				{
-					throw new JRRuntimeException("Could not load bucket value class", e);
+					throw new JRRuntimeException("Could not load measure value class", e);
 				}
 			}
 		}
@@ -205,7 +189,7 @@ public class JRBaseCrosstabMeasure implements JRCrosstabMeasure, Serializable
 		return percentageCalculatorClassName;
 	}
 
-	public Class getPercentageCalculatorClass()
+	public Class<?> getPercentageCalculatorClass()
 	{
 		if (percentageCalculatorClass == null)
 		{
@@ -244,18 +228,19 @@ public class JRBaseCrosstabMeasure implements JRCrosstabMeasure, Serializable
 	 */
 	public Object clone() 
 	{
+		JRBaseCrosstabMeasure clone = null;
 		try
 		{
-			JRBaseCrosstabMeasure clone = (JRBaseCrosstabMeasure) super.clone();
-			clone.expression = (JRExpression) JRCloneUtils.nullSafeClone(expression);
-			clone.variable = (JRVariable) JRCloneUtils.nullSafeClone(variable);
-			return clone;
+			clone = (JRBaseCrosstabMeasure) super.clone();
 		}
 		catch (CloneNotSupportedException e)
 		{
 			// never
 			throw new JRRuntimeException(e);
 		}
+		clone.expression = JRCloneUtils.nullSafeClone(expression);
+		clone.variable = JRCloneUtils.nullSafeClone(variable);
+		return clone;
 	}
 
 	
