@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -59,6 +59,7 @@ import net.sf.jasperreports.engine.JRExpressionCollector;
 import net.sf.jasperreports.engine.JRParameter;
 import net.sf.jasperreports.engine.JRVariable;
 import net.sf.jasperreports.engine.JRVisitor;
+import net.sf.jasperreports.engine.ReportContext;
 import net.sf.jasperreports.engine.design.JRDesignElement;
 import net.sf.jasperreports.engine.design.JRDesignVariable;
 import net.sf.jasperreports.engine.type.CalculationEnum;
@@ -66,6 +67,7 @@ import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.type.RunDirectionEnum;
 import net.sf.jasperreports.engine.util.FileResolver;
 import net.sf.jasperreports.engine.util.FormatFactory;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 import net.sf.jasperreports.engine.util.Pair;
 
@@ -75,7 +77,7 @@ import org.apache.commons.collections.SequencedHashMap;
  * Design-time {@link net.sf.jasperreports.crosstabs.JRCrosstab crosstab} implementation.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRDesignCrosstab.java 4017 2010-10-27 12:10:17Z teodord $
+ * @version $Id: JRDesignCrosstab.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 {
@@ -107,23 +109,23 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	
 	public static final String PROPERTY_IGNORE_WIDTH = "ignoreWidth";
 
-	protected List parametersList;
-	protected Map parametersMap;
+	protected List<JRCrosstabParameter> parametersList;
+	protected Map<String, JRCrosstabParameter> parametersMap;
 	protected SequencedHashMap variablesList;
 	protected JRExpression parametersMapExpression;
 	protected JRDesignCrosstabDataset dataset;
-	protected List rowGroups;
-	protected List columnGroups;
-	protected List measures;
-	protected Map rowGroupsMap;
-	protected Map columnGroupsMap;
-	protected Map measuresMap;
+	protected List<JRCrosstabRowGroup> rowGroups;
+	protected List<JRCrosstabColumnGroup> columnGroups;
+	protected List<JRCrosstabMeasure> measures;
+	protected Map<String, Integer> rowGroupsMap;
+	protected Map<String, Integer> columnGroupsMap;
+	protected Map<String, Integer> measuresMap;
 	protected int columnBreakOffset = DEFAULT_COLUMN_BREAK_OFFSET;
 	protected boolean repeatColumnHeaders = true;
 	protected boolean repeatRowHeaders = true;
 	protected RunDirectionEnum runDirectionValue;
-	protected List cellsList;
-	protected Map cellsMap;
+	protected List<JRCrosstabCell> cellsList;
+	protected Map<Pair,JRCrosstabCell> cellsMap;
 	protected JRDesignCrosstabCell[][] crossCells;
 	protected JRDesignCellContents whenNoDataCell;
 	protected JRDesignCellContents headerCell;
@@ -142,6 +144,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	private PropertyChangeListener measureClassChangeListener = new MeasureClassChangeListener();
 	
 	private static final Object[] BUILT_IN_PARAMETERS = new Object[] { 
+		JRParameter.REPORT_CONTEXT, ReportContext.class, 
 		JRParameter.REPORT_PARAMETERS_MAP, java.util.Map.class, 
 		JRParameter.REPORT_LOCALE, Locale.class, 
 		JRParameter.REPORT_RESOURCE_BUNDLE, ResourceBundle.class,
@@ -165,18 +168,17 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	{
 		super(defaultStyleProvider);
 		
-		parametersList = new ArrayList();
-		parametersMap = new HashMap();
+		parametersList = new ArrayList<JRCrosstabParameter>();
+		parametersMap = new HashMap<String, JRCrosstabParameter>();
+		rowGroupsMap = new HashMap<String, Integer>();
+		rowGroups = new ArrayList<JRCrosstabRowGroup>();
+		columnGroupsMap = new HashMap<String, Integer>();
+		columnGroups = new ArrayList<JRCrosstabColumnGroup>();
+		measuresMap = new HashMap<String, Integer>();
+		measures = new ArrayList<JRCrosstabMeasure>();
 		
-		rowGroupsMap = new HashMap();
-		rowGroups = new ArrayList();
-		columnGroupsMap = new HashMap();
-		columnGroups = new ArrayList();
-		measuresMap = new HashMap();
-		measures = new ArrayList();
-		
-		cellsMap = new HashMap();
-		cellsList = new ArrayList();
+		cellsMap = new HashMap<Pair,JRCrosstabCell>();
+		cellsList = new ArrayList<JRCrosstabCell>();
 		
 		addBuiltinParameters();
 		
@@ -192,7 +194,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		{
 			JRDesignCrosstabParameter parameter = new JRDesignCrosstabParameter();
 			parameter.setName((String) BUILT_IN_PARAMETERS[i++]);
-			parameter.setValueClass((Class) BUILT_IN_PARAMETERS[i]);
+			parameter.setValueClass((Class<?>) BUILT_IN_PARAMETERS[i]);
 			parameter.setSystemDefined(true);
 			try
 			{
@@ -211,7 +213,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		{
 			JRDesignVariable variable = new JRDesignVariable();
 			variable.setName((String) BUILT_IN_VARIABLES[i]);
-			variable.setValueClass((Class) BUILT_IN_VARIABLES[++i]);
+			variable.setValueClass((Class<?>) BUILT_IN_VARIABLES[++i]);
 			variable.setCalculation(CalculationEnum.SYSTEM);
 			variable.setSystemDefined(true);
 			addVariable(variable);
@@ -328,20 +330,50 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		
 		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_ROW_GROUPS, group, rowGroups.size() - 1);
 	}
+	
+	/**
+	 * Adds a row group.
+	 * <p>
+	 * This group will be a sub group of the last row group, if any.
+	 * 
+	 * @param group the group
+	 * @param index position
+	 * @throws JRException
+	 * @see JRCrosstab#getRowGroups()
+	 */
+	public void addRowGroup(int index, JRDesignCrosstabRowGroup group) throws JRException
+	{
+		String groupName = group.getName();
+		if (rowGroupsMap.containsKey(groupName) ||
+				columnGroupsMap.containsKey(groupName) ||
+				measuresMap.containsKey(groupName))
+		{
+			throw new JRException("A group or measure having the same name already exists in the crosstab.");
+		}
+		
+		rowGroupsMap.put(groupName, Integer.valueOf(rowGroups.size()));
+		rowGroups.add(index, group);
+		
+		addRowGroupVars(group);
+		
+		setParent(group);
+		
+		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_ROW_GROUPS, group, index);
+	}
 
 	
 	protected void addRowGroupVars(JRDesignCrosstabRowGroup rowGroup)
 	{
 		addVariable(rowGroup.getVariable());
 		
-		for (Iterator measureIt = measures.iterator(); measureIt.hasNext();)
+		for (Iterator<JRCrosstabMeasure> measureIt = measures.iterator(); measureIt.hasNext();)
 		{
-			JRCrosstabMeasure measure = (JRCrosstabMeasure) measureIt.next();
+			JRCrosstabMeasure measure = measureIt.next();
 			addTotalVar(measure, rowGroup, null);
 			
-			for (Iterator colIt = columnGroups.iterator(); colIt.hasNext();)
+			for (Iterator<JRCrosstabColumnGroup> colIt = columnGroups.iterator(); colIt.hasNext();)
 			{
-				JRCrosstabColumnGroup colGroup = (JRCrosstabColumnGroup) colIt.next();
+				JRCrosstabColumnGroup colGroup = colIt.next();
 				addTotalVar(measure, rowGroup, colGroup);
 			}
 		}
@@ -377,19 +409,48 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_COLUMN_GROUPS, group, columnGroups.size() - 1);
 	}
 	
+	/**
+	 * Adds a column group.
+	 * <p>
+	 * This group will be a sub group of the last column group, if any.
+	 * 
+	 * @param group the group
+	 * @throws JRException
+	 * @see JRCrosstab#getColumnGroups()
+	 */
+	public void addColumnGroup(int index, JRDesignCrosstabColumnGroup group) throws JRException
+	{
+		String groupName = group.getName();
+		if (rowGroupsMap.containsKey(groupName) ||
+				columnGroupsMap.containsKey(groupName) ||
+				measuresMap.containsKey(groupName))
+		{
+			throw new JRException("A group or measure having the same name already exists in the crosstab.");
+		}
+		
+		columnGroupsMap.put(groupName, Integer.valueOf(columnGroups.size()));
+		columnGroups.add(index, group);
+		
+		addColGroupVars(group);
+		
+		setParent(group);
+		
+		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_COLUMN_GROUPS, group, index);
+	}
+	
 	
 	protected void addColGroupVars(JRDesignCrosstabColumnGroup colGroup)
 	{
 		addVariable(colGroup.getVariable());
 		
-		for (Iterator measureIt = measures.iterator(); measureIt.hasNext();)
+		for (Iterator<JRCrosstabMeasure> measureIt = measures.iterator(); measureIt.hasNext();)
 		{
-			JRCrosstabMeasure measure = (JRCrosstabMeasure) measureIt.next();
+			JRCrosstabMeasure measure = measureIt.next();
 			addTotalVar(measure, null, colGroup);
 
-			for (Iterator rowIt = rowGroups.iterator(); rowIt.hasNext();)
+			for (Iterator<JRCrosstabRowGroup> rowIt = rowGroups.iterator(); rowIt.hasNext();)
 			{
-				JRCrosstabRowGroup rowGroup = (JRCrosstabRowGroup) rowIt.next();
+				JRCrosstabRowGroup rowGroup = rowIt.next();
 				addTotalVar(measure, rowGroup, colGroup);
 			}
 		}
@@ -421,25 +482,52 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		
 		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_MEASURES, measure, measures.size() - 1);
 	}
+	
+	/**
+	 * Adds a measure to the crosstab.
+	 * 
+	 * @param measure the measure
+	 * @throws JRException
+	 * @see JRCrosstab#getMeasures()
+	 */
+	public void addMeasure(int index, JRDesignCrosstabMeasure measure) throws JRException
+	{
+		String measureName = measure.getName();
+		if (rowGroupsMap.containsKey(measureName) ||
+				columnGroupsMap.containsKey(measureName) ||
+				measuresMap.containsKey(measureName))
+		{
+			throw new JRException("A group or measure having the same name already exists in the crosstab.");
+		}
+		
+		measure.addPropertyChangeListener(JRDesignCrosstabMeasure.PROPERTY_VALUE_CLASS, measureClassChangeListener);
+		
+		measuresMap.put(measureName, Integer.valueOf(measures.size()));
+		measures.add(index, measure);
+		
+		addMeasureVars(measure);
+		
+		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_MEASURES, measure, index);
+	}
 
 	protected void addMeasureVars(JRDesignCrosstabMeasure measure)
 	{
 		addVariable(measure.getVariable());
 		
-		for (Iterator colIt = columnGroups.iterator(); colIt.hasNext();)
+		for (Iterator<JRCrosstabColumnGroup> colIt = columnGroups.iterator(); colIt.hasNext();)
 		{
-			JRCrosstabColumnGroup colGroup = (JRCrosstabColumnGroup) colIt.next();
+			JRCrosstabColumnGroup colGroup = colIt.next();
 			addTotalVar(measure, null, colGroup);
 		}
 		
-		for (Iterator rowIt = rowGroups.iterator(); rowIt.hasNext();)
+		for (Iterator<JRCrosstabRowGroup> rowIt = rowGroups.iterator(); rowIt.hasNext();)
 		{
-			JRCrosstabRowGroup rowGroup = (JRCrosstabRowGroup) rowIt.next();
+			JRCrosstabRowGroup rowGroup = rowIt.next();
 			addTotalVar(measure, rowGroup, null);
 			
-			for (Iterator colIt = columnGroups.iterator(); colIt.hasNext();)
+			for (Iterator<JRCrosstabColumnGroup> colIt = columnGroups.iterator(); colIt.hasNext();)
 			{
-				JRCrosstabColumnGroup colGroup = (JRCrosstabColumnGroup) colIt.next();
+				JRCrosstabColumnGroup colGroup = colIt.next();
 				addTotalVar(measure, rowGroup, colGroup);
 			}
 		}
@@ -493,20 +581,20 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	{
 		JRCrosstabRowGroup removed = null;
 		
-		Integer idx = (Integer) rowGroupsMap.remove(groupName);
+		Integer idx = rowGroupsMap.remove(groupName);
 		if (idx != null)
 		{
-			removed = (JRCrosstabRowGroup) rowGroups.remove(idx.intValue());
+			removed = rowGroups.remove(idx.intValue());
 			
-			for (ListIterator it = rowGroups.listIterator(idx.intValue()); it.hasNext();)
+			for (ListIterator<JRCrosstabRowGroup> it = rowGroups.listIterator(idx.intValue()); it.hasNext();)
 			{
-				JRCrosstabRowGroup group = (JRCrosstabRowGroup) it.next();
+				JRCrosstabRowGroup group = it.next();
 				rowGroupsMap.put(group.getName(), Integer.valueOf(it.previousIndex()));
 			}
 			
-			for (Iterator it = cellsList.iterator(); it.hasNext();)
+			for (Iterator<JRCrosstabCell> it = cellsList.iterator(); it.hasNext();)
 			{
-				JRCrosstabCell cell = (JRCrosstabCell) it.next();
+				JRCrosstabCell cell = it.next();
 				String rowTotalGroup = cell.getRowTotalGroup();
 				if (rowTotalGroup != null && rowTotalGroup.equals(groupName))
 				{
@@ -528,14 +616,14 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	{
 		removeVariable(rowGroup.getVariable());
 		
-		for (Iterator measureIt = measures.iterator(); measureIt.hasNext();)
+		for (Iterator<JRCrosstabMeasure> measureIt = measures.iterator(); measureIt.hasNext();)
 		{
-			JRCrosstabMeasure measure = (JRCrosstabMeasure) measureIt.next();
+			JRCrosstabMeasure measure = measureIt.next();
 			removeTotalVar(measure, rowGroup, null);
 			
-			for (Iterator colIt = columnGroups.iterator(); colIt.hasNext();)
+			for (Iterator<JRCrosstabColumnGroup> colIt = columnGroups.iterator(); colIt.hasNext();)
 			{
-				JRCrosstabColumnGroup colGroup = (JRCrosstabColumnGroup) colIt.next();
+				JRCrosstabColumnGroup colGroup = colIt.next();
 				removeTotalVar(measure, rowGroup, colGroup);
 			}
 		}
@@ -564,20 +652,20 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	{
 		JRCrosstabColumnGroup removed = null;
 		
-		Integer idx = (Integer) columnGroupsMap.remove(groupName);
+		Integer idx = columnGroupsMap.remove(groupName);
 		if (idx != null)
 		{
-			removed = (JRCrosstabColumnGroup) columnGroups.remove(idx.intValue());
+			removed = columnGroups.remove(idx.intValue());
 			
-			for (ListIterator it = columnGroups.listIterator(idx.intValue()); it.hasNext();)
+			for (ListIterator<JRCrosstabColumnGroup> it = columnGroups.listIterator(idx.intValue()); it.hasNext();)
 			{
-				JRCrosstabColumnGroup group = (JRCrosstabColumnGroup) it.next();
+				JRCrosstabColumnGroup group = it.next();
 				columnGroupsMap.put(group.getName(), Integer.valueOf(it.previousIndex()));
 			}
 			
-			for (Iterator it = cellsList.iterator(); it.hasNext();)
+			for (Iterator<JRCrosstabCell> it = cellsList.iterator(); it.hasNext();)
 			{
-				JRCrosstabCell cell = (JRCrosstabCell) it.next();
+				JRCrosstabCell cell = it.next();
 				String columnTotalGroup = cell.getColumnTotalGroup();
 				if (columnTotalGroup != null && columnTotalGroup.equals(groupName))
 				{
@@ -600,14 +688,14 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	{
 		removeVariable(colGroup.getVariable());
 		
-		for (Iterator measureIt = measures.iterator(); measureIt.hasNext();)
+		for (Iterator<JRCrosstabMeasure> measureIt = measures.iterator(); measureIt.hasNext();)
 		{
-			JRCrosstabMeasure measure = (JRCrosstabMeasure) measureIt.next();
+			JRCrosstabMeasure measure = measureIt.next();
 			removeTotalVar(measure, null, colGroup);
 
-			for (Iterator rowIt = rowGroups.iterator(); rowIt.hasNext();)
+			for (Iterator<JRCrosstabRowGroup> rowIt = rowGroups.iterator(); rowIt.hasNext();)
 			{
-				JRCrosstabRowGroup rowGroup = (JRCrosstabRowGroup) rowIt.next();
+				JRCrosstabRowGroup rowGroup = rowIt.next();
 				removeTotalVar(measure, rowGroup, colGroup);
 			}
 		}
@@ -636,14 +724,14 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	{
 		JRDesignCrosstabMeasure removed = null;
 		
-		Integer idx = (Integer) measuresMap.remove(measureName);
+		Integer idx = measuresMap.remove(measureName);
 		if (idx != null)
 		{
 			removed = (JRDesignCrosstabMeasure) measures.remove(idx.intValue());
 			
-			for (ListIterator it = measures.listIterator(idx.intValue()); it.hasNext();)
+			for (ListIterator<JRCrosstabMeasure> it = measures.listIterator(idx.intValue()); it.hasNext();)
 			{
-				JRCrosstabMeasure group = (JRCrosstabMeasure) it.next();
+				JRCrosstabMeasure group = it.next();
 				measuresMap.put(group.getName(), Integer.valueOf(it.previousIndex()));
 			}
 			
@@ -661,20 +749,20 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	{
 		removeVariable(measure.getVariable());
 		
-		for (Iterator colIt = columnGroups.iterator(); colIt.hasNext();)
+		for (Iterator<JRCrosstabColumnGroup> colIt = columnGroups.iterator(); colIt.hasNext();)
 		{
-			JRCrosstabColumnGroup colGroup = (JRCrosstabColumnGroup) colIt.next();
+			JRCrosstabColumnGroup colGroup = colIt.next();
 			removeTotalVar(measure, null, colGroup);
 		}
 		
-		for (Iterator rowIt = rowGroups.iterator(); rowIt.hasNext();)
+		for (Iterator<JRCrosstabRowGroup> rowIt = rowGroups.iterator(); rowIt.hasNext();)
 		{
-			JRCrosstabRowGroup rowGroup = (JRCrosstabRowGroup) rowIt.next();
+			JRCrosstabRowGroup rowGroup = rowIt.next();
 			removeTotalVar(measure, rowGroup, null);
 			
-			for (Iterator colIt = columnGroups.iterator(); colIt.hasNext();)
+			for (Iterator<JRCrosstabColumnGroup> colIt = columnGroups.iterator(); colIt.hasNext();)
 			{
-				JRCrosstabColumnGroup colGroup = (JRCrosstabColumnGroup) colIt.next();
+				JRCrosstabColumnGroup colGroup = colIt.next();
 				removeTotalVar(measure, rowGroup, colGroup);
 			}
 		}
@@ -742,7 +830,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	 * @return the data cells list
 	 * @see #addCell(JRDesignCrosstabCell)
 	 */
-	public List getCellsList()
+	public List<JRCrosstabCell> getCellsList()
 	{
 		return cellsList;
 	}
@@ -756,7 +844,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	 * @see JRCrosstabCell#getRowTotalGroup()
 	 * @see JRCrosstabCell#getColumnTotalGroup()
 	 */
-	public Map getCellsMap()
+	public Map<Pair,JRCrosstabCell> getCellsMap()
 	{
 		return cellsMap;
 	}
@@ -782,7 +870,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 			throw new JRException("Row group " + columnTotalGroup + " does not exist.");
 		}
 		
-		Object cellKey = new Pair(rowTotalGroup, columnTotalGroup);
+		Pair cellKey = new Pair(rowTotalGroup, columnTotalGroup);
 		if (cellsMap.containsKey(cellKey))
 		{
 			throw new JRException("Duplicate cell in crosstab.");
@@ -810,7 +898,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	{
 		Object cellKey = new Pair(rowTotalGroup, columnTotalGroup);
 		
-		JRCrosstabCell cell = (JRCrosstabCell) cellsMap.remove(cellKey);
+		JRCrosstabCell cell = cellsMap.remove(cellKey);
 		if (cell != null)
 		{
 			cellsList.remove(cell);
@@ -846,7 +934,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	 * 
 	 * @return the paremeters list
 	 */
-	public List getParametersList()
+	public List<JRCrosstabParameter> getParametersList()
 	{
 		return parametersList;
 	}
@@ -857,7 +945,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	 * 
 	 * @return the parameters indexed by names
 	 */
-	public Map getParametersMap()
+	public Map<String, JRCrosstabParameter> getParametersMap()
 	{
 		return parametersMap;
 	}
@@ -891,6 +979,29 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_PARAMETERS, parameter, parametersList.size() - 1);
 	}
 	
+	/**
+	 * Adds a parameter to the crosstab.
+	 * 
+	 * @param parameter the parameter
+	 * @throws JRException
+	 * @see JRCrosstab#getMeasures()
+	 */
+	public void addParameter(int index, JRCrosstabParameter parameter) throws JRException
+	{
+		if (parametersMap.containsKey(parameter.getName()))
+		{
+			if (parametersMap.containsKey(parameter.getName()))
+			{
+				throw new JRException("Duplicate declaration of parameter : " + parameter.getName());
+			}
+		}
+		
+		parametersMap.put(parameter.getName(), parameter);
+		parametersList.add(index, parameter);
+		
+		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_PARAMETERS, parameter, index);
+	}
+	
 	
 	/**
 	 * Removes a parameter.
@@ -900,7 +1011,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	 */
 	public JRCrosstabParameter removeParameter(String parameterName)
 	{
-		JRCrosstabParameter param = (JRCrosstabParameter) parametersMap.remove(parameterName);
+		JRCrosstabParameter param = parametersMap.remove(parameterName);
 		
 		if (param != null)
 		{
@@ -947,10 +1058,10 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	 * 
 	 * @return the variables of this crosstab indexed by name
 	 */
-	public Map getVariablesMap()
+	public Map<String, JRVariable> getVariablesMap()
 	{
 		JRVariable[] variables = getVariables();
-		Map variablesMap = new HashMap();
+		Map<String, JRVariable> variablesMap = new HashMap<String, JRVariable>();
 		
 		for (int i = 0; i < variables.length; i++)
 		{
@@ -1010,9 +1121,9 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	}
 
 	
-	protected void setGroupVariablesClass(List groups)
+	protected <T> void setGroupVariablesClass(List<T> groups)
 	{
-		for (Iterator it = groups.iterator(); it.hasNext();)
+		for (Iterator<T> it = groups.iterator(); it.hasNext();)
 		{
 			JRDesignCrosstabGroup group = (JRDesignCrosstabGroup) it.next();
 			JRCrosstabBucket bucket = group.getBucket();
@@ -1021,7 +1132,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 				JRExpression expression = bucket.getExpression();
 				if (expression != null)
 				{
-					group.designVariable.setValueClassName(expression.getValueClassName());
+					group.designVariable.setValueClassName(bucket.getValueClassName());
 				}
 			}
 		}
@@ -1055,13 +1166,13 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	protected void createCellMatrix()
 	{
 		crossCells = new JRDesignCrosstabCell[rowGroups.size() + 1][columnGroups.size() + 1];
-		for (Iterator it = cellsList.iterator(); it.hasNext();)
+		for (Iterator<JRCrosstabCell> it = cellsList.iterator(); it.hasNext();)
 		{
 			JRDesignCrosstabCell crosstabCell = (JRDesignCrosstabCell) it.next();
 			JRDesignCellContents contents = (JRDesignCellContents) crosstabCell.getContents();
 			
 			String rowTotalGroup = crosstabCell.getRowTotalGroup();
-			int rowGroupIndex = rowTotalGroup == null ? rowGroups.size() : ((Integer) rowGroupsMap.get(rowTotalGroup)).intValue();
+			int rowGroupIndex = rowTotalGroup == null ? rowGroups.size() : (rowGroupsMap.get(rowTotalGroup)).intValue();
 			
 			Integer cellWidth = crosstabCell.getWidth();
 			if (cellWidth != null)
@@ -1070,7 +1181,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 			}
 
 			String columnTotalGroup = crosstabCell.getColumnTotalGroup();
-			int columnGroupIndex = columnTotalGroup == null ? columnGroups.size() : ((Integer) columnGroupsMap.get(columnTotalGroup)).intValue();
+			int columnGroupIndex = columnTotalGroup == null ? columnGroups.size() : (columnGroupsMap.get(columnTotalGroup)).intValue();
 			Integer cellHeight = crosstabCell.getHeight();
 			if (cellHeight != null)
 			{
@@ -1132,11 +1243,11 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		JRDesignCrosstabCell emptyCell = new JRDesignCrosstabCell();
 		if (i < rowGroups.size())
 		{
-			emptyCell.setRowTotalGroup(((JRCrosstabRowGroup) rowGroups.get(i)).getName());
+			emptyCell.setRowTotalGroup((rowGroups.get(i)).getName());
 		}
 		if (j < columnGroups.size())
 		{
-			emptyCell.setColumnTotalGroup(((JRCrosstabColumnGroup) columnGroups.get(j)).getName());
+			emptyCell.setColumnTotalGroup((columnGroups.get(j)).getName());
 		}
 		return emptyCell;
 	}
@@ -1357,20 +1468,20 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	
 	protected void measureClassChanged(JRDesignCrosstabMeasure measure, String valueClassName)
 	{
-		for (Iterator colIt = columnGroups.iterator(); colIt.hasNext();)
+		for (Iterator<JRCrosstabColumnGroup> colIt = columnGroups.iterator(); colIt.hasNext();)
 		{
-			JRCrosstabColumnGroup colGroup = (JRCrosstabColumnGroup) colIt.next();
+			JRCrosstabColumnGroup colGroup = colIt.next();
 			setTotalVarClass(measure, null, colGroup, valueClassName);
 		}
 		
-		for (Iterator rowIt = rowGroups.iterator(); rowIt.hasNext();)
+		for (Iterator<JRCrosstabRowGroup> rowIt = rowGroups.iterator(); rowIt.hasNext();)
 		{
-			JRCrosstabRowGroup rowGroup = (JRCrosstabRowGroup) rowIt.next();
+			JRCrosstabRowGroup rowGroup = rowIt.next();
 			setTotalVarClass(measure, rowGroup, null, valueClassName);
 			
-			for (Iterator colIt = columnGroups.iterator(); colIt.hasNext();)
+			for (Iterator<JRCrosstabColumnGroup> colIt = columnGroups.iterator(); colIt.hasNext();)
 			{
-				JRCrosstabColumnGroup colGroup = (JRCrosstabColumnGroup) colIt.next();
+				JRCrosstabColumnGroup colGroup = colIt.next();
 				setTotalVarClass(measure, rowGroup, colGroup, valueClassName);
 			}
 		}
@@ -1402,23 +1513,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		return (JRDesignVariable) variablesList.get(varName);
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #getRunDirectionValue()}.
-	 */
-	public byte getRunDirection()
-	{
-		return getRunDirectionValue() == null ? null : getRunDirectionValue().getValue();
-	}
-
 	
-	/**
-	 * @deprecated Replaced by {@link #setRunDirection(RunDirectionEnum)}.
-	 */
-	public void setRunDirection(byte runDirection)
-	{
-		setRunDirection(RunDirectionEnum.getByValue(runDirection));
-	}
-
 	/**
 	 *
 	 */
@@ -1470,34 +1565,27 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		
 		if (parametersList != null)
 		{
-			clone.parametersList = new ArrayList(parametersList.size());
-			clone.parametersMap = new HashMap(parametersList.size());
+			clone.parametersList = new ArrayList<JRCrosstabParameter>(parametersList.size());
+			clone.parametersMap = new HashMap<String, JRCrosstabParameter>(parametersList.size());
 			for(int i = 0; i < parametersList.size(); i++)
 			{
-				JRCrosstabParameter parameter = 
-					(JRCrosstabParameter)((JRCrosstabParameter)parametersList.get(i)).clone();
+				JRCrosstabParameter parameter = JRCloneUtils.nullSafeClone(parametersList.get(i));
 				clone.parametersList.add(parameter);
 				clone.parametersMap.put(parameter.getName(), parameter);
 			}
 		}
 		
-		if (parametersMapExpression != null)
-		{
-			clone.parametersMapExpression = (JRExpression)parametersMapExpression.clone();
-		}
-		if (dataset != null)
-		{
-			clone.dataset = (JRDesignCrosstabDataset)dataset.clone();
-		}
+		clone.parametersMapExpression = JRCloneUtils.nullSafeClone(parametersMapExpression);
+		clone.dataset = JRCloneUtils.nullSafeClone(dataset);
 		
 		// keep group and measure cloned variables to reuse the clone instances
 		// in the variables list
-		Map clonedVariables = new HashMap();
+		Map<JRVariable,JRVariable> clonedVariables = new HashMap<JRVariable,JRVariable>();
 		
 		if (rowGroups != null)
 		{
-			clone.rowGroups = new ArrayList(rowGroups.size());
-			clone.rowGroupsMap = new HashMap(rowGroups.size());
+			clone.rowGroups = new ArrayList<JRCrosstabRowGroup>(rowGroups.size());
+			clone.rowGroupsMap = new HashMap<String, Integer>(rowGroups.size());
 			for(int i = 0; i < rowGroups.size(); i++)
 			{
 				JRDesignCrosstabRowGroup group = 
@@ -1519,8 +1607,8 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		
 		if (columnGroups != null)
 		{
-			clone.columnGroups = new ArrayList(columnGroups.size());
-			clone.columnGroupsMap = new HashMap(columnGroups.size());
+			clone.columnGroups = new ArrayList<JRCrosstabColumnGroup>(columnGroups.size());
+			clone.columnGroupsMap = new HashMap<String, Integer>(columnGroups.size());
 			for(int i = 0; i < columnGroups.size(); i++)
 			{
 				JRDesignCrosstabColumnGroup group = 
@@ -1542,14 +1630,13 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		
 		if (measures != null)
 		{
-			clone.measures = new ArrayList(measures.size());
-			clone.measuresMap = new HashMap(measures.size());
+			clone.measures = new ArrayList<JRCrosstabMeasure>(measures.size());
+			clone.measuresMap = new HashMap<String,Integer>(measures.size());
 			for(int i = 0; i < measures.size(); i++)
 			{
 				JRDesignCrosstabMeasure measure = 
 					(JRDesignCrosstabMeasure) measures.get(i);
-				JRDesignCrosstabMeasure clonedMeasure = 
-					(JRDesignCrosstabMeasure) measure.clone();
+				JRDesignCrosstabMeasure clonedMeasure = JRCloneUtils.nullSafeClone(measure);
 				clone.measures.add(clonedMeasure);
 				clone.measuresMap.put(clonedMeasure.getName(), Integer.valueOf(i));
 				
@@ -1564,27 +1651,23 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		if (variablesList != null)
 		{
 			clone.variablesList = new SequencedHashMap(variablesList.size());
-			for(Iterator it = variablesList.values().iterator(); it.hasNext();)
+			for(Iterator<?> it = variablesList.values().iterator(); it.hasNext();)
 			{
 				JRVariable variable = (JRVariable) it.next();
 				// check whether the variable was already cloned as part of a group or measure
-				JRVariable variableClone = (JRVariable) clonedVariables.get(variable);
-				if (variableClone == null)
-				{
-					variableClone = (JRVariable) variable.clone();
-				}
+				JRVariable variableClone = clonedVariables.get(variable);
+				variableClone = JRCloneUtils.nullSafeClone(variable);
 				clone.variablesList.put(variableClone.getName(), variableClone);
 			}
 		}
 		
 		if (cellsList != null)
 		{
-			clone.cellsList = new ArrayList(cellsList.size());
-			clone.cellsMap = new HashMap(cellsList.size());
+			clone.cellsList = new ArrayList<JRCrosstabCell>(cellsList.size());
+			clone.cellsMap = new HashMap<Pair,JRCrosstabCell>(cellsList.size());
 			for(int i = 0; i < cellsList.size(); i++)
 			{
-				JRDesignCrosstabCell cell = 
-					(JRDesignCrosstabCell)((JRDesignCrosstabCell)cellsList.get(i)).clone();
+				JRCrosstabCell cell = JRCloneUtils.nullSafeClone(cellsList.get(i));
 				adjustCrosstabReference(clone, (JRDesignCellContents) cell.getContents());
 				clone.cellsList.add(cell);
 				clone.cellsMap.put(new Pair(cell.getRowTotalGroup(), cell.getColumnTotalGroup()), cell);
@@ -1594,16 +1677,10 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		// clone not preprocessed
 		clone.crossCells = null;
 		
-		if (whenNoDataCell != null)
-		{
-			clone.whenNoDataCell = (JRDesignCellContents)whenNoDataCell.clone();
-			adjustCrosstabReference(clone, clone.whenNoDataCell);
-		}
-		if (headerCell != null)
-		{
-			clone.headerCell = (JRDesignCellContents)headerCell.clone();
-			adjustCrosstabReference(clone, clone.headerCell);
-		}
+		clone.whenNoDataCell = JRCloneUtils.nullSafeClone(whenNoDataCell);
+		adjustCrosstabReference(clone, clone.whenNoDataCell);
+		clone.headerCell = JRCloneUtils.nullSafeClone(headerCell);
+		adjustCrosstabReference(clone, clone.headerCell);
 
 		return clone;
 	}
@@ -1630,32 +1707,32 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 			);
 	}
 	
-	public List getRowGroupsList()
+	public List<JRCrosstabRowGroup> getRowGroupsList()
 	{
 		return rowGroups;
 	}
 	
-	public Map getRowGroupIndicesMap()
+	public Map<String, Integer> getRowGroupIndicesMap()
 	{
 		return rowGroupsMap;
 	}
 	
-	public List getColumnGroupsList()
+	public List<JRCrosstabColumnGroup> getColumnGroupsList()
 	{
 		return columnGroups;
 	}
 	
-	public Map getColumnGroupIndicesMap()
+	public Map<String, Integer> getColumnGroupIndicesMap()
 	{
 		return columnGroupsMap;
 	}
 	
-	public List getMesuresList()
+	public List<JRCrosstabMeasure> getMesuresList()
 	{
 		return measures;
 	}
 	
-	public Map getMeasureIndicesMap()
+	public Map<String, Integer> getMeasureIndicesMap()
 	{
 		return measuresMap;
 	}
