@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -36,7 +36,7 @@ import net.sf.jasperreports.engine.type.SortOrderEnum;
  * to be used for report designing.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRDesignCrosstabBucket.java 3583 2010-03-12 11:35:40Z shertage $
+ * @version $Id: JRDesignCrosstabBucket.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRDesignCrosstabBucket extends JRBaseCrosstabBucket implements JRChangeEventsSupport
 {
@@ -50,6 +50,8 @@ public class JRDesignCrosstabBucket extends JRBaseCrosstabBucket implements JRCh
 
 	public static final String PROPERTY_ORDER = "order";
 
+	public static final String PROPERTY_VALUE_CLASS = "valueClassName";
+
 	
 	/**
 	 * Creates a crosstab group bucket.
@@ -106,14 +108,6 @@ public class JRDesignCrosstabBucket extends JRBaseCrosstabBucket implements JRCh
 	}
 
 	
-	/**
-	 * @deprecated Replaced by {@link #setOrder(SortOrderEnum)}.
-	 */
-	public void setOrder(byte order)
-	{
-		setOrder(SortOrderEnum.getByValue(order));
-	}
-	
 	/**
 	 * Sets the sorting type.
 	 * 
@@ -131,6 +125,35 @@ public class JRDesignCrosstabBucket extends JRBaseCrosstabBucket implements JRCh
 		getEventSupport().firePropertyChange(PROPERTY_ORDER, old, this.orderValue);
 	}
 	
+
+	/**
+	 * Sets the bucket value class name.
+	 * 
+	 * @param valueClassName the bucket value class name
+	 * @see net.sf.jasperreports.crosstabs.JRCrosstabBucket#getValueClassName()
+	 */
+	public void setValueClassName(String valueClassName)
+	{
+		String old = this.valueClassName;
+		
+		this.valueClassName = valueClassName;
+		this.valueClass = null;
+		this.valueClassRealName = null;
+		
+		getEventSupport().firePropertyChange(PROPERTY_VALUE_CLASS, old,
+				this.valueClassName);
+	}
+	
+	/**
+	 * 
+	 */
+	public Object clone()
+	{
+		JRDesignCrosstabBucket clone = (JRDesignCrosstabBucket)super.clone();
+		clone.eventSupport = null;
+		return clone;
+	}
+	
 	private transient JRPropertyChangeSupport eventSupport;
 	
 	public JRPropertyChangeSupport getEventSupport()
