@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,7 +35,7 @@ import net.sf.jasperreports.engine.type.CalculationEnum;
  * Base crosstab row/column group implementation to be used at design time.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRDesignCrosstabGroup.java 3583 2010-03-12 11:35:40Z shertage $
+ * @version $Id: JRDesignCrosstabGroup.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public abstract class JRDesignCrosstabGroup extends JRBaseCrosstabGroup implements JRChangeEventsSupport
 {
@@ -86,15 +86,6 @@ public abstract class JRDesignCrosstabGroup extends JRBaseCrosstabGroup implemen
 	}
 	
 	
-	/**
-	 * @deprecated Replaced by {@link #setTotalPosition(CrosstabTotalPositionEnum)}.
-	 */
-	public void setTotalPosition(byte totalPosition)
-	{
-		setTotalPosition(CrosstabTotalPositionEnum.getByValue(totalPosition));
-	}
-	
-	
 	/**
 	 * Sets the position of the total row/column.
 	 * 
@@ -198,6 +189,7 @@ public abstract class JRDesignCrosstabGroup extends JRBaseCrosstabGroup implemen
 	{
 		JRDesignCrosstabGroup clone = (JRDesignCrosstabGroup) clone();
 		clone.setParent(parent);
+		clone.eventSupport = null;
 		return clone;
 	}
 	
