@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -34,7 +34,7 @@ import net.sf.jasperreports.engine.JRConstants;
  * Crosstab row group implementation to be used for report designing.
  *  
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRDesignCrosstabRowGroup.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRDesignCrosstabRowGroup.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRDesignCrosstabRowGroup extends JRDesignCrosstabGroup implements JRCrosstabRowGroup
 {
@@ -52,28 +52,12 @@ public class JRDesignCrosstabRowGroup extends JRDesignCrosstabGroup implements J
 		super();
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getPositionValue()}.
-	 */
-	public byte getPosition()
-	{
-		return getPositionValue().getValue();
-	}
-
 	public CrosstabRowPositionEnum getPositionValue()
 	{
 		return positionValue;
 	}
 	
 	
-	/**
-	 * @deprecated Replaced by {@link #setPosition(CrosstabRowPositionEnum)}.
-	 */
-	public void setPosition(byte position)
-	{
-		setPosition(CrosstabRowPositionEnum.getByValue(position));
-	}
-
 	/**
 	 * Sets the header contents stretch position.
 	 * 
