@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -31,7 +31,7 @@ import net.sf.jasperreports.crosstabs.type.CrosstabRowPositionEnum;
  * Crosstab row group implementation used at fill time.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRFillCrosstabRowGroup.java 3498 2010-03-03 14:24:19Z teodord $
+ * @version $Id: JRFillCrosstabRowGroup.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRFillCrosstabRowGroup extends JRFillCrosstabGroup implements JRCrosstabRowGroup
 {
@@ -42,15 +42,6 @@ public class JRFillCrosstabRowGroup extends JRFillCrosstabGroup implements JRCro
 	}
 
 
-	/**
-	 * @deprecated Replaced by {@link #getPositionValue()}.
-	 */
-	public byte getPosition()
-	{
-		return getPositionValue().getValue();
-	}
-
-
 	public CrosstabRowPositionEnum getPositionValue()
 	{
 		return ((JRCrosstabRowGroup) parentGroup).getPositionValue();
