@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,13 +35,13 @@ import net.sf.jasperreports.engine.type.CalculationEnum;
  * Crosstab measure definition.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: MeasureDefinition.java 3529 2010-03-06 16:46:03Z teodord $
+ * @version $Id: MeasureDefinition.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class MeasureDefinition
 {
 	protected CalculationEnum calculation;
 	protected final JRExtendedIncrementerFactory incrementerFactory;
-	protected final Class valueClass;
+	protected final Class<?> valueClass;
 	protected final boolean isSystemDefined;
 	
 	
@@ -53,7 +53,7 @@ public class MeasureDefinition
 	 * @param incrementerFactory the incrementer factory
 	 */
 	public MeasureDefinition(
-			Class valueClass, 
+			Class<?> valueClass, 
 			CalculationEnum calculation, 
 			JRExtendedIncrementerFactory incrementerFactory) 
 	{
@@ -61,7 +61,7 @@ public class MeasureDefinition
 	}
 	
 	protected MeasureDefinition(
-			Class valueClass, 
+			Class<?> valueClass, 
 			CalculationEnum calculation, 
 			JRExtendedIncrementerFactory incrementerFactory, 
 			boolean isSystemDefined)
@@ -141,7 +141,7 @@ public class MeasureDefinition
 	 * 
 	 * @return the measure value class
 	 */
-	public Class getValueClass()
+	public Class<?> getValueClass()
 	{
 		return valueClass;
 	}
