@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -28,7 +28,6 @@ import java.io.InputStream;
 import java.math.BigDecimal;
 import java.math.BigInteger;
 import java.net.URL;
-import java.net.URLStreamHandlerFactory;
 import java.text.DateFormat;
 import java.text.NumberFormat;
 import java.text.ParseException;
@@ -54,30 +53,25 @@ import net.sf.jasperreports.engine.export.data.NumberTextValue;
 import net.sf.jasperreports.engine.export.data.StringTextValue;
 import net.sf.jasperreports.engine.export.data.TextValue;
 import net.sf.jasperreports.engine.util.DefaultFormatFactory;
-import net.sf.jasperreports.engine.util.FileResolver;
 import net.sf.jasperreports.engine.util.FormatFactory;
 import net.sf.jasperreports.engine.util.JRClassLoader;
 import net.sf.jasperreports.engine.util.JRDataUtils;
 import net.sf.jasperreports.engine.util.JRFontUtil;
 import net.sf.jasperreports.engine.util.JRLoader;
 import net.sf.jasperreports.engine.util.JRProperties;
-import net.sf.jasperreports.engine.util.JRResourcesUtil;
+import net.sf.jasperreports.engine.util.JRProperties.PropertySuffix;
 import net.sf.jasperreports.engine.util.JRStyledText;
 import net.sf.jasperreports.engine.util.JRStyledTextParser;
-import net.sf.jasperreports.engine.util.JRProperties.PropertySuffix;
+import net.sf.jasperreports.repo.RepositoryUtil;
+import net.sf.jasperreports.repo.SimpleRepositoryContext;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRAbstractExporter.java 3941 2010-08-20 10:55:10Z teodord $
+ * @version $Id: JRAbstractExporter.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public abstract class JRAbstractExporter implements JRExporter
 {
-	/**
-	 * Property that stores the formula which has to be applied to a given cell in an excel sheet.
-	 */
-	public static final String PROPERTY_CELL_FORMULA = JRProperties.PROPERTY_PREFIX + "export.xls.formula";
-
 	/**
 	 * A property that gives the generic default filter factory class name.
 	 * 
@@ -110,7 +104,7 @@ public abstract class JRAbstractExporter implements JRExporter
 			return jasperPrint;
 		}
 
-		public Map getExportParameters()
+		public Map<JRExporterParameter,Object> getExportParameters()
 		{
 			return parameters;
 		}
@@ -171,13 +165,13 @@ public abstract class JRAbstractExporter implements JRExporter
 			}
 			else
 			{
-				List properties = JRProperties.getProperties(jasperPrint.getPropertiesMap(), propertyPrefix);
+				List<PropertySuffix> properties = JRProperties.getProperties(jasperPrint.getPropertiesMap(), propertyPrefix);
 				if (properties != null)
 				{
 					values = new String[properties.size()];
 					for(int i = 0; i < values.length; i++)
 					{
-						values[i] = ((PropertySuffix)properties.get(i)).getValue();
+						values[i] = properties.get(i).getValue();
 					}
 				}
 			}
@@ -327,13 +321,13 @@ public abstract class JRAbstractExporter implements JRExporter
 			JRPropertiesMap hintsMap = jasperPrint.getPropertiesMap();
 			if (hintsMap != null)
 			{
-				List properties = JRProperties.getProperties(hintsMap, propertyPrefix);
+				List<PropertySuffix> properties = JRProperties.getProperties(hintsMap, propertyPrefix);
 				if (properties != null)
 				{
 					values = new String[properties.size()];
 					for(int i = 0; i < values.length; i++)
 					{
-						values[i] = ((PropertySuffix)properties.get(i)).getValue();
+						values[i] = properties.get(i).getValue();
 					}
 				}
 			}
@@ -489,44 +483,50 @@ public abstract class JRAbstractExporter implements JRExporter
 	/**
 	 *
 	 */
-	protected Map parameters = new HashMap();
+	protected Map<JRExporterParameter,Object> parameters = new HashMap<JRExporterParameter,Object>();
 
 	/**
 	 *
 	 */
-	protected List jasperPrintList;
+	protected List<JasperPrint> jasperPrintList;
 	protected JasperPrint jasperPrint;
 	protected boolean isModeBatch = true;
 	protected int startPageIndex;
 	protected int endPageIndex;
 	protected int globalOffsetX;
 	protected int globalOffsetY;
-	protected ClassLoader classLoader;
-	protected boolean classLoaderSet;
-	protected URLStreamHandlerFactory urlHandlerFactory;
-	protected boolean urlHandlerFactorySet;
-	protected FileResolver fileResolver;
-	protected boolean fileResolverSet;
+//	protected ClassLoader classLoader;
+//	protected boolean classLoaderSet;
+//	protected URLStreamHandlerFactory urlHandlerFactory;
+//	protected boolean urlHandlerFactorySet;
+//	protected FileResolver fileResolver;
+//	protected boolean fileResolverSet;
 	protected ExporterFilter filter;
 
 	/**
 	 *
 	 */
-	private LinkedList elementOffsetStack = new LinkedList();
+	private LinkedList<int[]> elementOffsetStack = new LinkedList<int[]>();
 	private int elementOffsetX = globalOffsetX;
 	private int elementOffsetY = globalOffsetY;
 
 	/**
 	 *
 	 */
-	protected Map dateFormatCache = new HashMap();
-	protected Map numberFormatCache = new HashMap();
+	protected Map<String, DateFormat> dateFormatCache = new HashMap<String, DateFormat>();
+	protected Map<String, NumberFormat> numberFormatCache = new HashMap<String, NumberFormat>();
 
 	/**
 	 *
 	 */
 	protected JRHyperlinkProducerFactory hyperlinkProducerFactory;
 	
+	/**
+	 *
+	 */
+	private ReportContext reportContext;
+	
+	
 	/**
 	 *
 	 */
@@ -540,8 +540,8 @@ public abstract class JRAbstractExporter implements JRExporter
 	 */
 	public void reset()
 	{
-		parameters = new HashMap();
-		elementOffsetStack = new LinkedList();
+		parameters = new HashMap<JRExporterParameter,Object>();
+		elementOffsetStack = new LinkedList<int[]>();
 	}
 	
 	
@@ -566,7 +566,7 @@ public abstract class JRAbstractExporter implements JRExporter
 	/**
 	 *
 	 */
-	public void setParameters(Map parameters)
+	public void setParameters(Map<JRExporterParameter,Object> parameters)
 	{
 		this.parameters = parameters;
 	}
@@ -575,7 +575,7 @@ public abstract class JRAbstractExporter implements JRExporter
 	/**
 	 *
 	 */
-	public Map getParameters()
+	public Map<JRExporterParameter,Object> getParameters()
 	{
 		return parameters;
 	}
@@ -671,6 +671,24 @@ public abstract class JRAbstractExporter implements JRExporter
 	}
 
 	
+	/**
+	 *
+	 */
+	public void setReportContext(ReportContext reportContext)
+	{
+		this.reportContext = reportContext;
+	}
+
+	
+	/**
+	 *
+	 */
+	public ReportContext getReportContext()
+	{
+		return reportContext;
+	}
+
+	
 	/**
 	 *
 	 */
@@ -720,30 +738,37 @@ public abstract class JRAbstractExporter implements JRExporter
 	 */
 	protected void setExportContext()
 	{
-		classLoaderSet = false;
-		urlHandlerFactorySet = false;
-		fileResolverSet = false;
-		
-		classLoader = (ClassLoader)parameters.get(JRExporterParameter.CLASS_LOADER);
-		if (classLoader != null)
-		{
-			JRResourcesUtil.setThreadClassLoader(classLoader);
-			classLoaderSet = true;
-		}
+//		classLoaderSet = false;
+//		urlHandlerFactorySet = false;
+//		fileResolverSet = false;
+//		
+//		classLoader = (ClassLoader)parameters.get(JRExporterParameter.CLASS_LOADER);
+//		if (classLoader != null)
+//		{
+//			JRResourcesUtil.setThreadClassLoader(classLoader);
+//			classLoaderSet = true;
+//		}
+//
+//		urlHandlerFactory = (URLStreamHandlerFactory) parameters.get(JRExporterParameter.URL_HANDLER_FACTORY);
+//		if (urlHandlerFactory != null)
+//		{
+//			JRResourcesUtil.setThreadURLHandlerFactory(urlHandlerFactory);
+//			urlHandlerFactorySet = true;
+//		}
+//
+//		fileResolver = (FileResolver) parameters.get(JRExporterParameter.FILE_RESOLVER);
+//		if (fileResolver != null)
+//		{
+//			JRResourcesUtil.setThreadFileResolver(fileResolver);
+//			fileResolverSet = true;
+//		}
 
-		urlHandlerFactory = (URLStreamHandlerFactory) parameters.get(JRExporterParameter.URL_HANDLER_FACTORY);
-		if (urlHandlerFactory != null)
-		{
-			JRResourcesUtil.setThreadURLHandlerFactory(urlHandlerFactory);
-			urlHandlerFactorySet = true;
-		}
+		Map<String, Object> contextParamValues = new HashMap<String, Object>(3);
+		contextParamValues.put(JRParameter.REPORT_CLASS_LOADER, parameters.get(JRExporterParameter.CLASS_LOADER));
+		contextParamValues.put(JRParameter.REPORT_URL_HANDLER_FACTORY, parameters.get(JRExporterParameter.URL_HANDLER_FACTORY));
+		contextParamValues.put(JRParameter.REPORT_FILE_RESOLVER, parameters.get(JRExporterParameter.FILE_RESOLVER));
 
-		fileResolver = (FileResolver) parameters.get(JRExporterParameter.FILE_RESOLVER);
-		if (fileResolver != null)
-		{
-			JRResourcesUtil.setThreadFileResolver(fileResolver);
-			fileResolverSet = true;
-		}
+		RepositoryUtil.setRepositoryContext(new SimpleRepositoryContext(contextParamValues));
 		
 		JRFontUtil.resetThreadMissingFontsCache();
 	}
@@ -754,20 +779,22 @@ public abstract class JRAbstractExporter implements JRExporter
 	 */
 	protected void resetExportContext()
 	{
-		if (classLoaderSet)
-		{
-			JRResourcesUtil.resetClassLoader();
-		}
-		
-		if (urlHandlerFactorySet)
-		{
-			JRResourcesUtil.resetThreadURLHandlerFactory();
-		}
-		
-		if (fileResolverSet)
-		{
-			JRResourcesUtil.resetThreadFileResolver();
-		}
+//		if (classLoaderSet)
+//		{
+//			JRResourcesUtil.resetClassLoader();
+//		}
+//		
+//		if (urlHandlerFactorySet)
+//		{
+//			JRResourcesUtil.resetThreadURLHandlerFactory();
+//		}
+//		
+//		if (fileResolverSet)
+//		{
+//			JRResourcesUtil.resetThreadFileResolver();
+//		}
+
+		RepositoryUtil.revertRepositoryContext();
 	}
 
 	
@@ -806,7 +833,7 @@ public abstract class JRAbstractExporter implements JRExporter
 	 */
 	protected void setInput() throws JRException
 	{
-		jasperPrintList = (List)parameters.get(JRExporterParameter.JASPER_PRINT_LIST);
+		jasperPrintList = (List<JasperPrint>)parameters.get(JRExporterParameter.JASPER_PRINT_LIST);
 		if (jasperPrintList == null)
 		{
 			isModeBatch = false;
@@ -838,7 +865,7 @@ public abstract class JRAbstractExporter implements JRExporter
 							String fileName = (String)parameters.get(JRExporterParameter.INPUT_FILE_NAME);
 							if (fileName != null)
 							{
-								jasperPrint = (JasperPrint)JRLoader.loadObject(fileName);
+								jasperPrint = (JasperPrint)JRLoader.loadObjectFromFile(fileName);
 							}
 							else
 							{
@@ -849,7 +876,7 @@ public abstract class JRAbstractExporter implements JRExporter
 				}
 			}
 			
-			jasperPrintList = new ArrayList();
+			jasperPrintList = new ArrayList<JasperPrint>();
 			jasperPrintList.add(jasperPrint);
 		}
 		else
@@ -861,7 +888,7 @@ public abstract class JRAbstractExporter implements JRExporter
 				throw new JRException("Empty input source supplied to the exporter in batch mode.");
 			}
 
-			jasperPrint = (JasperPrint)jasperPrintList.get(0);
+			jasperPrint = jasperPrintList.get(0);
 		}
 
 		setJasperPrint(jasperPrint);
@@ -1018,7 +1045,7 @@ public abstract class JRAbstractExporter implements JRExporter
 	 */
 	protected void restoreElementOffsets()
 	{
-		int[] offsets = (int[]) elementOffsetStack.removeLast();
+		int[] offsets = elementOffsetStack.removeLast();
 		elementOffsetX = offsets[0];
 		elementOffsetY = offsets[1];
 	}
@@ -1071,7 +1098,7 @@ public abstract class JRAbstractExporter implements JRExporter
 		{
 			try
 			{
-				Class valueClass = JRClassLoader.loadClassForRealName(text.getValueClassName());
+				Class<?> valueClass = JRClassLoader.loadClassForRealName(text.getValueClassName());
 				if (java.lang.Number.class.isAssignableFrom(valueClass))
 				{
 					textValue = getNumberCellValue(text, textStr);
@@ -1108,78 +1135,69 @@ public abstract class JRAbstractExporter implements JRExporter
 		return new StringTextValue(textStr);
 	}
 
-	protected TextValue getBooleanCellValue(JRPrintText text, String textStr)
-	{
-		Boolean value = null;
-		if (textStr != null && textStr.length() > 0)
-		{
-			value = Boolean.valueOf(textStr);
-		}
-		return new BooleanTextValue(textStr, value);
-	}
-
 	protected TextValue getDateCellValue(JRPrintText text, String textStr) throws ParseException
 	{
-		TextValue textValue;
-		String pattern = text.getPattern();
-		if (pattern == null || pattern.trim().length() == 0)
-		{
-			textValue = getTextValueString(text, textStr);
-		}
-		else
-		{
-			DateFormat dateFormat = getDateFormat(getTextFormatFactoryClass(text), pattern, getTextLocale(text), getTextTimeZone(text));
-			
-			Date value = null;
-			if (textStr != null && textStr.length() > 0)
-			{
-				value = dateFormat.parse(textStr);
-			}
-			textValue = new DateTextValue(textStr, value, pattern);
-		}
-		return textValue;
+		return new DateTextValue(textStr, (Date)text.getValue(), text.getPattern());
+//		TextValue textValue;
+//		String pattern = text.getPattern();
+//		if (pattern == null || pattern.trim().length() == 0)
+//		{
+//			textValue = getTextValueString(text, textStr);
+//		}
+//		else
+//		{
+//			DateFormat dateFormat = getDateFormat(getTextFormatFactoryClass(text), pattern, getTextLocale(text), getTextTimeZone(text));
+//			
+//			Date value = null;
+//			if (textStr != null && textStr.length() > 0)
+//			{
+//				value = dateFormat.parse(textStr);
+//			}
+//			textValue = new DateTextValue(textStr, value, getPattern(text));
+//		}
+//		return textValue;
 	}
 
 	protected TextValue getNumberCellValue(JRPrintText text, String textStr) throws ParseException, ClassNotFoundException
 	{
-		TextValue textValue;
-		String pattern = text.getPattern();
-		if (pattern == null || pattern.trim().length() == 0)
-		{
-			if (textStr != null && textStr.length() > 0)
-			{
-				Number value = defaultParseNumber(textStr, JRClassLoader.loadClassForRealName(text.getValueClassName()));
-
-				if (value != null)
-				{
-					textValue = new NumberTextValue(textStr, value, null);
-				}
-				else
-				{
-					textValue = getTextValueString(text, textStr);
-				}
-			}
-			else
-			{
-				textValue = new NumberTextValue(textStr, null, null);
-			}
-		}
-		else
-		{
-			NumberFormat numberFormat = getNumberFormat(getTextFormatFactoryClass(text), pattern, getTextLocale(text));
-			
-			Number value = null;
-			if (textStr != null && textStr.length() > 0)
-			{
-				value = numberFormat.parse(textStr);
-			}
-			textValue = new NumberTextValue(textStr, value, pattern);
-		}
-		return textValue;
+		return new NumberTextValue(textStr, (Number)text.getValue(), text.getPattern());
+//		TextValue textValue;
+//		String pattern = text.getPattern();
+//		if (pattern == null || pattern.trim().length() == 0)
+//		{
+//			if (textStr != null && textStr.length() > 0)
+//			{
+//				Number value = defaultParseNumber(textStr, JRClassLoader.loadClassForRealName(text.getValueClassName()));
+//
+//				if (value != null)
+//				{
+//					textValue = new NumberTextValue(textStr, value, getPattern(text));
+//				}
+//				else
+//				{
+//					textValue = getTextValueString(text, textStr);
+//				}
+//			}
+//			else
+//			{
+//				textValue = new NumberTextValue(textStr, null, getPattern(text));
+//			}
+//		}
+//		else
+//		{
+//			NumberFormat numberFormat = getNumberFormat(getTextFormatFactoryClass(text), pattern, getTextLocale(text));
+//			
+//			Number value = null;
+//			if (textStr != null && textStr.length() > 0)
+//			{
+//				value = numberFormat.parse(textStr);
+//			}
+//			textValue = new NumberTextValue(textStr, value, getPattern(text));
+//		}
+//		return textValue;
 	}
 
-
-	protected Number defaultParseNumber(String textStr, Class valueClass)
+	protected Number defaultParseNumber(String textStr, Class<?> valueClass)
 	{
 		Number value = null;
 		try
@@ -1224,6 +1242,15 @@ public abstract class JRAbstractExporter implements JRExporter
 		return value;
 	}
 	
+	protected TextValue getBooleanCellValue(JRPrintText text, String textStr)
+	{
+		Boolean value = null;
+		if (textStr != null && textStr.length() > 0)
+		{
+			value = Boolean.valueOf(textStr);
+		}
+		return new BooleanTextValue(textStr, value);
+	}
 
 	protected DateFormat getDateFormat(String formatFactoryClass, String pattern, Locale lc, TimeZone tz)
 	{
@@ -1231,7 +1258,7 @@ public abstract class JRAbstractExporter implements JRExporter
 			+ "|" + pattern 
 			+ "|" + (lc == null ? "" : JRDataUtils.getLocaleCode(lc)) 
 			+ "|" + (tz == null ? "" : JRDataUtils.getTimeZoneId(tz));
-		DateFormat dateFormat = (DateFormat)dateFormatCache.get(key);
+		DateFormat dateFormat = dateFormatCache.get(key);
 		if (dateFormat == null)
 		{
 			FormatFactory formatFactory = DefaultFormatFactory.createFormatFactory(formatFactoryClass);//FIXMEFORMAT cache this too
@@ -1240,14 +1267,13 @@ public abstract class JRAbstractExporter implements JRExporter
 		}
 		return dateFormat;
 	}
-	
 
 	protected NumberFormat getNumberFormat(String formatFactoryClass, String pattern, Locale lc)
 	{
 		String key = formatFactoryClass 
 			+ "|" + pattern 
 			+ "|" + (lc == null ? "" : JRDataUtils.getLocaleCode(lc)); 
-		NumberFormat numberFormat = (NumberFormat)numberFormatCache.get(key);
+		NumberFormat numberFormat = numberFormatCache.get(key);
 		if (numberFormat == null)
 		{
 			FormatFactory formatFactory = DefaultFormatFactory.createFormatFactory(formatFactoryClass);//FIXMEFORMAT cache this too
@@ -1256,7 +1282,6 @@ public abstract class JRAbstractExporter implements JRExporter
 		}
 		return numberFormat;
 	}
-
 	
 	protected ExporterFilter createFilter(final String exportPropertyPrefix) 
 			throws JRException
