@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,9 +35,9 @@ import net.sf.jasperreports.engine.util.JRProperties;
  * datasource can be also displayed in a chart, embedded in the report. There are a lot of chart types, each with
  * its own dataset and characteristics. This interface only defines the common properties.
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRChart.java 3549 2010-03-09 13:43:58Z shertage $
+ * @version $Id: JRChart.java 4595 2011-09-08 15:55:10Z teodord $
  */
-public interface JRChart extends JRElement, JRAnchor, JRHyperlink, JRBox, JRBoxContainer
+public interface JRChart extends JRElement, JRAnchor, JRHyperlink, JRBoxContainer
 {
 
 	/**
@@ -54,40 +54,6 @@ public interface JRChart extends JRElement, JRAnchor, JRHyperlink, JRBox, JRBoxC
 	 */
 	public static final String PROPERTY_CHART_THEME = JRProperties.PROPERTY_PREFIX + "chart.theme";
 
-	/**
-	 * @deprecated Replaced by {@link EdgeEnum#TOP}.
-	 */
-	public static final byte EDGE_TOP = 1;
-	/**
-	 * @deprecated Replaced by {@link EdgeEnum#BOTTOM}.
-	 */
-	public static final byte EDGE_BOTTOM = 2;
-	/**
-	 * @deprecated Replaced by {@link EdgeEnum#LEFT}.
-	 */
-	public static final byte EDGE_LEFT = 3;
-	/**
-	 * @deprecated Replaced by {@link EdgeEnum#RIGHT}.
-	 */
-	public static final byte EDGE_RIGHT = 4;
-
-	/**
-	 * @deprecated Replaced by {@link EdgeEnum#TOP}.
-	 */
-	public static final byte TITLE_POSITION_TOP = EDGE_TOP;
-	/**
-	 * @deprecated Replaced by {@link EdgeEnum#BOTTOM}.
-	 */
-	public static final byte TITLE_POSITION_BOTTOM = EDGE_BOTTOM;
-	/**
-	 * @deprecated Replaced by {@link EdgeEnum#LEFT}.
-	 */
-	public static final byte TITLE_POSITION_LEFT = EDGE_LEFT;
-	/**
-	 * @deprecated Replaced by {@link EdgeEnum#RIGHT}.
-	 */
-	public static final byte TITLE_POSITION_RIGHT = EDGE_RIGHT;
-
 
 	/**
 	 *
@@ -121,31 +87,16 @@ public interface JRChart extends JRElement, JRAnchor, JRHyperlink, JRBox, JRBoxC
 	public static final String RENDER_TYPE_IMAGE = "image";
 	public static final String RENDER_TYPE_SVG = "svg";
 
-	/**
-	 * @deprecated Replaced by {@link #getShowLegend()}
-	 */
-	public boolean isShowLegend();
-
 	/**
 	 * 
 	 */
 	public Boolean getShowLegend();
 
-	/**
-	 * @deprecated Replaced by {@link #setShowLegend(Boolean)}
-	 */
-	public void setShowLegend(boolean isShowLegend);
-
 	/**
 	 *
 	 */
 	public void setShowLegend(Boolean isShowLegend);
 
-	/**
-	 * @deprecated Replaced by {@link #getEvaluationTimeValue()}.
-	 */
-	public byte getEvaluationTime();
-
 	/**
 	 * Returns the evaluation time for this chart.
 	 */
@@ -156,12 +107,6 @@ public interface JRChart extends JRElement, JRAnchor, JRHyperlink, JRBox, JRBoxC
 	 */
 	public JRGroup getEvaluationGroup();
 
-	/**
-	 * Gets the box around the element.
-	 * @deprecated Replaced by {@link JRBoxContainer#getLineBox()}
-	 */
-	public JRBox getBox();
-
 	/**
 	 * Gets the expression whose evaluation will form the title.
 	 */
@@ -174,29 +119,6 @@ public interface JRChart extends JRElement, JRAnchor, JRHyperlink, JRBox, JRBoxC
 	public JRFont getTitleFont();
 
 
-	/**
-	 * @deprecated Replaced by {@link #getTitlePositionValue()}
-	 */
-	public byte getTitlePosition();
-
-
-	/**
-	 * @deprecated Replaced by {@link #setTitlePosition(EdgeEnum)}
-	 */
-	public void setTitlePosition(byte titlePosition);
-	
-	/**
-	 * @deprecated Replaced by {@link #getTitlePositionValue()}
-	 */
-	public Byte getTitlePositionByte();
-
-
-	/**
-	 * @deprecated Replaced by {@link #setTitlePosition(EdgeEnum)}
-	 */
-	public void setTitlePosition(Byte titlePosition);
-	
-
 	/**
 	 * Gets the title position relative to the chart.
 	 */
@@ -290,28 +212,6 @@ public interface JRChart extends JRElement, JRAnchor, JRHyperlink, JRBox, JRBoxC
 	 */
 	public JRFont getLegendFont();
 	
-	/**
-	 * @deprecated Replaced by {@link #getLegendPositionValue()}
-	 */
-	public byte getLegendPosition();
-
-
-	/**
-	 * @deprecated Replaced by {@link #setLegendPosition(EdgeEnum)}
-	 */
-	public void setLegendPosition(byte legendPosition);
-	
-	/**
-	 * @deprecated Replaced by {@link #getLegendPositionValue()}
-	 */
-	public Byte getLegendPositionByte();
-
-
-	/**
-	 * @deprecated Replaced by {@link #setLegendPosition(EdgeEnum)}
-	 */
-	public void setLegendPosition(Byte legendPosition);
-	
 
 	/**
 	 *
