@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -33,7 +33,7 @@ import net.sf.jasperreports.engine.type.ModeEnum;
  * constants and methods that apply to all report elements.
  *
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRCommonElement.java 3411 2010-02-17 12:51:18Z teodord $
+ * @version $Id: JRCommonElement.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public interface JRCommonElement extends JRStyleContainer
 {
@@ -47,16 +47,6 @@ public interface JRCommonElement extends JRStyleContainer
 	 */
 	public String getKey();
 
-	/**
-	 * @deprecated Replaced by {@link #getModeValue()}.
-	 */
-	public byte getMode();
-	
-	/**
-	 * @deprecated Replaced by {@link #getOwnModeValue()}.
-	 */
-	public Byte getOwnMode();
-	
 	/**
 	 * Returns the element transparency mode.
 	 * The default value depends on the type of the report element. Graphic elements like rectangles and lines are
@@ -67,16 +57,6 @@ public interface JRCommonElement extends JRStyleContainer
 	
 	public ModeEnum getOwnModeValue();
 
-	/**
-	 * @deprecated Replaced by {@link #setMode(ModeEnum)}.
-	 */
-	public void setMode(byte mode);
-	
-	/**
-	 * @deprecated Replaced by {@link #setMode(ModeEnum)}.
-	 */
-	public void setMode(Byte mode);
-	
 	/**
 	 * Sets the element transparency mode.
 	 */
