@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -30,7 +30,7 @@ import net.sf.jasperreports.engine.type.FillEnum;
  * An abstract representation of a report graphic element. It provides basic functionality for images, lines, rectangles
  * and ellipses.
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRCommonGraphicElement.java 3583 2010-03-12 11:35:40Z shertage $
+ * @version $Id: JRCommonGraphicElement.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public interface JRCommonGraphicElement extends JRCommonElement, JRPenContainer
 {
@@ -41,26 +41,6 @@ public interface JRCommonGraphicElement extends JRCommonElement, JRPenContainer
 	 */
 	public JRPen getLinePen();
 
-	/**
-	 * @deprecated Replaced by {@link #getFillValue()}.
-	 */
-	public byte getFill();
-
-	/**
-	 * @deprecated Replaced by {@link #getOwnFillValue()}.
-	 */
-	public Byte getOwnFill();
-	
-	/**
-	 * @deprecated Replaced by {@link #setFill(FillEnum)}.
-	 */
-	public void setFill(byte fill);
-	
-	/**
-	 * @deprecated Replaced by {@link #setFill(FillEnum)}.
-	 */
-	public void setFill(Byte fill);
-
 	/**
 	 * Indicates the fill type used for this element.
 	 * @return a value representing one of the fill type constants in {@link FillEnum}
