@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -28,9 +28,9 @@ package net.sf.jasperreports.engine;
  * An interface that provides a default style when none is specified. All classes that might need to return a default style
  * if one is not specified will implement this interface.
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRDefaultStyleProvider.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: JRDefaultStyleProvider.java 4595 2011-09-08 15:55:10Z teodord $
  */
-public interface JRDefaultStyleProvider extends JRDefaultFontProvider
+public interface JRDefaultStyleProvider
 {
 
 	
