@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -32,16 +32,11 @@ import net.sf.jasperreports.engine.type.ResetTypeEnum;
  * This is the superinterface for all datasets and contains common dataset properties.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRElementDataset.java 3506 2010-03-04 14:48:54Z shertage $
+ * @version $Id: JRElementDataset.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public interface JRElementDataset extends JRCloneable
 {
 
-	/**
-	 * @deprecated Replaced by {@link #getResetTypeValue()}.
-	 */
-	public byte getResetType();
-
 	/**
 	 * Gets the reset type. This specifies the range of report data used for filling the dataset.
 	 * @return one of the reset constants in {@link ResetTypeEnum}
@@ -53,11 +48,6 @@ public interface JRElementDataset extends JRCloneable
 	 */
 	public JRGroup getResetGroup();
 
-	/**
-	 * @deprecated Replaced by {@link #getIncrementTypeValue()}.
-	 */
-	public byte getIncrementType();
-
 	/**
 	 * Returns the increment type. This specifies dataset values increment step.
 	 * @return one of the increment constants in {@link IncrementTypeEnum}.
