@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -43,7 +43,7 @@ import net.sf.jasperreports.engine.util.JRProperties;
  * parameters, if present.
  *
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRExporterParameter.java 3775 2010-05-03 12:11:56Z teodord $
+ * @version $Id: JRExporterParameter.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRExporterParameter
 {
@@ -52,7 +52,7 @@ public class JRExporterParameter
 	/**
 	 *
 	 */
-	private String name = null;
+	private String name;
 
 
 	/**
