@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -28,6 +28,7 @@ import java.util.Collection;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
+import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -88,7 +89,7 @@ import net.sf.jasperreports.engine.component.ComponentsEnvironment;
  * and used at report fill time to evaluate expressions.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRExpressionCollector.java 3940 2010-08-20 10:35:15Z teodord $
+ * @version $Id: JRExpressionCollector.java 4606 2011-09-14 14:13:58Z lucianc $
  */
 public class JRExpressionCollector
 {
@@ -100,7 +101,7 @@ public class JRExpressionCollector
 		return collector;
 	}
 
-	public static List collectExpressions(JRReport report)
+	public static List<JRExpression> collectExpressions(JRReport report)
 	{
 		return collector(report).getExpressions();
 	}
@@ -112,7 +113,7 @@ public class JRExpressionCollector
 		return collector;
 	}
 
-	public static List collectExpressions(JRReport report, JRCrosstab crosstab)
+	public static List<JRExpression> collectExpressions(JRReport report, JRCrosstab crosstab)
 	{
 		return collector(report, crosstab).getExpressions(crosstab);
 	}
@@ -120,19 +121,22 @@ public class JRExpressionCollector
 	private final JRReport report;
 	private final JRExpressionCollector parent;
 
-	private Map expressionIds;
+	private Map<JRExpression,Integer> expressionIds;
+	
+	private LinkedList<Object> contextStack;
+	private Map<JRExpression, Object> expressionContextMap;
 
 	protected static class GeneratedIds
 	{
-		private final TreeMap ids = new TreeMap();
+		private final TreeMap<Integer, JRExpression> ids = new TreeMap<Integer, JRExpression>();
 		private int nextId;
-		private List expressions;
+		private List<JRExpression> expressions;
 
 		public JRExpression put(Integer id, JRExpression expression)
 		{
 			expressions = null;
 
-			return (JRExpression) ids.put(id, expression);
+			return ids.put(id, expression);
 		}
 
 		public Integer nextId()
@@ -145,35 +149,35 @@ public class JRExpressionCollector
 			return id;
 		}
 
-		public List expressions()
+		public List<JRExpression> expressions()
 		{
 			if (expressions == null)
 			{
-				expressions = new ArrayList(ids.values());
+				expressions = new ArrayList<JRExpression>(ids.values());
 			}
 			return expressions;
 		}
 
 		public JRExpression expression(int id)
 		{
-			return (JRExpression) ids.get(Integer.valueOf(id));
+			return ids.get(Integer.valueOf(id));
 		}
 	}
 	private GeneratedIds generatedIds = new GeneratedIds();
 
-	private Map crosstabIds = new HashMap();
+	private Map<JRCrosstab,Integer> crosstabIds = new HashMap<JRCrosstab,Integer>();
 
 	/**
 	 * Collectors for sub datasets indexed by dataset name.
 	 */
-	private Map datasetCollectors;
+	private Map<String,JRExpressionCollector> datasetCollectors;
 
 	/**
 	 * Collectors for crosstabs.
 	 */
-	private Map crosstabCollectors;
+	private Map<JRCrosstab,JRExpressionCollector> crosstabCollectors;
 
-	private final Set collectedStyles;
+	private final Set<JRStyle> collectedStyles;
 
 
 	protected JRExpressionCollector(JRExpressionCollector parent, JRReport report)
@@ -183,16 +187,20 @@ public class JRExpressionCollector
 
 		if (parent == null)
 		{
-			expressionIds = new HashMap();
-			datasetCollectors = new HashMap();
-			crosstabCollectors = new HashMap();
+			expressionIds = new HashMap<JRExpression,Integer>();
+			datasetCollectors = new HashMap<String,JRExpressionCollector>();
+			crosstabCollectors = new HashMap<JRCrosstab,JRExpressionCollector>();
+			contextStack = new LinkedList<Object>();
+			expressionContextMap = new HashMap<JRExpression, Object>();
 		}
 		else
 		{
 			expressionIds = this.parent.expressionIds;
+			contextStack = this.parent.contextStack;
+			expressionContextMap = this.parent.expressionContextMap;
 		}
 
-		collectedStyles = new HashSet();
+		collectedStyles = new HashSet<JRStyle>();
 	}
 
 	/**
@@ -221,6 +229,8 @@ public class JRExpressionCollector
 					generatedIds.put(newId, existingExpression);
 				}
 			}
+			
+			setExpressionContext(expression);
 		}
 	}
 
@@ -242,7 +252,25 @@ public class JRExpressionCollector
 		}
 	}
 
+	protected void pushContextObject(Object context)
+	{
+		contextStack.addLast(context);
+	}
 
+	protected Object popContextObject()
+	{
+		return contextStack.removeLast();
+	}
+
+	protected void setExpressionContext(JRExpression expression)
+	{
+		if (!contextStack.isEmpty())
+		{
+			Object context = contextStack.getLast();
+			expressionContextMap.put(expression, context);
+		}
+	}
+	
 	/**
 	 * Returns the expression collector to which expressions in an element
 	 * dataset belong.
@@ -284,7 +312,7 @@ public class JRExpressionCollector
 		JRExpressionCollector collector;
 		if (parent == null)
 		{
-			collector = (JRExpressionCollector) datasetCollectors.get(datasetName);
+			collector = datasetCollectors.get(datasetName);
 			if (collector == null)
 			{
 				collector = new JRExpressionCollector(this, report);
@@ -338,7 +366,7 @@ public class JRExpressionCollector
 		JRExpressionCollector collector;
 		if (parent == null)
 		{
-			collector = (JRExpressionCollector) crosstabCollectors.get(crosstab);
+			collector = crosstabCollectors.get(crosstab);
 			if (collector == null)
 			{
 				collector = new JRExpressionCollector(this, report);
@@ -358,9 +386,9 @@ public class JRExpressionCollector
 	 *
 	 * @return the collected expressions
 	 */
-	public List getExpressions()
+	public List<JRExpression> getExpressions()
 	{
-		return new ArrayList(generatedIds.expressions());
+		return new ArrayList<JRExpression>(generatedIds.expressions());
 	}
 
 
@@ -370,7 +398,7 @@ public class JRExpressionCollector
 	 * @param dataset the dataset
 	 * @return the expressions
 	 */
-	public List getExpressions(JRDataset dataset)
+	public List<JRExpression> getExpressions(JRDataset dataset)
 	{
 		return getCollector(dataset).getExpressions();
 	}
@@ -382,7 +410,7 @@ public class JRExpressionCollector
 	 * @param crosstab the crosstab
 	 * @return the expressions
 	 */
-	public List getExpressions(JRCrosstab crosstab)
+	public List<JRExpression> getExpressions(JRCrosstab crosstab)
 	{
 		return getCollector(crosstab).getExpressions();
 	}
@@ -390,7 +418,7 @@ public class JRExpressionCollector
 
 	public Integer getExpressionId(JRExpression expression)
 	{
-		return (Integer) expressionIds.get(expression);
+		return expressionIds.get(expression);
 	}
 
 
@@ -402,14 +430,18 @@ public class JRExpressionCollector
 
 	public Integer getCrosstabId(JRCrosstab crosstab)
 	{
-		return (Integer) crosstabIds.get(crosstab);
+		return crosstabIds.get(crosstab);
 	}
 
+	public Object getExpressionContext(JRExpression expression)
+	{
+		return expressionContextMap.get(expression);
+	}
 
 	/**
 	 *
 	 */
-	public Collection collect()
+	public Collection<JRExpression> collect()
 	{
 		collectTemplates();
 
@@ -694,6 +726,7 @@ public class JRExpressionCollector
 	{
 		collectElement(textField);
 		addExpression(textField.getExpression());
+		addExpression(textField.getPatternExpression());
 		collectAnchor(textField);
 		collectHyperlink(textField);
 	}
@@ -1075,13 +1108,13 @@ public class JRExpressionCollector
 	 */
 	public void collect(JRMeterPlot meterPlot)
 	{
-		List intervals = meterPlot.getIntervals();
+		List<JRMeterInterval> intervals = meterPlot.getIntervals();
 		if (intervals != null)
 		{
-			Iterator iter = intervals.iterator();
+			Iterator<JRMeterInterval> iter = intervals.iterator();
 			while (iter.hasNext())
 			{
-				JRMeterInterval interval = (JRMeterInterval)iter.next();
+				JRMeterInterval interval = iter.next();
 				collect(interval.getDataRange());
 			}
 		}
@@ -1173,11 +1206,14 @@ public class JRExpressionCollector
 				JRCrosstabRowGroup rowGroup = rowGroups[i];
 				JRCrosstabBucket bucket = rowGroup.getBucket();
 				datasetCollector.addExpression(bucket.getExpression());
+				
+				crosstabCollector.pushContextObject(rowGroup);
 				//order by expression is in the crosstab context
 				crosstabCollector.addExpression(bucket.getOrderByExpression());
 				addExpression(bucket.getComparatorExpression());
 				crosstabCollector.collect(rowGroup.getHeader());
 				crosstabCollector.collect(rowGroup.getTotalHeader());
+				crosstabCollector.popContextObject();
 			}
 		}
 
@@ -1189,11 +1225,14 @@ public class JRExpressionCollector
 				JRCrosstabColumnGroup columnGroup = colGroups[i];
 				JRCrosstabBucket bucket = columnGroup.getBucket();
 				datasetCollector.addExpression(bucket.getExpression());
+				
+				crosstabCollector.pushContextObject(columnGroup);
 				//order by expression is in the crosstab context
 				crosstabCollector.addExpression(bucket.getOrderByExpression());
 				addExpression(bucket.getComparatorExpression());
 				crosstabCollector.collect(columnGroup.getHeader());
 				crosstabCollector.collect(columnGroup.getTotalHeader());
+				crosstabCollector.popContextObject();
 			}
 		}
 
@@ -1222,13 +1261,13 @@ public class JRExpressionCollector
 	{
 		if (crosstab instanceof JRDesignCrosstab)
 		{
-			List cellsList = ((JRDesignCrosstab) crosstab).getCellsList();
+			List<JRCrosstabCell> cellsList = ((JRDesignCrosstab) crosstab).getCellsList();
 
 			if (cellsList != null)
 			{
-				for (Iterator iter = cellsList.iterator(); iter.hasNext();)
+				for (Iterator<JRCrosstabCell> iter = cellsList.iterator(); iter.hasNext();)
 				{
-					JRCrosstabCell cell = (JRCrosstabCell) iter.next();
+					JRCrosstabCell cell = iter.next();
 					crosstabCollector.collect(cell.getContents());
 				}
 			}
@@ -1259,7 +1298,7 @@ public class JRExpressionCollector
 	 * @param dataset the dataset
 	 * @return collected expressions
 	 */
-	public Collection collect(JRDataset dataset)
+	public Collection<JRExpression> collect(JRDataset dataset)
 	{
 		JRExpressionCollector collector = getCollector(dataset);
 		collector.collect(dataset.getParameters());
