@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -31,70 +31,11 @@ import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
  * Utility class that manages built-in hyperlink types.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRHyperlinkHelper.java 3712 2010-04-08 09:53:09Z teodord $
+ * @version $Id: JRHyperlinkHelper.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public final class JRHyperlinkHelper
 {
-	/**
-	 * "None" link type, equivalent to {@link JRHyperlink#HYPERLINK_TYPE_NONE JRHyperlink.HYPERLINK_TYPE_NONE}.
-	 * @deprecated Replaced by {@link HyperlinkTypeEnum#NONE}.
-	 */
-	public static final String HYPERLINK_TYPE_NONE = HyperlinkTypeEnum.NONE.getName();
-	
-	/**
-	 * "Reference" link type, equivalent to {@link JRHyperlink#HYPERLINK_TYPE_REFERENCE JRHyperlink.HYPERLINK_TYPE_REFERENCE}.
-	 * @deprecated Replaced by {@link HyperlinkTypeEnum#REFERENCE}.
-	 */
-	public static final String HYPERLINK_TYPE_REFERENCE = HyperlinkTypeEnum.REFERENCE.getName();
-	
-	/**
-	 * "LocalAnchor" link type, equivalent to {@link JRHyperlink#HYPERLINK_TYPE_LOCAL_ANCHOR JRHyperlink.HYPERLINK_LOCAL_ANCHOR}.
-	 * @deprecated Replaced by {@link HyperlinkTypeEnum#LOCAL_ANCHOR}.
-	 */
-	public static final String HYPERLINK_TYPE_LOCAL_ANCHOR = HyperlinkTypeEnum.LOCAL_ANCHOR.getName();
-	
-	/**
-	 * "LocalPage" link type, equivalent to {@link JRHyperlink#HYPERLINK_TYPE_LOCAL_PAGE JRHyperlink.HYPERLINK_TYPE_LOCAL_PAGE}.
-	 * @deprecated Replaced by {@link HyperlinkTypeEnum#LOCAL_PAGE}.
-	 */
-	public static final String HYPERLINK_TYPE_LOCAL_PAGE = HyperlinkTypeEnum.LOCAL_PAGE.getName();
-	
-	/**
-	 * "RemoteAnchor" link type, equivalent to {@link JRHyperlink#HYPERLINK_TYPE_REMOTE_ANCHOR JRHyperlink.HYPERLINK_TYPE_REMOTE_ANCHOR}.
-	 * @deprecated Replaced by {@link HyperlinkTypeEnum#REMOTE_ANCHOR}.
-	 */
-	public static final String HYPERLINK_TYPE_REMOTE_ANCHOR = HyperlinkTypeEnum.REMOTE_ANCHOR.getName();
-	
-	/**
-	 * "RemotePage" link type, equivalent to {@link JRHyperlink#HYPERLINK_TYPE_REMOTE_PAGE JRHyperlink.HYPERLINK_TYPE_REMOTE_PAGE}.
-	 * @deprecated Replaced by {@link HyperlinkTypeEnum#REMOTE_PAGE}.
-	 */
-	public static final String HYPERLINK_TYPE_REMOTE_PAGE = HyperlinkTypeEnum.REMOTE_PAGE.getName();
-	
-	/**
-	 * "Self" link target name, equivalent to {@link JRHyperlink#HYPERLINK_TARGET_SELF JRHyperlink.HYPERLINK_TARGET_SELF}.
-	 * @deprecated Replaced by {@link HyperlinkTargetEnum#SELF}.
-	 */
-	public static final String HYPERLINK_TARGET_SELF = HyperlinkTargetEnum.SELF.getName();
 
-	/**
-	 * "Blank" link target name, equivalent to {@link JRHyperlink#HYPERLINK_TARGET_BLANK JRHyperlink.HYPERLINK_TARGET_BLANK}.
-	 * @deprecated Replaced by {@link HyperlinkTargetEnum#BLANK}.
-	 */
-	public static final String HYPERLINK_TARGET_BLANK = HyperlinkTargetEnum.BLANK.getName();
-
-	/**
-	 * "Parent" link target name, equivalent to {@link JRHyperlink#HYPERLINK_TARGET_PARENT JRHyperlink.HYPERLINK_TARGET_PARENT}.
-	 * @deprecated Replaced by {@link HyperlinkTargetEnum#PARENT}.
-	 */
-	public static final String HYPERLINK_TARGET_PARENT = HyperlinkTargetEnum.PARENT.getName();
-
-	/**
-	 * "Top" link target name, equivalent to {@link JRHyperlink#HYPERLINK_TARGET_TOP JRHyperlink.HYPERLINK_TARGET_TOP}.
-	 * @deprecated Replaced by {@link HyperlinkTargetEnum#TOP}.
-	 */
-	public static final String HYPERLINK_TARGET_TOP = HyperlinkTargetEnum.TOP.getName();
-	
 	
 	/**
 	 * @deprecated Replaced by {@link #getHyperlinkTypeValue(JRHyperlink)}.
@@ -106,7 +47,7 @@ public final class JRHyperlinkHelper
 	
 
 	/**
-	 * Returns the built-in hyperlink type, or {@link JRHyperlink#HYPERLINK_TYPE_CUSTOM JRHyperlink.HYPERLINK_TYPE_CUSTOM}
+	 * Returns the built-in hyperlink type, or {@link HyperlinkTypeEnum#CUSTOM HyperlinkTypeEnum.CUSTOM}
 	 * if the type is not a built-in type.
 	 * 
 	 * @param hyperlink the hyperlink object
@@ -128,7 +69,7 @@ public final class JRHyperlinkHelper
 	
 	
 	/**
-	 * Returns the built-in hyperlink type, or {@link JRHyperlink#HYPERLINK_TYPE_CUSTOM JRHyperlink.HYPERLINK_TYPE_CUSTOM}
+	 * Returns the built-in hyperlink type, or {@link HyperlinkTypeEnum#CUSTOM HyperlinkTypeEnum.CUSTOM}
 	 * if the type is not a built-in type.
 	 * 
 	 * @param linkType the link type
@@ -158,7 +99,7 @@ public final class JRHyperlinkHelper
 	
 
 	/**
-	 * Returns the built-in hyperlink target, or {@link JRHyperlink#HYPERLINK_TARGET_CUSTOM JRHyperlink.HYPERLINK_TARGET_CUSTOM}
+	 * Returns the built-in hyperlink target, or {@link HyperlinkTargetEnum#CUSTOM HyperlinkTargetEnum.CUSTOM}
 	 * if the target name is not a built-in one.
 	 * 
 	 * @param hyperlink the hyperlink object
@@ -274,13 +215,13 @@ public final class JRHyperlinkHelper
 				target = null;
 				break;
 			case BLANK:
-				target = HYPERLINK_TARGET_BLANK;
+				target = HyperlinkTargetEnum.BLANK.getName();
 				break;
 			case PARENT:
-				target = HYPERLINK_TARGET_PARENT;
+				target = HyperlinkTargetEnum.PARENT.getName();
 				break;
 			case TOP:
-				target = HYPERLINK_TARGET_TOP;
+				target = HyperlinkTargetEnum.TOP.getName();
 				break;
 			case CUSTOM:
 				throw new JRRuntimeException("Custom hyperlink targets cannot be specified using the byte constant");
