@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -25,7 +25,6 @@ package net.sf.jasperreports.engine;
 
 import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
 import net.sf.jasperreports.engine.type.OnErrorTypeEnum;
-import net.sf.jasperreports.engine.type.ScaleImageEnum;
 
 
 /**
@@ -33,62 +32,26 @@ import net.sf.jasperreports.engine.type.ScaleImageEnum;
  * also contain hyperlinks or be anchors for other hyperlinks.
  *
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRImage.java 3583 2010-03-12 11:35:40Z shertage $
+ * @version $Id: JRImage.java 4595 2011-09-08 15:55:10Z teodord $
  */
-public interface JRImage extends JRGraphicElement, JRAnchor, JRHyperlink, JRAlignment, JRBox, JRCommonImage
+public interface JRImage extends JRGraphicElement, JRAnchor, JRHyperlink, JRAlignment, JRCommonImage
 {
 
 
-	/**
-	 * @deprecated Replaced by {@link ScaleImageEnum#CLIP}.
-	 */
-	public static final byte SCALE_IMAGE_CLIP = 1;
-
-	/**
-	 * @deprecated Replaced by {@link ScaleImageEnum#FILL_FRAME}.
-	 */
-	public static final byte SCALE_IMAGE_FILL_FRAME = 2;
-
-	/**
-	 * @deprecated Replaced by {@link ScaleImageEnum#RETAIN_SHAPE}.
-	 */
-	public static final byte SCALE_IMAGE_RETAIN_SHAPE = 3;
-	
-	/**
-	 * @deprecated Replaced by {@link ScaleImageEnum#REAL_HEIGHT}.
-	 */
-	public static final byte SCALE_IMAGE_REAL_HEIGHT = 4;
-	
-	/**
-	 * @deprecated Replaced by {@link ScaleImageEnum#REAL_SIZE}.
-	 */
-	public static final byte SCALE_IMAGE_REAL_SIZE = 5;
-
-
-	/**
-	 * @deprecated Replaced by {@link OnErrorTypeEnum#ERROR}.
-	 */
-	public static final byte ON_ERROR_TYPE_ERROR = 1;
-
-	/**
-	 * @deprecated Replaced by {@link OnErrorTypeEnum#BLANK}.
-	 */
-	public static final byte ON_ERROR_TYPE_BLANK = 2;
-
-	/**
-	 * @deprecated Replaced by {@link OnErrorTypeEnum#ICON}.
-	 */
-	public static final byte ON_ERROR_TYPE_ICON = 3;
-	
-
 	/**
 	 * Indicates if the engine is loading the current image from cache.
 	 * Implementations of this method rely on default values that depend on the type of the image expression
 	 * if a value was not explicitly set of this flag.
 	 * @return true if the image should be loaded from cache, false otherwise
+	 * @deprecated Replaced by {@link #getUsingCache()}.
 	 */
 	public boolean isUsingCache();
 
+	/**
+	 * @deprecated Replaced by {@link #getUsingCache()}.
+	 */
+	public Boolean isOwnUsingCache();
+
 	/**
 	 * Indicates if the engine is loading the current image from cache.
 	 * Implementations of this method return the actual value for the internal flag that was explicitly 
@@ -96,7 +59,7 @@ public interface JRImage extends JRGraphicElement, JRAnchor, JRHyperlink, JRAlig
 	 * @return Boolean.TRUE if the image should be loaded from cache, Boolean.FALSE otherwise 
 	 * or null in case the flag was never explicitly set on this image element
 	 */
-	public Boolean isOwnUsingCache();
+	public Boolean getUsingCache();
 
 	/**
 	 * Specifies if the engine should be loading the current image from cache. If set to true, the reporting engine
@@ -131,16 +94,6 @@ public interface JRImage extends JRGraphicElement, JRAnchor, JRHyperlink, JRAlig
 	 */
 	public void setLazy(boolean isLazy);
 
-	/**
-	 * @deprecated Replaced by {@link #getOnErrorTypeValue()}.
-	 */
-	public byte getOnErrorType();
-
-	/**
-	 * @deprecated Replaced by {@link #setOnErrorType(OnErrorTypeEnum)}.
-	 */
-	public void setOnErrorType(byte onErrorType);
-
 	/**
 	 * Indicates how the engine will treat a missing image.
 	 * @return a value representing one of the missing image handling constants in {@link OnErrorTypeEnum}
@@ -153,11 +106,6 @@ public interface JRImage extends JRGraphicElement, JRAnchor, JRHyperlink, JRAlig
 	 */
 	public void setOnErrorType(OnErrorTypeEnum onErrorTypeEnum);
 	
-	/**
-	 * @deprecated Replaced by {@link #getEvaluationTimeValue()}.
-	 */
-	public byte getEvaluationTime();
-		
 	/**
 	 * Indicates the evaluation time for this image.
 	 * @return one of the evaluation time constants in {@link EvaluationTimeEnum}
@@ -175,10 +123,4 @@ public interface JRImage extends JRGraphicElement, JRAnchor, JRHyperlink, JRAlig
 	 */
 	public JRExpression getExpression();
 
-	/**
-	 * Returns an object containing all border and padding properties for this text element
-	 * @deprecated Replaced by {@link JRBoxContainer#getLineBox()}
-	 */
-	public JRBox getBox();
-
 }
