@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -29,33 +29,12 @@ import net.sf.jasperreports.engine.type.LineDirectionEnum;
 /**
  * An abstract representation of a graphic element representing a straight line.
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRLine.java 3583 2010-03-12 11:35:40Z shertage $
+ * @version $Id: JRLine.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public interface JRLine extends JRGraphicElement
 {
 
 
-	/**
-	 * @deprecated Replaced by {@link LineDirectionEnum#TOP_DOWN}.
-	 */
-	public static final byte DIRECTION_TOP_DOWN = 1;
-
-	/**
-	 * @deprecated Replaced by {@link LineDirectionEnum#BOTTOM_UP}.
-	 */
-	public static final byte DIRECTION_BOTTOM_UP = 2;
-
-
-	/**
-	 * @deprecated Replaced by {@link #getDirectionValue()}.
-	 */
-	public byte getDirection();
-
-	/**
-	 * @deprecated Replaced by {@link #setDirection(LineDirectionEnum)}.
-	 */
-	public void setDirection(byte direction);
-
 	/**
 	 * Gets the line direction.
 	 * @return a value representing one of the line direction constants in {@link LineDirectionEnum}
