@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -32,7 +32,7 @@ import net.sf.jasperreports.engine.type.BandTypeEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JROrigin.java 3743 2010-04-16 17:01:19Z lucianc $
+ * @version $Id: JROrigin.java 4732 2011-10-21 09:14:15Z lucianc $
  */
 public class JROrigin implements JRCloneable, Serializable
 {
@@ -42,64 +42,11 @@ public class JROrigin implements JRCloneable, Serializable
 	 */
 	private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 
-	/**
-	 * @deprecated Replaced by {@link BandTypeEnum#UNKNOWN}.
-	 */
-	public static final byte UNKNOWN = 0;
-	/**
-	 * @deprecated Replaced by {@link BandTypeEnum#BACKGROUND}.
-	 */
-	public static final byte BACKGROUND = 1;
-	/**
-	 * @deprecated Replaced by {@link BandTypeEnum#UNKNOWN}.
-	 */
-	public static final byte TITLE = 2;
-	/**
-	 * @deprecated Replaced by {@link BandTypeEnum#PAGE_HEADER}.
-	 */
-	public static final byte PAGE_HEADER = 3;
-	/**
-	 * @deprecated Replaced by {@link BandTypeEnum#COLUMN_HEADER}.
-	 */
-	public static final byte COLUMN_HEADER = 4;
-	/**
-	 * @deprecated Replaced by {@link BandTypeEnum#GROUP_HEADER}.
-	 */
-	public static final byte GROUP_HEADER = 5;
-	/**
-	 * @deprecated Replaced by {@link BandTypeEnum#DETAIL}.
-	 */
-	public static final byte DETAIL = 6;
-	/**
-	 * @deprecated Replaced by {@link BandTypeEnum#GROUP_FOOTER}.
-	 */
-	public static final byte GROUP_FOOTER = 7;
-	/**
-	 * @deprecated Replaced by {@link BandTypeEnum#COLUMN_FOOTER}.
-	 */
-	public static final byte COLUMN_FOOTER = 8;
-	/**
-	 * @deprecated Replaced by {@link BandTypeEnum#PAGE_FOOTER}.
-	 */
-	public static final byte PAGE_FOOTER = 9;
-	/**
-	 * @deprecated Replaced by {@link BandTypeEnum#LAST_PAGE_FOOTER}.
-	 */
-	public static final byte LAST_PAGE_FOOTER = 10;
-	/**
-	 * @deprecated Replaced by {@link BandTypeEnum#SUMMARY}.
-	 */
-	public static final byte SUMMARY = 11;
-	/**
-	 * @deprecated Replaced by {@link BandTypeEnum#NO_DATA}.
-	 */
-	public static final byte NO_DATA = 12;
-
 	private BandTypeEnum bandTypeValue = BandTypeEnum.UNKNOWN;
-	private String groupName = null;
-	private String reportName = null;
+	private String groupName;
+	private String reportName;
 	
-	private int hashCode = 0;
+	private transient Integer hashCode;
 	
 	/**
 	 * 
@@ -134,45 +81,6 @@ public class JROrigin implements JRCloneable, Serializable
 		this.reportName = reportName;
 		this.groupName = groupName;
 		this.bandTypeValue = bandTypeValue;
-
-		int hash = 17;
-		hash = 31 * hash + (reportName == null ? 0 : reportName.hashCode());
-		hash = 31 * hash + (groupName == null ? 0 : groupName.hashCode());
-		hash = 31 * hash + bandTypeValue.hashCode();
-		hashCode = hash;
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #JROrigin(BandTypeEnum)}.
-	 */
-	public JROrigin(
-		byte bandType
-		)
-	{
-		this(null, null, BandTypeEnum.getByValue(bandType));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #JROrigin(String, BandTypeEnum)}.
-	 */
-	public JROrigin(
-		String reportName,
-		byte bandType
-		)
-	{
-		this(reportName, null, BandTypeEnum.getByValue(bandType));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #JROrigin(String, String, BandTypeEnum)}.
-	 */
-	public JROrigin(
-		String reportName,
-		String groupName,
-		byte bandType
-		)
-	{
-		this(reportName, groupName, BandTypeEnum.getByValue(bandType));
 	}
 
 	/**
@@ -191,14 +99,6 @@ public class JROrigin implements JRCloneable, Serializable
 		return groupName;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getBandTypeValue()}. 
-	 */
-	public byte getBandType()
-	{
-		return getBandTypeValue().getValue();
-	}
-	
 	/**
 	 * 
 	 */
@@ -230,7 +130,15 @@ public class JROrigin implements JRCloneable, Serializable
 	 */
 	public int hashCode() 
 	{
-		return hashCode;
+		if (hashCode == null)
+		{
+			int hash = 17;
+			hash = 31 * hash + (reportName == null ? 0 : reportName.hashCode());
+			hash = 31 * hash + (groupName == null ? 0 : groupName.hashCode());
+			hash = 31 * hash + bandTypeValue.hashCode();
+			hashCode = new Integer(hash);
+		}
+		return hashCode.intValue();
 	}
 
 
@@ -248,6 +156,16 @@ public class JROrigin implements JRCloneable, Serializable
 			throw new JRRuntimeException(e);
 		}
 	}
+	
+	@Override
+	public String toString()
+	{
+		return "{reportName: " + reportName 
+				+ ", groupName: " + groupName 
+				+ ",bandType: " + bandTypeValue + "}";
+	}
+
+
 
 	/*
 	 * These fields are only for serialization backward compatibility.
