@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -30,31 +30,11 @@ import net.sf.jasperreports.engine.type.LineStyleEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRPen.java 3583 2010-03-12 11:35:40Z shertage $
+ * @version $Id: JRPen.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public interface JRPen
 {
 
-	/**
-	 * @deprecated Replaced by {@link LineStyleEnum#SOLID}.
-	 */
-	public static final byte LINE_STYLE_SOLID = 0;
-
-	/**
-	 * @deprecated Replaced by {@link LineStyleEnum#DASHED}.
-	 */
-	public static final byte LINE_STYLE_DASHED = 1;
-
-	/**
-	 * @deprecated Replaced by {@link LineStyleEnum#DOTTED}.
-	 */
-	public static final byte LINE_STYLE_DOTTED = 2;
-
-	/**
-	 * @deprecated Replaced by {@link LineStyleEnum#DOUBLE}.
-	 */
-	public static final byte LINE_STYLE_DOUBLE = 3;
-
 	public static final Float LINE_WIDTH_0 = new Float(0f);
 	public static final Float LINE_WIDTH_1 = new Float(1f);
 
@@ -86,26 +66,6 @@ public interface JRPen
 
 	public void setLineWidth(Float lineWidth);
 
-	/**
-	 * @deprecated Replaced by {@link #getLineStyleValue()}.
-	 */
-	public Byte getLineStyle();
-
-	/**
-	 * @deprecated Replaced by {@link #getOwnLineStyleValue()}.
-	 */
-	public Byte getOwnLineStyle();
-
-	/**
-	 * @deprecated Replaced by {@link #setLineStyle(LineStyleEnum)}.
-	 */
-	public void setLineStyle(byte lineStyle);
-
-	/**
-	 * @deprecated Replaced by {@link #setLineStyle(LineStyleEnum)}.
-	 */
-	public void setLineStyle(Byte lineStyle);
-
 	/**
 	 * Indicates the line style used for this pen.
 	 * @return a value representing one of the line style constants in {@link LineStyleEnum}
