@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -29,16 +29,11 @@ import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRPrintHyperlink.java 3502 2010-03-04 11:05:10Z teodord $
+ * @version $Id: JRPrintHyperlink.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public interface JRPrintHyperlink
 {
 
-	/**
-	 * @deprecated Replaced by {@link #getHyperlinkTypeValue()}.
-	 */
-	public byte getHyperlinkType();
-
 	/**
 	 * Retrieves the hyperlink type for the element.
 	 * <p>
@@ -52,11 +47,6 @@ public interface JRPrintHyperlink
 	 */
 	public HyperlinkTypeEnum getHyperlinkTypeValue();
 
-	/**
-	 * @deprecated Replaced by {@link #setHyperlinkType(HyperlinkTypeEnum)}.
-	 */
-	public void setHyperlinkType(byte hyperlinkType);
-
 	/**
 	 * Sets the link type as a built-in hyperlink type.
 	 * 
@@ -65,21 +55,11 @@ public interface JRPrintHyperlink
 	 */
 	public void setHyperlinkType(HyperlinkTypeEnum hyperlinkType);
 		
-	/**
-	 * @deprecated Replaced by {@link #getHyperlinkTargetValue()}.
-	 */
-	public byte getHyperlinkTarget();
-	
 	/**
 	 *
 	 */
 	public HyperlinkTargetEnum getHyperlinkTargetValue();
 		
-	/**
-	 * @deprecated Replaced by {@link #setHyperlinkTarget(HyperlinkTargetEnum)}.
-	 */
-	public void setHyperlinkTarget(byte hyperlinkTarget);
-	
 	/**
 	 *
 	 */
