@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -36,9 +36,9 @@ import net.sf.jasperreports.engine.type.ScaleImageEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRPrintImage.java 3583 2010-03-12 11:35:40Z shertage $
+ * @version $Id: JRPrintImage.java 4595 2011-09-08 15:55:10Z teodord $
  */
-public interface JRPrintImage extends JRPrintGraphicElement, JRPrintAnchor, JRPrintHyperlink, JRAlignment, JRBox, JRCommonImage
+public interface JRPrintImage extends JRPrintGraphicElement, JRPrintAnchor, JRPrintHyperlink, JRAlignment, JRCommonImage
 {
 
 
@@ -52,16 +52,6 @@ public interface JRPrintImage extends JRPrintGraphicElement, JRPrintAnchor, JRPr
 	 */
 	public void setRenderer(JRRenderable renderer);
 		
-	/**
-	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
-	 */
-	public void setScaleImage(byte scaleImage);
-	
-	/**
-	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
-	 */
-	public void setScaleImage(Byte scaleImage);
-	
 	/**
 	 * 
 	 */
@@ -87,16 +77,6 @@ public interface JRPrintImage extends JRPrintGraphicElement, JRPrintAnchor, JRPr
 	 */
 	public void setLazy(boolean isLazy);
 
-	/**
-	 * @deprecated Replaced by {@link #getOnErrorTypeValue()}
-	 */
-	public byte getOnErrorType();
-
-	/**
-	 * @deprecated Replaced by {@link #setOnErrorType(OnErrorTypeEnum)}
-	 */
-	public void setOnErrorType(byte onErrorType);
-
 	/**
 	 * 
 	 */
@@ -107,15 +87,5 @@ public interface JRPrintImage extends JRPrintGraphicElement, JRPrintAnchor, JRPr
 	 */
 	public void setOnErrorType(OnErrorTypeEnum onErrorType);
 
-	/**
-	 * @deprecated Replaced by {@link JRBoxContainer#getLineBox()}
-	 */
-	public JRBox getBox();
-
-	/**
-	 * @deprecated Replaced by {@link JRBoxContainer#getLineBox()}
-	 */
-	public void setBox(JRBox box);
-
 
 }
