@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -36,6 +36,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 
+import net.sf.jasperreports.engine.design.events.JRPropertyChangeSupport;
+
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
@@ -46,7 +48,7 @@ import org.apache.commons.logging.LogFactory;
  * is the same as the order in which the properties were added.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRPropertiesMap.java 3675 2010-04-02 08:58:23Z shertage $
+ * @version $Id: JRPropertiesMap.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRPropertiesMap implements Serializable, Cloneable
 {
@@ -54,8 +56,10 @@ public class JRPropertiesMap implements Serializable, Cloneable
 	
 	private static final Log log = LogFactory.getLog(JRPropertiesMap.class);
 	
-	private Map propertiesMap;
-	private List propertiesList;
+	public static final String PROPERTY_VALUE = "value";
+	
+	private Map<String, String> propertiesMap;
+	private List<String> propertiesList;
 	
 	private JRPropertiesMap base;
 	
@@ -97,8 +101,8 @@ public class JRPropertiesMap implements Serializable, Cloneable
 
 	private void init()
 	{
-		propertiesMap = new HashMap();
-		propertiesList = new ArrayList();
+		propertiesMap = new HashMap<String, String>();
+		propertiesList = new ArrayList<String>();
 	}
 
 	
@@ -114,13 +118,13 @@ public class JRPropertiesMap implements Serializable, Cloneable
 		{
 			if (base == null)
 			{
-				names = (String[]) propertiesList.toArray(new String[propertiesList.size()]);
+				names = propertiesList.toArray(new String[propertiesList.size()]);
 			}
 			else
 			{
-				LinkedHashSet namesSet = new LinkedHashSet();
+				LinkedHashSet<String> namesSet = new LinkedHashSet<String>();
 				collectPropertyNames(namesSet);
-				names = (String[]) namesSet.toArray(new String[namesSet.size()]);
+				names = namesSet.toArray(new String[namesSet.size()]);
 			}
 		}
 		else if (base != null)
@@ -135,7 +139,7 @@ public class JRPropertiesMap implements Serializable, Cloneable
 	}
 
 	
-	protected void collectPropertyNames(Collection names)
+	protected void collectPropertyNames(Collection<String> names)
 	{
 		if (base != null)
 		{
@@ -209,6 +213,8 @@ public class JRPropertiesMap implements Serializable, Cloneable
 	 */
 	public void setProperty(String propName, String value)
 	{
+		Object old = getOwnProperty(propName);
+		
 		ensureInit();
 		
 		if (!hasOwnProperty(propName))
@@ -216,6 +222,8 @@ public class JRPropertiesMap implements Serializable, Cloneable
 			propertiesList.add(propName);
 		}
 		propertiesMap.put(propName, value);
+
+		getEventSupport().firePropertyChange(PROPERTY_VALUE, old, value);
 	}
 	
 	
@@ -268,8 +276,8 @@ public class JRPropertiesMap implements Serializable, Cloneable
 		if (propertiesList == null && propertiesMap != null)// an instance from an old version has been deserialized
 		{
 			//recreate the properties list and map
-			propertiesList = new ArrayList(propertiesMap.keySet());
-			propertiesMap = new HashMap(propertiesMap);
+			propertiesList = new ArrayList<String>(propertiesMap.keySet());
+			propertiesMap = new HashMap<String, String>(propertiesMap);
 		}
 	}
 	
@@ -372,7 +380,7 @@ public class JRPropertiesMap implements Serializable, Cloneable
 			stream.close();
 			
 			JRPropertiesMap properties = new JRPropertiesMap();
-			for (Enumeration names = props.propertyNames(); names.hasMoreElements(); )
+			for (Enumeration<?> names = props.propertyNames(); names.hasMoreElements(); )
 			{
 				String name = (String) names.nextElement();
 				String value = props.getProperty(name);
@@ -402,4 +410,20 @@ public class JRPropertiesMap implements Serializable, Cloneable
 			}
 		}
 	}
+
+	
+	private transient JRPropertyChangeSupport eventSupport;
+	
+	public JRPropertyChangeSupport getEventSupport()
+	{
+		synchronized (this)
+		{
+			if (eventSupport == null)
+			{
+				eventSupport = new JRPropertyChangeSupport(this);
+			}
+		}
+		
+		return eventSupport;
+	}
 }
