@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -25,6 +25,7 @@ package net.sf.jasperreports.engine;
 
 import net.sf.jasperreports.engine.type.OrientationEnum;
 import net.sf.jasperreports.engine.type.PrintOrderEnum;
+import net.sf.jasperreports.engine.type.RunDirectionEnum;
 import net.sf.jasperreports.engine.type.WhenNoDataTypeEnum;
 import net.sf.jasperreports.engine.type.WhenResourceMissingTypeEnum;
 
@@ -34,9 +35,9 @@ import net.sf.jasperreports.engine.type.WhenResourceMissingTypeEnum;
  * (designs, compiled reports, filled reports). It only contains constants and getters and setters for the most common
  * report properties and elements.
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRReport.java 3583 2010-03-12 11:35:40Z shertage $
+ * @version $Id: JRReport.java 4595 2011-09-08 15:55:10Z teodord $
  */
-public interface JRReport extends JRDefaultFontProvider, JRDefaultStyleProvider, JRPropertiesHolder
+public interface JRReport extends JRDefaultStyleProvider, JRPropertiesHolder
 {
 
 
@@ -50,84 +51,6 @@ public interface JRReport extends JRDefaultFontProvider, JRDefaultStyleProvider,
 	 */
 	public static final String LANGUAGE_GROOVY = "groovy";
 
-	/**
-	 * @deprecated Replaced by {@link PrintOrderEnum#VERTICAL}.
-	 */
-	public static final byte PRINT_ORDER_VERTICAL = 1;
-
-
-	/**
-	 * @deprecated Replaced by {@link PrintOrderEnum#HORIZONTAL}.
-	 */
-	public static final byte PRINT_ORDER_HORIZONTAL = 2;
-
-
-	/**
-	 * @deprecated Replaced by {@link OrientationEnum#PORTRAIT}.
-	 */
-	public static final byte ORIENTATION_PORTRAIT = 1;
-
-
-	/**
-	 * @deprecated Replaced by {@link OrientationEnum#LANDSCAPE}.
-	 */
-	public static final byte ORIENTATION_LANDSCAPE = 2;
-
-	
-	/**
-	 * Specifies that in case of empty datasources, there will be an empty report.
-	 * @deprecated Replaced by {@link WhenNoDataTypeEnum#NO_PAGES}.
-	 */
-	public static final byte WHEN_NO_DATA_TYPE_NO_PAGES = 1;
-
-
-	/**
-	 * Specifies that in case of empty datasources, there will be a report with just one blank page.
-	 * @deprecated Replaced by {@link WhenNoDataTypeEnum#BLANK_PAGE}.
-	 */
-	public static final byte WHEN_NO_DATA_TYPE_BLANK_PAGE = 2;
-
-
-	/**
-	 * Specifies that in case of empty datasources, all sections except detail will displayed.
-	 * @deprecated Replaced by {@link WhenNoDataTypeEnum#ALL_SECTIONS_NO_DETAIL}.
-	 */
-	public static final byte WHEN_NO_DATA_TYPE_ALL_SECTIONS_NO_DETAIL = 3;
-
-	/**
-	 * Specifies that in case of empty datasources, the NoData section will be displayed.
-	 * @deprecated Replaced by {@link WhenNoDataTypeEnum#NO_DATA_SECTION}.
-	 */
-	public static final byte WHEN_NO_DATA_TYPE_NO_DATA_SECTION = 4;
-
-
-	/**
-	 * Return NULL when a resource is missing.
-	 * @deprecated Replaced by {@link WhenResourceMissingTypeEnum#NULL}.
-	 */
-	public static final byte WHEN_RESOURCE_MISSING_TYPE_NULL = JRDataset.WHEN_RESOURCE_MISSING_TYPE_NULL;
-
-
-	/**
-	 * Return empty string when a resource is missing.
-	 * @deprecated Replaced by {@link WhenResourceMissingTypeEnum#EMPTY}.
-	 */
-	public static final byte WHEN_RESOURCE_MISSING_TYPE_EMPTY = JRDataset.WHEN_RESOURCE_MISSING_TYPE_EMPTY;
-
-
-	/**
-	 * Return the key when a resource is missing.
-	 * @deprecated Replaced by {@link WhenResourceMissingTypeEnum#KEY}.
-	 */
-	public static final byte WHEN_RESOURCE_MISSING_TYPE_KEY = JRDataset.WHEN_RESOURCE_MISSING_TYPE_KEY;
-
-
-	/**
-	 * Throw an exception when a resource is missing.
-	 * @deprecated Replaced by {@link WhenResourceMissingTypeEnum#ERROR}.
-	 */
-	public static final byte WHEN_RESOURCE_MISSING_TYPE_ERROR = JRDataset.WHEN_RESOURCE_MISSING_TYPE_ERROR;
-
 
 	/**
 	 * Gets the report name.
@@ -144,17 +67,18 @@ public interface JRReport extends JRDefaultFontProvider, JRDefaultStyleProvider,
 	 */
 	public int getColumnCount();
 
-	/**
-	 * @deprecated Replaced by {@link #getPrintOrderValue()}.
-	 */
-	public byte getPrintOrder();
-	
 	/**
 	 * Specifies whether columns will be filled horizontally or vertically.
 	 * @return a value representing one of the print order constants in {@link PrintOrderEnum}
 	 */
 	public PrintOrderEnum getPrintOrderValue();
 	
+	/**
+	 * Specifies whether columns will be filled from left to right or from right to left.
+	 * @return a value representing one of the column direction constants in {@link RunDirectionEnum}
+	 */
+	public RunDirectionEnum getColumnDirection();
+	
 	/**
 	 *
 	 */
@@ -165,32 +89,17 @@ public interface JRReport extends JRDefaultFontProvider, JRDefaultStyleProvider,
 	 */
 	public int getPageHeight();
 
-	/**
-	 * @deprecated Replaced by {@link #getOrientationValue()}.
-	 */
-	public byte getOrientation();
-
 	/**
 	 * Specifies whether document pages will be rendered in a portrait or landscape layout.
 	 * @return a value representing one of the orientation constants in {@link OrientationEnum}
 	 */
 	public OrientationEnum getOrientationValue();
 
-	/**
-	 * @deprecated Replaced by {@link #getWhenNoDataTypeValue()}.
-	 */
-	public byte getWhenNoDataType();
-
 	/**
 	 * Specifies the report behavior in case of empty datasources.
 	 */
 	public WhenNoDataTypeEnum getWhenNoDataTypeValue();
 
-	/**
-	 * @deprecated Replaced by {@link #setWhenNoDataType(WhenNoDataTypeEnum)}.
-	 */
-	public void setWhenNoDataType(byte whenNoDataType);
-
 	/**
 	 * Sets the report behavior in case of empty datasources.
 	 */
@@ -290,11 +199,6 @@ public interface JRReport extends JRDefaultFontProvider, JRDefaultStyleProvider,
 	 */
 	public String[] getImports();
 
-	/**
-	 * Gets an array of report fonts.
-	 */
-	public JRReportFont[] getFonts();
-
 	/**
 	 * Gets an array of report styles.
 	 */
@@ -355,11 +259,6 @@ public interface JRReport extends JRDefaultFontProvider, JRDefaultStyleProvider,
 	 */
 	public JRBand getColumnHeader();
 
-	/**
-	 * @deprecated Replaced by {@link #getDetailSection()}.
-	 */
-	public JRBand getDetail();
-
 	/**
 	 *
 	 */
@@ -390,21 +289,11 @@ public interface JRReport extends JRDefaultFontProvider, JRDefaultStyleProvider,
 	 */
 	public JRBand getNoData();
 
-	/**
-	 * @deprecated Replaced by {@link #getWhenResourceMissingTypeValue()}.
-	 */
-	public byte getWhenResourceMissingType();
-
 	/**
 	 * Returns the resource missing handling type.
 	 */
 	public WhenResourceMissingTypeEnum getWhenResourceMissingTypeValue();
 
-	/**
-	 * @deprecated Replaced by {@link #setWhenResourceMissingType(WhenResourceMissingTypeEnum)}
-	 */
-	public void setWhenResourceMissingType(byte whenResourceMissingType);
-
 	/**
 	 * Sets the resource missing handling type.
 	 * @param whenResourceMissingType the resource missing handling type
