@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,46 +17,37 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
 package net.sf.jasperreports.engine;
 
+import net.sf.jasperreports.engine.type.SortFieldTypeEnum;
 import net.sf.jasperreports.engine.type.SortOrderEnum;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRSortField.java 3500 2010-03-03 15:56:41Z teodord $
+ * @version $Id: JRSortField.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public interface JRSortField extends JRCloneable
 {
 
-	/**
-	 * @deprecated Replaced by {@link SortOrderEnum#ASCENDING}.
-	 */
-	public byte SORT_ORDER_ASCENDING = 0;
-	/**
-	 * @deprecated Replaced by {@link SortOrderEnum#DESCENDING}.
-	 */
-	public byte SORT_ORDER_DESCENDING = 1;
-
 
 	/**
 	 * Gets the sort field name.
 	 */
 	public String getName();
 		
-	/**
-	 * @deprecated Replaced by {@link #getOrderValue()}.
-	 */
-	public byte getOrder();
-	
 	/**
 	 * Gets the sort order for the field.
 	 */
 	public SortOrderEnum getOrderValue();
 		
+	/**
+	 * Gets the type of the sort field.
+	 */
+	public SortFieldTypeEnum getType();
 
 }
