@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -29,7 +29,7 @@ import net.sf.jasperreports.engine.type.CalculationEnum;
  * A value copied from a subreport into a variable of the master report.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRSubreportReturnValue.java 3510 2010-03-05 10:38:28Z shertage $
+ * @version $Id: JRSubreportReturnValue.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public interface JRSubreportReturnValue extends JRCloneable
 {
@@ -48,11 +48,6 @@ public interface JRSubreportReturnValue extends JRCloneable
 	 */
 	public String getToVariable();
 
-	/**
-	 * @deprecated Replaced by {@link #getCalculationValue()}
-	 */
-	public byte getCalculation();
-	
 	/**
 	 * Returns the calculation type.
 	 * <p>
