@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -39,7 +39,7 @@ import net.sf.jasperreports.engine.type.ResetTypeEnum;
  * current group expression like you can see done in the "BreakGroup" of the <i>jasper</i> sample).
  *
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRVariable.java 3583 2010-03-12 11:35:40Z shertage $
+ * @version $Id: JRVariable.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public interface JRVariable extends JRCloneable
 {
@@ -75,102 +75,6 @@ public interface JRVariable extends JRCloneable
 	public static final String COLUMN_NUMBER = "COLUMN_NUMBER";
 
 
-	/**
-	 * @deprecated Replaced by {@link ResetTypeEnum#REPORT}.
-	 */
-	public static final byte RESET_TYPE_REPORT = 1;
-
-
-	/**
-	 * @deprecated Replaced by {@link ResetTypeEnum#PAGE}.
-	 */
-	public static final byte RESET_TYPE_PAGE = 2;
-
-
-	/**
-	 * @deprecated Replaced by {@link ResetTypeEnum#COLUMN}.
-	 */
-	public static final byte RESET_TYPE_COLUMN = 3;
-
-
-	/**
-	 * @deprecated Replaced by {@link ResetTypeEnum#GROUP}.
-	 */
-	public static final byte RESET_TYPE_GROUP = 4;
-
-
-	/**
-	 * @deprecated Replaced by {@link ResetTypeEnum#NONE}.
-	 */
-	public static final byte RESET_TYPE_NONE = 5;
-
-
-	/**
-	 * @deprecated Replaced by {@link CalculationEnum#NOTHING}.
-	 */
-	public static final byte CALCULATION_NOTHING = 0;
-
-
-	/**
-	 * @deprecated Replaced by {@link CalculationEnum#COUNT}.
-	 */
-	public static final byte CALCULATION_COUNT = 1;
-
-
-	/**
-	 * @deprecated Replaced by {@link CalculationEnum#SUM}.
-	 */
-	public static final byte CALCULATION_SUM = 2;
-
-
-	/**
-	 * @deprecated Replaced by {@link CalculationEnum#AVERAGE}.
-	 */
-	public static final byte CALCULATION_AVERAGE = 3;
-
-
-	/**
-	 * @deprecated Replaced by {@link CalculationEnum#LOWEST}.
-	 */
-	public static final byte CALCULATION_LOWEST = 4;
-
-
-	/**
-	 * @deprecated Replaced by {@link CalculationEnum#HIGHEST}.
-	 */
-	public static final byte CALCULATION_HIGHEST = 5;
-
-
-	/**
-	 * @deprecated Replaced by {@link CalculationEnum#STANDARD_DEVIATION}.
-	 */
-	public static final byte CALCULATION_STANDARD_DEVIATION = 6;
-
-
-	/**
-	 * @deprecated Replaced by {@link CalculationEnum#VARIANCE}.
-	 */
-	public static final byte CALCULATION_VARIANCE = 7;
-
-
-	/**
-	 * @deprecated Replaced by {@link CalculationEnum#SYSTEM}.
-	 */
-	public static final byte CALCULATION_SYSTEM = 8;
-	
-	
-	/**
-	 * @deprecated Replaced by {@link CalculationEnum#FIRST}.
-	 */
-	public static final byte CALCULATION_FIRST = 9;
-
-
-	/**
-	 * @deprecated Replaced by {@link CalculationEnum#DISTINCT_COUNT}.
-	 */
-	public static final byte CALCULATION_DISTINCT_COUNT = 10;
-
-
 	/**
 	 * Returns the name of the variable. Since all variables are stored in a map, the variable names are the keys in the map.
 	 * @return a string containing the variable name
@@ -182,7 +86,7 @@ public interface JRVariable extends JRCloneable
 	 * Returns the class of the variable value. Any class is allowed as long as it is in the classpath at compile and run time.
 	 * @return a <tt>Class</tt> instance representing the variable value class
 	 */
-	public Class getValueClass();
+	public Class<?> getValueClass();
 		
 	/**
 	 * Returns the string name of the variable value class.
@@ -195,23 +99,13 @@ public interface JRVariable extends JRCloneable
 	 * @see net.sf.jasperreports.engine.fill.JRIncrementer
 	 * @see net.sf.jasperreports.engine.fill.JRIncrementerFactory
 	 */
-	public Class getIncrementerFactoryClass();
+	public Class<?> getIncrementerFactoryClass();
 		
 	/**
 	 * Returns the string name of the variable value class.
 	 */
 	public String getIncrementerFactoryClassName();
 		
-	/**
-	 * @deprecated Replaced by {@link #getResetTypeValue()}.
-	 */
-	public byte getResetType();
-		
-	/**
-	 * @deprecated Replaced by {@link #getIncrementTypeValue()}.
-	 */
-	public byte getIncrementType();
-	
 	/**
 	 * Gets the variable reset type.
 	 * @return a value representing one of the reset type constants in {@link ResetTypeEnum}
@@ -224,11 +118,6 @@ public interface JRVariable extends JRCloneable
 	 */
 	public IncrementTypeEnum getIncrementTypeValue();
 	
-	/**
-	 * @deprecated Replaced by {@link #getCalculationValue()}.
-	 */
-	public byte getCalculation();
-	
 	/**
 	 * Gets the variable calculation type.
 	 * @return a value representing one of the calculation type constants in {@link CalculationEnum}
@@ -237,7 +126,7 @@ public interface JRVariable extends JRCloneable
 
 	/**
 	 * Returns <code>true</code> if the variable calculation type is system defined.
-	 * @see JRVariable#CALCULATION_SYSTEM
+	 * @see CalculationEnum#SYSTEM
 	 */
 	public boolean isSystemDefined();
 
@@ -254,14 +143,14 @@ public interface JRVariable extends JRCloneable
 	public JRExpression getInitialValueExpression();
 		
 	/**
-	 * Returns the group whose break triggers the variable reset. Only used when {@link JRVariable#getResetType()} returns
-	 * {@link JRVariable#RESET_TYPE_GROUP}.
+	 * Returns the group whose break triggers the variable reset. Only used when {@link JRVariable#getResetTypeValue()} returns
+	 * {@link ResetTypeEnum#GROUP}.
 	 */
 	public JRGroup getResetGroup();
 		
 	/**
-	 * Returns the group whose break triggers the variable increment. Only used when {@link JRVariable#getIncrementType()} returns
-	 * {@link JRVariable#RESET_TYPE_GROUP}.
+	 * Returns the group whose break triggers the variable increment. Only used when {@link JRVariable#getIncrementTypeValue()} returns
+	 * {@link ResetTypeEnum#GROUP}.
 	 */
 	public JRGroup getIncrementGroup();
 		
