@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -27,11 +27,11 @@ package net.sf.jasperreports.engine;
  * Virtualization helper class.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRVirtualizationHelper.java 3713 2010-04-08 11:06:05Z teodord $
+ * @version $Id: JRVirtualizationHelper.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public final class JRVirtualizationHelper
 {
-	private static final ThreadLocal threadVirtualizer = new ThreadLocal();
+	private static final ThreadLocal<JRVirtualizer> threadVirtualizer = new ThreadLocal<JRVirtualizer>();
 
 	
 	/**
@@ -67,7 +67,7 @@ public final class JRVirtualizationHelper
 	 */
 	public static JRVirtualizer getThreadVirtualizer()
 	{
-		return (JRVirtualizer) threadVirtualizer.get();
+		return threadVirtualizer.get();
 	}
 	
 	
