@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -54,7 +54,7 @@ import net.sf.jasperreports.engine.util.JRProperties;
  * other formats like PDF, HTML, XLS, CSV or XML.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JasperPrint.java 3792 2010-05-12 14:23:56Z teodord $
+ * @version $Id: JasperPrint.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JasperPrint implements Serializable, JRPropertiesHolder
 {
@@ -74,25 +74,13 @@ public class JasperPrint implements Serializable, JRPropertiesHolder
 	{
 		private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 		
-		private JRReportFont defaultFont;
 		private JRStyle defaultStyle;
 
-		DefaultStyleProvider(JRReportFont font, JRStyle style)
+		DefaultStyleProvider(JRStyle style)
 		{
-			this.defaultFont = font;
 			this.defaultStyle = style;
 		}
 
-		public JRReportFont getDefaultFont()
-		{
-			return defaultFont;
-		}
-
-		void setDefaultFont(JRReportFont font)
-		{
-			this.defaultFont = font;
-		}
-
 		public JRStyle getDefaultStyle()
 		{
 			return defaultStyle;
@@ -113,26 +101,24 @@ public class JasperPrint implements Serializable, JRPropertiesHolder
 	/**
 	 *
 	 */
-	private String name = null;
-	private int pageWidth = 0;
-	private int pageHeight = 0;
-	private Integer topMargin = 0;
-	private Integer leftMargin = 0;
-	private Integer bottomMargin = 0;
-	private Integer rightMargin = 0;
+	private String name;
+	private int pageWidth;
+	private int pageHeight;
+	private Integer topMargin;
+	private Integer leftMargin;
+	private Integer bottomMargin;
+	private Integer rightMargin;
 	private OrientationEnum orientationValue = OrientationEnum.PORTRAIT;
 
-	private Map fontsMap = new HashMap();
-	private List fontsList = new ArrayList();
-	private Map stylesMap = new HashMap();
-	private List stylesList = new ArrayList();
-	private Map originsMap = new HashMap();
-	private List originsList = new ArrayList();
+	private Map<String, JRStyle> stylesMap = new HashMap<String, JRStyle>();
+	private List<JRStyle> stylesList = new ArrayList<JRStyle>();
+	private Map<JROrigin, Integer> originsMap = new HashMap<JROrigin, Integer>();
+	private List<JROrigin> originsList = new ArrayList<JROrigin>();
 
-	private List pages = new ArrayList();
+	private List<JRPrintPage> pages = new ArrayList<JRPrintPage>();
 
-	private transient Map anchorIndexes = null;
-	private DefaultStyleProvider defaultStyleProvider = null;
+	private transient Map<String,JRPrintAnchorIndex> anchorIndexes;
+	private DefaultStyleProvider defaultStyleProvider;
 	
 	private String formatFactoryClass;
 	private String localeCode;
@@ -146,7 +132,7 @@ public class JasperPrint implements Serializable, JRPropertiesHolder
 	 */
 	public JasperPrint()
 	{
-		defaultStyleProvider = new DefaultStyleProvider(null, null);
+		defaultStyleProvider = new DefaultStyleProvider(null);
 
 		propertiesMap = new JRPropertiesMap();
 	}
@@ -277,22 +263,6 @@ public class JasperPrint implements Serializable, JRPropertiesHolder
 		this.rightMargin = rightMargin;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getOrientationValue()}.
-	 */
-	public byte getOrientation()
-	{
-		return getOrientationValue().getValue();
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #setOrientation(OrientationEnum)}.
-	 */
-	public void setOrientation(byte orientation)
-	{
-		this.orientation = orientation;
-	}
-
 	/**
 	 * Returns the page orientation.
 	 * @see OrientationEnum PORTRAIT,
@@ -363,125 +333,6 @@ public class JasperPrint implements Serializable, JRPropertiesHolder
 		propertiesMap.removeProperty(propName);
 	}
 
-	/**
-	 * Returns the default report font.
-	 */
-	public JRReportFont getDefaultFont()
-	{
-		return defaultStyleProvider.getDefaultFont();
-	}
-
-	/**
-	 * Sets the default report font.
-	 */
-	public void setDefaultFont(JRReportFont font)
-	{
-		defaultStyleProvider.setDefaultFont(font);
-	}
-
-	/**
-	 * When we want to virtualize pages, we want a font provider that
-	 * is <i>not</i> the print object itself.
-	 */
-	public JRDefaultFontProvider getDefaultFontProvider()
-	{
-		return defaultStyleProvider;
-	}
-		
-	/**
-	 * Gets an array of report fonts.
-	 * @deprecated
-	 */
-	public JRReportFont[] getFonts()
-	{
-		JRReportFont[] fontsArray = new JRReportFont[fontsList.size()];
-		
-		fontsList.toArray(fontsArray);
-
-		return fontsArray;
-	}
-
-	/**
-	 * Gets a list of report fonts.
-	 * @deprecated
-	 */
-	public List getFontsList()
-	{
-		return fontsList;
-	}
-
-	/**
-	 * Gets a map of report fonts.
-	 * @deprecated
-	 */
-	public Map getFontsMap()
-	{
-		return fontsMap;
-	}
-
-	/**
-	 * Adds a new font to the report fonts.
-	 * @deprecated
-	 */
-	public synchronized void addFont(JRReportFont reportFont) throws JRException
-	{
-		addFont(reportFont, false);
-	}
-
-	/**
-	 * Adds a new font to the report fonts.
-	 * @deprecated
-	 */
-	public synchronized void addFont(JRReportFont reportFont, boolean isIgnoreDuplicate) throws JRException
-	{
-		if (fontsMap.containsKey(reportFont.getName()))
-		{
-			if (!isIgnoreDuplicate)
-			{
-				throw new JRException("Duplicate declaration of report font : "	+ reportFont.getName());
-			}
-		}
-		else
-		{
-			fontsList.add(reportFont);
-			fontsMap.put(reportFont.getName(), reportFont);
-			
-			if (reportFont.isDefault())
-			{
-				setDefaultFont(reportFont);
-			}
-		}
-	}
-
-	/**
-	 * @deprecated
-	 */
-	public synchronized JRReportFont removeFont(String fontName)
-	{
-		return removeFont(
-			(JRReportFont)fontsMap.get(fontName)
-			);
-	}
-
-	/**
-	 * @deprecated
-	 */
-	public synchronized JRReportFont removeFont(JRReportFont reportFont)
-	{
-		if (reportFont != null)
-		{
-			if (reportFont.isDefault())
-			{
-				setDefaultFont(null);
-			}
-
-			fontsList.remove(reportFont);
-			fontsMap.remove(reportFont.getName());
-		}
-		
-		return reportFont;
-	}
-
 	/**
 	 * Returns the default report style.
 	 */
@@ -522,7 +373,7 @@ public class JasperPrint implements Serializable, JRPropertiesHolder
 	/**
 	 * Gets a list of report styles.
 	 */
-	public List getStylesList()
+	public List<JRStyle> getStylesList()
 	{
 		return stylesList;
 	}
@@ -530,7 +381,7 @@ public class JasperPrint implements Serializable, JRPropertiesHolder
 	/**
 	 * Gets a map of report styles.
 	 */
-	public Map getStylesMap()
+	public Map<String, JRStyle> getStylesMap()
 	{
 		return stylesMap;
 	}
@@ -572,9 +423,7 @@ public class JasperPrint implements Serializable, JRPropertiesHolder
 	 */
 	public synchronized JRStyle removeStyle(String styleName)
 	{
-		return removeStyle(
-			(JRStyle)stylesMap.get(styleName)
-			);
+		return removeStyle(stylesMap.get(styleName));
 	}
 
 	/**
@@ -601,13 +450,13 @@ public class JasperPrint implements Serializable, JRPropertiesHolder
 	 */
 	public JROrigin[] getOrigins()
 	{
-		return (JROrigin[]) originsList.toArray(new JROrigin[originsList.size()]);
+		return originsList.toArray(new JROrigin[originsList.size()]);
 	}
 
 	/**
 	 * Gets a list of report origins.
 	 */
-	public List getOriginsList()
+	public List<JROrigin> getOriginsList()
 	{
 		return originsList;
 	}
@@ -615,7 +464,7 @@ public class JasperPrint implements Serializable, JRPropertiesHolder
 	/**
 	 * Gets a map of report origins.
 	 */
-	public Map getOriginsMap()
+	public Map<JROrigin, Integer> getOriginsMap()
 	{
 		return originsMap;
 	}
@@ -640,7 +489,7 @@ public class JasperPrint implements Serializable, JRPropertiesHolder
 		if (originsMap.containsKey(origin))
 		{
 			originsList.remove(origin);
-			originsMap = new HashMap();
+			originsMap = new HashMap<JROrigin, Integer>();
 			for(int i = 0; i < originsList.size(); i++)
 			{
 				originsMap.put(originsList.get(i), Integer.valueOf(i));
@@ -653,7 +502,7 @@ public class JasperPrint implements Serializable, JRPropertiesHolder
 	/**
 	 * Returns a list of all pages in the filled report.
 	 */
-	public List getPages()
+	public List<JRPrintPage> getPages()
 	{
 		return pages;
 	}
@@ -682,23 +531,23 @@ public class JasperPrint implements Serializable, JRPropertiesHolder
 	public synchronized JRPrintPage removePage(int index)
 	{
 		anchorIndexes = null;
-		return (JRPrintPage)pages.remove(index);
+		return pages.remove(index);
 	}
 
 	/**
 	 *
 	 */
-	public synchronized Map getAnchorIndexes()
+	public synchronized Map<String,JRPrintAnchorIndex> getAnchorIndexes()
 	{
 		if (anchorIndexes == null)
 		{
-			anchorIndexes = new HashMap();
+			anchorIndexes = new HashMap<String,JRPrintAnchorIndex>();
 			
 			int i = 0;
-			for(Iterator itp = pages.iterator(); itp.hasNext(); i++)
+			for(Iterator<JRPrintPage> itp = pages.iterator(); itp.hasNext(); i++)
 			{
-				JRPrintPage page = (JRPrintPage)itp.next();
-				Collection elements = page.getElements();
+				JRPrintPage page = itp.next();
+				Collection<JRPrintElement> elements = page.getElements();
 				collectAnchors(elements, i, 0, 0);
 			}
 		}
@@ -706,14 +555,14 @@ public class JasperPrint implements Serializable, JRPropertiesHolder
 		return anchorIndexes;
 	}
 
-	protected void collectAnchors(Collection elements, int pageIndex, int offsetX, int offsetY)
+	protected void collectAnchors(Collection<JRPrintElement> elements, int pageIndex, int offsetX, int offsetY)
 	{
 		if (elements != null && elements.size() > 0)
 		{
 			JRPrintElement element = null;
-			for(Iterator it = elements.iterator(); it.hasNext();)
+			for(Iterator<JRPrintElement> it = elements.iterator(); it.hasNext();)
 			{
-				element = (JRPrintElement)it.next();
+				element = it.next();
 				if (element instanceof JRPrintAnchor)
 				{
 					anchorIndexes.put(
