@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -36,7 +36,7 @@ import net.sf.jasperreports.engine.type.BreakTypeEnum;
 /**
  * The actual implementation of a break element.
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseBreak.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBaseBreak.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseBreak extends JRBaseElement implements JRBreak
 {
@@ -84,22 +84,6 @@ public class JRBaseBreak extends JRBaseElement implements JRBreak
 		return 1;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getTypeValue()}.
-	 */
-	public byte getType()
-	{
-		return getTypeValue().getValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setType(BreakTypeEnum)}.
-	 */
-	public void setType(byte type)
-	{
-		setType(BreakTypeEnum.getByValue(type));
-	}
-
 	/**
 	 *
 	 */
