@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -52,7 +52,6 @@ import net.sf.jasperreports.charts.JRXyDataset;
 import net.sf.jasperreports.charts.JRXyzDataset;
 import net.sf.jasperreports.charts.type.EdgeEnum;
 import net.sf.jasperreports.engine.JRAnchor;
-import net.sf.jasperreports.engine.JRBox;
 import net.sf.jasperreports.engine.JRChart;
 import net.sf.jasperreports.engine.JRChartDataset;
 import net.sf.jasperreports.engine.JRChartPlot;
@@ -71,14 +70,13 @@ import net.sf.jasperreports.engine.type.HyperlinkTargetEnum;
 import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
 import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
-import net.sf.jasperreports.engine.util.JRPenUtil;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
-import net.sf.jasperreports.engine.util.LineBoxWrapper;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseChart.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBaseChart.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseChart extends JRBaseElement implements JRChart
 {
@@ -114,23 +112,23 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 	/**
 	 *
 	 */
-	protected byte chartType = 0;
+	protected byte chartType;
 
 	/**
 	 *
 	 */
-	protected Boolean showLegend = null;
+	protected Boolean showLegend;
 	protected EvaluationTimeEnum evaluationTimeValue = EvaluationTimeEnum.NOW;
 	protected String linkType;
 	protected String linkTarget;
 	private JRHyperlinkParameter[] hyperlinkParameters;
 	
-	protected Color titleColor = null;
-	protected Color subtitleColor = null;
-	protected Color legendColor = null;
-	protected Color legendBackgroundColor = null;
-	protected EdgeEnum legendPositionValue = null;
-	protected EdgeEnum titlePositionValue = null;
+	protected Color titleColor;
+	protected Color subtitleColor;
+	protected Color legendColor;
+	protected Color legendBackgroundColor;
+	protected EdgeEnum legendPositionValue;
+	protected EdgeEnum titlePositionValue;
 
 	protected String renderType;
 	protected String theme;
@@ -138,27 +136,27 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 	/**
 	 *
 	 */
-	protected JRLineBox lineBox = null;
-	protected JRFont titleFont = null;
-	protected JRFont subtitleFont = null;
-	protected JRFont legendFont = null;
+	protected JRLineBox lineBox;
+	protected JRFont titleFont;
+	protected JRFont subtitleFont;
+	protected JRFont legendFont;
 
 	protected String customizerClass;
 
 	/**
 	 *
 	 */
-	protected JRGroup evaluationGroup = null;
-	protected JRExpression titleExpression = null;
-	protected JRExpression subtitleExpression = null;
-	protected JRExpression anchorNameExpression = null;
-	protected JRExpression hyperlinkReferenceExpression = null;
-	protected JRExpression hyperlinkAnchorExpression = null;
-	protected JRExpression hyperlinkPageExpression = null;
+	protected JRGroup evaluationGroup;
+	protected JRExpression titleExpression;
+	protected JRExpression subtitleExpression;
+	protected JRExpression anchorNameExpression;
+	protected JRExpression hyperlinkReferenceExpression;
+	protected JRExpression hyperlinkAnchorExpression;
+	protected JRExpression hyperlinkPageExpression;
 	private JRExpression hyperlinkTooltipExpression;
 
-	protected JRChartDataset dataset = null;
-	protected JRChartPlot plot = null;
+	protected JRChartDataset dataset;
+	protected JRChartPlot plot;
 
 	/**
 	 * The bookmark level for the anchor associated with this chart.
@@ -289,9 +287,9 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 		renderType = chart.getRenderType();
 		theme = chart.getTheme();
 		
-		titleFont = new JRBaseFont(this, chart.getTitleFont());
-		subtitleFont = new JRBaseFont(this, chart.getSubtitleFont());
-		legendFont = new JRBaseFont(this, chart.getLegendFont());
+		titleFont = factory.getFont(this, chart.getTitleFont());
+		subtitleFont = factory.getFont(this, chart.getSubtitleFont());
+		legendFont =  factory.getFont(this, chart.getLegendFont());
 
 		evaluationGroup = factory.getGroup(chart.getEvaluationGroup());
 		titleExpression = factory.getExpression(chart.getTitleExpression());
@@ -310,22 +308,6 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 	}
 		
 
-	/**
-	 * @deprecated Replaced by {@link #getShowLegend()}
-	 */
-	public boolean isShowLegend()
-	{
-		return this.showLegend == null ? false : showLegend.booleanValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setShowLegend(Boolean)}
-	 */
-	public void setShowLegend(boolean isShowLegend)
-	{
-		setShowLegend(Boolean.valueOf(isShowLegend));
-	}
-
 	/**
 	 * 
 	 */
@@ -344,14 +326,6 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 		getEventSupport().firePropertyChange(PROPERTY_SHOW_LEGEND, old, this.showLegend);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getEvaluationTimeValue()}.
-	 */
-	public byte getEvaluationTime()
-	{
-		return getEvaluationTimeValue().getValue();
-	}
-		
 	/**
 	 *
 	 */
@@ -368,14 +342,6 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 		return evaluationGroup;
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public JRBox getBox()
-	{
-		return new LineBoxWrapper(getLineBox());
-	}
-
 	/**
 	 *
 	 */
@@ -392,38 +358,6 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 		return titleFont;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getTitlePositionValue()}
-	 */
-	public byte getTitlePosition()
-	{
-		return getTitlePositionValue() == null ? EdgeEnum.TOP.getValue() : getTitlePositionValue().getValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setTitlePosition(EdgeEnum)}
-	 */
-	public void setTitlePosition(byte titlePosition)
-	{
-		setTitlePosition(EdgeEnum.getByValue(titlePosition));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getTitlePositionValue()}
-	 */
-	public Byte getTitlePositionByte()
-	{
-		return getTitlePositionValue() == null ? null : getTitlePositionValue().getValueByte();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setTitlePosition(EdgeEnum)}
-	 */
-	public void setTitlePosition(Byte titlePosition)
-	{
-		setTitlePosition(EdgeEnum.getByValue(titlePosition));
-	}
-
 	/**
 	 *
 	 */
@@ -537,38 +471,6 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 		getEventSupport().firePropertyChange(PROPERTY_LEGEND_COLOR, old, this.legendColor);
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #getLegendPositionValue()}
-	 */
-	public byte getLegendPosition()
-	{
-		return getLegendPositionValue() == null? EdgeEnum.BOTTOM.getValue() : getLegendPositionValue().getValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setLegendPosition(EdgeEnum)}
-	 */
-	public void setLegendPosition(byte legendPosition)
-	{
-		setLegendPosition(EdgeEnum.getByValue(legendPosition));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLegendPositionValue()}
-	 */
-	public Byte getLegendPositionByte()
-	{
-		return getLegendPositionValue() == null? null : getLegendPositionValue().getValueByte();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setLegendPosition(EdgeEnum)}
-	 */
-	public void setLegendPosition(Byte legendPosition)
-	{
-		setLegendPosition(EdgeEnum.getByValue(legendPosition));
-	}
-
 	/**
 	 *
 	 */
@@ -750,446 +652,6 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(lineBox.getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBorder(byte border)
-	{
-		JRPenUtil.setLinePenFromPen(border, lineBox.getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBorder(Byte border)
-	{
-		JRPenUtil.setLinePenFromPen(border, lineBox.getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getBorderColor()
-	{
-		return lineBox.getPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnBorderColor()
-	{
-		return lineBox.getPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBorderColor(Color borderColor)
-	{
-		lineBox.getPen().setLineColor(borderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getPadding()
-	{
-		return lineBox.getPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnPadding()
-	{
-		return lineBox.getOwnPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setPadding(int padding)
-	{
-		lineBox.setPadding(padding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setPadding(Integer padding)
-	{
-		lineBox.setPadding(padding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getTopBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(lineBox.getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnTopBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopBorder(byte topBorder)
-	{
-		JRPenUtil.setLinePenFromPen(topBorder, lineBox.getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopBorder(Byte topBorder)
-	{
-		JRPenUtil.setLinePenFromPen(topBorder, lineBox.getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getTopBorderColor()
-	{
-		return lineBox.getTopPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnTopBorderColor()
-	{
-		return lineBox.getTopPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopBorderColor(Color topBorderColor)
-	{
-		lineBox.getTopPen().setLineColor(topBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getTopPadding()
-	{
-		return lineBox.getTopPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnTopPadding()
-	{
-		return lineBox.getOwnTopPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopPadding(int topPadding)
-	{
-		lineBox.setTopPadding(topPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopPadding(Integer topPadding)
-	{
-		lineBox.setTopPadding(topPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getLeftBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(lineBox.getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnLeftBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftBorder(byte leftBorder)
-	{
-		JRPenUtil.setLinePenFromPen(leftBorder, lineBox.getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftBorder(Byte leftBorder)
-	{
-		JRPenUtil.setLinePenFromPen(leftBorder, lineBox.getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getLeftBorderColor()
-	{
-		return lineBox.getLeftPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnLeftBorderColor()
-	{
-		return lineBox.getLeftPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftBorderColor(Color leftBorderColor)
-	{
-		lineBox.getLeftPen().setLineColor(leftBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getLeftPadding()
-	{
-		return lineBox.getLeftPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnLeftPadding()
-	{
-		return lineBox.getOwnLeftPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftPadding(int leftPadding)
-	{
-		lineBox.setLeftPadding(leftPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftPadding(Integer leftPadding)
-	{
-		lineBox.setLeftPadding(leftPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getBottomBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(lineBox.getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnBottomBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomBorder(byte bottomBorder)
-	{
-		JRPenUtil.setLinePenFromPen(bottomBorder, lineBox.getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomBorder(Byte bottomBorder)
-	{
-		JRPenUtil.setLinePenFromPen(bottomBorder, lineBox.getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getBottomBorderColor()
-	{
-		return lineBox.getBottomPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnBottomBorderColor()
-	{
-		return lineBox.getBottomPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomBorderColor(Color bottomBorderColor)
-	{
-		lineBox.getBottomPen().setLineColor(bottomBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getBottomPadding()
-	{
-		return lineBox.getBottomPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnBottomPadding()
-	{
-		return lineBox.getOwnBottomPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomPadding(int bottomPadding)
-	{
-		lineBox.setBottomPadding(bottomPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomPadding(Integer bottomPadding)
-	{
-		lineBox.setBottomPadding(bottomPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getRightBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(lineBox.getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnRightBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightBorder(byte rightBorder)
-	{
-		JRPenUtil.setLinePenFromPen(rightBorder, lineBox.getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightBorder(Byte rightBorder)
-	{
-		JRPenUtil.setLinePenFromPen(rightBorder, lineBox.getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getRightBorderColor()
-	{
-		return lineBox.getRightPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnRightBorderColor()
-	{
-		return lineBox.getRightPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightBorderColor(Color rightBorderColor)
-	{
-		lineBox.getRightPen().setLineColor(rightBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getRightPadding()
-	{
-		return lineBox.getRightPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnRightPadding()
-	{
-		return lineBox.getOwnRightPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightPadding(int rightPadding)
-	{
-		lineBox.setRightPadding(rightPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightPadding(Integer rightPadding)
-	{
-		lineBox.setRightPadding(rightPadding);
-	}
-
 
 	public String getLinkType()
 	{
@@ -1230,53 +692,20 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 		JRBaseChart clone = (JRBaseChart)super.clone();
 		
 		clone.lineBox = lineBox.clone(clone);
+		clone.hyperlinkParameters = JRCloneUtils.cloneArray(hyperlinkParameters);
+		clone.titleFont = JRCloneUtils.nullSafeClone((JRBaseFont)titleFont);
+		clone.subtitleFont = JRCloneUtils.nullSafeClone((JRBaseFont)subtitleFont);
+		clone.legendFont = JRCloneUtils.nullSafeClone((JRBaseFont)legendFont);
 
-		if (hyperlinkParameters != null)
-		{
-			clone.hyperlinkParameters = new JRHyperlinkParameter[hyperlinkParameters.length];
-			for(int i = 0; i < hyperlinkParameters.length; i++)
-			{
-				clone.hyperlinkParameters[i] = (JRHyperlinkParameter)hyperlinkParameters[i].clone();
-			}
-		}
-
-		if (titleExpression != null)
-		{
-			clone.titleExpression = (JRExpression)titleExpression.clone();
-		}
-		if (subtitleExpression != null)
-		{
-			clone.subtitleExpression = (JRExpression)subtitleExpression.clone();
-		}
-		if (anchorNameExpression != null)
-		{
-			clone.anchorNameExpression = (JRExpression)anchorNameExpression.clone();
-		}
-		if (hyperlinkReferenceExpression != null)
-		{
-			clone.hyperlinkReferenceExpression = (JRExpression)hyperlinkReferenceExpression.clone();
-		}
-		if (hyperlinkAnchorExpression != null)
-		{
-			clone.hyperlinkAnchorExpression = (JRExpression)hyperlinkAnchorExpression.clone();
-		}
-		if (hyperlinkPageExpression != null)
-		{
-			clone.hyperlinkPageExpression = (JRExpression)hyperlinkPageExpression.clone();
-		}
-		if (hyperlinkTooltipExpression != null)
-		{
-			clone.hyperlinkTooltipExpression = (JRExpression)hyperlinkTooltipExpression.clone();
-		}
-
-		if (dataset != null)
-		{
-			clone.dataset = (JRChartDataset)dataset.clone();
-		}
-		if (plot != null)
-		{
-			clone.plot = (JRChartPlot)plot.clone(clone);
-		}
+		clone.titleExpression = JRCloneUtils.nullSafeClone(titleExpression);
+		clone.subtitleExpression = JRCloneUtils.nullSafeClone(subtitleExpression);
+		clone.anchorNameExpression = JRCloneUtils.nullSafeClone(anchorNameExpression);
+		clone.hyperlinkReferenceExpression = JRCloneUtils.nullSafeClone(hyperlinkReferenceExpression);
+		clone.hyperlinkAnchorExpression = JRCloneUtils.nullSafeClone(hyperlinkAnchorExpression);
+		clone.hyperlinkPageExpression = JRCloneUtils.nullSafeClone(hyperlinkPageExpression);
+		clone.hyperlinkTooltipExpression = JRCloneUtils.nullSafeClone(hyperlinkTooltipExpression);
+		clone.dataset = JRCloneUtils.nullSafeClone(dataset);
+		clone.plot = JRCloneUtils.nullSafeClone(plot);
 
 		return clone;
 	}
@@ -1289,67 +718,67 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 	/**
 	 * @deprecated
 	 */
-	private Byte border = null;
+	private Byte border;
 	/**
 	 * @deprecated
 	 */
-	private Byte topBorder = null;
+	private Byte topBorder;
 	/**
 	 * @deprecated
 	 */
-	private Byte leftBorder = null;
+	private Byte leftBorder;
 	/**
 	 * @deprecated
 	 */
-	private Byte bottomBorder = null;
+	private Byte bottomBorder;
 	/**
 	 * @deprecated
 	 */
-	private Byte rightBorder = null;
+	private Byte rightBorder;
 	/**
 	 * @deprecated
 	 */
-	private Color borderColor = null;
+	private Color borderColor;
 	/**
 	 * @deprecated
 	 */
-	private Color topBorderColor = null;
+	private Color topBorderColor;
 	/**
 	 * @deprecated
 	 */
-	private Color leftBorderColor = null;
+	private Color leftBorderColor;
 	/**
 	 * @deprecated
 	 */
-	private Color bottomBorderColor = null;
+	private Color bottomBorderColor;
 	/**
 	 * @deprecated
 	 */
-	private Color rightBorderColor = null;
+	private Color rightBorderColor;
 	/**
 	 * @deprecated
 	 */
-	private Integer padding = null;
+	private Integer padding;
 	/**
 	 * @deprecated
 	 */
-	private Integer topPadding = null;
+	private Integer topPadding;
 	/**
 	 * @deprecated
 	 */
-	private Integer leftPadding = null;
+	private Integer leftPadding;
 	/**
 	 * @deprecated
 	 */
-	private Integer bottomPadding = null;
+	private Integer bottomPadding;
 	/**
 	 * @deprecated
 	 */
-	private Integer rightPadding = null;
+	private Integer rightPadding;
 	/**
 	 * @deprecated
 	 */
-	private boolean isShowLegend = false;
+	private boolean isShowLegend;
 	/**
 	 * @deprecated
 	 */
@@ -1373,11 +802,11 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 	/**
 	 * @deprecated
 	 */
-	private Byte legendPositionByte = null;
+	private Byte legendPositionByte;
 	/**
 	 * @deprecated
 	 */
-	private Byte titlePositionByte = null;
+	private Byte titlePositionByte;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
