@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,11 +35,12 @@ import net.sf.jasperreports.engine.JRGroup;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.type.IncrementTypeEnum;
 import net.sf.jasperreports.engine.type.ResetTypeEnum;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseElementDataset.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBaseElementDataset.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public abstract class JRBaseElementDataset implements JRElementDataset, Serializable
 {
@@ -52,8 +53,8 @@ public abstract class JRBaseElementDataset implements JRElementDataset, Serializ
 
 	protected ResetTypeEnum resetTypeValue = ResetTypeEnum.REPORT;
 	protected IncrementTypeEnum incrementTypeValue = IncrementTypeEnum.NONE;
-	protected JRGroup resetGroup = null;
-	protected JRGroup incrementGroup = null;
+	protected JRGroup resetGroup;
+	protected JRGroup incrementGroup;
 	
 	protected JRDatasetRun datasetRun;
 	protected JRExpression incrementWhenExpression;
@@ -97,22 +98,6 @@ public abstract class JRBaseElementDataset implements JRElementDataset, Serializ
 	}
 
 	
-	/**
-	 * @deprecated Replaced by {@link #getResetTypeValue()}.
-	 */
-	public byte getResetType()
-	{
-		return getResetTypeValue().getValue();
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #getIncrementTypeValue()}.
-	 */
-	public byte getIncrementType()
-	{
-		return getIncrementTypeValue().getValue();
-	}
-		
 	/**
 	 *
 	 */
@@ -200,14 +185,9 @@ public abstract class JRBaseElementDataset implements JRElementDataset, Serializ
 			throw new JRRuntimeException(e);
 		}
 
-		if (incrementWhenExpression != null)
-		{
-			clone.incrementWhenExpression = (JRExpression)incrementWhenExpression.clone();
-		}
-		if (datasetRun != null)
-		{
-			clone.datasetRun = (JRDatasetRun)datasetRun.clone();
-		}
+		clone.incrementWhenExpression = JRCloneUtils.nullSafeClone(incrementWhenExpression);
+		clone.datasetRun = JRCloneUtils.nullSafeClone(datasetRun);
+		
 		return clone;
 	}
 
