@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -40,7 +40,7 @@ import net.sf.jasperreports.engine.JRVisitor;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseElementGroup.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: JRBaseElementGroup.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseElementGroup implements JRElementGroup, Serializable
 {
@@ -54,8 +54,8 @@ public class JRBaseElementGroup implements JRElementGroup, Serializable
 	/**
 	 *
 	 */
-	protected List children = new ArrayList();
-	protected JRElementGroup elementGroup = null;
+	protected List<JRChild> children = new ArrayList<JRChild>();
+	protected JRElementGroup elementGroup;
 
 
 	/**
@@ -74,12 +74,12 @@ public class JRBaseElementGroup implements JRElementGroup, Serializable
 		factory.put(elementGrp, this);
 		
 		/*   */
-		List list = elementGrp.getChildren();
+		List<JRChild> list = elementGrp.getChildren();
 		if (list != null && list.size() > 0)
 		{
 			for(int i = 0; i < list.size(); i++)
 			{
-				JRChild child = (JRChild)list.get(i);
+				JRChild child = list.get(i);
 				child = (JRChild)factory.getVisitResult(child);
 				children.add(child);
 			}
@@ -92,7 +92,7 @@ public class JRBaseElementGroup implements JRElementGroup, Serializable
 	/**
 	 *
 	 */
-	public List getChildren()
+	public List<JRChild> getChildren()
 	{
 		return this.children;
 	}
@@ -110,13 +110,13 @@ public class JRBaseElementGroup implements JRElementGroup, Serializable
 	/**
 	 *
 	 */
-	public static JRElement[] getElements(List children)
+	public static JRElement[] getElements(List<JRChild> children)
 	{
 		JRElement[] elements = null;
 		
 		if (children != null)
 		{
-			List allElements = new ArrayList();
+			List<JRElement> allElements = new ArrayList<JRElement>();
 			Object child = null;
 			JRElement[] childElementArray = null;
 			for(int i = 0; i < children.size(); i++)
@@ -124,7 +124,7 @@ public class JRBaseElementGroup implements JRElementGroup, Serializable
 				child = children.get(i);
 				if (child instanceof JRElement)
 				{
-					allElements.add(child);
+					allElements.add((JRElement)child);
 				}
 				else if (child instanceof JRElementGroup)
 				{
@@ -219,10 +219,10 @@ public class JRBaseElementGroup implements JRElementGroup, Serializable
 
 		if (children != null)
 		{
-			clone.children = new ArrayList(children.size());
+			clone.children = new ArrayList<JRChild>(children.size());
 			for(int i = 0; i < children.size(); i++)
 			{
-				clone.children.add(((JRChild)children.get(i)).clone(clone));
+				clone.children.add((JRChild)(children.get(i).clone(clone)));
 			}
 		}
 
