@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -32,7 +32,7 @@ import net.sf.jasperreports.engine.JRRuntimeException;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseExpressionChunk.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: JRBaseExpressionChunk.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseExpressionChunk implements JRExpressionChunk, Serializable
 {
@@ -47,7 +47,7 @@ public class JRBaseExpressionChunk implements JRExpressionChunk, Serializable
 	 *
 	 */
 	protected byte type = TYPE_TEXT;
-	protected String text = null;
+	protected String text;
 
 
 	/**
