@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -41,7 +41,7 @@ import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
  * that is included in compiled reports.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRBaseGenericElement.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBaseGenericElement.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseGenericElement extends JRBaseElement implements
 		JRGenericElement
@@ -50,7 +50,7 @@ public class JRBaseGenericElement extends JRBaseElement implements
 	private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 	
 	private JRGenericElementType genericType;
-	private List parameters;
+	private List<JRGenericElementParameter> parameters;
 	private EvaluationTimeEnum evaluationTimeValue = EvaluationTimeEnum.NOW;
 	private String evaluationGroupName;
 	
@@ -70,7 +70,7 @@ public class JRBaseGenericElement extends JRBaseElement implements
 		this.evaluationGroupName = element.getEvaluationGroupName();
 		
 		JRGenericElementParameter[] elementParameters = element.getParameters();
-		this.parameters = new ArrayList(elementParameters.length);
+		this.parameters = new ArrayList<JRGenericElementParameter>(elementParameters.length);
 		for (int i = 0; i < elementParameters.length; i++)
 		{
 			JRGenericElementParameter elementParameter = elementParameters[i];
@@ -87,8 +87,7 @@ public class JRBaseGenericElement extends JRBaseElement implements
 
 	public JRGenericElementParameter[] getParameters()
 	{
-		return (JRGenericElementParameter[]) parameters.toArray(
-				new JRGenericElementParameter[parameters.size()]);
+		return parameters.toArray(new JRGenericElementParameter[parameters.size()]);
 	}
 
 	public void collectExpressions(JRExpressionCollector collector)
@@ -106,14 +105,6 @@ public class JRBaseGenericElement extends JRBaseElement implements
 		return evaluationGroupName;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getEvaluationTimeValue()}.
-	 */
-	public byte getEvaluationTime()
-	{
-		return getEvaluationTimeValue().getValue();
-	}
-
 	public EvaluationTimeEnum getEvaluationTimeValue()
 	{
 		return evaluationTimeValue;
