@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -39,7 +39,7 @@ import net.sf.jasperreports.engine.util.JRStyleResolver;
  * This class provides functionality common to graphic elements. It provides implementation for the methods described
  * in <tt>JRTextElement</tt>.
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseGraphicElement.java 3833 2010-05-27 14:16:59Z teodord $
+ * @version $Id: JRBaseGraphicElement.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public abstract class JRBaseGraphicElement extends JRBaseElement implements JRGraphicElement
 {
@@ -93,70 +93,6 @@ public abstract class JRBaseGraphicElement extends JRBaseElement implements JRGr
 		return linePen;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getLinePen()}
-	 */
-	public byte getPen()
-	{
-		return JRPenUtil.getPenFromLinePen(linePen);
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #getLinePen()}
-	 */
-	public Byte getOwnPen()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(linePen);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLinePen()}
-	 */
-	public void setPen(byte pen)
-	{
-		setPen(new Byte(pen));
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #getLinePen()}
-	 */
-	public void setPen(Byte pen)
-	{
-		JRPenUtil.setLinePenFromPen(pen, linePen);
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #getFillValue()}
-	 */
-	public byte getFill()
-	{
-		return getFillValue().getValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getOwnFillValue()}
-	 */
-	public Byte getOwnFill()
-	{
-		return getOwnFillValue() == null ? null : getOwnFillValue().getValueByte();
-	}
-	
-	/**
-	 * @deprecated Replaced by {@link #setFill(FillEnum)}
-	 */
-	public void setFill(byte fill)
-	{
-		setFill(FillEnum.getByValue(fill));
-	}
-	
-	/**
-	 * @deprecated Replaced by {@link #setFill(FillEnum)}
-	 */
-	public void setFill(Byte fill)
-	{
-		setFill(FillEnum.getByValue(fill));
-	}
-
 	/**
 	 *
 	 */
