@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -37,11 +37,12 @@ import net.sf.jasperreports.engine.JRVariable;
 import net.sf.jasperreports.engine.design.events.JRChangeEventsSupport;
 import net.sf.jasperreports.engine.design.events.JRPropertyChangeSupport;
 import net.sf.jasperreports.engine.type.FooterPositionEnum;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseGroup.java 3858 2010-06-03 12:52:24Z lucianc $
+ * @version $Id: JRBaseGroup.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseGroup implements JRGroup, Serializable, JRChangeEventsSupport
 {
@@ -69,22 +70,22 @@ public class JRBaseGroup implements JRGroup, Serializable, JRChangeEventsSupport
 	/**
 	 *
 	 */
-	protected String name = null;
-	protected boolean isStartNewColumn = false;
-	protected boolean isStartNewPage = false;
-	protected boolean isResetPageNumber = false;
-	protected boolean isReprintHeaderOnEachPage = false;
-	protected int minHeightToStartNewPage = 0;
+	protected String name;
+	protected boolean isStartNewColumn;
+	protected boolean isStartNewPage;
+	protected boolean isResetPageNumber;
+	protected boolean isReprintHeaderOnEachPage;
+	protected int minHeightToStartNewPage;
 	protected FooterPositionEnum footerPositionValue = FooterPositionEnum.NORMAL;
-	protected boolean keepTogether = false;
+	protected boolean keepTogether;
 
 	/**
 	 *
 	 */
-	protected JRExpression expression = null;
-	protected JRSection groupHeaderSection = null;
-	protected JRSection groupFooterSection = null;
-	protected JRVariable countVariable = null;
+	protected JRExpression expression;
+	protected JRSection groupHeaderSection;
+	protected JRSection groupFooterSection;
+	protected JRVariable countVariable;
 	
 
 	/**
@@ -216,14 +217,6 @@ public class JRBaseGroup implements JRGroup, Serializable, JRChangeEventsSupport
 		this.minHeightToStartNewPage = minHeight;
 		getEventSupport().firePropertyChange(PROPERTY_MIN_HEIGHT_TO_START_NEW_PAGE, old, this.minHeightToStartNewPage);
 	}
-		
-	/**
-	 * @deprecated Replaced by {@link #getFooterPositionValue()}.
-	 */
-	public byte getFooterPosition()
-	{
-		return getFooterPositionValue().getValue();
-	}
 
 	/**
 	 *
@@ -232,14 +225,6 @@ public class JRBaseGroup implements JRGroup, Serializable, JRChangeEventsSupport
 	{
 		return this.footerPositionValue;
 	}
-
-	/**
-	 * @deprecated Replaced by {@link #setFooterPosition(FooterPositionEnum)}.
-	 */
-	public void setFooterPosition(byte footerPosition)
-	{
-		setFooterPosition(FooterPositionEnum.getByValue(footerPosition));
-	}
 		
 	/**
 	 *
@@ -277,19 +262,6 @@ public class JRBaseGroup implements JRGroup, Serializable, JRChangeEventsSupport
 		return this.expression;
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #getGroupHeaderSection()}.
-	 */
-	public JRBand getGroupHeader()
-	{
-		return 
-			groupHeaderSection == null 
-			|| groupHeaderSection.getBands() == null 
-			|| groupHeaderSection.getBands().length == 0 
-				? null 
-				: (JRBand)groupHeaderSection.getBands()[0];
-	}
-		
 	/**
 	 *
 	 */
@@ -298,19 +270,6 @@ public class JRBaseGroup implements JRGroup, Serializable, JRChangeEventsSupport
 		return this.groupHeaderSection;
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getGroupFooterSection()}.
-	 */
-	public JRBand getGroupFooter()
-	{
-		return 
-			groupFooterSection == null 
-			|| groupFooterSection.getBands() == null 
-			|| groupFooterSection.getBands().length == 0 
-				? null 
-				: (JRBand)groupFooterSection.getBands()[0];
-	}
-		
 	/**
 	 *
 	 */
@@ -343,23 +302,12 @@ public class JRBaseGroup implements JRGroup, Serializable, JRChangeEventsSupport
 		{
 			throw new JRRuntimeException(e);
 		}
-		
-		if (expression != null)
-		{
-			clone.expression = (JRExpression)expression.clone();
-		}
-		if (groupHeader != null)
-		{
-			clone.groupHeader = (JRBand)groupHeader.clone();
-		}
-		if (groupFooter != null)
-		{
-			clone.groupFooter = (JRBand)groupFooter.clone();
-		}
-		if (countVariable != null)
-		{
-			clone.countVariable = (JRVariable)countVariable.clone();
-		}
+	
+		clone.expression = JRCloneUtils.nullSafeClone(expression);
+		clone.groupHeader = JRCloneUtils.nullSafeClone(groupHeader);
+		clone.groupFooter = JRCloneUtils.nullSafeClone(groupFooter);
+		clone.countVariable = JRCloneUtils.nullSafeClone(countVariable);
+		clone.eventSupport = null;
 		
 		return clone;
 	}
@@ -392,11 +340,11 @@ public class JRBaseGroup implements JRGroup, Serializable, JRChangeEventsSupport
 	/**
 	 * @deprecated
 	 */
-	private JRBand groupHeader = null;
+	private JRBand groupHeader;
 	/**
 	 * @deprecated
 	 */
-	private JRBand groupFooter = null;
+	private JRBand groupFooter;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
