@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -132,7 +132,6 @@ import net.sf.jasperreports.engine.JRPropertyExpression;
 import net.sf.jasperreports.engine.JRQuery;
 import net.sf.jasperreports.engine.JRQueryChunk;
 import net.sf.jasperreports.engine.JRRectangle;
-import net.sf.jasperreports.engine.JRReportFont;
 import net.sf.jasperreports.engine.JRReportTemplate;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRScriptlet;
@@ -153,7 +152,7 @@ import net.sf.jasperreports.engine.JRVariable;
  * Factory of objects used in compiled reports.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseObjectFactory.java 3741 2010-04-16 15:58:45Z lucianc $
+ * @version $Id: JRBaseObjectFactory.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseObjectFactory extends JRAbstractObjectFactory
 {
@@ -162,7 +161,7 @@ public class JRBaseObjectFactory extends JRAbstractObjectFactory
 	/**
 	 *
 	 */
-	private JRDefaultStyleProvider defaultStyleProvider = null;
+	private JRDefaultStyleProvider defaultStyleProvider;
 
 	/**
 	 * Expression collector used to retrieve generated expression IDs.
@@ -210,28 +209,6 @@ public class JRBaseObjectFactory extends JRAbstractObjectFactory
 	}
 
 
-	/**
-	 *
-	 */
-	@SuppressWarnings("deprecation")
-	public JRReportFont getReportFont(JRReportFont font)
-	{
-		JRBaseReportFont baseFont = null;
-
-		if (font != null)
-		{
-			baseFont = (JRBaseReportFont)get(font);
-			if (baseFont == null)
-			{
-				baseFont = new JRBaseReportFont(font);
-				put(font, baseFont);
-			}
-		}
-
-		return baseFont;
-	}
-
-
 	/**
 	 *
 	 */
@@ -279,32 +256,6 @@ public class JRBaseObjectFactory extends JRAbstractObjectFactory
 	}
 
 
-	/**
-	 *
-	 *
-	public JRFont getFont(JRFont font)
-	{
-		JRBaseFont baseFont = null;
-
-		if (font != null)
-		{
-			baseFont = (JRBaseFont)get(font);
-			if (baseFont == null)
-			{
-				baseFont =
-					new JRBaseFont(
-						defaultStyleProvider,
-						getReportFont(font.getReportFont()),
-						font
-						);
-				put(font, baseFont);
-			}
-		}
-
-		return baseFont;
-	}
-
-
 	/**
 	 *
 	 */
