@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -28,6 +28,7 @@ import java.io.IOException;
 import java.io.ObjectInputStream;
 import java.io.Serializable;
 
+import net.sf.jasperreports.engine.Deduplicable;
 import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRPen;
 import net.sf.jasperreports.engine.JRPenContainer;
@@ -37,15 +38,16 @@ import net.sf.jasperreports.engine.design.events.JRChangeEventsSupport;
 import net.sf.jasperreports.engine.design.events.JRPropertyChangeSupport;
 import net.sf.jasperreports.engine.type.LineStyleEnum;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
+import net.sf.jasperreports.engine.util.ObjectUtils;
 
 
 /**
  * This is useful for drawing borders around text elements and images. Boxes can have borders and paddings, which can
  * have different width and colour on each side of the element.
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBasePen.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBasePen.java 4647 2011-10-06 10:19:07Z lucianc $
  */
-public class JRBasePen implements JRPen, Serializable, Cloneable, JRChangeEventsSupport
+public class JRBasePen implements JRPen, Serializable, Cloneable, JRChangeEventsSupport, Deduplicable
 {
 
 
@@ -61,14 +63,14 @@ public class JRBasePen implements JRPen, Serializable, Cloneable, JRChangeEvents
 	public static final String PROPERTY_LINE_COLOR = "lineColor";
 	
 
-	protected JRPenContainer penContainer = null;
+	protected JRPenContainer penContainer;
 
 	/**
 	 *
 	 */
-	protected Float lineWidth = null;
-	protected LineStyleEnum lineStyleValue = null;
-	protected Color lineColor = null;
+	protected Float lineWidth;
+	protected LineStyleEnum lineStyleValue;
+	protected Color lineColor;
 
 	
 	/**
@@ -124,22 +126,6 @@ public class JRBasePen implements JRPen, Serializable, Cloneable, JRChangeEvents
 		getEventSupport().firePropertyChange(PROPERTY_LINE_WIDTH, old, this.lineWidth);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getLineStyleValue()}.
-	 */
-	public Byte getLineStyle()
-	{
-		return getLineStyleValue().getValueByte();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getOwnLineStyleValue()}.
-	 */
-	public Byte getOwnLineStyle()
-	{
-		return getOwnLineStyleValue() == null ? null : getOwnLineStyleValue().getValueByte();
-	}
-
 	/**
 	 *
 	 */
@@ -156,22 +142,6 @@ public class JRBasePen implements JRPen, Serializable, Cloneable, JRChangeEvents
 		return lineStyleValue;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setLineStyle(LineStyleEnum)}.
-	 */
-	public void setLineStyle(byte lineStyle)
-	{
-		setLineStyle(LineStyleEnum.getByValue(lineStyle));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setLineStyle(LineStyleEnum)}.
-	 */
-	public void setLineStyle(Byte lineStyle)
-	{
-		setLineStyle(LineStyleEnum.getByValue(lineStyle));
-	}
-
 	/**
 	 *
 	 */
@@ -230,6 +200,7 @@ public class JRBasePen implements JRPen, Serializable, Cloneable, JRChangeEvents
 		}
 		
 		clone.penContainer = penContainer;
+		clone.eventSupport = null;
 		
 		return clone;
 	}
@@ -257,7 +228,7 @@ public class JRBasePen implements JRPen, Serializable, Cloneable, JRChangeEvents
 	/**
 	 * @deprecated
 	 */
-	private Byte lineStyle = null;
+	private Byte lineStyle;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
@@ -271,4 +242,35 @@ public class JRBasePen implements JRPen, Serializable, Cloneable, JRChangeEvents
 		}
 	}
 
+
+	public int getHashCode()
+	{
+		ObjectUtils.HashCode hash = ObjectUtils.hash();
+		hash.add(lineWidth);
+		hash.add(lineStyleValue);
+		hash.add(lineColor);
+		return hash.getHashCode();
+	}
+
+
+	public boolean isIdentical(Object object)
+	{
+		if (this == object)
+		{
+			return true;
+		}
+		
+		if (!(object instanceof JRBasePen))
+		{
+			return false;
+		}
+		
+		JRBasePen pen = (JRBasePen) object;
+
+		return 
+				ObjectUtils.equals(lineWidth, pen.lineWidth)
+				&& ObjectUtils.equals(lineStyleValue, pen.lineStyleValue)
+				&& ObjectUtils.equals(lineColor, pen.lineColor);
+	}
+
 }
