@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -26,12 +26,13 @@ package net.sf.jasperreports.engine.base;
 import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRDefaultStyleProvider;
 import net.sf.jasperreports.engine.JRPrintRectangle;
+import net.sf.jasperreports.engine.PrintElementVisitor;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBasePrintRectangle.java 3676 2010-04-02 09:35:07Z shertage $
+ * @version $Id: JRBasePrintRectangle.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBasePrintRectangle extends JRBasePrintGraphicElement implements JRPrintRectangle
 {
@@ -44,7 +45,7 @@ public class JRBasePrintRectangle extends JRBasePrintGraphicElement implements J
 	/**
 	 *
 	 */
-	protected Integer radius = null;
+	protected Integer radius;
 
 
 	/**
@@ -88,5 +89,10 @@ public class JRBasePrintRectangle extends JRBasePrintGraphicElement implements J
 		this.radius = radius;
 	}
 
+	public <T> void accept(PrintElementVisitor<T> visitor, T arg)
+	{
+		visitor.visit(this, arg);
+	}
+
 
 }
