@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -30,12 +30,13 @@ import net.sf.jasperreports.engine.JRQuery;
 import net.sf.jasperreports.engine.JRQueryChunk;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.query.JRJdbcQueryExecuterFactory;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 import net.sf.jasperreports.engine.util.JRQueryParser;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseQuery.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: JRBaseQuery.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseQuery implements JRQuery, Serializable
 {
@@ -49,7 +50,7 @@ public class JRBaseQuery implements JRQuery, Serializable
 	/**
 	 *
 	 */
-	private JRQueryChunk[] chunks = null;
+	private JRQueryChunk[] chunks;
 	
 	protected String language = JRJdbcQueryExecuterFactory.QUERY_LANGUAGE_SQL;
 
@@ -124,14 +125,7 @@ public class JRBaseQuery implements JRQuery, Serializable
 			throw new JRRuntimeException(e);
 		}
 		
-		if (chunks != null)
-		{
-			clone.chunks = new JRQueryChunk[chunks.length];
-			for(int i = 0; i < chunks.length; i++)
-			{
-				clone.chunks[i] = (JRQueryChunk)chunks[i].clone();
-			}
-		}
+		clone.chunks = JRCloneUtils.cloneArray(chunks);
 
 		return clone;
 	}
