@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -28,12 +28,14 @@ import java.io.IOException;
 import java.io.ObjectInputStream;
 import java.io.Serializable;
 
+import net.sf.jasperreports.engine.Deduplicable;
 import net.sf.jasperreports.engine.JRAbstractObjectFactory;
 import net.sf.jasperreports.engine.JRCommonText;
 import net.sf.jasperreports.engine.JRConditionalStyle;
 import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRDefaultStyleProvider;
 import net.sf.jasperreports.engine.JRLineBox;
+import net.sf.jasperreports.engine.JRParagraph;
 import net.sf.jasperreports.engine.JRPen;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRStyle;
@@ -48,14 +50,16 @@ import net.sf.jasperreports.engine.type.RotationEnum;
 import net.sf.jasperreports.engine.type.ScaleImageEnum;
 import net.sf.jasperreports.engine.type.VerticalAlignEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 import net.sf.jasperreports.engine.util.JRPenUtil;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
+import net.sf.jasperreports.engine.util.ObjectUtils;
 
 /**
  * @author Ionut Nedelcu (ionutned@users.sourceforge.net)
- * @version $Id: JRBaseStyle.java 3941 2010-08-20 10:55:10Z teodord $
+ * @version $Id: JRBaseStyle.java 4647 2011-10-06 10:19:07Z lucianc $
  */
-public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
+public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport, Deduplicable
 {
 
 	/**
@@ -81,6 +85,9 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	
 	public static final String PROPERTY_ITALIC = "italic";
 	
+	/**
+	 * @deprecated Replaced by {@link JRBaseParagraph#PROPERTY_LINE_SPACING}
+	 */
 	public static final String PROPERTY_LINE_SPACING = "lineSpacing";
 	
 	public static final String PROPERTY_MODE = "mode";
@@ -101,11 +108,6 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	
 	public static final String PROPERTY_STRIKE_THROUGH = "strikeThrough";
 	
-	/**
-	 * @deprecated Replaced by {@link #PROPERTY_MARKUP}
-	 */
-	public static final String PROPERTY_IS_STYLED_TEXT = "isStyledText";
-	
 	public static final String PROPERTY_MARKUP = "markup";
 	
 	public static final String PROPERTY_UNDERLINE = "underline";
@@ -116,7 +118,7 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	/**
 	 *
 	 */
-	protected JRDefaultStyleProvider defaultStyleProvider;
+	protected JRDefaultStyleProvider defaultStyleProvider;//FIXME this is never set; it has been like that for a long time; trying to solve causes a stack overflow
 	protected JRStyle parentStyle;
 	protected String parentStyleNameReference;
 
@@ -126,8 +128,8 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	protected String name;
 	protected boolean isDefault;
 
-	protected Byte positionType;
-	protected Byte stretchType;
+	protected Byte positionType;//FIXME not used
+	protected Byte stretchType;//FIXME not used
 	protected ModeEnum modeValue;
 	protected Color forecolor;
 	protected Color backcolor;
@@ -142,6 +144,7 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	protected VerticalAlignEnum verticalAlignmentValue;
 
 	protected JRLineBox lineBox;
+	protected JRParagraph paragraph;
 
 	protected String fontName;
 	protected Boolean isBold;
@@ -154,7 +157,6 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	protected Boolean isPdfEmbedded;
 
 	protected RotationEnum rotationValue;
-	protected LineSpacingEnum lineSpacingValue;
 	protected String markup;
 
 	protected String pattern;
@@ -170,6 +172,7 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	{
 		linePen = new JRBasePen(this);
 		lineBox = new JRBaseLineBox(this);
+		paragraph = new JRBaseParagraph(this);
 	}
 
 	/**
@@ -181,6 +184,7 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 
 		linePen = new JRBasePen(this);
 		lineBox = new JRBaseLineBox(this);
+		paragraph = new JRBaseParagraph(this);
 	}
 
 	/**
@@ -219,9 +223,9 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		verticalAlignmentValue = style.getOwnVerticalAlignmentValue();
 
 		lineBox = style.getLineBox().clone(this);
-		
+		paragraph = style.getParagraph().clone(this);
+
 		rotationValue = style.getOwnRotationValue();
-		lineSpacingValue = style.getOwnLineSpacingValue();
 		markup = style.getOwnMarkup();
 
 		pattern = style.getOwnPattern();
@@ -341,54 +345,6 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		return linePen;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getLinePen()}
-	 */
-	public Byte getPen()
-	{
-		return new Byte(JRPenUtil.getPenFromLinePen(linePen));
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #getLinePen()}
-	 */
-	public Byte getOwnPen()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(linePen);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLinePen()}
-	 */
-	public void setPen(byte pen)
-	{
-		setPen(new Byte(pen));
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #getLinePen()}
-	 */
-	public void setPen(Byte pen)
-	{
-		JRPenUtil.setLinePenFromPen(pen, linePen);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getFillValue()}
-	 */
-	public Byte getFill()
-	{
-		return getFillValue() == null ? null : getFillValue().getValueByte();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getOwnFillValue()}
-	 */
-	public Byte getOwnFill()
-	{
-		return getOwnFillValue() == null ? null : getOwnFillValue().getValueByte();
-	}
-
 	public FillEnum getFillValue()
 	{
 		return JRStyleResolver.getFillValue(this);
@@ -409,22 +365,6 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		return radius;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getScaleImageValue()}.
-	 */
-	public Byte getScaleImage()
-	{
-		return getScaleImageValue() == null ? null : getScaleImageValue().getValueByte();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getOwnScaleImageValue()}.
-	 */
-	public Byte getOwnScaleImage()
-	{
-		return getOwnScaleImageValue() == null ? null : getOwnScaleImageValue().getValueByte();
-	}
-
 	/**
 	 * 
 	 */
@@ -441,22 +381,6 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		return this.scaleImageValue;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getHorizontalAlignmentValue()}.
-	 */
-	public Byte getHorizontalAlignment()
-	{
-		return getHorizontalAlignmentValue() == null ? null : getHorizontalAlignmentValue().getValueByte();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getOwnHorizontalAlignmentValue()}.
-	 */
-	public Byte getOwnHorizontalAlignment()
-	{
-		return getOwnHorizontalAlignmentValue() == null ? null : getOwnHorizontalAlignmentValue().getValueByte();
-	}
-
 	public HorizontalAlignEnum getHorizontalAlignmentValue()
 	{
 		return JRStyleResolver.getHorizontalAlignmentValue(this);
@@ -467,22 +391,6 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		return horizontalAlignmentValue;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getVerticalAlignmentValue()}.
-	 */
-	public Byte getVerticalAlignment()
-	{
-		return getVerticalAlignmentValue() == null ? null : getVerticalAlignmentValue().getValueByte();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getOwnVerticalAlignmentValue()}.
-	 */
-	public Byte getOwnVerticalAlignment()
-	{
-		return getOwnVerticalAlignmentValue() == null ? null : getOwnVerticalAlignmentValue().getValueByte();
-	}
-
 	public VerticalAlignEnum getVerticalAlignmentValue()
 	{
 		return JRStyleResolver.getVerticalAlignmentValue(this);
@@ -502,275 +410,11 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	}
 
 	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
+	 *
 	 */
-	public Byte getBorder()
+	public JRParagraph getParagraph()
 	{
-		return new Byte(JRPenUtil.getPenFromLinePen(lineBox.getPen()));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Byte getOwnBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getBorderColor()
-	{
-		return lineBox.getPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getOwnBorderColor()
-	{
-		return lineBox.getPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Integer getPadding()
-	{
-		return lineBox.getPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Integer getOwnPadding()
-	{
-		return lineBox.getOwnPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Byte getTopBorder()
-	{
-		return new Byte(JRPenUtil.getPenFromLinePen(lineBox.getTopPen()));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Byte getOwnTopBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getTopBorderColor()
-	{
-		return lineBox.getTopPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getOwnTopBorderColor()
-	{
-		return lineBox.getTopPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Integer getTopPadding()
-	{
-		return lineBox.getTopPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Integer getOwnTopPadding()
-	{
-		return lineBox.getOwnTopPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Byte getLeftBorder()
-	{
-		return new Byte(JRPenUtil.getPenFromLinePen(lineBox.getLeftPen()));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Byte getOwnLeftBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getLeftBorderColor()
-	{
-		return lineBox.getLeftPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getOwnLeftBorderColor()
-	{
-		return lineBox.getLeftPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Integer getLeftPadding()
-	{
-		return lineBox.getLeftPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Integer getOwnLeftPadding()
-	{
-		return lineBox.getOwnLeftPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Byte getBottomBorder()
-	{
-		return new Byte(JRPenUtil.getPenFromLinePen(lineBox.getBottomPen()));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Byte getOwnBottomBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getBottomBorderColor()
-	{
-		return lineBox.getBottomPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getOwnBottomBorderColor()
-	{
-		return lineBox.getBottomPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Integer getBottomPadding()
-	{
-		return lineBox.getBottomPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Integer getOwnBottomPadding()
-	{
-		return lineBox.getOwnBottomPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Byte getRightBorder()
-	{
-		return new Byte(JRPenUtil.getPenFromLinePen(lineBox.getRightPen()));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Byte getOwnRightBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getRightBorderColor()
-	{
-		return lineBox.getRightPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getOwnRightBorderColor()
-	{
-		return lineBox.getRightPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Integer getRightPadding()
-	{
-		return lineBox.getRightPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Integer getOwnRightPadding()
-	{
-		return lineBox.getOwnRightPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getRotationValue()}.
-	 */
-	public Byte getRotation()
-	{
-		return getRotationValue() == null ? null : getRotationValue().getValueByte();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getOwnRotationValue()}.
-	 */
-	public Byte getOwnRotation()
-	{
-		return getOwnRotationValue() == null? null : getOwnRotationValue().getValueByte();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setRotation(RotationEnum)}.
-	 */
-	public void setRotation(byte rotation)
-	{
-		setRotation(RotationEnum.getByValue(rotation));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setRotation(RotationEnum)}.
-	 */
-	public void setRotation(Byte rotation)
-	{
-		setRotation(RotationEnum.getByValue(rotation));
+		return paragraph;
 	}
 
 	/**
@@ -800,53 +444,19 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	}
 
 	/**
-	 * @deprecated Replaced by {@link #getLineSpacingValue()}.
-	 */
-	public Byte getLineSpacing()
-	{
-		return getLineSpacingValue() == null ? null : getLineSpacingValue().getValueByte();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getOwnLineSpacingValue()}.
-	 */
-	public Byte getOwnLineSpacing()
-	{
-		return getOwnLineSpacingValue() == null ? null : getOwnLineSpacingValue().getValueByte();
-	}
-
-	/**
-	 *
+	 * @deprecated Replaced by {@link JRParagraph#getLineSpacing()}.
 	 */
 	public LineSpacingEnum getLineSpacingValue()
 	{
-		return JRStyleResolver.getLineSpacingValue(this);
+		return getParagraph().getLineSpacing();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link JRParagraph#getOwnLineSpacing()}.
 	 */
 	public LineSpacingEnum getOwnLineSpacingValue()
 	{
-		return this.lineSpacingValue;
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getMarkup()}
-	 */
-	public Boolean isStyledText()
-	{
-		String mkp = getMarkup();
-		return JRCommonText.MARKUP_STYLED_TEXT.equals(mkp) ? Boolean.TRUE : (mkp == null ? null : Boolean.FALSE);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getOwnMarkup()}
-	 */
-	public Boolean isOwnStyledText()
-	{
-		String mkp = getOwnMarkup();
-		return JRCommonText.MARKUP_STYLED_TEXT.equals(mkp) ? Boolean.TRUE : (mkp == null ? null : Boolean.FALSE);
+		return getParagraph().getOwnLineSpacing();
 	}
 
 	public String getMarkup()
@@ -970,22 +580,6 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		return pattern;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getModeValue()}.
-	 */
-	public Byte getMode()
-	{
-		return getModeValue() == null ? null : getModeValue().getValueByte();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getOwnModeValue()}.
-	 */
-	public Byte getOwnMode()
-	{
-		return getOwnModeValue() == null ? null : getOwnModeValue().getValueByte();
-	}
-
 	/**
 	 *
 	 */
@@ -1022,22 +616,6 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		getEventSupport().firePropertyChange(PROPERTY_BACKCOLOR, old, this.backcolor);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setMode(ModeEnum)}.
-	 */
-	public void setMode(byte mode)
-	{
-		setMode(ModeEnum.getByValue(mode));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setMode(ModeEnum)}.
-	 */
-	public void setMode(Byte mode)
-	{
-		setMode(ModeEnum.getByValue(mode));
-	}
-
 	/**
 	 *
 	 */
@@ -1048,22 +626,6 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		getEventSupport().firePropertyChange(JRBaseStyle.PROPERTY_MODE, old, this.modeValue);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setFill(FillEnum)}.
-	 */
-	public void setFill(byte fill)
-	{
-		setFill(FillEnum.getByValue(fill));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setFill(FillEnum)}.
-	 */
-	public void setFill(Byte fill)
-	{
-		setFill(FillEnum.getByValue(fill));
-	}
-
 	/**
 	 *
 	 */
@@ -1092,22 +654,6 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		getEventSupport().firePropertyChange(PROPERTY_RADIUS, old, this.radius);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
-	 */
-	public void setScaleImage(byte scaleImage)
-	{
-		setScaleImage(ScaleImageEnum.getByValue(scaleImage));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
-	 */
-	public void setScaleImage(Byte scaleImage)
-	{
-		setScaleImage(ScaleImageEnum.getByValue(scaleImage));
-	}
-
 	/**
 	 *
 	 */
@@ -1118,22 +664,6 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		getEventSupport().firePropertyChange(PROPERTY_SCALE_IMAGE, old, this.scaleImageValue);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
-	 */
-	public void setHorizontalAlignment(byte horizontalAlignment)
-	{
-		setHorizontalAlignment(HorizontalAlignEnum.getByValue(horizontalAlignment));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
-	 */
-	public void setHorizontalAlignment(Byte horizontalAlignment)
-	{
-		setHorizontalAlignment(HorizontalAlignEnum.getByValue(horizontalAlignment));
-	}
-
 	/**
 	 *
 	 */
@@ -1144,22 +674,6 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		getEventSupport().firePropertyChange(PROPERTY_HORIZONTAL_ALIGNMENT, old, this.horizontalAlignmentValue);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
-	 */
-	public void setVerticalAlignment(byte verticalAlignment)
-	{
-		setVerticalAlignment(VerticalAlignEnum.getByValue(verticalAlignment));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
-	 */
-	public void setVerticalAlignment(Byte verticalAlignment)
-	{
-		setVerticalAlignment(VerticalAlignEnum.getByValue(verticalAlignment));
-	}
-
 	/**
 	 *
 	 */
@@ -1170,206 +684,6 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		getEventSupport().firePropertyChange(PROPERTY_VERTICAL_ALIGNMENT, old, this.verticalAlignmentValue);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setBorder(byte border)
-	{
-		JRPenUtil.setLinePenFromPen(border, lineBox.getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setBorder(Byte border)
-	{
-		JRPenUtil.setLinePenFromPen(border, lineBox.getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setBorderColor(Color borderColor)
-	{
-		lineBox.getPen().setLineColor(borderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setPadding(int padding)
-	{
-		lineBox.setPadding(padding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setPadding(Integer padding)
-	{
-		lineBox.setPadding(padding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setTopBorder(byte topBorder)
-	{
-		JRPenUtil.setLinePenFromPen(topBorder, lineBox.getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setTopBorder(Byte topBorder)
-	{
-		JRPenUtil.setLinePenFromPen(topBorder, lineBox.getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setTopBorderColor(Color topBorderColor)
-	{
-		lineBox.getTopPen().setLineColor(topBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setTopPadding(int topPadding)
-	{
-		lineBox.setTopPadding(topPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setTopPadding(Integer topPadding)
-	{
-		lineBox.setTopPadding(topPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setLeftBorder(byte leftBorder)
-	{
-		JRPenUtil.setLinePenFromPen(leftBorder, lineBox.getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setLeftBorder(Byte leftBorder)
-	{
-		JRPenUtil.setLinePenFromPen(leftBorder, lineBox.getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setLeftBorderColor(Color leftBorderColor)
-	{
-		lineBox.getLeftPen().setLineColor(leftBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setLeftPadding(int leftPadding)
-	{
-		lineBox.setLeftPadding(leftPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setLeftPadding(Integer leftPadding)
-	{
-		lineBox.setLeftPadding(leftPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setBottomBorder(byte bottomBorder)
-	{
-		JRPenUtil.setLinePenFromPen(bottomBorder, lineBox.getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setBottomBorder(Byte bottomBorder)
-	{
-		JRPenUtil.setLinePenFromPen(bottomBorder, lineBox.getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setBottomBorderColor(Color bottomBorderColor)
-	{
-		lineBox.getBottomPen().setLineColor(bottomBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setBottomPadding(int bottomPadding)
-	{
-		lineBox.setBottomPadding(bottomPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setBottomPadding(Integer bottomPadding)
-	{
-		lineBox.setBottomPadding(bottomPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setRightBorder(byte rightBorder)
-	{
-		JRPenUtil.setLinePenFromPen(rightBorder, lineBox.getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setRightBorder(Byte rightBorder)
-	{
-		JRPenUtil.setLinePenFromPen(rightBorder, lineBox.getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setRightBorderColor(Color rightBorderColor)
-	{
-		lineBox.getRightPen().setLineColor(rightBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setRightPadding(int rightPadding)
-	{
-		lineBox.setRightPadding(rightPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setRightPadding(Integer rightPadding)
-	{
-		lineBox.setRightPadding(rightPadding);
-	}
-
 	/**
 	 *
 	 */
@@ -1452,29 +766,6 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		getEventSupport().firePropertyChange(PROPERTY_STRIKE_THROUGH, old, this.isStrikeThrough);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setMarkup(String)}
-	 */
-	public void setStyledText(boolean styledText)
-	{
-		setStyledText(styledText ? Boolean.TRUE : Boolean.FALSE);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setMarkup(String)}
-	 */
-	public void setStyledText(Boolean styledText)
-	{
-		if (styledText == null)
-		{
-			setMarkup(null);
-		}
-		else
-		{
-			setMarkup(styledText.booleanValue() ? JRCommonText.MARKUP_STYLED_TEXT : JRCommonText.MARKUP_NONE);
-		}
-	}
-
 	/**
 	 *
 	 */
@@ -1522,29 +813,11 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	}
 
 	/**
-	 * @deprecated Replaced by {@link #setLineSpacing(LineSpacingEnum)}.
+	 * @deprecated Replaced by {@link JRParagraph#setLineSpacing(LineSpacingEnum)}.
 	 */
-	public void setLineSpacing(byte lineSpacing)
+	public void setLineSpacing(LineSpacingEnum lineSpacing)
 	{
-		setLineSpacing(LineSpacingEnum.getByValue(lineSpacing));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setLineSpacing(LineSpacingEnum)}.
-	 */
-	public void setLineSpacing(Byte lineSpacing)
-	{
-		setLineSpacing(LineSpacingEnum.getByValue(lineSpacing));
-	}
-
-	/**
-	 * 
-	 */
-	public void setLineSpacing(LineSpacingEnum lineSpacingValue)
-	{
-		Object old = this.lineSpacingValue;
-		this.lineSpacingValue = lineSpacingValue;
-		getEventSupport().firePropertyChange(PROPERTY_LINE_SPACING, old, this.lineSpacingValue);
+		getParagraph().setLineSpacing(lineSpacing);
 	}
 
 	/**
@@ -1665,6 +938,10 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	 * @deprecated
 	 */
 	private Byte lineSpacing;
+	/**
+	 * @deprecated
+	 */
+	private LineSpacingEnum lineSpacingValue;
 	/**
 	 * @deprecated
 	 */
@@ -1815,33 +1092,127 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 			markup = isStyledText.booleanValue() ? JRCommonText.MARKUP_STYLED_TEXT : JRCommonText.MARKUP_NONE;
 			isStyledText = null;
 		}
+
+		if (paragraph == null)
+		{
+			paragraph = new JRBaseParagraph(this);
+			paragraph.setLineSpacing(lineSpacingValue);
+			lineSpacingValue = null;
+		}
 	}
 	
 	public Object clone()
 	{
+		JRBaseStyle clone = null;
 		try
 		{
-			JRBaseStyle clone = (JRBaseStyle) super.clone();
-			clone.lineBox = lineBox == null ? null : lineBox.clone(clone);
-			clone.linePen = linePen == null ? null : linePen.clone(clone);
-			
-			if (conditionalStyles != null)
-			{
-				clone.conditionalStyles = new JRConditionalStyle[conditionalStyles.length];
-				for (int i = 0; i < conditionalStyles.length; i++)
-				{
-					JRConditionalStyle style = conditionalStyles[i];
-					JRConditionalStyle styleClone = (JRConditionalStyle) style.clone();
-					clone.conditionalStyles[i] = styleClone;
-				}
-			}
-			
-			return clone;
+			clone = (JRBaseStyle) super.clone();
 		}
 		catch (CloneNotSupportedException e)
 		{
 			// never
 			throw new JRRuntimeException(e);
 		}
+		clone.lineBox = lineBox == null ? null : lineBox.clone(clone);
+		clone.linePen = linePen == null ? null : linePen.clone(clone);
+		clone.paragraph = paragraph == null ? null : paragraph.clone(clone);
+		clone.conditionalStyles = JRCloneUtils.cloneArray(conditionalStyles);
+		clone.eventSupport = null;
+
+		return clone;
+	}
+
+	public int getHashCode()
+	{
+		ObjectUtils.HashCode hash = ObjectUtils.hash();
+		hash.addIdentity(parentStyle);
+		addStyleHash(hash);
+		
+		// maybe adding conditional style to the hash is not worth it
+		// as the remaining attributes provide good enough hash information
+		hash.addIdentical(conditionalStyles);
+		
+		return hash.getHashCode();
+	}
+
+	protected void addStyleHash(ObjectUtils.HashCode hash)
+	{
+		hash.add(name);
+		hash.add(isDefault);
+		hash.add(modeValue);
+		hash.add(forecolor);
+		hash.add(backcolor);
+		hash.addIdentical(linePen); 
+		hash.add(fillValue);
+		hash.add(radius);
+		hash.add(scaleImageValue);
+		hash.add(horizontalAlignmentValue);
+		hash.add(verticalAlignmentValue);
+		hash.addIdentical(lineBox); 
+		hash.addIdentical(paragraph); 
+		hash.add(fontName);
+		hash.add(isBold);
+		hash.add(isItalic);
+		hash.add(isUnderline);
+		hash.add(isStrikeThrough);
+		hash.add(fontSize);
+		hash.add(pdfFontName);
+		hash.add(pdfEncoding);
+		hash.add(isPdfEmbedded);
+		hash.add(rotationValue);
+		hash.add(markup);
+		hash.add(pattern);
+		hash.add(isBlankWhenNull);
+	}
+
+	public boolean isIdentical(Object object)
+	{
+		if (this == object)
+		{
+			return true;
+		}
+		
+		if (!(object instanceof JRBaseStyle))
+		{
+			return false;
+		}
+		
+		JRBaseStyle style = (JRBaseStyle) object;
+
+		return
+				ObjectUtils.equalsIdentity(parentStyle, style.parentStyle)
+				&& identicalStyle(style)
+				&& ObjectUtils.identical(conditionalStyles, style.conditionalStyles);
+	}
+
+	protected boolean identicalStyle(JRBaseStyle style)
+	{
+		return 
+				ObjectUtils.equals(name, style.name)
+				&& ObjectUtils.equals(isDefault, style.isDefault)
+				&& ObjectUtils.equals(modeValue, style.modeValue)
+				&& ObjectUtils.equals(forecolor, style.forecolor)
+				&& ObjectUtils.equals(backcolor, style.backcolor)
+				&& ObjectUtils.identical(linePen, style.linePen)
+				&& ObjectUtils.equals(fillValue, style.fillValue)
+				&& ObjectUtils.equals(radius, style.radius)
+				&& ObjectUtils.equals(scaleImageValue, style.scaleImageValue)
+				&& ObjectUtils.equals(horizontalAlignmentValue, style.horizontalAlignmentValue)
+				&& ObjectUtils.equals(verticalAlignmentValue, style.verticalAlignmentValue)
+				&& ObjectUtils.identical(lineBox, style.lineBox)
+				&& ObjectUtils.identical(paragraph, style.paragraph)
+				&& ObjectUtils.equals(fontName, style.fontName)
+				&& ObjectUtils.equals(isBold, style.isBold)
+				&& ObjectUtils.equals(isItalic, style.isItalic)
+				&& ObjectUtils.equals(isUnderline, style.isUnderline)
+				&& ObjectUtils.equals(isStrikeThrough, style.isStrikeThrough)
+				&& ObjectUtils.equals(fontSize, style.fontSize)
+				&& ObjectUtils.equals(pdfFontName, style.pdfFontName)
+				&& ObjectUtils.equals(pdfEncoding, style.pdfEncoding)
+				&& ObjectUtils.equals(isPdfEmbedded, style.isPdfEmbedded)
+				&& ObjectUtils.equals(rotationValue, style.rotationValue)
+				&& ObjectUtils.equals(markup, style.markup)
+				&& ObjectUtils.equals(pattern, style.pattern)
+				&& ObjectUtils.equals(isBlankWhenNull, style.isBlankWhenNull);
 	}
 }
