@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -31,12 +31,13 @@ import net.sf.jasperreports.engine.JRSubreportParameter;
 import net.sf.jasperreports.engine.JRSubreportReturnValue;
 import net.sf.jasperreports.engine.JRVisitor;
 import net.sf.jasperreports.engine.type.ModeEnum;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseSubreport.java 3420 2010-02-18 09:17:47Z teodord $
+ * @version $Id: JRBaseSubreport.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseSubreport extends JRBaseElement implements JRSubreport
 {
@@ -54,23 +55,23 @@ public class JRBaseSubreport extends JRBaseElement implements JRSubreport
 	/**
 	 *
 	 */
-	protected Boolean isUsingCache = null;
+	protected Boolean isUsingCache;
 
 	private Boolean runToBottom;
 
 	/**
 	 *
 	 */
-	protected JRExpression parametersMapExpression = null;
-	protected JRSubreportParameter[] parameters = null;
-	protected JRExpression connectionExpression = null;
-	protected JRExpression dataSourceExpression = null;
-	protected JRExpression expression = null;
+	protected JRExpression parametersMapExpression;
+	protected JRSubreportParameter[] parameters;
+	protected JRExpression connectionExpression;
+	protected JRExpression dataSourceExpression;
+	protected JRExpression expression;
 	
 	/**
 	 * Values to be copied from the subreport into the master report.
 	 */
-	protected JRSubreportReturnValue[] returnValues = null;
+	protected JRSubreportReturnValue[] returnValues;
 
 
 	/**
@@ -89,7 +90,7 @@ public class JRBaseSubreport extends JRBaseElement implements JRSubreport
 	{
 		super(subreport, factory);
 		
-		isUsingCache = subreport.isOwnUsingCache();
+		isUsingCache = subreport.getUsingCache();
 		
 		runToBottom = subreport.isRunToBottom();
 
@@ -124,7 +125,7 @@ public class JRBaseSubreport extends JRBaseElement implements JRSubreport
 		
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getUsingCache()}.
 	 */
 	public boolean isUsingCache()
 	{
@@ -141,15 +142,6 @@ public class JRBaseSubreport extends JRBaseElement implements JRSubreport
 	}
 
 
-	/**
-	 * @deprecated Replaced by {@link #setUsingCache(Boolean)}.
-	 */
-	public void setUsingCache(boolean isUsingCache)
-	{
-		setUsingCache(isUsingCache ? Boolean.TRUE : Boolean.FALSE);
-	}
-
-
 	/**
 	 *
 	 */
@@ -222,12 +214,21 @@ public class JRBaseSubreport extends JRBaseElement implements JRSubreport
 	}
 
 
+	/**
+	 * @deprecated Replaced by {@link #getUsingCache()}.
+	 */
 	public Boolean isOwnUsingCache()
 	{
 		return isUsingCache;
 	}
 
 
+	public Boolean getUsingCache()
+	{
+		return isUsingCache;
+	}
+
+
 	public void setUsingCache(Boolean isUsingCache)
 	{
 		Object old = this.isUsingCache;
@@ -256,42 +257,12 @@ public class JRBaseSubreport extends JRBaseElement implements JRSubreport
 	public Object clone() 
 	{
 		JRBaseSubreport clone = (JRBaseSubreport)super.clone();
-		
-		if (parameters != null)
-		{
-			clone.parameters = new JRSubreportParameter[parameters.length];
-			for(int i = 0; i < parameters.length; i++)
-			{
-				clone.parameters[i] = (JRSubreportParameter)parameters[i].clone();
-			}
-		}
-
-		if (returnValues != null)
-		{
-			clone.returnValues = new JRSubreportReturnValue[returnValues.length];
-			for(int i = 0; i < returnValues.length; i++)
-			{
-				clone.returnValues[i] = (JRSubreportReturnValue)returnValues[i].clone();
-			}
-		}
-
-		if (parametersMapExpression != null)
-		{
-			clone.parametersMapExpression = (JRExpression)parametersMapExpression.clone();
-		}
-		if (connectionExpression != null)
-		{
-			clone.connectionExpression = (JRExpression)connectionExpression.clone();
-		}
-		if (dataSourceExpression != null)
-		{
-			clone.dataSourceExpression = (JRExpression)dataSourceExpression.clone();
-		}
-		if (expression != null)
-		{
-			clone.expression = (JRExpression)expression.clone();
-		}
-
+		clone.parameters = JRCloneUtils.cloneArray(parameters);
+		clone.returnValues = JRCloneUtils.cloneArray(returnValues);
+		clone.parametersMapExpression = JRCloneUtils.nullSafeClone(parametersMapExpression);
+		clone.connectionExpression = JRCloneUtils.nullSafeClone(connectionExpression);
+		clone.dataSourceExpression = JRCloneUtils.nullSafeClone(dataSourceExpression);
+		clone.expression = JRCloneUtils.nullSafeClone(expression);
 		return clone;
 	}
 }
