@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -38,6 +38,7 @@ import net.sf.jasperreports.engine.JRVisitor;
 import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
 import net.sf.jasperreports.engine.type.HyperlinkTargetEnum;
 import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 
@@ -45,7 +46,7 @@ import net.sf.jasperreports.engine.util.JRStyleResolver;
  * This class is used for representing a text field.
  *
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseTextField.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBaseTextField.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseTextField extends JRBaseTextElement implements JRTextField
 {
@@ -61,10 +62,10 @@ public class JRBaseTextField extends JRBaseTextElement implements JRTextField
 	/**
 	 *
 	 */
-	protected boolean isStretchWithOverflow = false;
+	protected boolean isStretchWithOverflow;
 	protected EvaluationTimeEnum evaluationTimeValue = EvaluationTimeEnum.NOW;
 	protected String pattern;
-	protected Boolean isBlankWhenNull = null;
+	protected Boolean isBlankWhenNull;
 	protected String linkType;
 	protected String linkTarget;
 	private JRHyperlinkParameter[] hyperlinkParameters;
@@ -72,12 +73,13 @@ public class JRBaseTextField extends JRBaseTextElement implements JRTextField
 	/**
 	 *
 	 */
-	protected JRGroup evaluationGroup = null;
-	protected JRExpression expression = null;
-	protected JRExpression anchorNameExpression = null;
-	protected JRExpression hyperlinkReferenceExpression = null;
-	protected JRExpression hyperlinkAnchorExpression = null;
-	protected JRExpression hyperlinkPageExpression = null;
+	protected JRGroup evaluationGroup;
+	protected JRExpression expression;
+	protected JRExpression patternExpression;
+	protected JRExpression anchorNameExpression;
+	protected JRExpression hyperlinkReferenceExpression;
+	protected JRExpression hyperlinkAnchorExpression;
+	protected JRExpression hyperlinkPageExpression;
 	private JRExpression hyperlinkTooltipExpression;
 
 	/**
@@ -103,6 +105,7 @@ public class JRBaseTextField extends JRBaseTextElement implements JRTextField
 
 		evaluationGroup = factory.getGroup(textField.getEvaluationGroup());
 		expression = factory.getExpression(textField.getExpression());
+		patternExpression = factory.getExpression(textField.getPatternExpression());
 		anchorNameExpression = factory.getExpression(textField.getAnchorNameExpression());
 		hyperlinkReferenceExpression = factory.getExpression(textField.getHyperlinkReferenceExpression());
 		hyperlinkAnchorExpression = factory.getExpression(textField.getHyperlinkAnchorExpression());
@@ -130,14 +133,6 @@ public class JRBaseTextField extends JRBaseTextElement implements JRTextField
 		getEventSupport().firePropertyChange(PROPERTY_STRETCH_WITH_OVERFLOW, old, this.isStretchWithOverflow);
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getEvaluationTimeValue()}.
-	 */
-	public byte getEvaluationTime()
-	{
-		return getEvaluationTimeValue().getValue();
-	}
-		
 	/**
 	 *
 	 */
@@ -243,6 +238,14 @@ public class JRBaseTextField extends JRBaseTextElement implements JRTextField
 		return this.expression;
 	}
 
+	/**
+	 *
+	 */
+	public JRExpression getPatternExpression()
+	{
+		return this.patternExpression;
+	}
+		
 	/**
 	 *
 	 */
@@ -326,41 +329,14 @@ public class JRBaseTextField extends JRBaseTextElement implements JRTextField
 	public Object clone() 
 	{
 		JRBaseTextField clone = (JRBaseTextField)super.clone();
-		
-		if (hyperlinkParameters != null)
-		{
-			clone.hyperlinkParameters = new JRHyperlinkParameter[hyperlinkParameters.length];
-			for(int i = 0; i < hyperlinkParameters.length; i++)
-			{
-				clone.hyperlinkParameters[i] = (JRHyperlinkParameter)hyperlinkParameters[i].clone();
-			}
-		}
-
-		if (expression != null)
-		{
-			clone.expression = (JRExpression)expression.clone();
-		}
-		if (anchorNameExpression != null)
-		{
-			clone.anchorNameExpression = (JRExpression)anchorNameExpression.clone();
-		}
-		if (hyperlinkReferenceExpression != null)
-		{
-			clone.hyperlinkReferenceExpression = (JRExpression)hyperlinkReferenceExpression.clone();
-		}
-		if (hyperlinkAnchorExpression != null)
-		{
-			clone.hyperlinkAnchorExpression = (JRExpression)hyperlinkAnchorExpression.clone();
-		}
-		if (hyperlinkPageExpression != null)
-		{
-			clone.hyperlinkPageExpression = (JRExpression)hyperlinkPageExpression.clone();
-		}
-		if (hyperlinkTooltipExpression != null)
-		{
-			clone.hyperlinkTooltipExpression = (JRExpression)hyperlinkTooltipExpression.clone();
-		}
-
+		clone.hyperlinkParameters = JRCloneUtils.cloneArray(hyperlinkParameters);
+		clone.expression = JRCloneUtils.nullSafeClone(expression);
+		clone.patternExpression = JRCloneUtils.nullSafeClone(patternExpression);
+		clone.anchorNameExpression = JRCloneUtils.nullSafeClone(anchorNameExpression);
+		clone.hyperlinkReferenceExpression = JRCloneUtils.nullSafeClone(hyperlinkReferenceExpression);
+		clone.hyperlinkAnchorExpression = JRCloneUtils.nullSafeClone(hyperlinkAnchorExpression);
+		clone.hyperlinkPageExpression = JRCloneUtils.nullSafeClone(hyperlinkPageExpression);
+		clone.hyperlinkTooltipExpression = JRCloneUtils.nullSafeClone(hyperlinkTooltipExpression);
 		return clone;
 	}
 
