@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -36,11 +36,12 @@ import net.sf.jasperreports.engine.type.CalculationEnum;
 import net.sf.jasperreports.engine.type.IncrementTypeEnum;
 import net.sf.jasperreports.engine.type.ResetTypeEnum;
 import net.sf.jasperreports.engine.util.JRClassLoader;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseVariable.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBaseVariable.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRBaseVariable implements JRVariable, Serializable
 {
@@ -54,26 +55,26 @@ public class JRBaseVariable implements JRVariable, Serializable
 	/**
 	 *
 	 */
-	protected String name = null;
+	protected String name;
 	protected String valueClassName = java.lang.String.class.getName();
-	protected String valueClassRealName = null;
-	protected String incrementerFactoryClassName = null;
-	protected String incrementerFactoryClassRealName = null;
+	protected String valueClassRealName;
+	protected String incrementerFactoryClassName;
+	protected String incrementerFactoryClassRealName;
 	protected ResetTypeEnum resetTypeValue = ResetTypeEnum.REPORT;
 	protected IncrementTypeEnum incrementTypeValue = IncrementTypeEnum.NONE;
 	protected CalculationEnum calculationValue = CalculationEnum.NOTHING;
-	protected boolean isSystemDefined = false;
+	protected boolean isSystemDefined;
 
-	protected transient Class valueClass = null;
-	protected transient Class incrementerFactoryClass = null;
+	protected transient Class<?> valueClass;
+	protected transient Class<?> incrementerFactoryClass;
 
 	/**
 	 *
 	 */
-	protected JRExpression expression = null;
-	protected JRExpression initialValueExpression = null;
-	protected JRGroup resetGroup = null;
-	protected JRGroup incrementGroup = null;
+	protected JRExpression expression;
+	protected JRExpression initialValueExpression;
+	protected JRGroup resetGroup;
+	protected JRGroup incrementGroup;
 
 
 	/**
@@ -118,7 +119,7 @@ public class JRBaseVariable implements JRVariable, Serializable
 	/**
 	 *
 	 */
-	public Class getValueClass()
+	public Class<?> getValueClass()
 	{
 		if (valueClass == null)
 		{
@@ -163,7 +164,7 @@ public class JRBaseVariable implements JRVariable, Serializable
 	/**
 	 *
 	 */
-	public Class getIncrementerFactoryClass()
+	public Class<?> getIncrementerFactoryClass()
 	{
 		if (incrementerFactoryClass == null)
 		{
@@ -205,14 +206,6 @@ public class JRBaseVariable implements JRVariable, Serializable
 		return incrementerFactoryClassRealName;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getResetTypeValue()}
-	 */
-	public byte getResetType()
-	{
-		return getResetTypeValue().getValue();
-	}
-		
 	/**
 	 *
 	 */
@@ -221,14 +214,6 @@ public class JRBaseVariable implements JRVariable, Serializable
 		return this.resetTypeValue;
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getIncrementTypeValue()}
-	 */
-	public byte getIncrementType()
-	{
-		return getIncrementTypeValue().getValue();
-	}
-		
 	/**
 	 *
 	 */
@@ -237,14 +222,6 @@ public class JRBaseVariable implements JRVariable, Serializable
 		return this.incrementTypeValue;
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getCalculationValue()}
-	 */
-	public byte getCalculation()
-	{
-		return getCalculationValue().getValue();
-	}
-
 	/**
 	 * 
 	 */
@@ -309,14 +286,9 @@ public class JRBaseVariable implements JRVariable, Serializable
 			throw new JRRuntimeException(e);
 		}
 
-		if (expression != null)
-		{
-			clone.expression = (JRExpression)expression.clone();
-		}
-		if (initialValueExpression != null)
-		{
-			clone.initialValueExpression = (JRExpression)initialValueExpression.clone();
-		}
+		clone.expression = JRCloneUtils.nullSafeClone(expression);
+		clone.initialValueExpression = JRCloneUtils.nullSafeClone(initialValueExpression);
+		
 		return clone;
 	}
 		
