@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -43,7 +43,7 @@ import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
  * report component fill.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: FillContext.java 3775 2010-05-03 12:11:56Z teodord $
+ * @version $Id: FillContext.java 4648 2011-10-10 12:50:53Z lucianc $
  */
 public interface FillContext extends JRFillExpressionEvaluator
 {
@@ -55,6 +55,14 @@ public interface FillContext extends JRFillExpressionEvaluator
 	 */
 	JRComponentElement getComponentElement();
 
+	/**
+	 * Returns the fill element Id associated to the component element.
+	 * 
+	 * @return
+	 * @see JRPrintElement#getSourceElementId()
+	 */
+	int getElementSourceId();
+	
 	/**
 	 * Evaluates an expression in the main report dataset.
 	 * 
@@ -101,14 +109,14 @@ public interface FillContext extends JRFillExpressionEvaluator
 	 * @param printElement the print element
 	 * @param evaluationTime the delayed evaluation time; one of
 	 * <ul>
-	 * 	<li>{@link JRExpression#EVALUATION_TIME_BAND}
-	 * 	<li>{@link JRExpression#EVALUATION_TIME_COLUMN}
-	 * 	<li>{@link JRExpression#EVALUATION_TIME_PAGE}
-	 * 	<li>{@link JRExpression#EVALUATION_TIME_GROUP}
-	 * 	<li>{@link JRExpression#EVALUATION_TIME_REPORT}
+	 * 	<li>{@link EvaluationTimeEnum#BAND}
+	 * 	<li>{@link EvaluationTimeEnum#COLUMN}
+	 * 	<li>{@link EvaluationTimeEnum#PAGE}
+	 * 	<li>{@link EvaluationTimeEnum#GROUP}
+	 * 	<li>{@link EvaluationTimeEnum#REPORT}
 	 * </ul>
 	 * @param evaluationGroup the evaluation group name, if
-	 * <code>evaluationTime</code> is {@link JRExpression#EVALUATION_TIME_GROUP}
+	 * <code>evaluationTime</code> is {@link EvaluationTimeEnum#GROUP}
 	 * @see FillComponent#evaluateDelayedElement(JRPrintElement, byte)
 	 */
 	void registerDelayedEvaluation(JRPrintElement printElement, 
