@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -73,7 +73,7 @@ import org.jfree.date.DateUtilities;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: ConvertChartContext.java 3690 2010-04-06 12:23:17Z shertage $
+ * @version $Id: ConvertChartContext.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class ConvertChartContext implements ChartContext
 {
@@ -84,17 +84,23 @@ public class ConvertChartContext implements ChartContext
 		this.chart = chart;
 	}
 	
-	public Object evaluateExpression(JRExpression expression) throws JRException {
+	public String evaluateTextExpression(JRExpression expression) throws JRException 
+	{
 		if (expression != null)
 		{
-			if (String.class.getName().equals(expression.getValueClassName()))
-			{
-				return expression.getText();
-			}
+			return expression.getText();
 		}
 		return null;
 	}
 
+	/**
+	 *
+	 */
+	public Object evaluateExpression(JRExpression expression) throws JRException 
+	{
+		return null;
+	}
+
 	public JRChart getChart() {
 		return chart;
 	}
@@ -146,7 +152,7 @@ public class ConvertChartContext implements ChartContext
 		return null;
 	}
 	
-	private static DefaultCategoryDataset sampleCategoryDataset = null;
+	private static DefaultCategoryDataset sampleCategoryDataset;
 	
 	private CategoryDataset createCategoryDataset()
 	{
@@ -184,7 +190,7 @@ public class ConvertChartContext implements ChartContext
 		return sampleCategoryDataset;
 	}
 	
-	private static PieDataset samplePieDataset = null;
+	private static PieDataset samplePieDataset;
 	
 	private PieDataset createPieDataset()
 	{
@@ -203,7 +209,7 @@ public class ConvertChartContext implements ChartContext
 		return samplePieDataset;
 	}
 	
-	private static XYSeriesCollection sampleXyDataset = null;
+	private static XYSeriesCollection sampleXyDataset;
 	
 	private XYDataset createXyDataset()
 	{
@@ -253,7 +259,7 @@ public class ConvertChartContext implements ChartContext
 		return sampleXyDataset;
 	}
 	
-	private static TimeSeriesCollection sampleTimeSeriesDataset = null;
+	private static TimeSeriesCollection sampleTimeSeriesDataset;
 	
 	private TimeSeriesCollection createTimeSeriesDataset()
 	{
@@ -279,43 +285,37 @@ public class ConvertChartContext implements ChartContext
 			TimeSeriesCollection dataset = new TimeSeriesCollection();
 			
 			TimeSeries series = new TimeSeries("First", "Year", "Count", Year.class);
-			try 
-			{
-				series.add(new Year(1976), Integer.valueOf(0));
-				series.add(new Year(1977), Integer.valueOf(1));
-				series.add(new Year(1978), Integer.valueOf(0));
-				series.add(new Year(1979), Integer.valueOf(2));
-				series.add(new Year(1980), Integer.valueOf(0));
-				series.add(new Year(1981), Integer.valueOf(1));
-				series.add(new Year(1982), Integer.valueOf(2));
-				series.add(new Year(1983), Integer.valueOf(5));
-				series.add(new Year(1984), Integer.valueOf(21));
-				series.add(new Year(1985), Integer.valueOf(18));
-				series.add(new Year(1986), Integer.valueOf(18));
-				series.add(new Year(1987), Integer.valueOf(25));
-				series.add(new Year(1988), Integer.valueOf(11));
-				series.add(new Year(1989), Integer.valueOf(16));
-				series.add(new Year(1990), Integer.valueOf(23));
-				series.add(new Year(1991), Integer.valueOf(14));
-				series.add(new Year(1992), Integer.valueOf(31));
-				series.add(new Year(1993), Integer.valueOf(38));
-				series.add(new Year(1994), Integer.valueOf(31));
-				series.add(new Year(1995), Integer.valueOf(56));
-				series.add(new Year(1996), Integer.valueOf(45));
-				series.add(new Year(1997), Integer.valueOf(74));
-				series.add(new Year(1998), Integer.valueOf(68));
-				series.add(new Year(1999), Integer.valueOf(98));
-				series.add(new Year(2000), Integer.valueOf(85));
-				series.add(new Year(2001), Integer.valueOf(66));
-				series.add(new Year(2002), Integer.valueOf(71));
-				series.add(new Year(2003), Integer.valueOf(65));
-				series.add(new Year(2004), Integer.valueOf(59));
-				series.add(new Year(2005), Integer.valueOf(60));
-			}
-			catch (Exception e) 
-			{
-				System.err.println(e.getMessage());
-			}
+
+			series.add(new Year(1976), Integer.valueOf(0));
+			series.add(new Year(1977), Integer.valueOf(1));
+			series.add(new Year(1978), Integer.valueOf(0));
+			series.add(new Year(1979), Integer.valueOf(2));
+			series.add(new Year(1980), Integer.valueOf(0));
+			series.add(new Year(1981), Integer.valueOf(1));
+			series.add(new Year(1982), Integer.valueOf(2));
+			series.add(new Year(1983), Integer.valueOf(5));
+			series.add(new Year(1984), Integer.valueOf(21));
+			series.add(new Year(1985), Integer.valueOf(18));
+			series.add(new Year(1986), Integer.valueOf(18));
+			series.add(new Year(1987), Integer.valueOf(25));
+			series.add(new Year(1988), Integer.valueOf(11));
+			series.add(new Year(1989), Integer.valueOf(16));
+			series.add(new Year(1990), Integer.valueOf(23));
+			series.add(new Year(1991), Integer.valueOf(14));
+			series.add(new Year(1992), Integer.valueOf(31));
+			series.add(new Year(1993), Integer.valueOf(38));
+			series.add(new Year(1994), Integer.valueOf(31));
+			series.add(new Year(1995), Integer.valueOf(56));
+			series.add(new Year(1996), Integer.valueOf(45));
+			series.add(new Year(1997), Integer.valueOf(74));
+			series.add(new Year(1998), Integer.valueOf(68));
+			series.add(new Year(1999), Integer.valueOf(98));
+			series.add(new Year(2000), Integer.valueOf(85));
+			series.add(new Year(2001), Integer.valueOf(66));
+			series.add(new Year(2002), Integer.valueOf(71));
+			series.add(new Year(2003), Integer.valueOf(65));
+			series.add(new Year(2004), Integer.valueOf(59));
+			series.add(new Year(2005), Integer.valueOf(60));
 			
 			dataset.addSeries(series);
 			
@@ -325,7 +325,7 @@ public class ConvertChartContext implements ChartContext
 		return sampleTimeSeriesDataset;
 	}
 	
-	private static DefaultXYZDataset sampleXyzDataset = null;
+	private static DefaultXYZDataset sampleXyzDataset;
 	
 	private XYZDataset createXyzDataset()
 	{
@@ -348,7 +348,7 @@ public class ConvertChartContext implements ChartContext
 		return sampleXyzDataset;
 	}
 
-	private static TaskSeriesCollection sampleGanttDataset = null;
+	private static TaskSeriesCollection sampleGanttDataset;
 	
 	private IntervalCategoryDataset createGanttDataset() 
 	{
@@ -385,7 +385,7 @@ public class ConvertChartContext implements ChartContext
 		return calendar.getTime();
 	}
 
-	private static DefaultHighLowDataset sampleHighLowDataset = null;
+	private static DefaultHighLowDataset sampleHighLowDataset;
 	
 	private OHLCDataset createHighLowDataset() 
 	{
@@ -736,7 +736,7 @@ public class ConvertChartContext implements ChartContext
 		return sampleHighLowDataset;
 	}
 	
-	private static TimePeriodValuesCollection sampleTimePeriodDataset = null;
+	private static TimePeriodValuesCollection sampleTimePeriodDataset;
 	
 	private XYDataset createTimePeriodDataset()
 	{
