@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -53,7 +53,7 @@ import net.sf.jasperreports.engine.type.RunDirectionEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: CrosstabConverter.java 3687 2010-04-06 09:50:42Z shertage $
+ * @version $Id: CrosstabConverter.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public final class CrosstabConverter extends FrameConverter
 {
@@ -88,14 +88,14 @@ public final class CrosstabConverter extends FrameConverter
 		
 		copyElement(reportConverter, crosstab, printFrame);
 		
-		List children = getCrosstabChildren(reportConverter, crosstab);
+		List<JRPrintElement> children = getCrosstabChildren(reportConverter, crosstab);
 		if (children != null && children.size() > 0)
 		{
 //			ConvertVisitor convertVisitor = new ConvertVisitor(reportConverter, printFrame);
 			for(int i = 0; i < children.size(); i++)
 			{
 //				((JRChild)children.get(i)).visit(convertVisitor);
-				printFrame.addElement((JRPrintElement)children.get(i));
+				printFrame.addElement(children.get(i));
 			}
 		}
 		
@@ -105,9 +105,9 @@ public final class CrosstabConverter extends FrameConverter
 	/**
 	 *
 	 */
-	private List getCrosstabChildren(ReportConverter reportConverter, JRCrosstab crosstab)
+	private List<JRPrintElement> getCrosstabChildren(ReportConverter reportConverter, JRCrosstab crosstab)
 	{
-		List crosstabElements = new ArrayList();
+		List<JRPrintElement> crosstabElements = new ArrayList<JRPrintElement>();
 		
 		JRCrosstabRowGroup[] rowGroups = crosstab.getRowGroups();
 		int rowHeadersXOffset = 0;
@@ -168,12 +168,12 @@ public final class CrosstabConverter extends FrameConverter
 	/**
 	 *
 	 */
-	private void mirrorElements(List elements, int x, int width)
+	private void mirrorElements(List<JRPrintElement> elements, int x, int width)
 	{
-		for (Iterator it = elements.iterator(); it.hasNext();)
+		for (Iterator<JRPrintElement> it = elements.iterator(); it.hasNext();)
 		{
-			JRElement element = (JRElement) it.next();
-			int mirrorX = 2 * x + width - element.getX() - element.getWidth();
+			JRPrintElement element = it.next();
+			int mirrorX = width - element.getX() - element.getWidth();
 			element.setX(mirrorX);
 		}
 	}
@@ -242,13 +242,13 @@ public final class CrosstabConverter extends FrameConverter
 //				}
 //			}
 //		}
-		List children = cell.getChildren();
+		List<JRChild> children = cell.getChildren();
 		if (children != null && children.size() > 0)
 		{
 			ConvertVisitor convertVisitor = new ConvertVisitor(reportConverter, frame);
 			for(int i = 0; i < children.size(); i++)
 			{
-				((JRChild)children.get(i)).visit(convertVisitor);
+				children.get(i).visit(convertVisitor);
 			}
 		}
 		
@@ -262,7 +262,7 @@ public final class CrosstabConverter extends FrameConverter
 		ReportConverter reportConverter,
 		JRCrosstab crosstab, 
 		int rowHeadersXOffset, 
-		List crosstabElements
+		List<JRPrintElement> crosstabElements
 		)
 	{
 		JRCrosstabColumnGroup[] groups = crosstab.getColumnGroups();
@@ -283,7 +283,7 @@ public final class CrosstabConverter extends FrameConverter
 							totalHeader, 
 							rowHeadersXOffset + x, 
 							y, 
-							firstOnRow && crosstab.getRunDirectionValue() == RunDirectionEnum.LTR,
+							firstOnRow && crosstab.getRunDirectionValue() != RunDirectionEnum.RTL, //LTR or null
 							firstOnRow && crosstab.getRunDirectionValue() == RunDirectionEnum.RTL,
 							false
 							));
@@ -301,7 +301,7 @@ public final class CrosstabConverter extends FrameConverter
 						header, 
 						rowHeadersXOffset + x, 
 						y, 
-						firstOnRow && crosstab.getRunDirectionValue() == RunDirectionEnum.LTR,
+						firstOnRow && crosstab.getRunDirectionValue() != RunDirectionEnum.RTL, //LTR or null
 						firstOnRow && crosstab.getRunDirectionValue() == RunDirectionEnum.RTL,
 						false
 						));
@@ -338,7 +338,7 @@ public final class CrosstabConverter extends FrameConverter
 		JRCrosstab crosstab, 
 		int rowHeadersXOffset, 
 		int colHeadersYOffset, 
-		List crosstabElements
+		List<JRPrintElement> crosstabElements
 		)
 	{
 		JRCrosstabRowGroup[] groups = crosstab.getRowGroups();
@@ -442,7 +442,7 @@ public final class CrosstabConverter extends FrameConverter
 		int rowOffsetX, 
 		int rowOffsetY, 
 		int rowIndex,
-		List crosstabElements
+		List<JRPrintElement> crosstabElements
 		)
 	{
 		JRCrosstabCell[][] cells = crosstab.getCells();
