@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -45,7 +45,7 @@ import net.sf.jasperreports.engine.util.JRTextMeasurerUtil;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: TextElementConverter.java 3485 2010-02-26 16:29:04Z shertage $
+ * @version $Id: TextElementConverter.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public abstract class TextElementConverter extends ElementConverter
 {
@@ -58,17 +58,16 @@ public abstract class TextElementConverter extends ElementConverter
 		copyElement(reportConverter, textElement, printText);
 		
 		printText.copyBox(textElement.getLineBox());
+		printText.copyParagraph(textElement.getParagraph());
 		
 		printText.setBold(textElement.isOwnBold());
 		printText.setFontName(textElement.getOwnFontName());
 		printText.setFontSize(textElement.getOwnFontSize());
 		printText.setHorizontalAlignment(textElement.getOwnHorizontalAlignmentValue());
 		printText.setItalic(textElement.isOwnItalic());
-		printText.setLineSpacing(textElement.getOwnLineSpacingValue());
 		printText.setPdfEmbedded(textElement.isOwnPdfEmbedded());
 		printText.setPdfEncoding(textElement.getOwnPdfEncoding());
 		printText.setPdfFontName(textElement.getOwnPdfFontName());
-		printText.setReportFont(textElement.getReportFont());
 		printText.setRotation(textElement.getOwnRotationValue());
 		printText.setStrikeThrough(textElement.isOwnStrikeThrough());
 		printText.setMarkup(textElement.getOwnMarkup());
@@ -105,8 +104,8 @@ public abstract class TextElementConverter extends ElementConverter
 				false
 				);
 		printText.setTextHeight(measuredText.getTextHeight() < printText.getHeight() ? measuredText.getTextHeight() : printText.getHeight());
-		printText.setLeadingOffset(measuredText.getLeadingOffset());
-		printText.setLineSpacingFactor(measuredText.getLineSpacingFactor());
+		//printText.setLeadingOffset(measuredText.getLeadingOffset());
+		//printText.setLineSpacingFactor(measuredText.getLineSpacingFactor());
 		
 		int textEnd = measuredText.getTextOffset();
 		String printedText;
