@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -43,20 +43,20 @@ import net.sf.jasperreports.engine.design.JRDesignField;
  * implementation for bean properties introspection.
  * 
  * @author Peter Severin (peter_s@sourceforge.net, contact@jasperassistant.com)
- * @version $Id: JRAbstractBeanDataSourceProvider.java 3716 2010-04-08 19:57:14Z teodord $
+ * @version $Id: JRAbstractBeanDataSourceProvider.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public abstract class JRAbstractBeanDataSourceProvider implements JRDataSourceProvider 
 {
 
 	/** The introspected bean class */
-	private Class beanClass;
+	private Class<?> beanClass;
 
 	/**
 	 * Creates the provider. Superclasses must pass a valid class that will be
 	 * used to introspect the available bean fields.
 	 * @param beanClass the bean class to be introspected.
 	 */
-	public JRAbstractBeanDataSourceProvider(Class beanClass) {
+	public JRAbstractBeanDataSourceProvider(Class<?> beanClass) {
 		if (beanClass == null)
 		{
 			throw new JRRuntimeException("beanClass must not be null");
@@ -87,7 +87,7 @@ public abstract class JRAbstractBeanDataSourceProvider implements JRDataSourcePr
 		PropertyDescriptor[] descriptors = beanInfo.getPropertyDescriptors();
 		if(descriptors != null) 
 		{
-			ArrayList fields = new ArrayList(descriptors.length);
+			ArrayList<JRField> fields = new ArrayList<JRField>(descriptors.length);
 			
 			for (int i = 0; i < descriptors.length; i++) {
 				PropertyDescriptor descriptor = descriptors[i];
@@ -102,7 +102,7 @@ public abstract class JRAbstractBeanDataSourceProvider implements JRDataSourcePr
 				}
 			}
 	
-			return (JRField[]) fields.toArray(new JRField[fields.size()]);
+			return fields.toArray(new JRField[fields.size()]);
 		}
 
 		return new JRField[0];
@@ -111,7 +111,7 @@ public abstract class JRAbstractBeanDataSourceProvider implements JRDataSourcePr
 	/**
 	 * Converts a primitive class to its object counterpart
 	 */
-	private static Class normalizeClass(Class clazz) {
+	private static Class<?> normalizeClass(Class<?> clazz) {
 		if(clazz.isPrimitive()) 
 		{
 			if(clazz == boolean.class)
