@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -25,12 +25,17 @@ package net.sf.jasperreports.engine.data;
 
 import java.math.BigDecimal;
 import java.math.BigInteger;
+import java.text.DateFormat;
+import java.text.NumberFormat;
+import java.text.ParseException;
 import java.util.Date;
 import java.util.Locale;
 import java.util.TimeZone;
 
 import net.sf.jasperreports.engine.JRDataSource;
 import net.sf.jasperreports.engine.JRException;
+import net.sf.jasperreports.engine.util.FormatUtils;
+import net.sf.jasperreports.engine.util.JRDataUtils;
 import net.sf.jasperreports.engine.util.JRDateLocaleConverter;
 import net.sf.jasperreports.engine.util.JRFloatLocaleConverter;
 
@@ -41,7 +46,7 @@ import org.apache.commons.beanutils.locale.LocaleConvertUtilsBean;
  * data into numerical or date values.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRAbstractTextDataSource.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: JRAbstractTextDataSource.java 4709 2011-10-18 08:59:12Z narcism $
  */
 public abstract class JRAbstractTextDataSource implements JRDataSource
 {
@@ -53,7 +58,7 @@ public abstract class JRAbstractTextDataSource implements JRDataSource
 	private String numberPattern;
 	private TimeZone timeZone;
 
-	protected Object convertStringValue(String text, Class valueClass)
+	protected Object convertStringValue(String text, Class<?> valueClass)
 	{
 		Object value = null;
 		if (String.class.equals(valueClass))
@@ -75,7 +80,7 @@ public abstract class JRAbstractTextDataSource implements JRDataSource
 		return value;
 	}
 
-	protected Object convertNumber(Number number, Class valueClass) throws JRException
+	protected Object convertNumber(Number number, Class<?> valueClass) throws JRException
 	{
 		Number value = null;
 		if (valueClass.equals(Byte.class))
@@ -117,6 +122,22 @@ public abstract class JRAbstractTextDataSource implements JRDataSource
 		return value;
 	}
 
+	/**
+	 * @deprecated Replaced by {@link FormatUtils#getFormattedNumber(NumberFormat, String, Class)}
+	 */
+	protected Number getFormattedNumber(NumberFormat numberFormat, String fieldValue, Class<?> valueClass) throws ParseException
+	{
+		return FormatUtils.getFormattedNumber(numberFormat, fieldValue, valueClass);
+	}
+	
+	/**
+	 * @deprecated Replaced by {@link FormatUtils#getFormattedDate(DateFormat, String, Class)}
+	 */
+	protected Date getFormattedDate(DateFormat dateFormat, String fieldValue, Class<?> valueClass) throws ParseException 
+	{
+		return FormatUtils.getFormattedDate(dateFormat, fieldValue, valueClass);
+	}
+
 	protected LocaleConvertUtilsBean getConvertBean() 
 	{
 		if (convertBean == null)
@@ -165,6 +186,10 @@ public abstract class JRAbstractTextDataSource implements JRDataSource
 		this.locale = locale;
 		convertBean = null;
 	}
+	
+	public void setLocale(String locale) {
+		setLocale(JRDataUtils.getLocale(locale));
+	}
 
 	public String getDatePattern() {
 		return datePattern;
@@ -192,5 +217,9 @@ public abstract class JRAbstractTextDataSource implements JRDataSource
 		this.timeZone = timeZone;
 		convertBean = null;
 	}
-
+	
+	public void setTimeZone(String timeZoneId){
+		setTimeZone(JRDataUtils.getTimeZone(timeZoneId));
+	}
+	
 }
