@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -39,13 +39,18 @@ import net.sf.jasperreports.engine.JRField;
 import net.sf.jasperreports.engine.JRRewindableDataSource;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRSortField;
+import net.sf.jasperreports.engine.fill.DatasetSortUtil;
 import net.sf.jasperreports.engine.fill.JRFillInterruptedException;
 import net.sf.jasperreports.engine.type.SortOrderEnum;
 
 
 /**
+ * This data source implementation is now deprecated because it does not know about sorting on 
+ * dataset variables and should no longer be used.
+ * It will be removed from the library in future versions.
+ * @deprecated Replaced by {@link ListOfArrayDataSource} and {@link DatasetSortUtil}.
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRSortableDataSource.java 3860 2010-06-03 14:38:36Z lucianc $
+ * @version $Id: JRSortableDataSource.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRSortableDataSource implements JRRewindableDataSource
 {
@@ -54,12 +59,12 @@ public class JRSortableDataSource implements JRRewindableDataSource
 	/**
 	 *
 	 */
-	private List records = new ArrayList();
-	private Iterator iterator = null;
-	private Object[] currentRecord = null;
-	private Map fieldIndexMap = new HashMap();
+	private List<Object[]> records = new ArrayList<Object[]>();
+	private Iterator<Object[]> iterator;
+	private Object[] currentRecord;
+	private Map<String,Integer> fieldIndexMap = new HashMap<String,Integer>();
 
-	protected Collator collator = null;
+	protected Collator collator;
 
 
 	/**
@@ -95,7 +100,7 @@ public class JRSortableDataSource implements JRRewindableDataSource
 		for(int i = 0; i < sortFields.length; i++)
 		{
 			JRSortField sortField = sortFields[i];
-			sortIndexes[i] = ((Integer)fieldIndexMap.get(sortField.getName())).intValue();
+			sortIndexes[i] = fieldIndexMap.get(sortField.getName()).intValue();
 			sortOrders[i] = (SortOrderEnum.ASCENDING == sortField.getOrderValue() ? 1 : -1);
 
 			collatorFlags[i] = false;
@@ -150,7 +155,7 @@ public class JRSortableDataSource implements JRRewindableDataSource
 
 			if (hasNext)
 			{
-				currentRecord = (Object[])iterator.next();
+				currentRecord = iterator.next();
 			}
 		}
 
@@ -163,7 +168,7 @@ public class JRSortableDataSource implements JRRewindableDataSource
 	 */
 	public Object getFieldValue(JRField jrField)
 	{
-		Integer fieldIndex = (Integer)fieldIndexMap.get(jrField.getName());
+		Integer fieldIndex = fieldIndexMap.get(jrField.getName());
 
 		if (fieldIndex == null)
 		{
