@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -39,7 +39,7 @@ import net.sf.jasperreports.engine.JRRewindableDataSource;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRTableModelDataSource.java 3659 2010-03-31 10:20:49Z shertage $
+ * @version $Id: JRTableModelDataSource.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRTableModelDataSource implements JRRewindableDataSource
 {
@@ -48,9 +48,9 @@ public class JRTableModelDataSource implements JRRewindableDataSource
 	/**
 	 *
 	 */
-	private TableModel tableModel = null;
+	private TableModel tableModel;
 	private int index = -1;
-	private HashMap columnNames = new HashMap();
+	private HashMap<String, Integer> columnNames = new HashMap<String, Integer>();
 	
 
 	/**
@@ -93,7 +93,7 @@ public class JRTableModelDataSource implements JRRewindableDataSource
 	{
 		String fieldName = jrField.getName();
 		
-		Integer columnIndex = (Integer)this.columnNames.get(fieldName);
+		Integer columnIndex = this.columnNames.get(fieldName);
 		
 		if (columnIndex != null)
 		{
