@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -115,7 +115,7 @@ import org.xml.sax.InputSource;
  * consider implementing a custom data source that directly accesses the Document through the DOM API. 
  * </p>
  * @author Peter Severin (peter_p_s@sourceforge.net, contact@jasperassistant.com)
- * @version $Id: JRXmlDataSource.java 3690 2010-04-06 12:23:17Z shertage $
+ * @version $Id: JRXmlDataSource.java 4595 2011-09-08 15:55:10Z teodord $
  * @see JRXPathExecuterUtils
  */
 public class JRXmlDataSource extends JRAbstractTextDataSource implements JRRewindableDataSource {
@@ -298,7 +298,7 @@ public class JRXmlDataSource extends JRAbstractTextDataSource implements JRRewin
 		}
 		Object value = null;
 		
-		Class valueClass = jrField.getValueClass();
+		Class<?> valueClass = jrField.getValueClass();
 		Object selectedObject = xPathExecuter.selectObject(currentNode, expression);
 
 		if(Object.class != valueClass) 
