@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -36,7 +36,7 @@ import net.sf.jasperreports.engine.type.SplitTypeEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRDesignBand.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRDesignBand.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRDesignBand extends JRDesignElementGroup implements JRBand
 {
@@ -54,13 +54,13 @@ public class JRDesignBand extends JRDesignElementGroup implements JRBand
 	/**
 	 *
 	 */
-	protected int height = 0;
-	protected SplitTypeEnum splitTypeValue = null;
+	protected int height;
+	protected SplitTypeEnum splitTypeValue;
 
 	/**
 	 *
 	 */
-	protected JRExpression printWhenExpression = null;
+	protected JRExpression printWhenExpression;
 	
 	private JROrigin origin;
 
@@ -82,30 +82,6 @@ public class JRDesignBand extends JRDesignElementGroup implements JRBand
 		getEventSupport().firePropertyChange(PROPERTY_HEIGHT, old, this.height);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getSplitType()}.
-	 */
-	public boolean isSplitAllowed()
-	{
-		return !JRBand.SPLIT_TYPE_PREVENT.equals(getSplitType());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setSplitType(Byte)}.
-	 */
-	public void setSplitAllowed(boolean isSplitAllowed)
-	{
-		setSplitType(isSplitAllowed ? JRBand.SPLIT_TYPE_STRETCH : JRBand.SPLIT_TYPE_PREVENT);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getSplitTypeValue()}.
-	 */
-	public Byte getSplitType()
-	{
-		return getSplitTypeValue() == null ? null : getSplitTypeValue().getValueByte();
-	}
-
 	/**
 	 *
 	 */
@@ -114,14 +90,6 @@ public class JRDesignBand extends JRDesignElementGroup implements JRBand
 		return splitTypeValue;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setSplitType(SplitTypeEnum)}.
-	 */
-	public void setSplitType(Byte splitType)
-	{
-		setSplitType(SplitTypeEnum.getByValue(splitType));
-	}
-
 	/**
 	 *
 	 */
@@ -155,8 +123,8 @@ public class JRDesignBand extends JRDesignElementGroup implements JRBand
 	 * (e.g. detail/title/group header/etc).
 	 * The location is automatically set when the band is inserted
 	 * into the report (via one of the
-	 * {@link JasperDesign#setTitle(JRBand) setTitle}/
-	 * {@link JRDesignGroup#setGroupHeader(JRBand) setGroupHeader}
+	 * {@link JasperDesign#setTitle(JRBand) setTitle} /
+	 * {@link JasperDesign#setPageHeader(JRBand) setPageHeader}
 	 * methods).
 	 * 
 	 * @return the band origin
@@ -201,16 +169,15 @@ public class JRDesignBand extends JRDesignElementGroup implements JRBand
 	/**
 	 * @deprecated
 	 */
-	private Byte splitType = null;
+	private Byte splitType;
 	
-	@SuppressWarnings("deprecation")
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
 		in.defaultReadObject();
 		
 		if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_3_5_2)
 		{
-			splitType = isSplitAllowed ? JRBand.SPLIT_TYPE_STRETCH : JRBand.SPLIT_TYPE_PREVENT;
+			splitType = isSplitAllowed ? SplitTypeEnum.STRETCH.getValueByte() : SplitTypeEnum.PREVENT.getValueByte();
 		}
 		
 		if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_3_7_2)//FIXMEENUM check order of ifs for all
