@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -54,7 +54,6 @@ import net.sf.jasperreports.charts.design.JRDesignXyDataset;
 import net.sf.jasperreports.charts.design.JRDesignXyzDataset;
 import net.sf.jasperreports.charts.type.EdgeEnum;
 import net.sf.jasperreports.engine.JRAnchor;
-import net.sf.jasperreports.engine.JRBox;
 import net.sf.jasperreports.engine.JRChart;
 import net.sf.jasperreports.engine.JRChartDataset;
 import net.sf.jasperreports.engine.JRChartPlot;
@@ -70,21 +69,19 @@ import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRVisitor;
 import net.sf.jasperreports.engine.base.JRBaseChart;
-import net.sf.jasperreports.engine.base.JRBaseFont;
 import net.sf.jasperreports.engine.base.JRBaseLineBox;
 import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
 import net.sf.jasperreports.engine.type.HyperlinkTargetEnum;
 import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
 import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
-import net.sf.jasperreports.engine.util.JRPenUtil;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
-import net.sf.jasperreports.engine.util.LineBoxWrapper;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRDesignChart.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRDesignChart.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRDesignChart extends JRDesignElement implements JRChart
 {
@@ -126,48 +123,48 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	/**
 	 *
 	 */
-	protected byte chartType = 0;
+	protected byte chartType;
 
 	/**
 	 *
 	 */
-	protected Boolean showLegend = null;
+	protected Boolean showLegend;
 	protected EvaluationTimeEnum evaluationTimeValue = EvaluationTimeEnum.NOW;
 	protected String linkType;
 	protected String linkTarget;
-	protected Color titleColor = null;
-	protected Color subtitleColor = null;
-	protected Color legendColor = null;
-	protected Color legendBackgroundColor = null;
+	protected Color titleColor;
+	protected Color subtitleColor;
+	protected Color legendColor;
+	protected Color legendBackgroundColor;
 	protected String renderType;
 	protected String theme;
 
 	/**
 	 *
 	 */
-	protected JRFont titleFont = null;
-	protected JRFont subtitleFont = null;
-	protected JRFont legendFont = null;
-	protected EdgeEnum legendPositionValue = null;
-	protected EdgeEnum titlePositionValue = null;
+	protected JRFont titleFont;
+	protected JRFont subtitleFont;
+	protected JRFont legendFont;
+	protected EdgeEnum legendPositionValue;
+	protected EdgeEnum titlePositionValue;
 
 	protected String customizerClass;
 
 	/**
 	 *
 	 */
-	protected JRGroup evaluationGroup = null;
-	protected JRExpression titleExpression = null;
-	protected JRExpression subtitleExpression = null;
-	protected JRExpression anchorNameExpression = null;
-	protected JRExpression hyperlinkReferenceExpression = null;
-	protected JRExpression hyperlinkAnchorExpression = null;
-	protected JRExpression hyperlinkPageExpression = null;
+	protected JRGroup evaluationGroup;
+	protected JRExpression titleExpression;
+	protected JRExpression subtitleExpression;
+	protected JRExpression anchorNameExpression;
+	protected JRExpression hyperlinkReferenceExpression;
+	protected JRExpression hyperlinkAnchorExpression;
+	protected JRExpression hyperlinkPageExpression;
 	private JRExpression hyperlinkTooltipExpression;
-	private List hyperlinkParameters;
+	private List<JRHyperlinkParameter> hyperlinkParameters;
 
-	protected JRChartDataset dataset = null;
-	protected JRChartPlot plot = null;
+	protected JRChartDataset dataset;
+	protected JRChartPlot plot;
 
 	/**
 	 *
@@ -190,31 +187,11 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 		
 		setChartType(chartType);
 		
-		titleFont = new JRBaseFont(this, null);
-		subtitleFont = new JRBaseFont(this, null);
-		legendFont = new JRBaseFont(this, null);
-
-		hyperlinkParameters = new ArrayList();
+		hyperlinkParameters = new ArrayList<JRHyperlinkParameter>();
 		
 		lineBox = new JRBaseLineBox(this);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getShowLegend()}
-	 */
-	public boolean isShowLegend()
-	{
-		return this.showLegend == null ? false : showLegend.booleanValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setShowLegend(Boolean)}
-	 */
-	public void setShowLegend(boolean isShowLegend)
-	{
-		setShowLegend(Boolean.valueOf(isShowLegend));
-	}
-
 	/**
 	 * 
 	 */
@@ -270,14 +247,6 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 		getEventSupport().firePropertyChange(JRBaseChart.PROPERTY_THEME, old, this.theme);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getEvaluationTimeValue()}.
-	 */
-	public byte getEvaluationTime()
-	{
-		return getEvaluationTimeValue().getValue();
-	}
-		
 	/**
 	 *
 	 */
@@ -286,14 +255,6 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 		return evaluationTimeValue;
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #setEvaluationTime(EvaluationTimeEnum)}.
-	 */
-	public void setEvaluationTime(byte evaluationTime)
-	{
-		setEvaluationTime(EvaluationTimeEnum.getByValue(evaluationTime));
-	}
-		
 	/**
 	 *
 	 */
@@ -322,14 +283,6 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 		getEventSupport().firePropertyChange(PROPERTY_EVALUATION_GROUP, old, this.evaluationGroup);
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public JRBox getBox()
-	{
-		return new LineBoxWrapper(getLineBox());
-	}
-
 	/**
 	 *
 	 */
@@ -338,14 +291,6 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 		return lineBox;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setBox(JRBox box)
-	{
-		JRBoxUtil.setBoxToLineBox(box, lineBox);
-	}
-
 	/**
 	 *
 	 */
@@ -360,42 +305,10 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	public void setTitleFont(JRFont font)//FIXMEFONT embedded fonts should never be null so these font setting methods should be deprecated; check iR impact
 	{
 		Object old = this.titleFont;
-		this.titleFont = new JRBaseFont(this, font);
+		this.titleFont = font;
 		getEventSupport().firePropertyChange(PROPERTY_TITLE_FONT, old, this.titleFont);
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #getTitlePositionValue()}
-	 */
-	public byte getTitlePosition()
-	{
-		return getTitlePositionValue() == null ? EdgeEnum.TOP.getValue() : getTitlePositionValue().getValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setTitlePosition(EdgeEnum)}
-	 */
-	public void setTitlePosition(byte titlePosition)
-	{
-		setTitlePosition(EdgeEnum.getByValue(titlePosition));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getTitlePositionValue()}
-	 */
-	public Byte getTitlePositionByte()
-	{
-		return getTitlePositionValue() == null ? null : getTitlePositionValue().getValueByte();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setTitlePosition(EdgeEnum)}
-	 */
-	public void setTitlePosition(Byte titlePosition)
-	{
-		setTitlePosition(EdgeEnum.getByValue(titlePosition));
-	}
-
 	/**
 	 *
 	 */
@@ -454,7 +367,7 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	public void setSubtitleFont(JRFont font)
 	{
 		Object old = this.subtitleFont;
-		this.subtitleFont = new JRBaseFont(this, font);
+		this.subtitleFont = font;
 		getEventSupport().firePropertyChange(PROPERTY_SUBTITLE_FONT, old, this.subtitleFont);
 	}
 	
@@ -550,42 +463,10 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	public void setLegendFont(JRFont legendFont)
 	{
 		Object old = this.legendFont;
-		this.legendFont = new JRBaseFont(this, legendFont);
+		this.legendFont = legendFont;
 		getEventSupport().firePropertyChange(PROPERTY_LEGEND_FONT, old, this.legendFont);
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #getLegendPositionValue()}
-	 */
-	public byte getLegendPosition()
-	{
-		return getLegendPositionValue() == null? EdgeEnum.BOTTOM.getValue() : getLegendPositionValue().getValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setLegendPosition(EdgeEnum)}
-	 */
-	public void setLegendPosition(byte legendPosition)
-	{
-		setLegendPosition(EdgeEnum.getByValue(legendPosition));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLegendPositionValue()}
-	 */
-	public Byte getLegendPositionByte()
-	{
-		return getLegendPositionValue() == null? null : getLegendPositionValue().getValueByte();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setLegendPosition(EdgeEnum)}
-	 */
-	public void setLegendPosition(Byte legendPosition)
-	{
-		setLegendPosition(EdgeEnum.getByValue(legendPosition));
-	}
-
 	/**
 	 *
 	 */
@@ -836,8 +717,8 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 				plot = new JRDesignMeterPlot(plot, this);
 				break;
 			case CHART_TYPE_MULTI_AXIS:
-				plot = new JRDesignMultiAxisPlot(plot, this);
 				dataset = null;
+				plot = new JRDesignMultiAxisPlot(plot, this);
 				break;
 			case CHART_TYPE_PIE:
 				dataset = new JRDesignPieDataset(dataset);
@@ -964,446 +845,6 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(lineBox.getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBorder(byte border)
-	{
-		JRPenUtil.setLinePenFromPen(border, lineBox.getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBorder(Byte border)
-	{
-		JRPenUtil.setLinePenFromPen(border, lineBox.getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getBorderColor()
-	{
-		return lineBox.getPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnBorderColor()
-	{
-		return lineBox.getPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBorderColor(Color borderColor)
-	{
-		lineBox.getPen().setLineColor(borderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getPadding()
-	{
-		return lineBox.getPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnPadding()
-	{
-		return lineBox.getOwnPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setPadding(int padding)
-	{
-		lineBox.setPadding(padding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setPadding(Integer padding)
-	{
-		lineBox.setPadding(padding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getTopBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(lineBox.getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnTopBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopBorder(byte topBorder)
-	{
-		JRPenUtil.setLinePenFromPen(topBorder, lineBox.getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopBorder(Byte topBorder)
-	{
-		JRPenUtil.setLinePenFromPen(topBorder, lineBox.getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getTopBorderColor()
-	{
-		return lineBox.getTopPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnTopBorderColor()
-	{
-		return lineBox.getTopPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopBorderColor(Color topBorderColor)
-	{
-		lineBox.getTopPen().setLineColor(topBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getTopPadding()
-	{
-		return lineBox.getTopPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnTopPadding()
-	{
-		return lineBox.getOwnTopPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopPadding(int topPadding)
-	{
-		lineBox.setTopPadding(topPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopPadding(Integer topPadding)
-	{
-		lineBox.setTopPadding(topPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getLeftBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(lineBox.getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnLeftBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftBorder(byte leftBorder)
-	{
-		JRPenUtil.setLinePenFromPen(leftBorder, lineBox.getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftBorder(Byte leftBorder)
-	{
-		JRPenUtil.setLinePenFromPen(leftBorder, lineBox.getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getLeftBorderColor()
-	{
-		return lineBox.getLeftPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnLeftBorderColor()
-	{
-		return lineBox.getLeftPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftBorderColor(Color leftBorderColor)
-	{
-		lineBox.getLeftPen().setLineColor(leftBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getLeftPadding()
-	{
-		return lineBox.getLeftPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnLeftPadding()
-	{
-		return lineBox.getOwnLeftPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftPadding(int leftPadding)
-	{
-		lineBox.setLeftPadding(leftPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftPadding(Integer leftPadding)
-	{
-		lineBox.setLeftPadding(leftPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getBottomBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(lineBox.getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnBottomBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomBorder(byte bottomBorder)
-	{
-		JRPenUtil.setLinePenFromPen(bottomBorder, lineBox.getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomBorder(Byte bottomBorder)
-	{
-		JRPenUtil.setLinePenFromPen(bottomBorder, lineBox.getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getBottomBorderColor()
-	{
-		return lineBox.getBottomPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnBottomBorderColor()
-	{
-		return lineBox.getBottomPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomBorderColor(Color bottomBorderColor)
-	{
-		lineBox.getBottomPen().setLineColor(bottomBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getBottomPadding()
-	{
-		return lineBox.getBottomPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnBottomPadding()
-	{
-		return lineBox.getOwnBottomPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomPadding(int bottomPadding)
-	{
-		lineBox.setBottomPadding(bottomPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomPadding(Integer bottomPadding)
-	{
-		lineBox.setBottomPadding(bottomPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getRightBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(lineBox.getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnRightBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightBorder(byte rightBorder)
-	{
-		JRPenUtil.setLinePenFromPen(rightBorder, lineBox.getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightBorder(Byte rightBorder)
-	{
-		JRPenUtil.setLinePenFromPen(rightBorder, lineBox.getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getRightBorderColor()
-	{
-		return lineBox.getRightPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnRightBorderColor()
-	{
-		return lineBox.getRightPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightBorderColor(Color rightBorderColor)
-	{
-		lineBox.getRightPen().setLineColor(rightBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getRightPadding()
-	{
-		return lineBox.getRightPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnRightPadding()
-	{
-		return lineBox.getOwnRightPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightPadding(int rightPadding)
-	{
-		lineBox.setRightPadding(rightPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightPadding(Integer rightPadding)
-	{
-		lineBox.setRightPadding(rightPadding);
-	}
-
 
 	public String getLinkType()
 	{
@@ -1470,7 +911,7 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	 * 
 	 * @return the list of custom hyperlink parameters
 	 */
-	public List getHyperlinkParametersList()
+	public List<JRHyperlinkParameter> getHyperlinkParametersList()
 	{
 		return hyperlinkParameters;
 	}
@@ -1517,9 +958,9 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	 */
 	public void removeHyperlinkParameter(String parameterName)
 	{
-		for (ListIterator it = hyperlinkParameters.listIterator(); it.hasNext();)
+		for (ListIterator<JRHyperlinkParameter> it = hyperlinkParameters.listIterator(); it.hasNext();)
 		{
-			JRHyperlinkParameter parameter = (JRHyperlinkParameter) it.next();
+			JRHyperlinkParameter parameter = it.next();
 			if (parameter.getName() != null && parameter.getName().equals(parameterName))
 			{
 				it.remove();
@@ -1564,56 +1005,17 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	public Object clone() 
 	{
 		JRDesignChart clone = (JRDesignChart)super.clone();
-		
 		clone.lineBox = lineBox.clone(clone);
-
-		if (hyperlinkParameters != null)
-		{
-			clone.hyperlinkParameters = new ArrayList(hyperlinkParameters.size());
-			for(int i = 0; i < hyperlinkParameters.size(); i++)
-			{
-				clone.hyperlinkParameters.add(((JRHyperlinkParameter)hyperlinkParameters.get(i)).clone());
-			}
-		}
-
-		if (titleExpression != null)
-		{
-			clone.titleExpression = (JRExpression)titleExpression.clone();
-		}
-		if (subtitleExpression != null)
-		{
-			clone.subtitleExpression = (JRExpression)subtitleExpression.clone();
-		}
-		if (anchorNameExpression != null)
-		{
-			clone.anchorNameExpression = (JRExpression)anchorNameExpression.clone();
-		}
-		if (hyperlinkReferenceExpression != null)
-		{
-			clone.hyperlinkReferenceExpression = (JRExpression)hyperlinkReferenceExpression.clone();
-		}
-		if (hyperlinkAnchorExpression != null)
-		{
-			clone.hyperlinkAnchorExpression = (JRExpression)hyperlinkAnchorExpression.clone();
-		}
-		if (hyperlinkPageExpression != null)
-		{
-			clone.hyperlinkPageExpression = (JRExpression)hyperlinkPageExpression.clone();
-		}
-		if (hyperlinkTooltipExpression != null)
-		{
-			clone.hyperlinkTooltipExpression = (JRExpression)hyperlinkTooltipExpression.clone();
-		}
-
-		if (dataset != null)
-		{
-			clone.dataset = (JRChartDataset)dataset.clone();
-		}
-		if (plot != null)
-		{
-			clone.plot = (JRChartPlot)plot.clone(clone);
-		}
-
+		clone.hyperlinkParameters = JRCloneUtils.cloneList(hyperlinkParameters);
+		clone.titleExpression = JRCloneUtils.nullSafeClone(titleExpression);
+		clone.subtitleExpression = JRCloneUtils.nullSafeClone(subtitleExpression);
+		clone.anchorNameExpression = JRCloneUtils.nullSafeClone(anchorNameExpression);
+		clone.hyperlinkReferenceExpression = JRCloneUtils.nullSafeClone(hyperlinkReferenceExpression);
+		clone.hyperlinkAnchorExpression = JRCloneUtils.nullSafeClone(hyperlinkAnchorExpression);
+		clone.hyperlinkPageExpression = JRCloneUtils.nullSafeClone(hyperlinkPageExpression);
+		clone.hyperlinkTooltipExpression = JRCloneUtils.nullSafeClone(hyperlinkTooltipExpression);
+		clone.dataset = JRCloneUtils.nullSafeClone(dataset);
+		clone.plot = JRCloneUtils.nullSafeClone(plot);
 		return clone;
 	}
 	
@@ -1625,67 +1027,67 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	/**
 	 * @deprecated
 	 */
-	private Byte border = null;
+	private Byte border;
 	/**
 	 * @deprecated
 	 */
-	private Byte topBorder = null;
+	private Byte topBorder;
 	/**
 	 * @deprecated
 	 */
-	private Byte leftBorder = null;
+	private Byte leftBorder;
 	/**
 	 * @deprecated
 	 */
-	private Byte bottomBorder = null;
+	private Byte bottomBorder;
 	/**
 	 * @deprecated
 	 */
-	private Byte rightBorder = null;
+	private Byte rightBorder;
 	/**
 	 * @deprecated
 	 */
-	private Color borderColor = null;
+	private Color borderColor;
 	/**
 	 * @deprecated
 	 */
-	private Color topBorderColor = null;
+	private Color topBorderColor;
 	/**
 	 * @deprecated
 	 */
-	private Color leftBorderColor = null;
+	private Color leftBorderColor;
 	/**
 	 * @deprecated
 	 */
-	private Color bottomBorderColor = null;
+	private Color bottomBorderColor;
 	/**
 	 * @deprecated
 	 */
-	private Color rightBorderColor = null;
+	private Color rightBorderColor;
 	/**
 	 * @deprecated
 	 */
-	private Integer padding = null;
+	private Integer padding;
 	/**
 	 * @deprecated
 	 */
-	private Integer topPadding = null;
+	private Integer topPadding;
 	/**
 	 * @deprecated
 	 */
-	private Integer leftPadding = null;
+	private Integer leftPadding;
 	/**
 	 * @deprecated
 	 */
-	private Integer bottomPadding = null;
+	private Integer bottomPadding;
 	/**
 	 * @deprecated
 	 */
-	private Integer rightPadding = null;
+	private Integer rightPadding;
 	/**
 	 * @deprecated
 	 */
-	private boolean isShowLegend = false;
+	private boolean isShowLegend;
 	/**
 	 * @deprecated
 	 */
@@ -1709,11 +1111,11 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	/**
 	 * @deprecated
 	 */
-	private Byte legendPositionByte = null;
+	private Byte legendPositionByte;
 	/**
 	 * @deprecated
 	 */
-	private Byte titlePositionByte = null;
+	private Byte titlePositionByte;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
