@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -41,6 +41,7 @@ import java.util.Map;
 import java.util.ResourceBundle;
 import java.util.TimeZone;
 
+import net.sf.jasperreports.engine.DatasetFilter;
 import net.sf.jasperreports.engine.JRAbstractScriptlet;
 import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRDataSource;
@@ -56,19 +57,23 @@ import net.sf.jasperreports.engine.JRSortField;
 import net.sf.jasperreports.engine.JRVariable;
 import net.sf.jasperreports.engine.JRVirtualizer;
 import net.sf.jasperreports.engine.JasperReport;
+import net.sf.jasperreports.engine.ReportContext;
 import net.sf.jasperreports.engine.base.JRBaseDataset;
 import net.sf.jasperreports.engine.query.JRQueryExecuterFactory;
 import net.sf.jasperreports.engine.type.CalculationEnum;
 import net.sf.jasperreports.engine.type.ResetTypeEnum;
+import net.sf.jasperreports.engine.type.SortFieldTypeEnum;
+import net.sf.jasperreports.engine.type.SortOrderEnum;
 import net.sf.jasperreports.engine.util.FileResolver;
 import net.sf.jasperreports.engine.util.FormatFactory;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 import net.sf.jasperreports.engine.util.JRQueryExecuterUtils;
 
 /**
  * Implementation of {@link net.sf.jasperreports.engine.JRDataset JRDataset} to be used for report desing.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRDesignDataset.java 3861 2010-06-04 11:17:45Z teodord $
+ * @version $Id: JRDesignDataset.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRDesignDataset extends JRBaseDataset
 {
@@ -99,41 +104,41 @@ public class JRDesignDataset extends JRBaseDataset
 	/**
 	 * Scriptlets mapped by name.
 	 */
-	protected Map scriptletsMap = new HashMap();
-	protected List scriptletsList = new ArrayList();
+	protected Map<String, JRScriptlet> scriptletsMap = new HashMap<String, JRScriptlet>();
+	protected List<JRScriptlet> scriptletsList = new ArrayList<JRScriptlet>();
 
 	/**
 	 * Parameters mapped by name.
 	 */
-	protected Map parametersMap = new HashMap();
-	protected List parametersList = new ArrayList();
+	protected Map<String, JRParameter> parametersMap = new HashMap<String, JRParameter>();
+	protected List<JRParameter> parametersList = new ArrayList<JRParameter>();
 
 	/**
 	 * Fields mapped by name.
 	 */
-	protected Map fieldsMap = new HashMap();
-	protected List fieldsList = new ArrayList();
+	protected Map<String, JRField> fieldsMap = new HashMap<String, JRField>();
+	protected List<JRField> fieldsList = new ArrayList<JRField>();
 
 
 	/**
 	 * Sort fields mapped by name.
 	 */
-	protected Map sortFieldsMap = new HashMap();
-	protected List sortFieldsList = new ArrayList();
+	protected Map<String, JRSortField> sortFieldsMap = new HashMap<String, JRSortField>();
+	protected List<JRSortField> sortFieldsList = new ArrayList<JRSortField>();
 
 
 	/**
 	 * Variables mapped by name.
 	 */
-	protected Map variablesMap = new HashMap();
-	protected List variablesList = new ArrayList();
+	protected Map<String, JRVariable> variablesMap = new HashMap<String, JRVariable>();
+	protected List<JRVariable> variablesList = new ArrayList<JRVariable>();
 
 
 	/**
 	 * Groups mapped by name.
 	 */
-	protected Map groupsMap = new HashMap();
-	protected List groupsList = new ArrayList();
+	protected Map<String, JRGroup> groupsMap = new HashMap<String, JRGroup>();
+	protected List<JRGroup> groupsList = new ArrayList<JRGroup>();
 
 	private class QueryLanguageChangeListener implements PropertyChangeListener, Serializable
 	{
@@ -152,6 +157,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 * An array containing the built-in parameters that can be found and used in any report dataset.
 	 */
 	private static final Object[] BUILT_IN_PARAMETERS = new Object[] { 
+		JRParameter.REPORT_CONTEXT, ReportContext.class, 
 		JRParameter.REPORT_PARAMETERS_MAP, java.util.Map.class, 
 		JRParameter.JASPER_REPORT, JasperReport.class, 
 		JRParameter.REPORT_CONNECTION, Connection.class,
@@ -165,7 +171,10 @@ public class JRDesignDataset extends JRBaseDataset
 		JRParameter.REPORT_CLASS_LOADER, ClassLoader.class,
 		JRParameter.REPORT_URL_HANDLER_FACTORY, URLStreamHandlerFactory.class,
 		JRParameter.REPORT_FILE_RESOLVER, FileResolver.class,
-		JRParameter.REPORT_TEMPLATES, Collection.class};
+		JRParameter.REPORT_TEMPLATES, Collection.class,
+		JRParameter.SORT_FIELDS, List.class,
+		JRParameter.FILTER, DatasetFilter.class
+		};
 
 
 	
@@ -219,11 +228,11 @@ public class JRDesignDataset extends JRBaseDataset
 		variable.setCalculation(CalculationEnum.COUNT);
 		variable.setSystemDefined(true);
 		expression = new JRDesignExpression();
-		expression.setValueClass(Integer.class);
+		//expression.setValueClass(Integer.class);
 		expression.setText("new java.lang.Integer(1)");
 		variable.setExpression(expression);
 		expression = new JRDesignExpression();
-		expression.setValueClass(Integer.class);
+		//expression.setValueClass(Integer.class);
 		expression.setText("new java.lang.Integer(0)");
 		variable.setInitialValueExpression(expression);
 		return variable;
@@ -241,7 +250,7 @@ public class JRDesignDataset extends JRBaseDataset
 		variable.setCalculation(CalculationEnum.SYSTEM);
 		variable.setSystemDefined(true);
 		expression = new JRDesignExpression();
-		expression.setValueClass(Integer.class);
+		//expression.setValueClass(Integer.class);
 		//expression.setText("($V{COLUMN_NUMBER} != null)?(Integer.valueOf($V{COLUMN_NUMBER}.intValue() + 1)):(Integer.valueOf(1))");
 		expression.setText("new java.lang.Integer(1)");
 		variable.setInitialValueExpression(expression);
@@ -258,7 +267,7 @@ public class JRDesignDataset extends JRBaseDataset
 		variable.setCalculation(CalculationEnum.SYSTEM);
 		variable.setSystemDefined(true);
 		JRDesignExpression expression = new JRDesignExpression();
-		expression.setValueClass(Integer.class);
+		//expression.setValueClass(Integer.class);
 		//expression.setText("($V{PAGE_NUMBER} != null)?(Integer.valueOf($V{PAGE_NUMBER}.intValue() + 1)):(Integer.valueOf(1))");
 		expression.setText("new java.lang.Integer(1)");
 		variable.setInitialValueExpression(expression);
@@ -276,11 +285,11 @@ public class JRDesignDataset extends JRBaseDataset
 		variable.setCalculation(CalculationEnum.COUNT);
 		variable.setSystemDefined(true);
 		expression = new JRDesignExpression();
-		expression.setValueClass(Integer.class);
+		//expression.setValueClass(Integer.class);
 		expression.setText("new java.lang.Integer(1)");
 		variable.setExpression(expression);
 		expression = new JRDesignExpression();
-		expression.setValueClass(Integer.class);
+		//expression.setValueClass(Integer.class);
 		expression.setText("new java.lang.Integer(0)");
 		variable.setInitialValueExpression(expression);
 		return variable;
@@ -294,9 +303,9 @@ public class JRDesignDataset extends JRBaseDataset
 			parameter.setName((String) parametersArray[i++]);
 			
 			Object parameterType = parametersArray[i];
-			if (parameterType instanceof Class)
+			if (parameterType instanceof Class<?>)
 			{
-				parameter.setValueClass((Class) parameterType);
+				parameter.setValueClass((Class<?>) parameterType);
 			}
 			else if (parameterType instanceof String)
 			{
@@ -330,11 +339,11 @@ public class JRDesignDataset extends JRBaseDataset
 		variable.setCalculation(CalculationEnum.COUNT);
 		variable.setSystemDefined(true);
 		JRDesignExpression expression = new JRDesignExpression();
-		expression.setValueClass(Integer.class);
+		//expression.setValueClass(Integer.class);
 		expression.setText("new java.lang.Integer(1)");
 		variable.setExpression(expression);
 		expression = new JRDesignExpression();
-		expression.setValueClass(Integer.class);
+		//expression.setValueClass(Integer.class);
 		expression.setText("new java.lang.Integer(0)");
 		variable.setInitialValueExpression(expression);
 		return variable;
@@ -370,7 +379,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 * 
 	 * @return list of {@link JRScriptlet JRScriptlet} objects
 	 */
-	public List getScriptletsList()
+	public List<JRScriptlet> getScriptletsList()
 	{
 		return scriptletsList;
 	}
@@ -381,7 +390,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 * 
 	 * @return {@link JRScriptlet JRScriptlet} objects indexed by name
 	 */
-	public Map getScriptletsMap()
+	public Map<String, JRScriptlet> getScriptletsMap()
 	{
 		return scriptletsMap;
 	}
@@ -437,7 +446,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 */
 	public JRScriptlet removeScriptlet(String scriptletName)
 	{
-		return removeScriptlet((JRScriptlet) scriptletsMap.get(scriptletName));
+		return removeScriptlet(scriptletsMap.get(scriptletName));
 	}
 
 	
@@ -481,7 +490,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 * 
 	 * @return list of {@link JRParameter JRParameter} objects
 	 */
-	public List getParametersList()
+	public List<JRParameter> getParametersList()
 	{
 		return parametersList;
 	}
@@ -492,7 +501,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 * 
 	 * @return {@link JRParameter JRParameter} objects indexed by name
 	 */
-	public Map getParametersMap()
+	public Map<String, JRParameter> getParametersMap()
 	{
 		return parametersMap;
 	}
@@ -539,7 +548,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 */
 	public JRParameter removeParameter(String parameterName)
 	{
-		return removeParameter((JRParameter) parametersMap.get(parameterName));
+		return removeParameter(parametersMap.get(parameterName));
 	}
 
 	
@@ -574,7 +583,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 */
 	public void setQuery(JRDesignQuery query)
 	{
-		Object old = query;
+		Object old = this.query;
 		String oldLanguage = null;
 		if (this.query != null)
 		{
@@ -632,7 +641,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 * 
 	 * @return list of {@link JRField JRField} objects
 	 */
-	public List getFieldsList()
+	public List<JRField> getFieldsList()
 	{
 		return fieldsList;
 	}
@@ -643,7 +652,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 * 
 	 * @return {@link JRField JRField} objects indexed by name
 	 */
-	public Map getFieldsMap()
+	public Map<String, JRField> getFieldsMap()
 	{
 		return fieldsMap;
 	}
@@ -690,7 +699,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 */
 	public JRField removeField(String fieldName)
 	{
-		return removeField((JRField) fieldsMap.get(fieldName));
+		return removeField(fieldsMap.get(fieldName));
 	}
 
 	
@@ -733,7 +742,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 * 
 	 * @return list of {@link JRSortField JRSortField} objects
 	 */
-	public List getSortFieldsList()
+	public List<JRSortField> getSortFieldsList()
 	{
 		return sortFieldsList;
 	}
@@ -760,13 +769,14 @@ public class JRDesignDataset extends JRBaseDataset
 	 */
 	public void addSortField(int index, JRSortField sortField) throws JRException
 	{
-		if (sortFieldsMap.containsKey(sortField.getName()))
+		String sortFieldKey = getSortFieldKey(sortField);
+		if (sortFieldsMap.containsKey(sortFieldKey))
 		{
 			throw new JRException("Duplicate declaration of sort field : " + sortField.getName());
 		}
 
 		sortFieldsList.add(index, sortField);
-		sortFieldsMap.put(sortField.getName(), sortField);
+		sortFieldsMap.put(sortFieldKey, sortField);
 		
 		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_SORT_FIELDS, sortField, index);
 	}
@@ -777,10 +787,11 @@ public class JRDesignDataset extends JRBaseDataset
 	 * 
 	 * @param fieldName the field name
 	 * @return the removed sort field, or <code>null</code> if the sort field was not found
+	 * @deprecated To be removed.
 	 */
 	public JRSortField removeSortField(String fieldName)
 	{
-		return removeSortField((JRSortField) sortFieldsMap.get(fieldName));
+		return removeSortField(sortFieldsMap.get(getSortFieldKey(new JRDesignSortField(fieldName, SortFieldTypeEnum.FIELD, SortOrderEnum.ASCENDING))));
 	}
 
 	
@@ -798,7 +809,7 @@ public class JRDesignDataset extends JRBaseDataset
 			if (idx >= 0)
 			{
 				sortFieldsList.remove(idx);
-				sortFieldsMap.remove(sortField.getName());
+				sortFieldsMap.remove(getSortFieldKey(sortField));
 				getEventSupport().fireCollectionElementRemovedEvent(PROPERTY_SORT_FIELDS, sortField, idx);
 			}
 		}
@@ -823,7 +834,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 * @return list of {@link JRVariable JRVariable} objects
 	 */
 	
-	public List getVariablesList()
+	public List<JRVariable> getVariablesList()
 	{
 		return variablesList;
 	}
@@ -834,7 +845,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 * 
 	 * @return {@link JRVariable JRVariable} objects indexed by name
 	 */
-	public Map getVariablesMap()
+	public Map<String, JRVariable> getVariablesMap()
 	{
 		return variablesMap;
 	}
@@ -898,10 +909,10 @@ public class JRDesignDataset extends JRBaseDataset
 		if (system)
 		{
 			// add the variable before the first non-system variable
-			ListIterator it = variablesList.listIterator();
+			ListIterator<JRVariable> it = variablesList.listIterator();
 			while (it.hasNext())
 			{
-				JRVariable var = (JRVariable) it.next();
+				JRVariable var = it.next();
 				if (!var.isSystemDefined())
 				{
 					it.previous();
@@ -930,7 +941,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 */
 	public JRVariable removeVariable(String variableName)
 	{
-		return removeVariable((JRVariable) variablesMap.get(variableName));
+		return removeVariable(variablesMap.get(variableName));
 	}
 
 	
@@ -972,7 +983,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 * 
 	 * @return list of {@link JRGroup JRGroup} objects
 	 */
-	public List getGroupsList()
+	public List<JRGroup> getGroupsList()
 	{
 		return groupsList;
 	}
@@ -983,7 +994,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 * 
 	 * @return {@link JRGroup JRGroup} objects indexed by name
 	 */
-	public Map getGroupsMap()
+	public Map<String, JRGroup> getGroupsMap()
 	{
 		return groupsMap;
 	}
@@ -1023,11 +1034,11 @@ public class JRDesignDataset extends JRBaseDataset
 		countVariable.setCalculation(CalculationEnum.COUNT);
 		countVariable.setSystemDefined(true);
 		JRDesignExpression expression = new JRDesignExpression();
-		expression.setValueClass(Integer.class);
+		//expression.setValueClass(Integer.class);
 		expression.setText("new java.lang.Integer(1)");
 		countVariable.setExpression(expression);
 		expression = new JRDesignExpression();
-		expression.setValueClass(Integer.class);
+		//expression.setValueClass(Integer.class);
 		expression.setText("new java.lang.Integer(0)");
 		countVariable.setInitialValueExpression(expression);
 
@@ -1051,7 +1062,7 @@ public class JRDesignDataset extends JRBaseDataset
 	 */
 	public JRGroup removeGroup(String groupName)
 	{
-		return removeGroup((JRGroup) groupsMap.get(groupName));
+		return removeGroup(groupsMap.get(groupName));
 	}
 
 	
@@ -1126,12 +1137,12 @@ public class JRDesignDataset extends JRBaseDataset
 	
 	private void sortSystemParamsFirst()
 	{
-		Collections.sort(parametersList, new Comparator()
+		Collections.sort(parametersList, new Comparator<JRParameter>()
 				{
-					public int compare(Object o1, Object o2)
+					public int compare(JRParameter p1, JRParameter p2)
 					{
-						JRParameter p1 = (JRParameter) o1;
-						JRParameter p2 = (JRParameter) o2;
+//						JRParameter p1 = (JRParameter) o1;
+//						JRParameter p2 = (JRParameter) o2;
 						boolean s1 = p1.isSystemDefined();
 						boolean s2 = p2.isSystemDefined();
 						
@@ -1145,7 +1156,7 @@ public class JRDesignDataset extends JRBaseDataset
 		for (int i = 0; i < builtinParameters.length; i += 2)
 		{
 			String parameterName = (String) builtinParameters[i];
-			JRParameter parameter = (JRParameter) parametersMap.get(parameterName);
+			JRParameter parameter = parametersMap.get(parameterName);
 			if (parameter.isSystemDefined())
 			{
 				removeParameter(parameter);
@@ -1184,6 +1195,15 @@ public class JRDesignDataset extends JRBaseDataset
 	}
 
 
+	/**
+	 * 
+	 */
+	private String getSortFieldKey(JRSortField sortField)
+	{
+		return sortField.getName() + "|" + sortField.getType().getName();
+	}
+
+	
 	/**
 	 * 
 	 */
@@ -1193,11 +1213,11 @@ public class JRDesignDataset extends JRBaseDataset
 		
 		if (sortFieldsMap == null)
 		{
-			sortFieldsMap = new HashMap();
+			sortFieldsMap = new HashMap<String, JRSortField>();
 		}
 		if (sortFieldsList == null)
 		{
-			sortFieldsList = new ArrayList();
+			sortFieldsList = new ArrayList<JRSortField>();
 		}
 	}
 
@@ -1210,12 +1230,11 @@ public class JRDesignDataset extends JRBaseDataset
 		
 		if (parametersList != null)
 		{
-			clone.parametersList = new ArrayList(parametersList.size());
-			clone.parametersMap = new HashMap(parametersList.size());
+			clone.parametersList = new ArrayList<JRParameter>(parametersList.size());
+			clone.parametersMap = new HashMap<String, JRParameter>(parametersList.size());
 			for(int i = 0; i < parametersList.size(); i++)
 			{
-				JRParameter parameter = 
-					(JRParameter)((JRParameter)parametersList.get(i)).clone();
+				JRParameter parameter = JRCloneUtils.nullSafeClone(parametersList.get(i));
 				clone.parametersList.add(parameter);
 				clone.parametersMap.put(parameter.getName(), parameter);
 			}
@@ -1223,12 +1242,11 @@ public class JRDesignDataset extends JRBaseDataset
 		
 		if (fieldsList != null)
 		{
-			clone.fieldsList = new ArrayList(fieldsList.size());
-			clone.fieldsMap = new HashMap(fieldsList.size());
+			clone.fieldsList = new ArrayList<JRField>(fieldsList.size());
+			clone.fieldsMap = new HashMap<String, JRField>(fieldsList.size());
 			for(int i = 0; i < fieldsList.size(); i++)
 			{
-				JRField field = 
-					(JRField)((JRField)fieldsList.get(i)).clone();
+				JRField field = JRCloneUtils.nullSafeClone(fieldsList.get(i));
 				clone.fieldsList.add(field);
 				clone.fieldsMap.put(field.getName(), field);
 			}
@@ -1236,25 +1254,23 @@ public class JRDesignDataset extends JRBaseDataset
 		
 		if (sortFieldsList != null)
 		{
-			clone.sortFieldsList = new ArrayList(sortFieldsList.size());
-			clone.sortFieldsMap = new HashMap(sortFieldsList.size());
+			clone.sortFieldsList = new ArrayList<JRSortField>(sortFieldsList.size());
+			clone.sortFieldsMap = new HashMap<String, JRSortField>(sortFieldsList.size());
 			for(int i = 0; i < sortFieldsList.size(); i++)
 			{
-				JRSortField sortField = 
-					(JRSortField)((JRSortField)sortFieldsList.get(i)).clone();
+				JRSortField sortField = JRCloneUtils.nullSafeClone(sortFieldsList.get(i));
 				clone.sortFieldsList.add(sortField);
-				clone.sortFieldsMap.put(sortField.getName(), sortField);
+				clone.sortFieldsMap.put(getSortFieldKey(sortField), sortField);
 			}
 		}
 		
 		if (variablesList != null)
 		{
-			clone.variablesList = new ArrayList(variablesList.size());
-			clone.variablesMap = new HashMap(variablesList.size());
+			clone.variablesList = new ArrayList<JRVariable>(variablesList.size());
+			clone.variablesMap = new HashMap<String, JRVariable>(variablesList.size());
 			for(int i = 0; i < variablesList.size(); i++)
 			{
-				JRVariable variable = 
-					(JRVariable)((JRVariable)variablesList.get(i)).clone();
+				JRVariable variable = JRCloneUtils.nullSafeClone(variablesList.get(i));
 				clone.variablesList.add(variable);
 				clone.variablesMap.put(variable.getName(), variable);
 			}
@@ -1262,12 +1278,11 @@ public class JRDesignDataset extends JRBaseDataset
 		
 		if (groupsList != null)
 		{
-			clone.groupsList = new ArrayList(groupsList.size());
-			clone.groupsMap = new HashMap(groupsList.size());
+			clone.groupsList = new ArrayList<JRGroup>(groupsList.size());
+			clone.groupsMap = new HashMap<String, JRGroup>(groupsList.size());
 			for(int i = 0; i < groupsList.size(); i++)
 			{
-				JRGroup group = 
-					(JRGroup)((JRGroup)groupsList.get(i)).clone();
+				JRGroup group = JRCloneUtils.nullSafeClone(groupsList.get(i));
 				clone.groupsList.add(group);
 				clone.groupsMap.put(group.getName(), group);
 			}
