@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -32,7 +32,7 @@ import net.sf.jasperreports.engine.design.events.JRPropertyChangeSupport;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRDesignElementGroup.java 3861 2010-06-04 11:17:45Z teodord $
+ * @version $Id: JRDesignElementGroup.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRDesignElementGroup extends JRBaseElementGroup implements JRChangeEventsSupport
 {
@@ -130,6 +130,15 @@ public class JRDesignElementGroup extends JRBaseElementGroup implements JRChange
 		return elemGrp;
 	}
 
+	/**
+	 * 
+	 */
+	public Object clone()
+	{
+		JRDesignElementGroup clone = (JRDesignElementGroup)super.clone();
+		clone.eventSupport = null;
+		return clone;
+	}
 	
 	private transient JRPropertyChangeSupport eventSupport;
 	
