@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -44,7 +44,7 @@ import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
  * which should be used for report design purposes. 
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRDesignHyperlink.java 3502 2010-03-04 11:05:10Z teodord $
+ * @version $Id: JRDesignHyperlink.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRDesignHyperlink extends JRBaseHyperlink implements JRChangeEventsSupport
 {
@@ -67,20 +67,11 @@ public class JRDesignHyperlink extends JRBaseHyperlink implements JRChangeEvents
 	
 	public static final String PROPERTY_HYPERLINK_PARAMETERS = "hyperlinkParameters";
 	
-	private List hyperlinkParameters;
+	private List<JRHyperlinkParameter> hyperlinkParameters;
 	
 	public JRDesignHyperlink()
 	{
-		hyperlinkParameters = new ArrayList();
-	}
-
-	
-	/**
-	 * @deprecated Replaced by {@link #setHyperlinkType(HyperlinkTypeEnum)}.
-	 */
-	public void setHyperlinkType(byte hyperlinkType)
-	{
-		setHyperlinkType(HyperlinkTypeEnum.getByValue(hyperlinkType));
+		hyperlinkParameters = new ArrayList<JRHyperlinkParameter>();
 	}
 
 	
@@ -96,15 +87,6 @@ public class JRDesignHyperlink extends JRBaseHyperlink implements JRChangeEvents
 	}
 
 	
-	/**
-	 * @deprecated Replaced by {@link #setHyperlinkTarget(HyperlinkTargetEnum)}.
-	 */
-	public void setHyperlinkTarget(byte hyperlinkTarget)
-	{
-		setHyperlinkTarget(HyperlinkTargetEnum.getByValue(hyperlinkTarget));
-	}
-
-
 	/**
 	 * Sets the hyperlink target.
 	 * 
@@ -126,9 +108,9 @@ public class JRDesignHyperlink extends JRBaseHyperlink implements JRChangeEvents
 	 * or the referred document location.
 	 * <p>
 	 * This expression is used when the hyperlink type is
-	 * {@link JRHyperlink#HYPERLINK_TYPE_REFERENCE JRHyperlink.HYPERLINK_TYPE_REFERENCE},
-	 * {@link JRHyperlink#HYPERLINK_TYPE_REMOTE_ANCHOR JRHyperlink.HYPERLINK_TYPE_REMOTE_ANCHOR} or
-	 * {@link JRHyperlink#HYPERLINK_TYPE_REMOTE_PAGE JRHyperlink.HYPERLINK_TYPE_REMOTE_PAGE}.
+	 * {@link HyperlinkTypeEnum#REFERENCE HyperlinkTypeEnum.REFERENCE},
+	 * {@link HyperlinkTypeEnum#REMOTE_ANCHOR HyperlinkTypeEnum.REMOTE_ANCHOR} or
+	 * {@link HyperlinkTypeEnum#REMOTE_PAGE HyperlinkTypeEnum.REMOTE_PAGE}.
 	 * The type of the expression should be <code>java.lang.String</code>
 	 * </p>
 	 * 
@@ -147,8 +129,8 @@ public class JRDesignHyperlink extends JRBaseHyperlink implements JRChangeEvents
 	 * Sets the expression that will generate the referred anchor.
 	 * <p>
 	 * This expression is used when the hyperlink type is
-	 * {@link JRHyperlink#HYPERLINK_TYPE_LOCAL_ANCHOR JRHyperlink.HYPERLINK_TYPE_LOCAL_ANCHOR} or
-	 * {@link JRHyperlink#HYPERLINK_TYPE_REMOTE_ANCHOR JRHyperlink.HYPERLINK_TYPE_REMOTE_ANCHOR}.
+	 * {@link HyperlinkTypeEnum#LOCAL_ANCHOR HyperlinkTypeEnum.LOCAL_ANCHOR} or
+	 * {@link HyperlinkTypeEnum#REMOTE_ANCHOR HyperlinkTypeEnum.REMOTE_ANCHOR}.
 	 * The type of the expression should be <code>java.lang.String</code>
 	 * </p>
 	 * 
@@ -167,8 +149,8 @@ public class JRDesignHyperlink extends JRBaseHyperlink implements JRChangeEvents
 	 * Sets the expression that will generate the referred page.
 	 * <p>
 	 * This expression is used when the hyperlink type is
-	 * {@link JRHyperlink#HYPERLINK_TYPE_LOCAL_PAGE JRHyperlink.HYPERLINK_TYPE_LOCAL_PAGE} or
-	 * {@link JRHyperlink#HYPERLINK_TYPE_REMOTE_PAGE JRHyperlink.HYPERLINK_TYPE_REMOTE_PAGE}.
+	 * {@link HyperlinkTypeEnum#LOCAL_PAGE HyperlinkTypeEnum.LOCAL_PAGE} or
+	 * {@link HyperlinkTypeEnum#REMOTE_PAGE HyperlinkTypeEnum.REMOTE_PAGE}.
 	 * The type of the expression should be <code>java.lang.Integer</code>
 	 * </p>
 	 * 
@@ -237,7 +219,7 @@ public class JRDesignHyperlink extends JRBaseHyperlink implements JRChangeEvents
 	 * 
 	 * @return the list of custom hyperlink parameters
 	 */
-	public List getHyperlinkParametersList()
+	public List<JRHyperlinkParameter> getHyperlinkParametersList()
 	{
 		return hyperlinkParameters;
 	}
@@ -284,9 +266,9 @@ public class JRDesignHyperlink extends JRBaseHyperlink implements JRChangeEvents
 	 */
 	public void removeHyperlinkParameter(String parameterName)
 	{
-		for (ListIterator it = hyperlinkParameters.listIterator(); it.hasNext();)
+		for (ListIterator<JRHyperlinkParameter> it = hyperlinkParameters.listIterator(); it.hasNext();)
 		{
-			JRHyperlinkParameter parameter = (JRHyperlinkParameter) it.next();
+			JRHyperlinkParameter parameter = it.next();
 			if (parameter.getName() != null && parameter.getName().equals(parameterName))
 			{
 				it.remove();
@@ -311,6 +293,16 @@ public class JRDesignHyperlink extends JRBaseHyperlink implements JRChangeEvents
 		getEventSupport().firePropertyChange(PROPERTY_HYPERLINK_TARGET, old, this.hyperlinkTooltipExpression);
 	}
 	
+	/**
+	 * 
+	 */
+	public Object clone()
+	{
+		JRDesignHyperlink clone = (JRDesignHyperlink)super.clone();
+		clone.eventSupport = null;
+		return clone;
+	}
+
 	private transient JRPropertyChangeSupport eventSupport;
 	
 	public JRPropertyChangeSupport getEventSupport()
