@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -40,12 +40,13 @@ import net.sf.jasperreports.engine.JRSubreportReturnValue;
 import net.sf.jasperreports.engine.JRVisitor;
 import net.sf.jasperreports.engine.base.JRBaseSubreport;
 import net.sf.jasperreports.engine.type.ModeEnum;
+import net.sf.jasperreports.engine.util.JRCloneUtils;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRDesignSubreport.java 3872 2010-06-30 16:42:48Z lucianc $
+ * @version $Id: JRDesignSubreport.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRDesignSubreport extends JRDesignElement implements JRSubreport
 {
@@ -71,27 +72,27 @@ public class JRDesignSubreport extends JRDesignElement implements JRSubreport
 	/**
 	 *
 	 */
-	protected Boolean isUsingCache = null;
+	protected Boolean isUsingCache;
 
 	private Boolean runToBottom;
 
 	/**
 	 *
 	 */
-	protected Map parametersMap = new LinkedHashMap();
+	protected Map<String, JRSubreportParameter> parametersMap = new LinkedHashMap<String, JRSubreportParameter>();
 	
 	/**
 	 * Values to be copied from the subreport into the master report.
 	 */
-	protected List returnValues = new ArrayList();
+	protected List<JRSubreportReturnValue> returnValues = new ArrayList<JRSubreportReturnValue>();
 
 	/**
 	 *
 	 */
-	protected JRExpression parametersMapExpression = null;
-	protected JRExpression connectionExpression = null;
-	protected JRExpression dataSourceExpression = null;
-	protected JRExpression expression = null;
+	protected JRExpression parametersMapExpression;
+	protected JRExpression connectionExpression;
+	protected JRExpression dataSourceExpression;
+	protected JRExpression expression;
 
 
 	/**
@@ -113,7 +114,7 @@ public class JRDesignSubreport extends JRDesignElement implements JRSubreport
 
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getUsingCache()}.
 	 */
 	public boolean isUsingCache()
 	{
@@ -129,14 +130,6 @@ public class JRDesignSubreport extends JRDesignElement implements JRSubreport
 		return isUsingCache.booleanValue();
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setUsingCache(Boolean)}.
-	 */
-	public void setUsingCache(boolean isUsingCache)
-	{
-		setUsingCache(isUsingCache ? Boolean.TRUE : Boolean.FALSE);
-	}
-
 	/**
 	 *
 	 */
@@ -170,7 +163,7 @@ public class JRDesignSubreport extends JRDesignElement implements JRSubreport
 	/**
 	 *
 	 */
-	public Map getParametersMap()
+	public Map<String, JRSubreportParameter> getParametersMap()
 	{
 		return this.parametersMap;
 	}
@@ -195,7 +188,7 @@ public class JRDesignSubreport extends JRDesignElement implements JRSubreport
 	 */
 	public JRSubreportParameter removeParameter(String name)
 	{
-		JRSubreportParameter removed = (JRSubreportParameter)this.parametersMap.remove(name);
+		JRSubreportParameter removed = this.parametersMap.remove(name);
 		if (removed != null)
 		{
 			getEventSupport().fireCollectionElementRemovedEvent(PROPERTY_PARAMETERS, removed, -1);
@@ -315,7 +308,7 @@ public class JRDesignSubreport extends JRDesignElement implements JRSubreport
 	 * 
 	 * @return list of {@link JRSubreportReturnValue JRSubreportReturnValue} objects
 	 */
-	public List getReturnValuesList()
+	public List<JRSubreportReturnValue> getReturnValuesList()
 	{
 		return returnValues;
 	}
@@ -340,12 +333,24 @@ public class JRDesignSubreport extends JRDesignElement implements JRSubreport
 	}
 
 
+	/**
+	 * @deprecated Replaced by {@link #getUsingCache()}.
+	 */
 	public Boolean isOwnUsingCache()
 	{
 		return isUsingCache;
 	}
 
 
+	/**
+	 *
+	 */
+	public Boolean getUsingCache()
+	{
+		return isUsingCache;
+	}
+
+
 	public void setUsingCache(Boolean isUsingCache)
 	{
 		Object old = this.isUsingCache;
@@ -377,40 +382,18 @@ public class JRDesignSubreport extends JRDesignElement implements JRSubreport
 		
 		if (parametersMap != null)
 		{
-			clone.parametersMap = new LinkedHashMap();
-			for(Iterator it = parametersMap.keySet().iterator(); it.hasNext();)
+			clone.parametersMap = new LinkedHashMap<String, JRSubreportParameter>();
+			for(Iterator<String> it = parametersMap.keySet().iterator(); it.hasNext();)
 			{
-				String key = (String)it.next();
-				JRSubreportParameter parameter = (JRSubreportParameter)parametersMap.get(key);
-				clone.parametersMap.put(key, parameter.clone());
+				clone.parametersMap.put(key, JRCloneUtils.nullSafeClone(parametersMap.get(it.next())));
 			}
 		}
 
-		if (returnValues != null)
-		{
-			clone.returnValues = new ArrayList(returnValues.size());
-			for(int i = 0; i < returnValues.size(); i++)
-			{
-				clone.returnValues.add(((JRSubreportReturnValue)returnValues.get(i)).clone());
-			}
-		}
-
-		if (parametersMapExpression != null)
-		{
-			clone.parametersMapExpression = (JRExpression)parametersMapExpression.clone();
-		}
-		if (connectionExpression != null)
-		{
-			clone.connectionExpression = (JRExpression)connectionExpression.clone();
-		}
-		if (dataSourceExpression != null)
-		{
-			clone.dataSourceExpression = (JRExpression)dataSourceExpression.clone();
-		}
-		if (expression != null)
-		{
-			clone.expression = (JRExpression)expression.clone();
-		}
+		clone.returnValues = JRCloneUtils.cloneList(returnValues);
+		clone.parametersMapExpression = JRCloneUtils.nullSafeClone(parametersMapExpression);
+		clone.connectionExpression = JRCloneUtils.nullSafeClone(connectionExpression);
+		clone.dataSourceExpression = JRCloneUtils.nullSafeClone(dataSourceExpression);
+		clone.expression = JRCloneUtils.nullSafeClone(expression);
 
 		return clone;
 	}
