@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -34,7 +34,7 @@ import net.sf.jasperreports.engine.type.CalculationEnum;
  * to be used for report desing purposes.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRDesignSubreportReturnValue.java 3584 2010-03-12 12:43:25Z shertage $
+ * @version $Id: JRDesignSubreportReturnValue.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRDesignSubreportReturnValue extends JRBaseSubreportReturnValue implements JRChangeEventsSupport
 {
@@ -78,19 +78,11 @@ public class JRDesignSubreportReturnValue extends JRBaseSubreportReturnValue imp
 		getEventSupport().firePropertyChange(PROPERTY_TO_VARIABLE, old, this.toVariable);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setCalculation(CalculationEnum)}
-	 */
-	public void setCalculation(byte calculation)
-	{
-		setCalculation(CalculationEnum.getByValue(calculation));
-	}
-	
 	/**
 	 * Sets the calculation type.
 	 * 
 	 * @param calculationValue the calculation type
-	 * @see net.sf.jasperreports.engine.JRSubreportReturnValue#getCalculation()
+	 * @see net.sf.jasperreports.engine.JRSubreportReturnValue#getCalculationValue()
 	 */
 	public void setCalculation(CalculationEnum calculationValue)
 	{
@@ -112,6 +104,16 @@ public class JRDesignSubreportReturnValue extends JRBaseSubreportReturnValue imp
 		getEventSupport().firePropertyChange(PROPERTY_INCREMENTER_FACTORY_CLASS_NAME, old, this.incrementerFactoryClassName);
 	}
 	
+	/**
+	 * 
+	 */
+	public Object clone()
+	{
+		JRDesignSubreportReturnValue clone = (JRDesignSubreportReturnValue)super.clone();
+		clone.eventSupport = null;
+		return clone;
+	}
+
 	private transient JRPropertyChangeSupport eventSupport;
 	
 	public JRPropertyChangeSupport getEventSupport()
