@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -36,7 +36,7 @@ import net.sf.jasperreports.engine.type.ResetTypeEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRDesignVariable.java 3510 2010-03-05 10:38:28Z shertage $
+ * @version $Id: JRDesignVariable.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRDesignVariable extends JRBaseVariable implements JRChangeEventsSupport
 {
@@ -82,7 +82,7 @@ public class JRDesignVariable extends JRBaseVariable implements JRChangeEventsSu
 	/**
 	 *
 	 */
-	public void setValueClass(Class clazz)
+	public void setValueClass(Class<?> clazz)
 	{
 		setValueClassName(clazz.getName());
 	}
@@ -102,7 +102,7 @@ public class JRDesignVariable extends JRBaseVariable implements JRChangeEventsSu
 	/**
 	 *
 	 */
-	public void setIncrementerFactoryClass(Class clazz)
+	public void setIncrementerFactoryClass(Class<?> clazz)
 	{
 		setIncrementerFactoryClassName(clazz.getName());
 	}
@@ -119,14 +119,6 @@ public class JRDesignVariable extends JRBaseVariable implements JRChangeEventsSu
 		getEventSupport().firePropertyChange(PROPERTY_INCREMENTER_FACTORY_CLASS_NAME, old, this.incrementerFactoryClassName);
 	}
 		
-	/**
-	 *  @deprecated Replaced by {@link #setResetType(ResetTypeEnum)}
-	 */
-	public void setResetType(byte resetType)
-	{
-		setResetType(ResetTypeEnum.getByValue(resetType));
-	}
-		
 	/**
 	 *
 	 */
@@ -137,14 +129,6 @@ public class JRDesignVariable extends JRBaseVariable implements JRChangeEventsSu
 		getEventSupport().firePropertyChange(PROPERTY_RESET_TYPE, old, this.resetTypeValue);
 	}
 		
-	/**
-	 *  @deprecated Replaced by {@link #setIncrementType(IncrementTypeEnum)}
-	 */
-	public void setIncrementType(byte incrementType)
-	{
-		setIncrementType(IncrementTypeEnum.getByValue(incrementType));
-	}
-		
 	/**
 	 *
 	 */
@@ -155,14 +139,6 @@ public class JRDesignVariable extends JRBaseVariable implements JRChangeEventsSu
 		getEventSupport().firePropertyChange(PROPERTY_INCREMENT_TYPE, old, this.incrementTypeValue);
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #setCalculation(CalculationEnum)}
-	 */
-	public void setCalculation(byte calculation)
-	{
-		setCalculation(CalculationEnum.getByValue(calculation));
-	}
-
 	/**
 	 *
 	 */
@@ -223,6 +199,16 @@ public class JRDesignVariable extends JRBaseVariable implements JRChangeEventsSu
 		getEventSupport().firePropertyChange(PROPERTY_INCREMENT_GROUP, old, this.incrementGroup);
 	}
 	
+	/**
+	 * 
+	 */
+	public Object clone()
+	{
+		JRDesignVariable clone = (JRDesignVariable)super.clone();
+		clone.eventSupport = null;
+		return clone;
+	}
+
 	private transient JRPropertyChangeSupport eventSupport;
 	
 	public JRPropertyChangeSupport getEventSupport()
