@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -43,7 +43,6 @@ import net.sf.jasperreports.engine.JRField;
 import net.sf.jasperreports.engine.JRGroup;
 import net.sf.jasperreports.engine.JROrigin;
 import net.sf.jasperreports.engine.JRParameter;
-import net.sf.jasperreports.engine.JRReportFont;
 import net.sf.jasperreports.engine.JRReportTemplate;
 import net.sf.jasperreports.engine.JRScriptlet;
 import net.sf.jasperreports.engine.JRSection;
@@ -52,6 +51,10 @@ import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.JRVariable;
 import net.sf.jasperreports.engine.base.JRBaseReport;
 import net.sf.jasperreports.engine.design.events.PropagationChangeListener;
+import net.sf.jasperreports.engine.type.BandTypeEnum;
+import net.sf.jasperreports.engine.type.OrientationEnum;
+import net.sf.jasperreports.engine.type.PrintOrderEnum;
+import net.sf.jasperreports.engine.type.RunDirectionEnum;
 import net.sf.jasperreports.engine.util.JRElementsVisitor;
 import net.sf.jasperreports.engine.util.JRVisitorSupport;
 
@@ -66,7 +69,7 @@ import net.sf.jasperreports.engine.util.JRVisitorSupport;
  *
  * @see net.sf.jasperreports.engine.xml.JRXmlLoader
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JasperDesign.java 3132 2009-10-20 14:42:38Z teodord $
+ * @version $Id: JasperDesign.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JasperDesign extends JRBaseReport
 {
@@ -131,6 +134,8 @@ public class JasperDesign extends JRBaseReport
 
 	public static final String PROPERTY_PRINT_ORDER = "printOrder";
 
+	public static final String PROPERTY_COLUMN_DIRECTION = "columnDirection";
+
 	public static final String PROPERTY_RIGHT_MARGIN = "rightMargin";
 
 	public static final String PROPERTY_STYLES = "styles";
@@ -152,12 +157,10 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 * Report templates.
 	 */
-	private List templateList = new ArrayList();
+	private List<JRReportTemplate> templateList = new ArrayList<JRReportTemplate>();
 
-	private Map fontsMap = new HashMap();
-	private List fontsList = new ArrayList();
-	private Map stylesMap = new HashMap();
-	private List stylesList = new ArrayList();
+	private Map<String, JRStyle> stylesMap = new HashMap<String, JRStyle>();
+	private List<JRStyle> stylesList = new ArrayList<JRStyle>();
 
 	/**
 	 * Main report dataset.
@@ -167,8 +170,8 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 * Report sub datasets indexed by name.
 	 */
-	private Map datasetMap = new HashMap();
-	private List datasetList = new ArrayList();
+	private Map<String, JRDataset> datasetMap = new HashMap<String, JRDataset>();
+	private List<JRDataset> datasetList = new ArrayList<JRDataset>();
 
 	/**
 	 * Constructs a JasperDesign object and fills it with the default variables and parameters.
@@ -177,7 +180,7 @@ public class JasperDesign extends JRBaseReport
 	{
 		setMainDataset(new JRDesignDataset(true));
 		
-		detailSection = new JRDesignSection(new JROrigin(JROrigin.DETAIL));
+		detailSection = new JRDesignSection(new JROrigin(BandTypeEnum.DETAIL));
 	}
 
 
@@ -218,14 +221,25 @@ public class JasperDesign extends JRBaseReport
 
 	/**
 	 * Sets the print order. In case of multiple column reports, the engine can perform vertical or horizontal fill.
-	 * @see net.sf.jasperreports.engine.JRReport PRINT_ORDER_VERTICAL,
-	 * @see net.sf.jasperreports.engine.JRReport PRINT_ORDER_HORIZONTAL
+	 * @see net.sf.jasperreports.engine.type.PrintOrderEnum VERTICAL,
+	 * @see net.sf.jasperreports.engine.type.PrintOrderEnum HORIZONTAL
 	 */
-	public void setPrintOrder(byte printOrder)
+	public void setPrintOrder(PrintOrderEnum printOrderValue)
 	{
-		int old = this.printOrder;
-		this.printOrder = printOrder;
-		getEventSupport().firePropertyChange(PROPERTY_PRINT_ORDER, old, this.printOrder);
+		Object old = this.printOrderValue;
+		this.printOrderValue = printOrderValue;
+		getEventSupport().firePropertyChange(PROPERTY_PRINT_ORDER, old, this.printOrderValue);
+	}
+
+
+	/**
+	 * Sets the column direction.
+	 */
+	public void setColumnDirection(RunDirectionEnum columnDirection)
+	{
+		Object old = this.columnDirection;
+		this.columnDirection = columnDirection;
+		getEventSupport().firePropertyChange(PROPERTY_COLUMN_DIRECTION, old, this.columnDirection);
 	}
 
 
@@ -256,11 +270,11 @@ public class JasperDesign extends JRBaseReport
 	 * @see net.sf.jasperreports.engine.JRReport ORIENTATION_PORTRAIT,
 	 * @see net.sf.jasperreports.engine.JRReport ORIENTATION_LANDSCAPE
 	 */
-	public void setOrientation(byte orientation)
+	public void setOrientation(OrientationEnum orientationValue)
 	{
-		int old = this.orientation;
-		this.orientation = orientation;
-		getEventSupport().firePropertyChange(PROPERTY_ORIENTATION, old, this.orientation);
+		Object old = this.orientationValue;
+		this.orientationValue = orientationValue;
+		getEventSupport().firePropertyChange(PROPERTY_ORIENTATION, old, this.orientationValue);
 	}
 
 
@@ -269,7 +283,7 @@ public class JasperDesign extends JRBaseReport
 	 */
 	public void setColumnWidth(int columnWidth)
 	{
-		int old = columnWidth;
+		int old = this.columnWidth;
 		this.columnWidth = columnWidth;
 		getEventSupport().firePropertyChange(PROPERTY_COLUMN_WIDTH, old, this.columnWidth);
 	}
@@ -337,7 +351,7 @@ public class JasperDesign extends JRBaseReport
 	{
 		Object old = this.background;
 		this.background = background;
-		setBandOrigin(this.background, JROrigin.BACKGROUND);
+		setBandOrigin(this.background, BandTypeEnum.BACKGROUND);
 		getEventSupport().firePropertyChange(PROPERTY_BACKGROUND, old, this.background);
 	}
 
@@ -349,7 +363,7 @@ public class JasperDesign extends JRBaseReport
 	{
 		Object old = this.title;
 		this.title = title;
-		setBandOrigin(this.title, JROrigin.TITLE);
+		setBandOrigin(this.title, BandTypeEnum.TITLE);
 		getEventSupport().firePropertyChange(PROPERTY_TITLE, old, this.title);
 	}
 
@@ -375,7 +389,7 @@ public class JasperDesign extends JRBaseReport
 	{
 		Object old = this.summary;
 		this.summary = summary;
-		setBandOrigin(this.summary, JROrigin.SUMMARY);
+		setBandOrigin(this.summary, BandTypeEnum.SUMMARY);
 		getEventSupport().firePropertyChange(PROPERTY_SUMMARY, old, this.summary);
 	}
 
@@ -386,7 +400,7 @@ public class JasperDesign extends JRBaseReport
 	{
 		Object old = this.noData;
 		this.noData = noData;
-		setBandOrigin(this.noData, JROrigin.NO_DATA);
+		setBandOrigin(this.noData, BandTypeEnum.NO_DATA);
 		getEventSupport().firePropertyChange(PROPERTY_NO_DATA, old, this.noData);
 	}
 
@@ -438,7 +452,7 @@ public class JasperDesign extends JRBaseReport
 	{
 		Object old = this.pageHeader;
 		this.pageHeader = pageHeader;
-		setBandOrigin(this.pageHeader, JROrigin.PAGE_HEADER);
+		setBandOrigin(this.pageHeader, BandTypeEnum.PAGE_HEADER);
 		getEventSupport().firePropertyChange(PROPERTY_PAGE_HEADER, old, this.pageHeader);
 	}
 
@@ -450,7 +464,7 @@ public class JasperDesign extends JRBaseReport
 	{
 		Object old = this.pageFooter;
 		this.pageFooter = pageFooter;
-		setBandOrigin(this.pageFooter, JROrigin.PAGE_FOOTER);
+		setBandOrigin(this.pageFooter, BandTypeEnum.PAGE_FOOTER);
 		getEventSupport().firePropertyChange(PROPERTY_PAGE_FOOTER, old, this.pageFooter);
 	}
 
@@ -462,7 +476,7 @@ public class JasperDesign extends JRBaseReport
 	{
 		Object old = this.lastPageFooter;
 		this.lastPageFooter = lastPageFooter;
-		setBandOrigin(this.lastPageFooter, JROrigin.LAST_PAGE_FOOTER);
+		setBandOrigin(this.lastPageFooter, BandTypeEnum.LAST_PAGE_FOOTER);
 		getEventSupport().firePropertyChange(PROPERTY_LAST_PAGE_FOOTER, old, this.lastPageFooter);
 	}
 
@@ -474,7 +488,7 @@ public class JasperDesign extends JRBaseReport
 	{
 		Object old = this.columnHeader;
 		this.columnHeader = columnHeader;
-		setBandOrigin(this.columnHeader, JROrigin.COLUMN_HEADER);
+		setBandOrigin(this.columnHeader, BandTypeEnum.COLUMN_HEADER);
 		getEventSupport().firePropertyChange(PROPERTY_COLUMN_HEADER, old, this.columnHeader);
 	}
 
@@ -486,52 +500,11 @@ public class JasperDesign extends JRBaseReport
 	{
 		Object old = this.columnFooter;
 		this.columnFooter = columnFooter;
-		setBandOrigin(this.columnFooter, JROrigin.COLUMN_FOOTER);
+		setBandOrigin(this.columnFooter, BandTypeEnum.COLUMN_FOOTER);
 		getEventSupport().firePropertyChange(PROPERTY_COLUMN_FOOTER, old, this.columnFooter);
 	}
 
 
-	/**
-	 * Sets the detail band.
-	 * @deprecated Replaced by {@link #getDetailSection()}.
-	 */
-	public void setDetail(JRBand detail)
-	{
-		Object old = getDetail();
-
-//		if (detailSection == null)
-//		{
-//			detailSection = new JRDesignSection();
-//		}
-		
-		JRBand[] bands = detailSection.getBands(); 
-		if (bands == null || bands.length == 0)
-		{
-			((JRDesignSection)detailSection).addBand(detail);
-		}
-		else
-		{
-			((JRDesignSection)detailSection).removeBand(0);
-			((JRDesignSection)detailSection).addBand(0, detail);
-		}
-		
-//		setBandOrigin(detail, JROrigin.DETAIL);
-		getEventSupport().firePropertyChange(PROPERTY_DETAIL, old, detail);
-	}
-
-
-	/**
-	 * Sets the detail section.
-	 *
-	public void setDetail(JRSection detailSection)
-	{
-		Object old = this.detailSection;
-		this.detailSection = detailSection;
-		setSectionOrigin(this.detailSection, JROrigin.DETAIL);
-		getEventSupport().firePropertyChange(PROPERTY_DETAIL, old, this.detailSection);
-	}
-
-
 	/**
 	 *
 	 */
@@ -568,7 +541,7 @@ public class JasperDesign extends JRBaseReport
 	{
 		if (importsSet == null)
 		{
-			importsSet = new HashSet();
+			importsSet = new HashSet<String>();//FIXME maintain order
 		}
 		
 		if (importsSet.add(value))
@@ -594,107 +567,20 @@ public class JasperDesign extends JRBaseReport
 
 
 	/**
-	 * @deprecated
+	 *
 	 */
-	public void setDefaultFont(JRReportFont font)
+	public void resetDefaultStyle()
 	{
-		Object old = this.defaultFont;
-		this.defaultFont = font;
-		getEventSupport().firePropertyChange(PROPERTY_DEFAULT_FONT, old, this.defaultFont);
-	}
-
-
-	/**
-	 * Gets an array of report level fonts. These fonts can be referenced by text elements.
-	 * @deprecated
-	 */
-	public JRReportFont[] getFonts()
-	{
-		JRReportFont[] fontsArray = new JRReportFont[fontsList.size()];
-
-		fontsList.toArray(fontsArray);
-
-		return fontsArray;
-	}
-
-
-	/**
-	 * Gets a list of report level fonts. These fonts can be referenced by text elements.
-	 * @deprecated
-	 */
-	public List getFontsList()
-	{
-		return fontsList;
-	}
-
-
-	/**
-	 * @deprecated
-	 */
-	public Map getFontsMap()
-	{
-		return fontsMap;
-	}
-
-
-	/**
-	 * Adds a report font, that can be referenced by text elements.
-	 * @deprecated
-	 */
-	public void addFont(JRReportFont reportFont) throws JRException
-	{
-		if (fontsMap.containsKey(reportFont.getName()))
+		for (int i = stylesList.size() - 1; i >= 0; i--)
 		{
-			throw new JRException("Duplicate declaration of report font : " + reportFont.getName());
-		}
-
-		fontsList.add(reportFont);
-		fontsMap.put(reportFont.getName(), reportFont);
-
-		if (reportFont.isDefault())
-		{
-			setDefaultFont(reportFont);
-		}
-		
-		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_FONTS, reportFont, fontsList.size() - 1);
-	}
-
-
-	/**
-	 * Removes a report font from the list, based on the font name.
-	 * @deprecated
-	 */
-	public JRReportFont removeFont(String propName)
-	{
-		return removeFont(
-			(JRReportFont)fontsMap.get(propName)
-			);
-	}
-
-
-	/**
-	 * Removes a report font from the list.
-	 * @deprecated
-	 */
-	public JRReportFont removeFont(JRReportFont reportFont)
-	{
-		if (reportFont != null)
-		{
-			if (reportFont.isDefault())
+			JRStyle style = stylesList.get(i);
+			if (style.isDefault())
 			{
-				setDefaultFont(null);
-			}
-
-			int idx = fontsList.indexOf(reportFont);
-			if (idx >= 0)
-			{
-				fontsList.remove(idx);
-				fontsMap.remove(reportFont.getName());
-				getEventSupport().fireCollectionElementRemovedEvent(PROPERTY_FONTS, reportFont, idx);
+				setDefaultStyle(style);
+				return;
 			}
 		}
-
-		return reportFont;
+		setDefaultStyle(null);
 	}
 
 
@@ -725,7 +611,7 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 * Gets a list of report level styles. These styles can be referenced by report elements.
 	 */
-	public List getStylesList()
+	public List<JRStyle> getStylesList()
 	{
 		return stylesList;
 	}
@@ -734,7 +620,7 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 *
 	 */
-	public Map getStylesMap()
+	public Map<String, JRStyle> getStylesMap()
 	{
 		return stylesMap;
 	}
@@ -744,21 +630,30 @@ public class JasperDesign extends JRBaseReport
 	 * Adds a report style, that can be referenced by report elements.
 	 */
 	public void addStyle(JRStyle style) throws JRException
+	{
+		addStyle(stylesList.size(), style);
+	}
+
+
+	/**
+	 * Inserts a report style, that can be referenced by report elements, at specified position.
+	 */
+	public void addStyle(int index, JRStyle style) throws JRException
 	{
 		if (stylesMap.containsKey(style.getName()))
 		{
 			throw new JRException("Duplicate declaration of report style : " + style.getName());
 		}
 
-		stylesList.add(style);
+		stylesList.add(index, style);
 		stylesMap.put(style.getName(), style);
 
 		if (style.isDefault())
 		{
-			setDefaultStyle(style);
+			resetDefaultStyle();
 		}
 		
-		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_STYLES, style, stylesList.size() - 1);
+		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_STYLES, style, index);
 	}
 
 
@@ -767,9 +662,7 @@ public class JasperDesign extends JRBaseReport
 	 */
 	public JRStyle removeStyle(String styleName)
 	{
-		return removeStyle(
-			(JRStyle)stylesMap.get(styleName)
-			);
+		return removeStyle(stylesMap.get(styleName));
 	}
 
 
@@ -782,7 +675,7 @@ public class JasperDesign extends JRBaseReport
 		{
 			if (style.isDefault())
 			{
-				setDefaultStyle(null);
+				resetDefaultStyle();
 			}
 
 			int idx = stylesList.indexOf(style);
@@ -801,7 +694,7 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 * Gets a list of report scriptlets (excluding the one specified by scriptletClass).
 	 */
-	public List getScriptletsList()
+	public List<JRScriptlet> getScriptletsList()
 	{
 		return mainDesignDataset.getScriptletsList();
 	}
@@ -810,7 +703,7 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 * Gets a map of report scriptlets (excluding the one specified by scriptletClass).
 	 */
-	public Map getScriptletsMap()
+	public Map<String, JRScriptlet> getScriptletsMap()
 	{
 		return mainDesignDataset.getScriptletsMap();
 	}
@@ -846,7 +739,7 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 * Gets a list of report parameters (including built-in ones).
 	 */
-	public List getParametersList()
+	public List<JRParameter> getParametersList()
 	{
 		return mainDesignDataset.getParametersList();
 	}
@@ -855,7 +748,7 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 * Gets a map of report parameters (including built-in ones).
 	 */
-	public Map getParametersMap()
+	public Map<String, JRParameter> getParametersMap()
 	{
 		return mainDesignDataset.getParametersMap();
 	}
@@ -900,7 +793,7 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 * Gets a list of report fields.
 	 */
-	public List getFieldsList()
+	public List<JRField> getFieldsList()
 	{
 		return mainDesignDataset.getFieldsList();
 	}
@@ -909,7 +802,7 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 * Gets a map of report fields.
 	 */
-	public Map getFieldsMap()
+	public Map<String, JRField> getFieldsMap()
 	{
 		return mainDesignDataset.getFieldsMap();
 	}
@@ -945,7 +838,7 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 * Gets a list of sort report fields.
 	 */
-	public List getSortFieldsList()
+	public List<JRSortField> getSortFieldsList()
 	{
 		return mainDesignDataset.getSortFieldsList();
 	}
@@ -981,7 +874,7 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 * Gets a list of report variables.
 	 */
-	public List getVariablesList()
+	public List<JRVariable> getVariablesList()
 	{
 		return mainDesignDataset.getVariablesList();
 	}
@@ -990,7 +883,7 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 * Gets a map of report variables.
 	 */
-	public Map getVariablesMap()
+	public Map<String, JRVariable> getVariablesMap()
 	{
 		return mainDesignDataset.getVariablesMap();
 	}
@@ -1026,7 +919,7 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 * Gets an array of report groups.
 	 */
-	public List getGroupsList()
+	public List<JRGroup> getGroupsList()
 	{
 		return mainDesignDataset.getGroupsList();
 	}
@@ -1035,7 +928,7 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 * Gets a list of report groups.
 	 */
-	public Map getGroupsMap()
+	public Map<String, JRGroup> getGroupsMap()
 	{
 		return mainDesignDataset.getGroupsMap();
 	}
@@ -1051,7 +944,7 @@ public class JasperDesign extends JRBaseReport
 
 
 	/**
-	 * Adds a new group to the report design. Groups are nested.
+	 * Removes a new group from the report design.
 	 */
 	public JRGroup removeGroup(String groupName)
 	{
@@ -1071,7 +964,7 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 * Returns a collection of all report expressions.
 	 */
-	public Collection getExpressions()
+	public Collection<JRExpression> getExpressions()
 	{
 		return JRExpressionCollector.collectExpressions(this);
 	}
@@ -1091,7 +984,7 @@ public class JasperDesign extends JRBaseReport
 	 *
 	 * @return list of {@link JRDesignDataset JRDesignDataset} objects
 	 */
-	public List getDatasetsList()
+	public List<JRDataset> getDatasetsList()
 	{
 		return datasetList;
 	}
@@ -1102,7 +995,7 @@ public class JasperDesign extends JRBaseReport
 	 *
 	 * @return the sub datasets of the report indexed by name
 	 */
-	public Map getDatasetMap()
+	public Map<String, JRDataset> getDatasetMap()
 	{
 		return datasetMap;
 	}
@@ -1115,16 +1008,29 @@ public class JasperDesign extends JRBaseReport
 	 * @throws JRException
 	 */
 	public void addDataset(JRDesignDataset dataset) throws JRException
+	{
+		addDataset(datasetList.size(), dataset);
+	}
+
+
+	/**
+	 * Inserts a sub dataset at specified position into the report.
+	 *
+	 * @param index the position
+	 * @param dataset the dataset
+	 * @throws JRException
+	 */
+	public void addDataset(int index, JRDesignDataset dataset) throws JRException
 	{
 		if (datasetMap.containsKey(dataset.getName()))
 		{
 			throw new JRException("Duplicate declaration of dataset : " + dataset.getName());
 		}
 
-		datasetList.add(dataset);
+		datasetList.add(index, dataset);
 		datasetMap.put(dataset.getName(), dataset);
 		
-		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_DATASETS, dataset, datasetList.size() - 1);
+		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_DATASETS, dataset, index);
 	}
 
 
@@ -1136,9 +1042,7 @@ public class JasperDesign extends JRBaseReport
 	 */
 	public JRDataset removeDataset(String datasetName)
 	{
-		return removeDataset(
-			(JRDataset)datasetMap.get(datasetName)
-			);
+		return removeDataset(datasetMap.get(datasetName));
 	}
 
 
@@ -1198,16 +1102,16 @@ public class JasperDesign extends JRBaseReport
 	 */
 	public void preprocess()
 	{
-		for (Iterator it = getCrosstabs().iterator(); it.hasNext();)
+		for (Iterator<JRCrosstab> it = getCrosstabs().iterator(); it.hasNext();)
 		{
 			JRDesignCrosstab crosstab = (JRDesignCrosstab) it.next();
 			crosstab.preprocess();
 		}
 	}
 
-	protected List getCrosstabs()
+	protected List<JRCrosstab> getCrosstabs()
 	{
-		final List crosstabs = new ArrayList();
+		final List<JRCrosstab> crosstabs = new ArrayList<JRCrosstab>();
 		JRElementsVisitor.visitReport(this, new JRVisitorSupport()
 		{
 			public void visitCrosstab(JRCrosstab crosstab)
@@ -1265,9 +1169,21 @@ public class JasperDesign extends JRBaseReport
 	 */
 	public void addTemplate(JRReportTemplate template)
 	{
-		templateList.add(template);
+		addTemplate(templateList.size(), template);
+	}
+
+	/**
+	 * Inserts a report template at specified position.
+	 *
+	 * @param index the template position.
+	 * @param template the template to insert.
+	 * @see #getTemplates()
+	 */
+	public void addTemplate(int index, JRReportTemplate template)
+	{
+		templateList.add(index, template);
 		
-		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_TEMPLATES, template, templateList.size() - 1);
+		getEventSupport().fireCollectionElementAddedEvent(PROPERTY_TEMPLATES, template, index);
 	}
 
 	/**
@@ -1290,10 +1206,22 @@ public class JasperDesign extends JRBaseReport
 
 	public JRReportTemplate[] getTemplates()
 	{
-		return (JRReportTemplate[]) templateList.toArray(new JRReportTemplate[templateList.size()]);
+		return templateList.toArray(new JRReportTemplate[templateList.size()]);
 	}
 
-	protected void setBandOrigin(JRBand band, byte type)
+	/**
+	 * Returns the list of report templates defined in the report.
+	 * 
+	 * @return the list of {@link JRReportTemplate} objects for the report
+	 * @see #getTemplates()
+	 * @see #addTemplate(JRReportTemplate)
+	 */
+	public List<JRReportTemplate> getTemplatesList()
+	{
+		return templateList;
+	}
+	
+	protected void setBandOrigin(JRBand band, BandTypeEnum type)
 	{
 		if (band instanceof JRDesignBand)
 		{
@@ -1302,7 +1230,7 @@ public class JasperDesign extends JRBaseReport
 		}
 	}
 	
-	protected void setSectionOrigin(JRSection section, byte type)
+	protected void setSectionOrigin(JRSection section, BandTypeEnum type)
 	{
 		if (section instanceof JRDesignSection)
 		{
