@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -30,7 +30,7 @@ import net.sf.jasperreports.engine.util.JRClassLoader;
  * A {@link ExporterFilterFactory} utility class.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: ExporterFilterFactoryUtil.java 3713 2010-04-08 11:06:05Z teodord $
+ * @version $Id: ExporterFilterFactoryUtil.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public final class ExporterFilterFactoryUtil
 {
@@ -49,7 +49,7 @@ public final class ExporterFilterFactoryUtil
 		//return (ExporterFilterFactory) cache.getCachedInstance(factoryClassName);
 		try
 		{
-			Class clazz = JRClassLoader.loadClassForName(factoryClassName);
+			Class<?> clazz = JRClassLoader.loadClassForName(factoryClassName);
 			return (ExporterFilterFactory)clazz.newInstance();
 		}
 		catch (ClassNotFoundException e)
