@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -36,6 +36,7 @@ import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRPrintHyperlink;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.base.JRBaseGenericPrintElement;
+import net.sf.jasperreports.engine.util.JRProperties;
 import net.sf.jasperreports.engine.xml.JRXmlConstants;
 
 import org.apache.commons.logging.Log;
@@ -50,7 +51,7 @@ import org.apache.commons.logging.LogFactory;
  * </p>
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: FlashPrintElement.java 3864 2010-06-04 14:51:43Z lucianc $
+ * @version $Id: FlashPrintElement.java 4750 2011-10-27 07:09:22Z lucianc $
  * @see FlashHtmlHandler
  */
 public final class FlashPrintElement
@@ -79,6 +80,22 @@ public final class FlashPrintElement
 	 */
 	public static final String PARAMETER_FLASH_VAR_PREFIX = "FLASH_VAR_";
 
+	/**
+	 * Boolean property used to avoid setting the width and height of the SWFLoader control in the Flash report viewer.
+	 * <p>
+	 * Defaults to <code>false</code>.
+	 */
+	public static final String PROPERTY_IGNORE_SIZE = JRProperties.PROPERTY_PREFIX + "export.swf.ignore.size";
+	
+	/**
+	 * Property that determines the value of the allowScriptAccess parameter for Flash elements.
+	 * 
+	 * <p>
+	 * The property can be set at element, report and system levels.
+	 */
+	public static final String PROPERTY_ALLOW_SCRIPT_ACCESS = 
+			JRProperties.PROPERTY_PREFIX + "export.flash.element.allow.script.access";
+	
 	private static final GenericElementHandlerBundle HANDLER_BUNDLE = new GenericElementHandlerBundle()
 	{
 		public String getNamespace()
@@ -120,7 +137,7 @@ public final class FlashPrintElement
 	 * @return a Flash generic element
 	 */
 	public static JRGenericPrintElement makeFlashElement(JRPrintElement template,
-			String swfUrl, Map flashVars, Map elementParameters)
+			String swfUrl, Map<String,Object> flashVars, Map<String,Object> elementParameters)
 	{
 		// TODO use JRTemplateGenericElement
 		JRBaseGenericPrintElement flashEl = new JRBaseGenericPrintElement(
@@ -139,10 +156,10 @@ public final class FlashPrintElement
 		
 		flashEl.setGenericType(FLASH_ELEMENT_TYPE);
 		flashEl.setParameterValue(PARAMETER_SWF_URL, swfUrl);
-		for (Iterator it = flashVars.entrySet().iterator(); it.hasNext();)
+		for (Iterator<Map.Entry<String,Object>> it = flashVars.entrySet().iterator(); it.hasNext();)
 		{
-			Map.Entry entry = (Map.Entry) it.next();
-			String name = (String) entry.getKey();
+			Map.Entry<String,Object> entry = it.next();
+			String name = entry.getKey();
 			Object value = entry.getValue();
 			String paramName = PARAMETER_FLASH_VAR_PREFIX + name;
 			flashEl.setParameterValue(paramName, value);
@@ -150,10 +167,10 @@ public final class FlashPrintElement
 		
 		if (elementParameters != null && !elementParameters.isEmpty())
 		{
-			for (Iterator it = elementParameters.entrySet().iterator(); it.hasNext();)
+			for (Iterator<Map.Entry<String,Object>> it = elementParameters.entrySet().iterator(); it.hasNext();)
 			{
-				Map.Entry entry = (Map.Entry) it.next();
-				String name = (String) entry.getKey();
+				Map.Entry<String,Object> entry = it.next();
+				String name = entry.getKey();
 				Object value = entry.getValue();
 				flashEl.setParameterValue(name, value);
 			}
@@ -229,37 +246,37 @@ public final class FlashPrintElement
 			JRGenericPrintElement element,
 			JRHyperlinkProducer linkProducer)
 	{
-	    Matcher matcher = LINK_PATTERN.matcher(text);
-	    StringBuffer xml = new StringBuffer();
-	    while (matcher.find())
-	    {
-	    	String paramName = matcher.group(LINK_PARAM_NAME_GROUP);
-	    	JRPrintHyperlink hyperlink = 
-	    		(JRPrintHyperlink) element.getParameterValue(paramName);
-	    	
-	    	String replacement;
-	    	if (hyperlink == null)
-	    	{
-	    		if (log.isWarnEnabled())
-	    		{
-	    			log.warn("Hyperlink parameter " + paramName 
-	    					+ " not found in element");
-	    		}
-	    		
-	    		replacement = null;
-	    	}
-	    	else
-	    	{
-	    		replacement = linkProducer.getHyperlink(hyperlink);
-	    	}
-	    	
-	    	if (replacement == null)
-	    	{
-	    		replacement = "";
-	    	}
-	    	else
-	    	{
-	    		try
+		Matcher matcher = LINK_PATTERN.matcher(text);
+		StringBuffer xml = new StringBuffer();
+		while (matcher.find())
+		{
+			String paramName = matcher.group(LINK_PARAM_NAME_GROUP);
+			JRPrintHyperlink hyperlink = 
+				(JRPrintHyperlink) element.getParameterValue(paramName);
+			
+			String replacement;
+			if (hyperlink == null)
+			{
+				if (log.isWarnEnabled())
+				{
+					log.warn("Hyperlink parameter " + paramName 
+							+ " not found in element");
+				}
+				
+				replacement = null;
+			}
+			else
+			{
+				replacement = linkProducer.getHyperlink(hyperlink);
+			}
+			
+			if (replacement == null)
+			{
+				replacement = "";
+			}
+			else
+			{
+				try
 				{
 					replacement = URLEncoder.encode(replacement, "UTF-8");
 				}
@@ -267,13 +284,13 @@ public final class FlashPrintElement
 				{
 					throw new JRRuntimeException(e);
 				}
-	    	}
-	    	
-	    	matcher.appendReplacement(xml, replacement);
-	    }
-	    matcher.appendTail(xml);
-	    
-	    return xml.toString();
+			}
+			
+			matcher.appendReplacement(xml, replacement);
+		}
+		matcher.appendTail(xml);
+		
+		return xml.toString();
 
 	}
 	
