@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -41,7 +41,7 @@ import org.apache.commons.logging.LogFactory;
  * to a filled report.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: GenericElementReportTransformer.java 3713 2010-04-08 11:06:05Z teodord $
+ * @version $Id: GenericElementReportTransformer.java 4595 2011-09-08 15:55:10Z teodord $
  * @see GenericElementTransformer
  */
 public final class GenericElementReportTransformer
@@ -77,22 +77,23 @@ public final class GenericElementReportTransformer
 			String transformerExportKey)
 	{
 		TransformerContext transformerContext = new TransformerContext(report);
-		List pages = report.getPages();
-		for (Iterator pageIt = pages.iterator(); pageIt.hasNext();)
+		List<JRPrintPage> pages = report.getPages();
+		for (Iterator<JRPrintPage> pageIt = pages.iterator(); pageIt.hasNext();)
 		{
-			JRPrintPage page = (JRPrintPage) pageIt.next();
+			JRPrintPage page = pageIt.next();
 			transformElements(transformerContext, transformerExportKey, 
 					page.getElements());
 		}
 	}
 
 	protected static void transformElements(
-			TransformerContext context, String transformerExportKey, 
-			List elements)
+			TransformerContext context, 
+			String transformerExportKey, 
+			List<JRPrintElement> elements)
 	{
-		for (ListIterator it = elements.listIterator(); it.hasNext();)
+		for (ListIterator<JRPrintElement> it = elements.listIterator(); it.hasNext();)
 		{
-			JRPrintElement element = (JRPrintElement) it.next();
+			JRPrintElement element = it.next();
 			if (element instanceof JRGenericPrintElement)
 			{
 				JRGenericPrintElement genericElement = 
