@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,6 +35,8 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.SortedMap;
+import java.util.TreeMap;
 
 import net.sf.jasperreports.engine.JRBoxContainer;
 import net.sf.jasperreports.engine.JRLineBox;
@@ -44,12 +46,13 @@ import net.sf.jasperreports.engine.JRPrintPage;
 import net.sf.jasperreports.engine.base.JRBasePrintFrame;
 import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
+import net.sf.jasperreports.engine.util.JRProperties;
 
 /**
  * Utility class used by grid exporters to create a grid for page layout.
  *
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRGridLayout.java 3875 2010-07-14 09:58:21Z teodord $
+ * @version $Id: JRGridLayout.java 4748 2011-10-26 17:06:50Z teodord $
  */
 public class JRGridLayout
 {
@@ -65,17 +68,17 @@ public class JRGridLayout
 	private CutsInfo yCuts;
 	private JRExporterGridCell[][] grid;
 
-	private Map boxesCache;
+	private Map<BoxKey,JRLineBox> boxesCache;
 
-	private int virtualFrameIndex = 0;
+	private int virtualFrameIndex;
 
 	private boolean hasTopMargin = true;
 	private boolean hasBottomMargin = true;
 	private boolean hasLeftMargin = true;
 	private boolean hasRightMargin = true;
-
+	
 	private boolean isNested;
-
+	
 	/**
 	 * Constructor.
 	 *
@@ -87,7 +90,7 @@ public class JRGridLayout
 	 */
 	public JRGridLayout(
 		ExporterNature nature,
-		List elements,
+		List<JRPrintElement> elements,
 		int width,
 		int height,
 		int offsetX,
@@ -117,7 +120,7 @@ public class JRGridLayout
 	 */
 	public JRGridLayout(
 		ExporterNature nature,
-		List elements,
+		List<JRPrintElement> elements,
 		int width,
 		int height,
 		int offsetX,
@@ -133,11 +136,11 @@ public class JRGridLayout
 		this.address = null;
 		this.xCuts = xCuts;
 
-		boxesCache = new HashMap();
+		boxesCache = new HashMap<BoxKey,JRLineBox>();
 
 		virtualFrameIndex = elements.size();
 
-		layoutGrid(createWrappers(elements, address));
+		layoutGrid(createWrappers(null, elements, address));
 
 		if (nature.isSplitSharedRowSpan())
 		{
@@ -175,8 +178,8 @@ public class JRGridLayout
 		//this constructor is called only in nested grids:
 		this.isNested = true;
 
-		boxesCache = new HashMap();
-
+		boxesCache = new HashMap<BoxKey,JRLineBox>();
+		
 		layoutGrid(wrappers);
 
 		if (nature.isSplitSharedRowSpan())
@@ -197,34 +200,22 @@ public class JRGridLayout
 		)
 	{
 		JRBasePrintFrame frame = new JRBasePrintFrame(null);
-		List wrappers = new ArrayList();
+		List<ElementWrapper> wrappers = new ArrayList<ElementWrapper>();
 
-		frame.setWidth(xCuts.getCut(col2) - xCuts.getCut(col1));
-		frame.setHeight(yCuts.getCut(row2) - yCuts.getCut(row1));
+		frame.setWidth(xCuts.getCutOffset(col2) - xCuts.getCutOffset(col1));
+		frame.setHeight(yCuts.getCutOffset(row2) - yCuts.getCutOffset(row1));
 
 		String virtualAddress = (address == null ? "" : address + "_") + getNextVirtualFrameIndex();
 
 		JRExporterGridCell gridCell =
 			new ElementGridCell(
-				new ElementWrapper(frame, virtualAddress, null),
+				new ElementWrapper(null, frame, virtualAddress),
 				frame.getWidth(),
 				frame.getHeight(),
 				col2 - col1,
 				row2 - row1
 				);
 
-		gridCell.setLayout(
-			new JRGridLayout(
-				nature,
-				(ElementWrapper[]) wrappers.toArray(new ElementWrapper[wrappers.size()]),
-				frame.getWidth(),
-				frame.getHeight(),
-				offsetX -xCuts.getCut(col1),
-				offsetY -yCuts.getCut(row1),
-				virtualAddress
-				)
-			);
-
 		OccupiedGridCell occupiedGridCell = new OccupiedGridCell(gridCell);
 		for(int row = row1; row < row2; row++)
 		{
@@ -241,6 +232,18 @@ public class JRGridLayout
 			}
 		}
 
+		gridCell.setLayout(
+			new JRGridLayout(
+				nature,
+				wrappers.toArray(new ElementWrapper[wrappers.size()]),
+				frame.getWidth(),
+				frame.getHeight(),
+				offsetX -xCuts.getCutOffset(col1),
+				offsetY -yCuts.getCutOffset(row1),
+				virtualAddress
+				)
+			);
+
 		grid[row1][col1] = gridCell;
 	}
 
@@ -256,13 +259,13 @@ public class JRGridLayout
 		xCuts = createXCuts ? new CutsInfo() : xCuts;
 		yCuts = nature.isIgnoreLastRow() ? new CutsInfo(0) : new CutsInfo(height);
 
-		if(!isNested && nature.isIgnorePageMargins())
+		if(!isNested && nature.isIgnorePageMargins()) //FIXMEXLS left and right margins are not ignored when all pages on a single sheet
 		{
 			setMargins(wrappers);
 
 			if(createXCuts)
 			{
-				List xCutsList = xCuts.getCuts();
+				List<Integer> xCutsList = xCuts.getCutOffsets();
 
 				if(hasLeftMargin)
 				{
@@ -270,7 +273,7 @@ public class JRGridLayout
 				}
 			}
 
-			List yCutsList = yCuts.getCuts();
+			List<Integer> yCutsList = yCuts.getCutOffsets();
 
 			if(hasTopMargin)
 			{
@@ -288,9 +291,9 @@ public class JRGridLayout
 		// is not to be removed and no element goes beyond the width
 		if (createXCuts && (isNested
 				|| (!(nature.isIgnorePageMargins() && hasRightMargin)
-				&& !(xCuts.hasCuts() && xCuts.getLastCut() >= width))))
+				&& !(xCuts.hasCuts() && xCuts.getLastCutOffset() >= width))))
 		{
-			xCuts.addCut(width);
+			xCuts.addCutOffset(width);
 		}
 		
 		xCuts.use();
@@ -307,8 +310,8 @@ public class JRGridLayout
 			{
 				grid[row][col] =
 					new EmptyGridCell(
-						xCuts.getCut(col + 1) - xCuts.getCut(col),
-						yCuts.getCut(row + 1) - yCuts.getCut(row),
+						xCuts.getCutOffset(col + 1) - xCuts.getCutOffset(col),
+						yCuts.getCutOffset(row + 1) - yCuts.getCutOffset(row),
 						1,
 						1
 						);
@@ -334,10 +337,12 @@ public class JRGridLayout
 			{
 				if (createXCuts)
 				{
-					xCuts.addXCuts(element, elementOffsetX);
+					xCuts.addCutOffset(element.getX() + elementOffsetX);
+					xCuts.addCutOffset(element.getX() + element.getWidth() + elementOffsetX);
 				}
 
-				yCuts.addYCuts(element, elementOffsetY);
+				yCuts.addCutOffset(element.getY() + elementOffsetY);
+				yCuts.addCutOffset(element.getY() + element.getHeight() + elementOffsetY);
 				
 				JRPrintFrame frame = element instanceof JRPrintFrame ? (JRPrintFrame)element : null;
 				if (frame != null && nature.isDeep(frame))
@@ -401,10 +406,10 @@ public class JRGridLayout
 				int x = element.getX() + elementOffsetX;
 				int y = element.getY() + elementOffsetY;
 
-				int col1 = xCuts.indexOfCut(x);
-				int row1 = yCuts.indexOfCut(y);
-				int col2 = xCuts.indexOfCut(x + element.getWidth());
-				int row2 = yCuts.indexOfCut(y + element.getHeight());
+				int col1 = xCuts.indexOfCutOffset(x);
+				int row1 = yCuts.indexOfCutOffset(y);
+				int col2 = xCuts.indexOfCutOffset(x + element.getWidth());
+				int row2 = yCuts.indexOfCutOffset(y + element.getHeight());
 
 				if (!isOverlap(row1, col1, row2, col2))
 				{
@@ -502,25 +507,82 @@ public class JRGridLayout
 
 	protected void setGridElement(ElementWrapper wrapper, int row1, int col1, int row2, int col2)
 	{
-		yCuts.addUsage(row1, CutsInfo.USAGE_NOT_EMPTY);
-		xCuts.addUsage(col1, CutsInfo.USAGE_NOT_EMPTY);
+		yCuts.addUsage(row1, Cut.USAGE_NOT_EMPTY);
+		xCuts.addUsage(col1, Cut.USAGE_NOT_EMPTY);
+
+		JRPrintElement element = wrapper.getElement();
+		JRPrintFrame frame = element instanceof JRPrintFrame ? (JRPrintFrame) element : null;
+
+		int rowSpan = nature.isSpanCells() ? row2 - row1 : 1;
+		int colSpan = nature.isSpanCells() ? col2 - col1 : 1;
+
+		JRExporterGridCell gridCell =
+			new ElementGridCell(
+				wrapper,
+				element.getWidth(),
+				element.getHeight(),
+				colSpan,
+				rowSpan
+				);
+
+		Boolean rowAutoFit = nature.getRowAutoFit(element);
+		if (rowAutoFit != null)
+		{
+			yCuts.setAutoFit(row1, rowAutoFit.booleanValue());
+		}
+		Boolean columnAutoFit = nature.getColumnAutoFit(element);
+		if (columnAutoFit != null)
+		{
+			xCuts.setAutoFit(col1, columnAutoFit.booleanValue());
+		}
+
+		Integer columnCustomWidth = nature.getCustomColumnWidth(element);
+		if (columnCustomWidth != null && (xCuts.getCustomWidth(col1) == null || xCuts.getCustomWidth(col1) < columnCustomWidth))
+		{
+			xCuts.setCustomWidth(col1, columnCustomWidth);
+		}
+
+		Float widthRatio = nature.getColumnWidthRatio(element);
+		if(widthRatio != null && (xCuts.getWidthRatio() == null || xCuts.getWidthRatio() < widthRatio))
+		{
+			xCuts.setWidthRatio(widthRatio);
+		}
+
+		List<JRProperties.PropertySuffix> rowLevelSuffixes = nature.getRowLevelSuffixes(element);
+		if(rowLevelSuffixes != null && !rowLevelSuffixes.isEmpty())
+		{
+			SortedMap<String, Boolean> levelMap = new TreeMap<String, Boolean>();
+			for(JRProperties.PropertySuffix suffix : rowLevelSuffixes)
+			{
+				String level = suffix.getSuffix();
+				String marker = suffix.getValue();
+				
+				levelMap.put(level, "end".equalsIgnoreCase(marker));
+			}
+			yCuts.setRowLevelMap(row1, levelMap);
+		}
+		
+
+		if (nature.isSpanCells())
+		{
+			OccupiedGridCell occupiedGridCell = new OccupiedGridCell(gridCell);
+			for (int row = row1; row < row2; row++)
+			{
+				for (int col = col1; col < col2; col++)
+				{
+					grid[row][col] = occupiedGridCell;
+				}
+				yCuts.addUsage(row, Cut.USAGE_SPANNED);
+			}
+
+			for (int col = col1; col < col2; col++)
+			{
+				xCuts.addUsage(col, Cut.USAGE_SPANNED);
+			}
+		}
 
 		if (col2 - col1 != 0 && row2 - row1 != 0)
 		{
-			JRPrintElement element = wrapper.getElement();
-			JRPrintFrame frame = element instanceof JRPrintFrame ? (JRPrintFrame) element : null;
-
-			int rowSpan = nature.isSpanCells() ? row2 - row1 : 1;
-			int colSpan = nature.isSpanCells() ? col2 - col1 : 1;
-			JRExporterGridCell gridCell =
-				new ElementGridCell(
-					wrapper,
-					element.getWidth(),
-					element.getHeight(),
-					colSpan,
-					rowSpan
-					);
-
 			if (frame != null)//FIXMEODT if deep, does this make sense?
 			{
 				gridCell.setLayout(
@@ -540,29 +602,11 @@ public class JRGridLayout
 
 			if (nature.isBreakBeforeRow(element))
 			{
-				yCuts.addUsage(row1,  CutsInfo.USAGE_BREAK);
+				yCuts.addUsage(row1,  Cut.USAGE_BREAK);
 			}
 			if (nature.isBreakAfterRow(element))
 			{
-				yCuts.addUsage(row1 + rowSpan,  CutsInfo.USAGE_BREAK);
-			}
-
-			if (nature.isSpanCells())
-			{
-				OccupiedGridCell occupiedGridCell = new OccupiedGridCell(gridCell);
-				for (int row = row1; row < row2; row++)
-				{
-					for (int col = col1; col < col2; col++)
-					{
-						grid[row][col] = occupiedGridCell;
-					}
-					yCuts.addUsage(row, CutsInfo.USAGE_SPANNED);
-				}
-
-				for (int col = col1; col < col2; col++)
-				{
-					xCuts.addUsage(col, CutsInfo.USAGE_SPANNED);
-				}
+				yCuts.addUsage(row1 + rowSpan,  Cut.USAGE_BREAK);
 			}
 
 			grid[row1][col1] = gridCell;
@@ -601,11 +645,11 @@ public class JRGridLayout
 				if (keepLeft || keepRight || keepTop || keepBottom)
 				{
 					JRLineBox cellBox = cell.getBox();
-					Object key = new BoxKey(frame.getLineBox(), cellBox, keepLeft, keepRight, keepTop, keepBottom);
-					JRLineBox modBox = (JRLineBox) boxesCache.get(key);
+					BoxKey key = new BoxKey(frame.getLineBox(), cellBox, keepLeft, keepRight, keepTop, keepBottom);
+					JRLineBox modBox = boxesCache.get(key);
 					if (modBox == null)
 					{
-						modBox = JRBoxUtil.clone(frame.getLineBox(), keepLeft, keepRight, keepTop, keepBottom, cellBox);
+						modBox = JRBoxUtil.copyBordersNoPadding(frame.getLineBox(), keepLeft, keepRight, keepTop, keepBottom, cellBox);
 						boxesCache.put(key, modBox);
 					}
 
@@ -750,14 +794,21 @@ public class JRGridLayout
 	}
 
 
-	public int getRowHeight(int row)
+	public int getColumnWidth(int col)
 	{
-		return yCuts.getCut(row + 1) - yCuts.getCut(row);
+		return xCuts.getCutOffset(col + 1) - xCuts.getCutOffset(col);
 	}
 
 
-	public static int getMaxRowHeight(JRExporterGridCell[] row)
+	public int getRowHeight(int row)
 	{
+		return yCuts.getCutOffset(row + 1) - yCuts.getCutOffset(row);
+	}
+
+
+	public int getMaxRowHeight(int rowIndex)
+	{
+		JRExporterGridCell[] row = grid[rowIndex];
 		int maxRowHeight = row[0].getHeight();
 		for (int col = 0; col < row.length; col++)
 		{
@@ -830,21 +881,21 @@ public class JRGridLayout
 	 * @param offsetX
 	 *            horizontal element position offset
 	 */
-	public static CutsInfo calculateXCuts(ExporterNature nature, List pages, int startPageIndex, int endPageIndex, int width, int offsetX)
+	public static CutsInfo calculateXCuts(ExporterNature nature, List<JRPrintPage> pages, int startPageIndex, int endPageIndex, int width, int offsetX)
 	{
 		CutsInfo xCuts = new CutsInfo();
 
 		for (int pageIndex = startPageIndex; pageIndex <= endPageIndex; pageIndex++)
 		{
-			JRPrintPage page = (JRPrintPage) pages.get(pageIndex);
+			JRPrintPage page = pages.get(pageIndex);
 			addXCuts(nature, page.getElements(), offsetX, xCuts);
 		}
 		
 		// add a cut at the page width if no element goes beyond the width
-		int lastCut = xCuts.getLastCut();
+		int lastCut = xCuts.getLastCutOffset();
 		if (lastCut < width)
 		{
-			xCuts.addCut(width);
+			xCuts.addCutOffset(width);
 		}
 
 		return xCuts;
@@ -861,15 +912,16 @@ public class JRGridLayout
 	 * @param xCuts
 	 *            The list to which the X cuts are to be added.
 	 */
-	protected static void addXCuts(ExporterNature nature, List elementsList, int elementOffsetX, CutsInfo xCuts)
+	protected static void addXCuts(ExporterNature nature, List<JRPrintElement> elementsList, int elementOffsetX, CutsInfo xCuts)
 	{
-		for (Iterator it = elementsList.iterator(); it.hasNext();)
+		for (Iterator<JRPrintElement> it = elementsList.iterator(); it.hasNext();)
 		{
-			JRPrintElement element = ((JRPrintElement) it.next());
+			JRPrintElement element = it.next();
 
 			if (nature.isToExport(element))
 			{
-				xCuts.addXCuts(element, elementOffsetX);
+				xCuts.addCutOffset(element.getX() + elementOffsetX);
+				xCuts.addCutOffset(element.getX() + element.getWidth() + elementOffsetX);
 				
 				if (element instanceof JRPrintFrame)
 				{
@@ -897,29 +949,35 @@ public class JRGridLayout
 	/**
 	 *
 	 */
-	private static ElementWrapper[] createWrappers(List elementsList, String parentAddress)
+	private static ElementWrapper[] createWrappers(ElementWrapper parentWrapper, List<JRPrintElement> elementsList, String parentAddress)
 	{
 		ElementWrapper[] wrappers = new ElementWrapper[elementsList.size()];
 
 		for (int elementIndex = 0; elementIndex < elementsList.size(); elementIndex++)
 		{
-			JRPrintElement element = ((JRPrintElement) elementsList.get(elementIndex));
+			JRPrintElement element = elementsList.get(elementIndex);
 
 			String address = (parentAddress == null ? "" : parentAddress + "_") + elementIndex;
 
-			wrappers[elementIndex] =
+			ElementWrapper wrapper = 
 				new ElementWrapper(
+					parentWrapper,
 					element,
-					address,
-					element instanceof JRPrintFrame
-						? createWrappers(((JRPrintFrame)element).getElements(), address)
-						: null
+					address
 					);
+			
+			if (element instanceof JRPrintFrame)
+			{
+				wrapper.setWrappers(createWrappers(wrapper, ((JRPrintFrame)element).getElements(), address));
+			}
+
+			wrappers[elementIndex] = wrapper;
 		}
 
 		return wrappers;
 	}
-
+	
+	
 	/**
 	 *
 	 */
@@ -974,5 +1032,4 @@ public class JRGridLayout
 		}
 	}
 
-
 }
\ No newline at end of file
