@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -37,14 +37,13 @@ import java.util.Map;
 import net.sf.jasperreports.engine.JROrigin;
 import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRPropertiesMap;
-import net.sf.jasperreports.engine.fill.JRTemplatePrintElement;
 import net.sf.jasperreports.engine.type.BandTypeEnum;
 import net.sf.jasperreports.engine.util.JRProperties;
 import net.sf.jasperreports.engine.util.JRProperties.PropertySuffix;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JROriginExporterFilter.java 3456 2010-02-21 08:10:10Z teodord $
+ * @version $Id: JROriginExporterFilter.java 4648 2011-10-10 12:50:53Z lucianc $
  */
 public class JROriginExporterFilter implements ResetableExporterFilter
 {
@@ -59,8 +58,8 @@ public class JROriginExporterFilter implements ResetableExporterFilter
 	private static final String GROUP_PREFIX = "group.";
 	private static final String REPORT_PREFIX = "report.";
 	
-	private Map originsToExclude = new HashMap();
-	private Map firstOccurrences = new HashMap();
+	private Map<JROrigin,Boolean> originsToExclude = new HashMap<JROrigin,Boolean>();
+	private Map<Integer,JRPrintElement> firstOccurrences = new HashMap<Integer,JRPrintElement>();
 	
 	public void addOrigin(JROrigin origin)
 	{
@@ -79,7 +78,7 @@ public class JROriginExporterFilter implements ResetableExporterFilter
 	
 	public void reset()
 	{
-		firstOccurrences = new HashMap();
+		firstOccurrences = new HashMap<Integer,JRPrintElement>();
 	}
 	
 	public boolean isToExport(JRPrintElement element)
@@ -92,17 +91,24 @@ public class JROriginExporterFilter implements ResetableExporterFilter
 		return
 			!originMatched 
 			|| (keepFirst.booleanValue() 
-				&& (!(element instanceof JRTemplatePrintElement) 
-					|| isFirst((JRTemplatePrintElement)element)));
+				&& isFirst(element));
 	}
 	
-	private boolean isFirst(JRTemplatePrintElement element)
+	private boolean isFirst(JRPrintElement element)
 	{
-		Object template = element.getTemplate();
-		Object firstElement = firstOccurrences.get(template);
+		int elementId = element.getSourceElementId();
+		if (elementId == JRPrintElement.UNSET_SOURCE_ELEMENT_ID)
+		{
+			// for some reason the element doesn't have a valid source Id.
+			// do not exclude the element in that case.
+			return true;
+		}
+		
+		// FIXME this doesn't work well with batch exporting
+		JRPrintElement firstElement = firstOccurrences.get(elementId);
 		if (firstElement == null || firstElement == element)
 		{
-			firstOccurrences.put(template, element);
+			firstOccurrences.put(elementId, element);
 			return true;
 		}
 		return false;
@@ -125,16 +131,16 @@ public class JROriginExporterFilter implements ResetableExporterFilter
 		boolean keepFirst
 		)
 	{
-		List properties = JRProperties.getProperties(originFilterPrefix + BAND_PREFIX);
+		List<PropertySuffix> properties = JRProperties.getProperties(originFilterPrefix + BAND_PREFIX);
 		properties.addAll(JRProperties.getProperties(propertiesMap, originFilterPrefix + BAND_PREFIX));
 		
 		if (!properties.isEmpty())
 		{
 			filter = (filter == null ? new JROriginExporterFilter(): filter);
 				
-			for(Iterator it = properties.iterator(); it.hasNext();)
+			for(Iterator<PropertySuffix> it = properties.iterator(); it.hasNext();)
 			{
-				PropertySuffix propertySuffix = (PropertySuffix)it.next();
+				PropertySuffix propertySuffix = it.next();
 				String suffix = propertySuffix.getSuffix();
 				BandTypeEnum bandType = 
 					BandTypeEnum.getByName(
