@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,10 +17,11 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
+
 package net.sf.jasperreports.engine.export;
 
 import net.sf.jasperreports.engine.JRExporterParameter;
@@ -35,7 +36,7 @@ import net.sf.jasperreports.engine.util.JRProperties;
  * <p>
  *
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRPdfExporterParameter.java 3795 2010-05-13 09:43:07Z lucianc $
+ * @version $Id: JRPdfExporterParameter.java 4600 2011-09-12 10:32:17Z teodord $
  */
 public class JRPdfExporterParameter extends JRExporterParameter
 {
@@ -50,6 +51,10 @@ public class JRPdfExporterParameter extends JRExporterParameter
 
 	public static final String PRINT_SCALING_DEFAULT = "default";
 	public static final String PRINT_SCALING_NONE = "none";
+	
+	public static final String PDFA_CONFORMANCE_1A = "pdfa1a";
+	public static final String PDFA_CONFORMANCE_1B = "pdfa1b";
+	public static final String PDFA_CONFORMANCE_NONE = "none";
 
 	/**
 	 *
@@ -219,6 +224,7 @@ public class JRPdfExporterParameter extends JRExporterParameter
 	 *
 	 * @see #PROPERTY_FORCE_LINEBREAK_POLICY
 	 * @see net.sf.jasperreports.engine.util.BreakIteratorSplitCharacter
+	 * @deprecated No longer used.
 	 */
 	public static final JRPdfExporterParameter FORCE_LINEBREAK_POLICY = new JRPdfExporterParameter("Force linebreak policy");
 
@@ -228,6 +234,7 @@ public class JRPdfExporterParameter extends JRExporterParameter
 	 * PDF exporter parameter.
 	 * 
 	 * @see #FORCE_LINEBREAK_POLICY
+	 * @deprecated No longer used.
 	 */
 	public static final String PROPERTY_FORCE_LINEBREAK_POLICY = JRProperties.PROPERTY_PREFIX + "export.pdf.force.linebreak.policy";
 	
@@ -342,4 +349,39 @@ public class JRPdfExporterParameter extends JRExporterParameter
 	public static final String PROPERTY_COLLAPSE_MISSING_BOOKMARK_LEVELS = 
 		JRProperties.PROPERTY_PREFIX + "export.pdf.collapse.missing.bookmark.levels";
 	
+	
+	/**
+	 * The Conformance level of the PDF/A document, as java.lang.String.
+	 * <p/>
+	 * Possible values are:
+	 * <ul>
+	 * 	<li>{@link #PDFA_CONFORMANCE_NONE}</li>
+	 * 	<li>{@link #PDFA_CONFORMANCE_1A}</li>
+	 * 	<li>{@link #PDFA_CONFORMANCE_1B}</li>
+	 * </ul>
+	 */
+	public static final JRPdfExporterParameter PDFA_CONFORMANCE = new JRPdfExporterParameter("PDF/A Conformance");
+	
+	
+	/**
+	 * Property whose value is used as default for the {@link #PDFA_CONFORMANCE} export parameter.
+	 * <p/>
+	 * By default, this property is set to {@link #PDFA_CONFORMANCE_NONE}.
+	 * 
+	 * @see JRProperties
+	 */
+	public static final String PROPERTY_PDFA_CONFORMANCE = JRProperties.PROPERTY_PREFIX + "export.pdfa.conformance";
+	
+	
+	/**
+	 * The path to the ICC profile file for the PDF/A compliant document
+	 */
+	public static final JRPdfExporterParameter PDFA_ICC_PROFILE_PATH = new JRPdfExporterParameter("PDF/A sRGB profile");
+	
+	
+	/**
+	 * Property whose value is used as default for the {@link #PDFA_ICC_PROFILE_PATH} export parameter.
+	 */
+	public static final String PROPERTY_PDFA_ICC_PROFILE_PATH = JRProperties.PROPERTY_PREFIX + "export.pdfa.icc.profile.path";
+	
 }
