@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -52,7 +52,7 @@ import com.lowagie.text.pdf.PdfWriter;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRPdfExporterTagHelper.java 3668 2010-03-31 15:23:49Z shertage $
+ * @version $Id: JRPdfExporterTagHelper.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRPdfExporterTagHelper
 {
@@ -69,19 +69,19 @@ public class JRPdfExporterTagHelper
 	public static final String TAG_END = "end";
 	public static final String TAG_FULL = "full";
 	
-	protected JRPdfExporter exporter = null;
+	protected JRPdfExporter exporter;
 
-	protected PdfContentByte pdfContentByte = null;
-	protected PdfWriter pdfWriter = null;
+	protected PdfContentByte pdfContentByte;
+	protected PdfWriter pdfWriter;
 
-	protected PdfStructureElement allTag = null;
-	protected Stack tagStack = null;
+	protected PdfStructureElement allTag;
+	protected Stack<PdfStructureElement> tagStack;
 	protected boolean isTagEmpty = true;
 	protected int crtCrosstabRowY = -1;
-	protected int crosstabFrameDepth = 0;
-	protected boolean isDataCellPrinted = false;
+	protected int crosstabFrameDepth;
+	protected boolean isDataCellPrinted;
 
-	protected boolean isTagged = false;
+	protected boolean isTagged;
 
 	/**
 	 *
@@ -134,7 +134,7 @@ public class JRPdfExporterTagHelper
 			{
 				allTag.put(PdfName.LANG, new PdfString(language));
 			}
-			tagStack = new Stack();
+			tagStack = new Stack<PdfStructureElement>();
 			tagStack.push(allTag);
 		}
 	}
@@ -346,7 +346,7 @@ public class JRPdfExporterTagHelper
 		{
 //			PdfStructureElement parentTag = tableCellTag == null ? (tableHeaderTag == null ? allTag : tableHeaderTag): tableCellTag;
 //			PdfStructureElement textTag = new PdfStructureElement(parentTag, PdfName.TEXT);
-			PdfStructureElement textTag = new PdfStructureElement((PdfStructureElement)tagStack.peek(), PdfName.TEXT);
+			PdfStructureElement textTag = new PdfStructureElement(tagStack.peek(), PdfName.TEXT);
 			pdfContentByte.beginMarkedContentSequence(textTag);
 		}
 	}
@@ -405,7 +405,7 @@ public class JRPdfExporterTagHelper
 			prop = element.getPropertiesMap().getProperty(PROPERTY_TAG_H1);
 			if (prop != null && (TAG_START.equals(prop) || TAG_FULL.equals(prop)))
 			{
-				PdfStructureElement headingTag = new PdfStructureElement((PdfStructureElement)tagStack.peek(), new PdfName("H1"));
+				PdfStructureElement headingTag = new PdfStructureElement(tagStack.peek(), new PdfName("H1"));
 				pdfContentByte.beginMarkedContentSequence(headingTag);
 				headingTag.put(PdfName.K, new PdfArray());
 				tagStack.push(headingTag);
@@ -415,7 +415,7 @@ public class JRPdfExporterTagHelper
 			prop = element.getPropertiesMap().getProperty(PROPERTY_TAG_H2);
 			if (prop != null && (TAG_START.equals(prop) || TAG_FULL.equals(prop)))
 			{
-				PdfStructureElement headingTag = new PdfStructureElement((PdfStructureElement)tagStack.peek(), new PdfName("H2"));
+				PdfStructureElement headingTag = new PdfStructureElement(tagStack.peek(), new PdfName("H2"));
 				pdfContentByte.beginMarkedContentSequence(headingTag);
 				headingTag.put(PdfName.K, new PdfArray());
 				tagStack.push(headingTag);
@@ -425,7 +425,7 @@ public class JRPdfExporterTagHelper
 			prop = element.getPropertiesMap().getProperty(PROPERTY_TAG_H3);
 			if (prop != null && (TAG_START.equals(prop) || TAG_FULL.equals(prop)))
 			{
-				PdfStructureElement headingTag = new PdfStructureElement((PdfStructureElement)tagStack.peek(), new PdfName("H3"));
+				PdfStructureElement headingTag = new PdfStructureElement(tagStack.peek(), new PdfName("H3"));
 				pdfContentByte.beginMarkedContentSequence(headingTag);
 				headingTag.put(PdfName.K, new PdfArray());
 				tagStack.push(headingTag);
@@ -446,7 +446,7 @@ public class JRPdfExporterTagHelper
 	
 	protected void createTrStartTag()
 	{
-		PdfStructureElement tableRowTag = new PdfStructureElement((PdfStructureElement)tagStack.peek(), new PdfName("TR"));
+		PdfStructureElement tableRowTag = new PdfStructureElement(tagStack.peek(), new PdfName("TR"));
 		pdfContentByte.beginMarkedContentSequence(tableRowTag);
 		tableRowTag.put(PdfName.K, new PdfArray());
 		tagStack.push(tableRowTag);
@@ -455,7 +455,7 @@ public class JRPdfExporterTagHelper
 	
 	protected void createThStartTag(JRPrintElement element)
 	{
-		PdfStructureElement tableHeaderTag = new PdfStructureElement((PdfStructureElement)tagStack.peek(), new PdfName("TH"));
+		PdfStructureElement tableHeaderTag = new PdfStructureElement(tagStack.peek(), new PdfName("TH"));
 		pdfContentByte.beginMarkedContentSequence(tableHeaderTag);
 		tableHeaderTag.put(PdfName.K, new PdfArray());
 		tagStack.push(tableHeaderTag);
@@ -467,7 +467,7 @@ public class JRPdfExporterTagHelper
 	
 	protected void createTdStartTag(JRPrintElement element)
 	{
-		PdfStructureElement tableCellTag = new PdfStructureElement((PdfStructureElement)tagStack.peek(), new PdfName("TD"));
+		PdfStructureElement tableCellTag = new PdfStructureElement(tagStack.peek(), new PdfName("TD"));
 		pdfContentByte.beginMarkedContentSequence(tableCellTag);
 		tableCellTag.put(PdfName.K, new PdfArray());
 		tagStack.push(tableCellTag);
@@ -539,7 +539,7 @@ public class JRPdfExporterTagHelper
 				
 				if (isTagEmpty)
 				{
-					pdfContentByte.beginMarkedContentSequence(new PdfStructureElement((PdfStructureElement)tagStack.peek(), PdfName.SPAN));
+					pdfContentByte.beginMarkedContentSequence(new PdfStructureElement(tagStack.peek(), PdfName.SPAN));
 					pdfContentByte.endMarkedContentSequence();
 				}
 				
@@ -553,7 +553,7 @@ public class JRPdfExporterTagHelper
 				
 				if (isTagEmpty)
 				{
-					pdfContentByte.beginMarkedContentSequence(new PdfStructureElement((PdfStructureElement)tagStack.peek(), PdfName.SPAN));
+					pdfContentByte.beginMarkedContentSequence(new PdfStructureElement(tagStack.peek(), PdfName.SPAN));
 					pdfContentByte.endMarkedContentSequence();
 				}
 
@@ -572,7 +572,7 @@ public class JRPdfExporterTagHelper
 				
 				if (isTagEmpty)
 				{
-					pdfContentByte.beginMarkedContentSequence(new PdfStructureElement((PdfStructureElement)tagStack.peek(), PdfName.SPAN));
+					pdfContentByte.beginMarkedContentSequence(new PdfStructureElement(tagStack.peek(), PdfName.SPAN));
 					pdfContentByte.endMarkedContentSequence();
 				}
 
@@ -586,7 +586,7 @@ public class JRPdfExporterTagHelper
 
 				if (isTagEmpty)
 				{
-					pdfContentByte.beginMarkedContentSequence(new PdfStructureElement((PdfStructureElement)tagStack.peek(), PdfName.SPAN));
+					pdfContentByte.beginMarkedContentSequence(new PdfStructureElement(tagStack.peek(), PdfName.SPAN));
 					pdfContentByte.endMarkedContentSequence();
 				}
 
@@ -600,7 +600,7 @@ public class JRPdfExporterTagHelper
 
 				if (isTagEmpty)
 				{
-					pdfContentByte.beginMarkedContentSequence(new PdfStructureElement((PdfStructureElement)tagStack.peek(), PdfName.SPAN));
+					pdfContentByte.beginMarkedContentSequence(new PdfStructureElement(tagStack.peek(), PdfName.SPAN));
 					pdfContentByte.endMarkedContentSequence();
 				}
 
@@ -614,7 +614,7 @@ public class JRPdfExporterTagHelper
 
 				if (isTagEmpty)
 				{
-					pdfContentByte.beginMarkedContentSequence(new PdfStructureElement((PdfStructureElement)tagStack.peek(), PdfName.SPAN));
+					pdfContentByte.beginMarkedContentSequence(new PdfStructureElement(tagStack.peek(), PdfName.SPAN));
 					pdfContentByte.endMarkedContentSequence();
 				}
 
