@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -45,6 +45,7 @@ import java.io.OutputStreamWriter;
 import java.io.StringWriter;
 import java.io.Writer;
 import java.text.AttributedCharacterIterator;
+import java.text.AttributedCharacterIterator.Attribute;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.Iterator;
@@ -80,19 +81,22 @@ import net.sf.jasperreports.engine.JRRenderable;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRWrappingSvgRenderer;
 import net.sf.jasperreports.engine.JasperPrint;
+import net.sf.jasperreports.engine.base.JRBasePrintText;
 import net.sf.jasperreports.engine.fonts.FontFamily;
 import net.sf.jasperreports.engine.fonts.FontInfo;
 import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
 import net.sf.jasperreports.engine.type.LineDirectionEnum;
-import net.sf.jasperreports.engine.type.LineSpacingEnum;
 import net.sf.jasperreports.engine.type.ModeEnum;
+import net.sf.jasperreports.engine.type.RotationEnum;
 import net.sf.jasperreports.engine.type.RunDirectionEnum;
 import net.sf.jasperreports.engine.type.ScaleImageEnum;
+import net.sf.jasperreports.engine.util.JRBoxUtil;
 import net.sf.jasperreports.engine.util.JRColorUtil;
 import net.sf.jasperreports.engine.util.JRFontUtil;
 import net.sf.jasperreports.engine.util.JRProperties;
 import net.sf.jasperreports.engine.util.JRStringUtil;
 import net.sf.jasperreports.engine.util.JRStyledText;
+import net.sf.jasperreports.engine.util.JRTextAttribute;
 import net.sf.jasperreports.engine.util.Pair;
 
 import org.apache.commons.logging.Log;
@@ -103,7 +107,7 @@ import org.apache.commons.logging.LogFactory;
  * Exports a JasperReports document to XHTML format.
 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRXhtmlExporter.java 3717 2010-04-09 10:01:33Z teodord $
+ * @version $Id: JRXhtmlExporter.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRXhtmlExporter extends JRAbstractExporter
 {
@@ -158,26 +162,31 @@ public class JRXhtmlExporter extends JRAbstractExporter
 	/**
 	 *
 	 */
-	protected Writer writer = null;
-	protected JRExportProgressMonitor progressMonitor = null;
-	protected Map rendererToImagePathMap = null;
-	protected Map imageMaps;
-	protected List imagesToProcess = null;
-
-	protected int reportIndex = 0;
-	protected int pageIndex = 0;
-	protected List frameIndexStack = null;
-	protected int elementIndex = 0;
+	protected Writer writer;
+	protected JRExportProgressMonitor progressMonitor;
+	protected Map<String,String> rendererToImagePathMap;
+	protected Map<Pair,String> imageMaps;
+	protected Map<String,byte[]> imageNameToImageDataMap;
+	protected List<JRPrintElementIndex> imagesToProcess;
+	
+	protected int reportIndex;
+	protected int pageIndex;
+	protected List<Integer> frameIndexStack;
+	protected int elementIndex;
+	protected int topLimit;
+	protected int leftLimit;
+	protected int rightLimit;
+	protected int bottomLimit;
 
 	/**
 	 *
 	 */
-	protected File imagesDir = null;
-	protected String imagesURI = null;
-	protected boolean isOutputImagesToDir = false;
+	protected File imagesDir;
+	protected String imagesURI;
+	protected boolean isOutputImagesToDir;
 	protected boolean isWhitePageBackground;
 	protected String encoding;
-	protected String sizeUnit = null;
+	protected String sizeUnit;
 	protected float zoom = DEFAULT_ZOOM;
 	protected boolean isWrapBreakWord;
 	protected boolean isIgnorePageMargins;
@@ -185,19 +194,19 @@ public class JRXhtmlExporter extends JRAbstractExporter
 	/**
 	 *
 	 */
-	protected String htmlHeader = null;
-	protected String betweenPagesHtml = null;
-	protected String htmlFooter = null;
+	protected String htmlHeader;
+	protected String betweenPagesHtml;
+	protected String htmlFooter;
 
 
 	/**
 	 * @deprecated
 	 */
-	protected Map fontMap = null;
+	protected Map<String,String> fontMap;
 
 	protected JRHyperlinkTargetProducerFactory targetProducerFactory = new DefaultHyperlinkTargetProducerFactory();		
 
-	protected boolean hyperlinkStarted = false;	
+	protected boolean hyperlinkStarted;	
 	
 	protected JRHtmlExporterContext exporterContext = new ExporterContext();
 
@@ -273,11 +282,19 @@ public class JRXhtmlExporter extends JRAbstractExporter
 					JRExporterParameter.CHARACTER_ENCODING, 
 					JRExporterParameter.PROPERTY_CHARACTER_ENCODING
 					);
+
+			rendererToImagePathMap = new HashMap<String,String>();
+			imageMaps = new HashMap<Pair,String>();
+			imagesToProcess = new ArrayList<JRPrintElementIndex>();
 	
-			rendererToImagePathMap = new HashMap();
-			imageMaps = new HashMap();
-			imagesToProcess = new ArrayList();
-	
+			//backward compatibility with the IMAGE_MAP parameter
+			imageNameToImageDataMap = (Map<String,byte[]>)parameters.get(JRHtmlExporterParameter.IMAGES_MAP);
+	//		if (imageNameToImageDataMap == null)
+	//		{
+	//			imageNameToImageDataMap = new HashMap();
+	//		}
+			//END - backward compatibility with the IMAGE_MAP parameter
+
 			isWrapBreakWord = 
 				getBooleanParameter(
 					JRHtmlExporterParameter.IS_WRAP_BREAK_WORD,
@@ -312,7 +329,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 					false
 					);
 			
-			fontMap = (Map) parameters.get(JRExporterParameter.FONT_MAP);
+			fontMap = (Map<String,String>) parameters.get(JRExporterParameter.FONT_MAP);
 						
 			setHyperlinkProducerFactory();
 			
@@ -452,9 +469,9 @@ public class JRXhtmlExporter extends JRAbstractExporter
 						imagesDir.mkdir();
 					}
 	
-					for(Iterator it = imagesToProcess.iterator(); it.hasNext();)
+					for(Iterator<JRPrintElementIndex> it = imagesToProcess.iterator(); it.hasNext();)
 					{
-						JRPrintElementIndex imageIndex = (JRPrintElementIndex)it.next();
+						JRPrintElementIndex imageIndex = it.next();
 	
 						JRPrintImage image = getImage(jasperPrintList, imageIndex);
 						JRRenderable renderer = image.getRenderer();
@@ -506,16 +523,16 @@ public class JRXhtmlExporter extends JRAbstractExporter
 	}
 
 
-	public static JRPrintImage getImage(List jasperPrintList, String imageName)
+	public static JRPrintImage getImage(List<JasperPrint> jasperPrintList, String imageName)
 	{
 		return getImage(jasperPrintList, getPrintElementIndex(imageName));
 	}
 
 
-	public static JRPrintImage getImage(List jasperPrintList, JRPrintElementIndex imageIndex)
+	public static JRPrintImage getImage(List<JasperPrint> jasperPrintList, JRPrintElementIndex imageIndex)
 	{
-		JasperPrint report = (JasperPrint)jasperPrintList.get(imageIndex.getReportIndex());
-		JRPrintPage page = (JRPrintPage)report.getPages().get(imageIndex.getPageIndex());
+		JasperPrint report = jasperPrintList.get(imageIndex.getReportIndex());
+		JRPrintPage page = report.getPages().get(imageIndex.getPageIndex());
 
 		Integer[] elementIndexes = imageIndex.getAddressArray();
 		Object element = page.getElements().get(elementIndexes[0].intValue());
@@ -558,9 +575,9 @@ public class JRXhtmlExporter extends JRAbstractExporter
 
 		for(reportIndex = 0; reportIndex < jasperPrintList.size(); reportIndex++)
 		{
-			setJasperPrint((JasperPrint)jasperPrintList.get(reportIndex));
+			setJasperPrint(jasperPrintList.get(reportIndex));
 
-			List pages = jasperPrint.getPages();
+			List<JRPrintPage> pages = jasperPrint.getPages();
 			if (pages != null && pages.size() > 0)
 			{
 				if (isModeBatch)
@@ -577,7 +594,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 						throw new JRException("Current thread interrupted.");
 					}
 
-					page = (JRPrintPage)pages.get(pageIndex);
+					page = pages.get(pageIndex);
 
 					writer.write("<a name=\"" + JR_PAGE_ANCHOR_PREFIX + reportIndex + "_" + (pageIndex + 1) + "\"></a>\n");
 
@@ -622,9 +639,46 @@ public class JRXhtmlExporter extends JRAbstractExporter
 	 */
 	protected void exportPage(JRPrintPage page) throws JRException, IOException
 	{
-		writer.write("<div style=\"position:relative;width:" + toSizeUnit(jasperPrint.getPageWidth()) + ";height:" + toSizeUnit(jasperPrint.getPageHeight()) + ";\">\n");
+		topLimit = jasperPrint.getPageHeight();
+		leftLimit = jasperPrint.getPageWidth();
+		rightLimit = 0;
+		bottomLimit = 0;
+		
+		setPageLimits(page.getElements());
 
-		frameIndexStack = new ArrayList();
+		if (!isIgnorePageMargins)
+		{
+			topLimit = 0;
+		}
+		if (!isIgnorePageMargins)
+		{
+			leftLimit = 0;
+		}
+		if (jasperPrint.getPageWidth() > rightLimit && !isIgnorePageMargins)
+		{
+			rightLimit = jasperPrint.getPageWidth();
+		}
+		if (jasperPrint.getPageHeight() > bottomLimit && !isIgnorePageMargins)
+		{
+			bottomLimit = jasperPrint.getPageHeight();
+		}
+		
+		if (topLimit > bottomLimit)//these can occur only when empty page and page margins are ignored
+		{
+			topLimit = bottomLimit;
+		}
+		if (leftLimit > rightLimit)
+		{
+			leftLimit = rightLimit;
+		}
+		
+		writer.write(
+			"<div style=\"" + (isWhitePageBackground ? "background-color: #FFFFFF;" : "") 
+			+ "position:relative;width:" + toSizeUnit(rightLimit - leftLimit) 
+			+ ";height:" + toSizeUnit(bottomLimit - topLimit) + ";\">\n"
+			);
+
+		frameIndexStack = new ArrayList<Integer>();
 		
 		exportElements(page.getElements());
 
@@ -640,7 +694,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 	/**
 	 *
 	 */
-	protected void exportElements(List elements) throws IOException, JRException
+	protected void exportElements(List<JRPrintElement> elements) throws IOException, JRException
 	{
 		if (elements != null && elements.size() > 0)
 		{
@@ -649,7 +703,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 			{
 				elementIndex = i;
 				
-				element = (JRPrintElement)elements.get(i);
+				element = elements.get(i);
 				
 				if (filter == null || filter.isToExport(element))
 				{
@@ -829,13 +883,13 @@ public class JRXhtmlExporter extends JRAbstractExporter
 	/**
 	 *
 	 */
-	protected void exportStyledTextRun(Map attributes, String text, Locale locale) throws IOException
+	protected void exportStyledTextRun(Map<Attribute,Object> attributes, String text, Locale locale) throws IOException
 	{
 		exportStyledTextRun(attributes, text, null, locale);
 	}
 	
 	protected void exportStyledTextRun(
-		Map attributes, 
+		Map<Attribute,Object> attributes, 
 		String text,
 		String tooltip,
 		Locale locale
@@ -845,7 +899,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 		String fontFamily = fontFamilyAttr;
 		if (fontMap != null && fontMap.containsKey(fontFamilyAttr))
 		{
-			fontFamily = (String) fontMap.get(fontFamilyAttr);
+			fontFamily = fontMap.get(fontFamilyAttr);
 		}
 		else
 		{
@@ -861,6 +915,15 @@ public class JRXhtmlExporter extends JRAbstractExporter
 				}
 			}
 		}
+
+		boolean localHyperlink = false;
+		JRPrintHyperlink hyperlink = (JRPrintHyperlink)attributes.get(JRTextAttribute.HYPERLINK);
+		if (!hyperlinkStarted && hyperlink != null)
+		{
+			startHyperlink(hyperlink);
+			localHyperlink = true;
+		}
+		
 		writer.write("<span style=\"font-family: ");
 		writer.write(fontFamily);
 		writer.write("; ");
@@ -936,6 +999,11 @@ public class JRXhtmlExporter extends JRAbstractExporter
 			);
 
 		writer.write("</span>");
+
+		if (localHyperlink)
+		{
+			endHyperlink();
+		}
 	}
 
 
@@ -960,7 +1028,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 			writer.write("\"></a>");
 		}
 
-		writer.write("<span");//FIXME why dealing with cell style if no text to print (textLength == 0)?
+		writer.write("<div");//FIXME why dealing with cell style if no text to print (textLength == 0)?
 
 		appendId(text);
 
@@ -970,10 +1038,103 @@ public class JRXhtmlExporter extends JRAbstractExporter
 		}
 
 		StringBuffer styleBuffer = new StringBuffer();
-		appendPositionStyle(text, styleBuffer);
-		appendSizeStyle(text, text, styleBuffer);
-		appendBackcolorStyle(text, styleBuffer);
-		appendBorderStyle(text.getLineBox(), styleBuffer);
+		StringBuffer divStyleBuffer = new StringBuffer();
+		String rotationValue = null;
+
+		if (text.getRotationValue() == RotationEnum.NONE)
+		{
+			appendPositionStyle(text, divStyleBuffer);
+//			appendSizeStyle(text, text, styleBuffer);
+			styleBuffer.append("width: 100%; height: 100%;");
+			appendSizeStyle(text, text, divStyleBuffer);
+			appendBorderStyle(text.getLineBox(), divStyleBuffer);
+		}
+		else
+		{
+			JRBasePrintText rotatedText = new JRBasePrintText(text.getDefaultStyleProvider());
+			rotatedText.setX(text.getX());
+			rotatedText.setY(text.getY());
+			rotatedText.setWidth(text.getWidth());
+			rotatedText.setHeight(text.getHeight());
+			rotatedText.copyBox(text.getLineBox());
+			
+			JRBoxUtil.rotate(rotatedText.getLineBox(), text.getRotationValue());
+			
+			int rotationIE = 0;
+			int rotationAngle = 0;
+			int translateX = 0;
+			int translateY = 0;
+			switch (text.getRotationValue())
+			{
+				case LEFT : 
+				{
+					translateX = - (text.getHeight() - text.getWidth()) / 2;
+					translateY = (text.getHeight() - text.getWidth()) / 2;
+					rotatedText.setWidth(text.getHeight());
+					rotatedText.setHeight(text.getWidth());
+					rotationIE = 3;
+					rotationAngle = -90;
+					rotationValue = "left";
+					break;
+				}
+				case RIGHT : 
+				{
+					translateX = - (text.getHeight() - text.getWidth()) / 2;
+					translateY = (text.getHeight() - text.getWidth()) / 2;
+					rotatedText.setWidth(text.getHeight());
+					rotatedText.setHeight(text.getWidth());
+					rotationIE = 1;
+					rotationAngle = 90;
+					rotationValue = "right";
+					break;
+				}
+				case UPSIDE_DOWN : 
+				{
+					rotationIE = 2;
+					rotationAngle = 180;
+					rotationValue = "upsideDown";
+					break;
+				}
+				case NONE :
+				default :
+				{
+				}
+			}
+			
+			appendPositionStyle(rotatedText, divStyleBuffer);
+			appendSizeStyle(rotatedText, rotatedText, styleBuffer);
+			appendSizeStyle(text, text, divStyleBuffer);
+			appendBorderStyle(text.getLineBox(), divStyleBuffer);
+
+			styleBuffer.append("-webkit-transform: translate(" + translateX + "px," + translateY + "px) ");
+			styleBuffer.append("rotate(" + rotationAngle + "deg); ");
+			styleBuffer.append("-moz-transform: translate(" + translateX + "px," + translateY + "px) ");
+			styleBuffer.append("rotate(" + rotationAngle + "deg); ");
+			styleBuffer.append("filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=" + rotationIE + "); ");
+		}
+
+		appendBackcolorStyle(text, divStyleBuffer);
+
+		String verticalAlignment = HTML_VERTICAL_ALIGN_TOP;
+
+		switch (text.getVerticalAlignmentValue())
+		{
+			case BOTTOM :
+			{
+				verticalAlignment = HTML_VERTICAL_ALIGN_BOTTOM;
+				break;
+			}
+			case MIDDLE :
+			{
+				verticalAlignment = HTML_VERTICAL_ALIGN_MIDDLE;
+				break;
+			}
+			case TOP :
+			default :
+			{
+				verticalAlignment = HTML_VERTICAL_ALIGN_TOP;
+			}
+		}
 
 		String horizontalAlignment = CSS_TEXT_ALIGN_LEFT;
 
@@ -1014,47 +1175,57 @@ public class JRXhtmlExporter extends JRAbstractExporter
 				styleBuffer.append(horizontalAlignment);
 				styleBuffer.append(";");
 //			}
-
-			String verticalAlignment = HTML_VERTICAL_ALIGN_TOP;
-
-			switch (text.getVerticalAlignmentValue())
-			{
-				case BOTTOM :
-				{
-					verticalAlignment = HTML_VERTICAL_ALIGN_BOTTOM;
-					break;
-				}
-				case MIDDLE :
-				{
-					verticalAlignment = HTML_VERTICAL_ALIGN_MIDDLE;
-					break;
-				}
-				case TOP :
-				default :
-				{
-					verticalAlignment = HTML_VERTICAL_ALIGN_TOP;
-				}
-			}
-
-			if (!verticalAlignment.equals(HTML_VERTICAL_ALIGN_TOP))
-			{
-				styleBuffer.append(" vertical-align: ");
-				styleBuffer.append(verticalAlignment);
-				styleBuffer.append(";");
-			}
+//
+//			if (!verticalAlignment.equals(HTML_VERTICAL_ALIGN_TOP))
+//			{
+				styleBuffer.append(" display:table;");
+//			}
 		}
 
 		if (isWrapBreakWord)
 		{
-			styleBuffer.append("width: " + toSizeUnit(text.getWidth()) + "; ");
+			//styleBuffer.append("width: " + toSizeUnit(text.getWidth()) + "; ");
 			styleBuffer.append("word-wrap: break-word; ");
 		}
 		
-		if (text.getLineSpacingValue() != LineSpacingEnum.SINGLE)
+		switch (text.getParagraph().getLineSpacing())
 		{
-			styleBuffer.append("line-height: " + text.getLineSpacingFactor() + "; ");
+			case SINGLE:
+			default:
+			{
+				styleBuffer.append("line-height: 1.0; ");
+				break;
+			}
+			case ONE_AND_HALF:
+			{
+				styleBuffer.append("line-height: 1.5; ");
+				break;
+			}
+			case DOUBLE:
+			{
+				styleBuffer.append("line-height: 2.0; ");
+				break;
+			}
+			case PROPORTIONAL:
+			{
+				//styleBuffer.append("line-height: " + (int)(100 * text.getParagraph().getLineSpacingSize().floatValue()) + "%; ");
+				styleBuffer.append("line-height: " + text.getParagraph().getLineSpacingSize().floatValue() + "; ");
+				break;
+			}
+			case AT_LEAST:
+			case FIXED:
+			{
+				styleBuffer.append("line-height: " + text.getParagraph().getLineSpacingSize().floatValue() + "px; ");
+				break;
+			}
 		}
 
+		styleBuffer.append("text-indent: " + text.getParagraph().getFirstLineIndent().intValue() + "px; ");
+//		styleBuffer.append("margin-left: " + text.getParagraph().getLeftIndent().intValue() + "px; ");
+//		styleBuffer.append("margin-right: " + text.getParagraph().getRightIndent().intValue() + "px; ");
+//		styleBuffer.append("margin-top: " + text.getParagraph().getSpacingBefore().intValue() + "px; ");
+//		styleBuffer.append("margin-bottom: " + text.getParagraph().getSpacingAfter().intValue() + "px; ");
+
 		if (text.getLineBreakOffsets() != null)
 		{
 			//if we have line breaks saved in the text, set nowrap so that
@@ -1062,6 +1233,21 @@ public class JRXhtmlExporter extends JRAbstractExporter
 			styleBuffer.append("white-space: nowrap; ");
 		}
 		
+		divStyleBuffer.append("overflow: hidden;");
+		
+		if (divStyleBuffer.length() > 0) 
+		{
+			writer.write(" style=\"");
+			writer.write(divStyleBuffer.toString());
+			writer.write("\"");
+		}
+		writer.write("><span");
+		
+		if (rotationValue != null) 
+		{
+			writer.write(" class=\"rotated\" data-rotation=\"" + rotationValue + "\"");
+		}
+		
 		if (styleBuffer.length() > 0)
 		{
 			writer.write(" style=\"");
@@ -1070,6 +1256,13 @@ public class JRXhtmlExporter extends JRAbstractExporter
 		}
 		
 		writer.write(">");
+		
+//		if (!verticalAlignment.equals(HTML_VERTICAL_ALIGN_TOP))
+//		{
+			writer.write("<span style=\"display:table-cell;vertical-align:"); //display:table-cell conflicts with overflow: hidden;
+			writer.write(verticalAlignment);
+			writer.write(";\">");
+//		}
 
 		startHyperlink(text);
 
@@ -1086,7 +1279,12 @@ public class JRXhtmlExporter extends JRAbstractExporter
 
 		endHyperlink();
 
-		writer.write("</span>\n");
+//		if (!verticalAlignment.equals(HTML_VERTICAL_ALIGN_TOP))
+//		{
+			writer.write("</span>");//FIXMENOW move tooltip span here
+//		}
+
+		writer.write("</span></div>\n");
 	}
 
 
@@ -1150,12 +1348,12 @@ public class JRXhtmlExporter extends JRAbstractExporter
 				case CUSTOM :
 				{
 					boolean paramFound = false;
-					List parameters = link.getHyperlinkParameters() == null ? null : link.getHyperlinkParameters().getParameters();
+					List<JRPrintHyperlinkParameter> parameters = link.getHyperlinkParameters() == null ? null : link.getHyperlinkParameters().getParameters();
 					if (parameters != null)
 					{
-						for(Iterator it = parameters.iterator(); it.hasNext();)
+						for(Iterator<JRPrintHyperlinkParameter> it = parameters.iterator(); it.hasNext();)
 						{
-							JRPrintHyperlinkParameter parameter = (JRPrintHyperlinkParameter)it.next();
+							JRPrintHyperlinkParameter parameter = it.next();
 							if (link.getLinkTarget().equals(parameter.getName()))
 							{
 								target = parameter.getValue() == null ? null : parameter.getValue().toString();
@@ -1379,10 +1577,10 @@ public class JRXhtmlExporter extends JRAbstractExporter
 	{
 		styleBuffer.append("position:absolute;");
 		styleBuffer.append("left:");
-		styleBuffer.append(toSizeUnit(element.getX()));
+		styleBuffer.append(toSizeUnit(element.getX() - (frameIndexStack.size() == 0 ? leftLimit : 0)));
 		styleBuffer.append(";");
 		styleBuffer.append("top:");
-		styleBuffer.append(toSizeUnit(element.getY()));
+		styleBuffer.append(toSizeUnit(element.getY() - (frameIndexStack.size() == 0 ? topLimit : 0)));
 		styleBuffer.append(";");
 	}
 
@@ -1503,7 +1701,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 			writer.write("<img");
 			String imagePath = null;
 			String imageMapName = null;
-			List imageMapAreas = null;
+			List<JRPrintImageAreaHyperlink> imageMapAreas = null;
 	
 			ScaleImageEnum scaleImage = image.getScaleImageValue();
 			
@@ -1511,7 +1709,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 			{
 				if (renderer.getType() == JRRenderable.TYPE_IMAGE && rendererToImagePathMap.containsKey(renderer.getId()))
 				{
-					imagePath = (String)rendererToImagePathMap.get(renderer.getId());
+					imagePath = rendererToImagePathMap.get(renderer.getId());
 				}
 				else
 				{
@@ -1526,6 +1724,22 @@ public class JRXhtmlExporter extends JRAbstractExporter
 	
 						String imageName = getImageName(imageIndex);
 						imagePath = imagesURI + imageName;
+
+						//backward compatibility with the IMAGE_MAP parameter
+						if (imageNameToImageDataMap != null)
+						{
+							if (renderer.getType() == JRRenderable.TYPE_SVG)
+							{
+								renderer =
+									new JRWrappingSvgRenderer(
+										renderer,
+										new Dimension(image.getWidth(), image.getHeight()),
+										ModeEnum.OPAQUE == image.getModeValue() ? image.getBackcolor() : null
+										);
+							}
+							imageNameToImageDataMap.put(imageName, renderer.getImageData());
+						}
+						//END - backward compatibility with the IMAGE_MAP parameter
 					}
 	
 					rendererToImagePathMap.put(renderer.getId(), imagePath);
@@ -1537,7 +1751,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 					
 					if (renderer.getType() == JRRenderable.TYPE_IMAGE)
 					{
-						imageMapName = (String) imageMaps.get(new Pair(renderer.getId(), renderingArea));
+						imageMapName = imageMaps.get(new Pair(renderer.getId(), renderingArea));
 					}
 	
 					if (imageMapName == null)
@@ -1768,7 +1982,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 		StringBuffer sbuffer = new StringBuffer();
 		for (int i = 0; i < frameIndexStack.size(); i++)
 		{
-			Integer frameIndex = (Integer)frameIndexStack.get(i);
+			Integer frameIndex = frameIndexStack.get(i);
 
 			sbuffer.append(frameIndex).append("_");
 		}
@@ -1783,13 +1997,13 @@ public class JRXhtmlExporter extends JRAbstractExporter
 	}
 
 
-	protected void writeImageMap(String imageMapName, JRPrintImage image, List imageMapAreas) throws IOException
+	protected void writeImageMap(String imageMapName, JRPrintImage image, List<JRPrintImageAreaHyperlink> imageMapAreas) throws IOException
 	{
 		writer.write("<map name=\"" + imageMapName + "\">\n");
 
-		for (ListIterator it = imageMapAreas.listIterator(imageMapAreas.size()); it.hasPrevious();)
+		for (ListIterator<JRPrintImageAreaHyperlink> it = imageMapAreas.listIterator(imageMapAreas.size()); it.hasPrevious();)
 		{
-			JRPrintImageAreaHyperlink areaHyperlink = (JRPrintImageAreaHyperlink) it.previous();
+			JRPrintImageAreaHyperlink areaHyperlink = it.previous();
 			JRPrintImageArea area = areaHyperlink.getArea();
 
 			writer.write("  <area shape=\"" + JRPrintImageArea.getHtmlShape(area.getShape()) + "\"");
@@ -1815,11 +2029,11 @@ public class JRXhtmlExporter extends JRAbstractExporter
 		if (coords != null && coords.length > 0)
 		{
 			StringBuffer coordsEnum = new StringBuffer(coords.length * 4);
-			coordsEnum.append(coords[0]);
+			coordsEnum.append(toZoom(coords[0]));
 			for (int i = 1; i < coords.length; i++)
 			{
 				coordsEnum.append(',');
-				coordsEnum.append(coords[i]);
+				coordsEnum.append(toZoom(coords[i]));
 			}
 			writer.write(" coords=\"" + coordsEnum + "\"");
 		}		
@@ -1969,9 +2183,40 @@ public class JRXhtmlExporter extends JRAbstractExporter
 		{
 			writer.write(" id=\"" + id + "\"");
 		}
+		String clazz = JRProperties.getProperty(element, JRHtmlExporter.PROPERTY_HTML_CLASS);
+		if (clazz != null)
+		{
+			writer.write(" class=\"" + clazz + "\"");
+		}
 	}
 	
 		
+	/**
+	 *
+	 */
+	private void setPageLimits(List<JRPrintElement> elements) throws IOException, JRException
+	{
+		if (elements != null && elements.size() > 0)
+		{
+			JRPrintElement element;
+			for(int i = 0; i < elements.size(); i++)
+			{
+				elementIndex = i;
+				
+				element = elements.get(i);
+				
+				if (filter == null || filter.isToExport(element))
+				{
+					topLimit = element.getY() < topLimit ? element.getY() : topLimit;
+					leftLimit = element.getX() < leftLimit ? element.getX() : leftLimit;
+					rightLimit = (element.getX() + element.getWidth()) > rightLimit ? element.getX() + element.getWidth() : rightLimit;
+					bottomLimit = (element.getY() + element.getHeight()) > bottomLimit ? element.getY() + element.getHeight() : bottomLimit;
+				}
+			}
+		}
+	}
+
+	
 	/**
 	 *
 	 */
@@ -2009,7 +2254,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 
 		if (styleBuffer.length() > 0)
 		{
-			writer.write(" style=\"");
+			writer.write(" style=\"overflow:hidden;");
 			writer.write(styleBuffer.toString());
 			writer.write("\"");
 		}
@@ -2042,22 +2287,22 @@ public class JRXhtmlExporter extends JRAbstractExporter
 		}
 		else
 		{
-			writer.write("<div");
-
-			StringBuffer styleBuffer = new StringBuffer();
-
-			appendPositionStyle(element, styleBuffer);
-			appendSizeStyle(element, (JRBoxContainer)null, styleBuffer);
-			appendBackcolorStyle(element, styleBuffer);
-			
-			if (styleBuffer.length() > 0)
-			{
-				writer.write(" style=\"");
-				writer.write(styleBuffer.toString());
-				writer.write("\"");
-			}
-
-			writer.write(">");
+//			writer.write("<div");
+//
+//			StringBuffer styleBuffer = new StringBuffer();
+//
+//			appendPositionStyle(element, styleBuffer);
+//			appendSizeStyle(element, (JRBoxContainer)null, styleBuffer);
+//			appendBackcolorStyle(element, styleBuffer);
+//			
+//			if (styleBuffer.length() > 0)
+//			{
+//				writer.write(" style=\"");
+//				writer.write(styleBuffer.toString());
+//				writer.write("\"");
+//			}
+//
+//			writer.write(">");
 
 			String htmlFragment = handler.getHtmlFragment(exporterContext, element);
 			if (htmlFragment != null)
@@ -2065,11 +2310,11 @@ public class JRXhtmlExporter extends JRAbstractExporter
 				writer.write(htmlFragment);
 			}
 
-			writer.write("</div>\n");
+//			writer.write("</div>\n");
 		}
 	}
 
-	public Map getExportParameters()
+	public Map<JRExporterParameter,Object> getExportParameters()
 	{
 		return parameters;
 	}
@@ -2087,7 +2332,12 @@ public class JRXhtmlExporter extends JRAbstractExporter
 
 	public String toSizeUnit(int size)
 	{
-		return String.valueOf((int)(zoom * size)) + sizeUnit;
+		return String.valueOf(toZoom(size)) + sizeUnit;
+	}
+
+	public int toZoom(int size)
+	{
+		return (int)(zoom * size);
 	}
 
 
