@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -47,16 +47,18 @@ import net.sf.jasperreports.engine.util.JRPenUtil;
 
 
 /**
+ * @param <T> the type of the element that the drawer supports
+ * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: ElementDrawer.java 3467 2010-02-23 13:11:13Z teodord $
+ * @version $Id: ElementDrawer.java 4595 2011-09-08 15:55:10Z teodord $
  */
-public abstract class ElementDrawer
+public abstract class ElementDrawer<T extends JRPrintElement>
 {
 
 	/**
 	 *
 	 */
-	public abstract void draw(Graphics2D grx, JRPrintElement element, int offsetX, int offsetY) throws JRException;
+	public abstract void draw(Graphics2D grx, T element, int offsetX, int offsetY) throws JRException;
 	
 	
 	/**
@@ -476,12 +478,4 @@ public abstract class ElementDrawer
 		}
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link JRPenUtil#getStroke(JRPen, int)}
-	 */
-	protected static Stroke getStroke(JRPen pen, int lineCap)
-	{
-		return JRPenUtil.getStroke(pen, lineCap);
-	}
-	
 }
