@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -28,12 +28,13 @@ import java.io.Writer;
 
 import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JRPen;
+import net.sf.jasperreports.engine.export.LengthUtil;
 import net.sf.jasperreports.engine.util.JRColorUtil;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: BorderStyle.java 3467 2010-02-23 13:11:13Z teodord $
+ * @version $Id: BorderStyle.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public abstract class BorderStyle extends Style
 {
@@ -67,13 +68,13 @@ public abstract class BorderStyle extends Style
 		if (box != null)
 		{
 			appendBorder(box.getTopPen(), TOP_BORDER);
-			borderPadding[TOP_BORDER] = String.valueOf(Utility.translatePixelsToInchesWithNoRoundOff(box.getTopPadding().intValue()));
+			borderPadding[TOP_BORDER] = String.valueOf(LengthUtil.inchNoRound(box.getTopPadding().intValue()));
 			appendBorder(box.getLeftPen(), LEFT_BORDER);
-			borderPadding[LEFT_BORDER] = String.valueOf(Utility.translatePixelsToInchesWithNoRoundOff(box.getLeftPadding().intValue()));
+			borderPadding[LEFT_BORDER] = String.valueOf(LengthUtil.inchNoRound(box.getLeftPadding().intValue()));
 			appendBorder(box.getBottomPen(), BOTTOM_BORDER);
-			borderPadding[BOTTOM_BORDER] = String.valueOf(Utility.translatePixelsToInchesWithNoRoundOff(box.getBottomPadding().intValue()));
+			borderPadding[BOTTOM_BORDER] = String.valueOf(LengthUtil.inchNoRound(box.getBottomPadding().intValue()));
 			appendBorder(box.getRightPen(), RIGHT_BORDER);
-			borderPadding[RIGHT_BORDER] = String.valueOf(Utility.translatePixelsToInchesWithNoRoundOff(box.getRightPadding().intValue()));
+			borderPadding[RIGHT_BORDER] = String.valueOf(LengthUtil.inchNoRound(box.getRightPadding().intValue()));
 		}
 	}
 
@@ -166,7 +167,7 @@ public abstract class BorderStyle extends Style
 				}
 			}
 
-			borderWidth[side] = String.valueOf(Utility.translatePixelsToInchesWithNoRoundOff(width));
+			borderWidth[side] = String.valueOf(LengthUtil.inchNoRound(width));
 		}
 		else
 		{
