@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -29,14 +29,19 @@
 
 package net.sf.jasperreports.engine.export.oasis;
 
+import java.util.List;
+
 import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRPrintFrame;
 import net.sf.jasperreports.engine.export.ExporterFilter;
 import net.sf.jasperreports.engine.export.ExporterNature;
+import net.sf.jasperreports.engine.export.JRXlsAbstractExporter;
+import net.sf.jasperreports.engine.util.JRProperties;
+import net.sf.jasperreports.engine.util.JRProperties.PropertySuffix;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JROpenDocumentExporterNature.java 3875 2010-07-14 09:58:21Z teodord $
+ * @version $Id: JROpenDocumentExporterNature.java 4713 2011-10-18 14:55:22Z shertage $
  */
 public abstract class JROpenDocumentExporterNature implements ExporterNature
 {
@@ -44,7 +49,7 @@ public abstract class JROpenDocumentExporterNature implements ExporterNature
 	public static final byte ODT_NATURE = 1;
 	public static final byte ODS_NATURE = 2;
 	
-	protected ExporterFilter filter = null;
+	protected ExporterFilter filter;
 
 	/**
 	 * 
@@ -124,4 +129,39 @@ public abstract class JROpenDocumentExporterNature implements ExporterNature
 	}
 	
 	protected abstract byte getOpenDocumentNature();
+	
+	/**
+	 *
+	 */
+	public Boolean getRowAutoFit(JRPrintElement element)
+	{
+		return null;
+	}
+	
+	/**
+	 *
+	 */
+	public Boolean getColumnAutoFit(JRPrintElement element)
+	{
+		return null;
+	}
+	
+	/**
+	 *
+	 */
+	public Integer getCustomColumnWidth(JRPrintElement element)
+	{
+		return null;
+	}
+
+	public Float getColumnWidthRatio(JRPrintElement element) 
+	{
+		return null;
+	}
+	
+	public List<PropertySuffix> getRowLevelSuffixes(JRPrintElement element)
+	{
+		return null;
+	}
+
 }
