@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -27,20 +27,21 @@ import java.io.Writer;
 
 import net.sf.jasperreports.engine.export.CutsInfo;
 import net.sf.jasperreports.engine.export.JRExporterGridCell;
+import net.sf.jasperreports.engine.export.LengthUtil;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: DocxTableHelper.java 3439 2010-02-18 14:57:42Z teodord $
+ * @version $Id: DocxTableHelper.java 4646 2011-10-06 09:34:19Z teodord $
  */
 public class DocxTableHelper extends BaseHelper
 {
 	/**
 	 * 
 	 */
-	private CutsInfo xCuts = null;
-	private DocxCellHelper cellHelper = null;
-	private DocxParagraphHelper paragraphHelper = null;
+	private CutsInfo xCuts;
+	private DocxCellHelper cellHelper;
+	private DocxParagraphHelper paragraphHelper;
 
 
 	/**
@@ -90,7 +91,7 @@ public class DocxTableHelper extends BaseHelper
 		write("   <w:tblGrid>\n");
 		for(int col = 1; col < xCuts.size(); col++)
 		{
-			write("    <w:gridCol w:w=\"" + Utility.twip(xCuts.getCut(col) - xCuts.getCut(col - 1)) + "\"/>\n");
+			write("    <w:gridCol w:w=\"" + LengthUtil.twip(xCuts.getCutOffset(col) - xCuts.getCutOffset(col - 1)) + "\"/>\n");
 		}
 		write("   </w:tblGrid>\n");
 	}
@@ -103,7 +104,7 @@ public class DocxTableHelper extends BaseHelper
 			write("    <w:p>\n");
 			write("    <w:pPr>\n");
 			write("  <w:sectPr>\n");
-			write("   <w:pgSz w:w=\"" + Utility.twip(pageWidth) + "\" w:h=\"" + Utility.twip(pageHeight) + "\" />\n");
+			write("   <w:pgSz w:w=\"" + LengthUtil.twip(pageWidth) + "\" w:h=\"" + LengthUtil.twip(pageHeight) + "\" />\n");
 			write("   <w:pgMar w:top=\"0\" w:right=\"0\" w:bottom=\"0\" w:left=\"0\" w:header=\"0\" w:footer=\"0\" w:gutter=\"0\" />\n");
 			write("   <w:docGrid w:linePitch=\"360\" />\n");
 			write("  </w:sectPr>\n");
@@ -116,7 +117,7 @@ public class DocxTableHelper extends BaseHelper
 	{
 		write("   <w:tr>\n");
 		write("    <w:trPr>\n");
-		write("     <w:trHeight w:hRule=\"" + (allowRowResize ? "atLeast" : "exact")  + "\" w:val=\"" +  + Utility.twip(rowHeight) + "\" />\n");
+		write("     <w:trHeight w:hRule=\"" + (allowRowResize ? "atLeast" : "exact")  + "\" w:val=\"" +  + LengthUtil.twip(rowHeight) + "\" />\n");
 		write("    </w:trPr>\n");
 	}
 	
