@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -11,13 +11,13 @@
  * JasperReports is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
- *(at your option) any later version.
+ * (at your option) any later version.
  *
  * JasperReports is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -31,7 +31,7 @@ import net.sf.jasperreports.engine.export.zip.FileBufferedZip;
 
 /**
  * @author sanda zaharia (shertage@users.sourceforge.net)
- * @version $Id: OoxmlZip.java 2976 2009-07-28 14:38:22Z teodord $
+ * @version $Id: DocxZip.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class DocxZip extends FileBufferedZip
 {
@@ -39,9 +39,10 @@ public class DocxZip extends FileBufferedZip
 	/**
 	 * 
 	 */
-	private ExportZipEntry documentEntry = null;
-	private ExportZipEntry stylesEntry = null;
-	private ExportZipEntry relsEntry = null;
+	private ExportZipEntry documentEntry;
+	private ExportZipEntry stylesEntry;
+	private ExportZipEntry settingsEntry;
+	private ExportZipEntry relsEntry;
 	
 	/**
 	 * 
@@ -54,11 +55,14 @@ public class DocxZip extends FileBufferedZip
 		stylesEntry = createEntry("word/styles.xml");
 		addEntry(stylesEntry);
 		
+		settingsEntry = createEntry("word/settings.xml");
+		addEntry(settingsEntry);
+		
 		relsEntry = createEntry("word/_rels/document.xml.rels");
 		addEntry(relsEntry);
 		
 		addEntry("_rels/.rels", "net/sf/jasperreports/engine/export/ooxml/docx/_rels/xml.rels");
-		addEntry("[Content_Types].xml", "net/sf/jasperreports/engine/export/ooxml/docx/[Content_Types].xml");
+		addEntry("[Content_Types].xml", "net/sf/jasperreports/engine/export/ooxml/docx/Content_Types.xml");
 	}
 	
 	/**
@@ -77,6 +81,14 @@ public class DocxZip extends FileBufferedZip
 		return stylesEntry;
 	}
 	
+	/**
+	 *
+	 */
+	public ExportZipEntry getSettingsEntry()
+	{
+		return settingsEntry;
+	}
+	
 	/**
 	 *
 	 */
