@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -25,6 +25,7 @@ package net.sf.jasperreports.engine.export.ooxml;
 
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRGenericPrintElement;
+import net.sf.jasperreports.engine.JRPrintImage;
 import net.sf.jasperreports.engine.export.GenericElementHandler;
 import net.sf.jasperreports.engine.export.JRExporterGridCell;
 
@@ -32,7 +33,7 @@ import net.sf.jasperreports.engine.export.JRExporterGridCell;
  * A generic print element XLSX export handler.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: GenericElementPdfHandler.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: GenericElementXlsxHandler.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public interface GenericElementXlsxHandler extends GenericElementHandler
 {
@@ -55,4 +56,12 @@ public interface GenericElementXlsxHandler extends GenericElementHandler
 		int rowIndex
 		) throws JRException;
 	
+	/**
+	 * Creates an equivalent image of the {@link JRGenericPrintElement} element to be exported instead.
+	 * 
+	 * @param element the generic element to export
+	 * @return JRPrintImage the equivalent image
+	 */
+	JRPrintImage getImage(JRGenericPrintElement element) throws JRException;
+	
 }
