@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -32,6 +32,7 @@ import java.io.IOException;
 import java.io.OutputStream;
 import java.io.Writer;
 import java.text.AttributedCharacterIterator;
+import java.text.AttributedCharacterIterator.Attribute;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.Iterator;
@@ -72,6 +73,7 @@ import net.sf.jasperreports.engine.export.JRExportProgressMonitor;
 import net.sf.jasperreports.engine.export.JRExporterGridCell;
 import net.sf.jasperreports.engine.export.JRGridLayout;
 import net.sf.jasperreports.engine.export.JRHyperlinkProducer;
+import net.sf.jasperreports.engine.export.LengthUtil;
 import net.sf.jasperreports.engine.export.OccupiedGridCell;
 import net.sf.jasperreports.engine.export.zip.FileBufferedZipEntry;
 import net.sf.jasperreports.engine.type.LineDirectionEnum;
@@ -79,6 +81,7 @@ import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.util.JRProperties;
 import net.sf.jasperreports.engine.util.JRStringUtil;
 import net.sf.jasperreports.engine.util.JRStyledText;
+import net.sf.jasperreports.engine.util.JRTextAttribute;
 import net.sf.jasperreports.engine.util.JRTypeSniffer;
 
 import org.apache.commons.logging.Log;
@@ -89,7 +92,7 @@ import org.apache.commons.logging.LogFactory;
  * Exports a JasperReports document to DOCX format. It has character output type and exports the document to a
  * grid-based layout.
  * @author sanda zaharia (shertage@users.sourceforge.net)
- * @version $Id: JRDocxExporter.java 3816 2010-05-20 09:30:33Z teodord $
+ * @version $Id: JRDocxExporter.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRDocxExporter extends JRAbstractExporter
 {
@@ -103,6 +106,12 @@ public class JRDocxExporter extends JRAbstractExporter
 	
 	protected static final String DOCX_EXPORTER_PROPERTIES_PREFIX = JRProperties.PROPERTY_PREFIX + "export.docx.";
 
+	/**
+	 * This property is used to mark text elements as being hidden either for printing or on-screen display.
+	 * @see JRProperties
+	 */
+	public static final String PROPERTY_HIDDEN_TEXT = JRProperties.PROPERTY_PREFIX + "export.docx.hidden.text";
+
 	/**
 	 *
 	 */
@@ -117,36 +126,31 @@ public class JRDocxExporter extends JRAbstractExporter
 	/**
 	 *
 	 */
-	protected DocxDocumentHelper docHelper = null;
-	protected Writer docWriter = null;
+	protected DocxDocumentHelper docHelper;
+	protected Writer docWriter;
 
-	protected JRExportProgressMonitor progressMonitor = null;
-	protected Map rendererToImagePathMap = null;
-	protected Map imageMaps;
-	protected List imagesToProcess = null;
-//	protected Map hyperlinksMap = null;
+	protected JRExportProgressMonitor progressMonitor;
+	protected Map<String, String> rendererToImagePathMap;
+//	protected Map imageMaps;
+	protected List<JRPrintElementIndex> imagesToProcess;
+//	protected Map hyperlinksMap;
 
-	protected int reportIndex = 0;
-	protected int pageIndex = 0;
-	protected int tableIndex = 0;
+	protected int reportIndex;
+	protected int pageIndex;
+	protected int tableIndex;
 	protected boolean startPage;
 
-	/**
-	 *
-	 */
-	protected boolean isWrapBreakWord = false;
-
 	/**
 	 * @deprecated
 	 */
-	protected Map fontMap = null;
+	protected Map<String,String> fontMap;
 
-	protected LinkedList backcolorStack;
+	protected LinkedList<Color> backcolorStack;
 	protected Color backcolor;
 
-	private DocxRunHelper runHelper = null;
+	private DocxRunHelper runHelper;
 
-	protected ExporterNature nature = null;
+	protected ExporterNature nature;
 
 	protected boolean deepGrid;
 
@@ -176,7 +180,7 @@ public class JRDocxExporter extends JRAbstractExporter
 	
 	public JRDocxExporter()
 	{
-		backcolorStack = new LinkedList();
+		backcolorStack = new LinkedList<Color>();
 		backcolor = null;
 	}
 
@@ -210,12 +214,12 @@ public class JRDocxExporter extends JRAbstractExporter
 				setPageRange();
 			}
 
-			rendererToImagePathMap = new HashMap();
-			imageMaps = new HashMap();
-			imagesToProcess = new ArrayList();
+			rendererToImagePathMap = new HashMap<String,String>();
+//			imageMaps = new HashMap();
+			imagesToProcess = new ArrayList<JRPrintElementIndex>();
 //			hyperlinksMap = new HashMap();
 
-			fontMap = (Map) parameters.get(JRExporterParameter.FONT_MAP);
+			fontMap = (Map<String,String>) parameters.get(JRExporterParameter.FONT_MAP);
 
 			setHyperlinkProducerFactory();
 
@@ -283,16 +287,16 @@ public class JRDocxExporter extends JRAbstractExporter
 	/**
 	 *
 	 */
-	public static JRPrintImage getImage(List jasperPrintList, String imageName)
+	public static JRPrintImage getImage(List<JasperPrint> jasperPrintList, String imageName) throws JRException
 	{
 		return getImage(jasperPrintList, getPrintElementIndex(imageName));
 	}
 
 
-	public static JRPrintImage getImage(List jasperPrintList, JRPrintElementIndex imageIndex)
+	public static JRPrintImage getImage(List<JasperPrint> jasperPrintList, JRPrintElementIndex imageIndex) throws JRException
 	{
-		JasperPrint report = (JasperPrint)jasperPrintList.get(imageIndex.getReportIndex());
-		JRPrintPage page = (JRPrintPage)report.getPages().get(imageIndex.getPageIndex());
+		JasperPrint report = jasperPrintList.get(imageIndex.getReportIndex());
+		JRPrintPage page = report.getPages().get(imageIndex.getPageIndex());
 
 		Integer[] elementIndexes = imageIndex.getAddressArray();
 		Object element = page.getElements().get(elementIndexes[0].intValue());
@@ -303,6 +307,15 @@ public class JRDocxExporter extends JRAbstractExporter
 			element = frame.getElements().get(elementIndexes[i].intValue());
 		}
 
+		if(element instanceof JRGenericPrintElement)
+		{
+			JRGenericPrintElement genericPrintElement = (JRGenericPrintElement)element;
+			return ((GenericElementDocxHandler)GenericElementHandlerEnviroment.getHandler(
+					genericPrintElement.getGenericType(), 
+					DOCX_EXPORTER_KEY
+					)).getImage(genericPrintElement);
+		}
+		
 		return (JRPrintImage) element;
 	}
 
@@ -331,13 +344,20 @@ public class JRDocxExporter extends JRAbstractExporter
 		styleHelper.export(jasperPrintList);
 		styleHelper.close();
 
+		DocxSettingsHelper settingsHelper = 
+			new DocxSettingsHelper(
+				docxZip.getSettingsEntry().getWriter()
+				);
+		settingsHelper.export(jasperPrint);
+		settingsHelper.close();
+
 		runHelper = new DocxRunHelper(docWriter, fontMap, getExporterKey());
 
 		for(reportIndex = 0; reportIndex < jasperPrintList.size(); reportIndex++)
 		{
-			setJasperPrint((JasperPrint)jasperPrintList.get(reportIndex));
+			setJasperPrint(jasperPrintList.get(reportIndex));
 
-			List pages = jasperPrint.getPages();
+			List<JRPrintPage> pages = jasperPrint.getPages();
 			if (pages != null && pages.size() > 0)
 			{
 				if (isModeBatch)
@@ -354,7 +374,7 @@ public class JRDocxExporter extends JRAbstractExporter
 						throw new JRException("Current thread interrupted.");
 					}
 
-					page = (JRPrintPage)pages.get(pageIndex);
+					page = pages.get(pageIndex);
 
 					exportPage(page);
 				}
@@ -366,9 +386,9 @@ public class JRDocxExporter extends JRAbstractExporter
 
 		if ((imagesToProcess != null && imagesToProcess.size() > 0))
 		{
-			for(Iterator it = imagesToProcess.iterator(); it.hasNext();)
+			for(Iterator<JRPrintElementIndex> it = imagesToProcess.iterator(); it.hasNext();)
 			{
-				JRPrintElementIndex imageIndex = (JRPrintElementIndex)it.next();
+				JRPrintElementIndex imageIndex = it.next();
 
 				JRPrintImage image = getImage(jasperPrintList, imageIndex);
 				JRRenderable renderer = image.getRenderer();
@@ -687,12 +707,6 @@ public class JRDocxExporter extends JRAbstractExporter
 			textLength = styledText.length();
 		}
 
-//		if (isWrapBreakWord)
-//		{
-//			styleBuffer.append("width: " + gridCell.width + "; ");
-//			styleBuffer.append("word-wrap: break-word; ");
-//		}
-
 //		if (styleBuffer.length() > 0)
 //		{
 //			writer.write(" style=\"");
@@ -717,7 +731,13 @@ public class JRDocxExporter extends JRAbstractExporter
 
 		if (textLength > 0)
 		{
-			exportStyledText(text.getStyle(), styledText, getTextLocale(text));
+			exportStyledText(
+				text.getStyle(), 
+				styledText, 
+				getTextLocale(text),
+				JRProperties.getBooleanProperty(text, PROPERTY_HIDDEN_TEXT, false),
+				startedHyperlink
+				);
 		}
 
 		if (startedHyperlink)
@@ -735,7 +755,7 @@ public class JRDocxExporter extends JRAbstractExporter
 	/**
 	 *
 	 */
-	protected void exportStyledText(JRStyle style, JRStyledText styledText, Locale locale)
+	protected void exportStyledText(JRStyle style, JRStyledText styledText, Locale locale, boolean hiddenText, boolean startedHyperlink)
 	{
 		String text = styledText.getText();
 
@@ -745,12 +765,31 @@ public class JRDocxExporter extends JRAbstractExporter
 
 		while(runLimit < styledText.length() && (runLimit = iterator.getRunLimit()) <= styledText.length())
 		{
+			Map<Attribute,Object> attributes = iterator.getAttributes();
+			
+			boolean localHyperlink = false;
+
+			if (!startedHyperlink)
+			{
+				JRPrintHyperlink hyperlink = (JRPrintHyperlink)attributes.get(JRTextAttribute.HYPERLINK);
+				if (hyperlink != null)
+				{
+					localHyperlink = startHyperlink(hyperlink, true);
+				}
+			}
+			
 			runHelper.export(
 				style, 
 				iterator.getAttributes(), 
 				text.substring(iterator.getIndex(), runLimit),
-				locale
+				locale,
+				hiddenText
 				);
+			
+			if (localHyperlink)
+			{
+				endHyperlink(true);
+			}
 
 			iterator.setIndex(runLimit);
 		}
@@ -760,7 +799,7 @@ public class JRDocxExporter extends JRAbstractExporter
 	/**
 	 *
 	 */
-	protected void exportImage(DocxTableHelper tableHelper, JRPrintImage image, JRExporterGridCell gridCell) throws JRException
+	public void exportImage(DocxTableHelper tableHelper, JRPrintImage image, JRExporterGridCell gridCell) throws JRException
 	{
 		int leftPadding = image.getLineBox().getLeftPadding().intValue();
 		int topPadding = image.getLineBox().getTopPadding().intValue();//FIXMEDOCX maybe consider border thickness
@@ -940,13 +979,14 @@ public class JRDocxExporter extends JRAbstractExporter
 			docHelper.write("<wp:positionV relativeFrom=\"line\"><wp:posOffset>0</wp:posOffset></wp:positionV>");
 //			docHelper.write("<wp:positionV relativeFrom=\"line\"><wp:align>" + CellHelper.getVerticalAlignment(new Byte(image.getVerticalAlignment())) + "</wp:align></wp:positionV>");
 			
-			docHelper.write("<wp:extent cx=\"" + Utility.emu(width) + "\" cy=\"" + Utility.emu(height) + "\"/>\n");
+			int imageId = image.hashCode() > 0 ? image.hashCode() : -image.hashCode();
+			docHelper.write("<wp:extent cx=\"" + LengthUtil.emu(width) + "\" cy=\"" + LengthUtil.emu(height) + "\"/>\n");
 			docHelper.write("<wp:wrapNone/>");
-			docHelper.write("<wp:docPr id=\"" + image.hashCode() + "\" name=\"Picture\"/>\n");
+			docHelper.write("<wp:docPr id=\"" + imageId + "\" name=\"Picture\"/>\n");
 			docHelper.write("<a:graphic>\n");
 			docHelper.write("<a:graphicData uri=\"http://schemas.openxmlformats.org/drawingml/2006/picture\">\n");
 			docHelper.write("<pic:pic>\n");
-			docHelper.write("<pic:nvPicPr><pic:cNvPr id=\"" + image.hashCode() + "\" name=\"Picture\"/><pic:cNvPicPr/></pic:nvPicPr>\n");
+			docHelper.write("<pic:nvPicPr><pic:cNvPr id=\"" + imageId + "\" name=\"Picture\"/><pic:cNvPicPr/></pic:nvPicPr>\n");
 			docHelper.write("<pic:blipFill>\n");
 			docHelper.write("<a:blip r:embed=\"" + getImagePath(renderer, image.isLazy(), gridCell) + "\"/>");
 			docHelper.write("<a:srcRect");
@@ -969,7 +1009,7 @@ public class JRDocxExporter extends JRAbstractExporter
 			docHelper.write("/>");
 			docHelper.write("<a:stretch><a:fillRect/></a:stretch>\n");
 			docHelper.write("</pic:blipFill>\n");
-			docHelper.write("<pic:spPr><a:xfrm><a:off x=\"0\" y=\"0\"/><a:ext cx=\"" + Utility.emu(width) + "\" cy=\"" + Utility.emu(height) + "\"/>");
+			docHelper.write("<pic:spPr><a:xfrm><a:off x=\"0\" y=\"0\"/><a:ext cx=\"" + LengthUtil.emu(width) + "\" cy=\"" + LengthUtil.emu(height) + "\"/>");
 			docHelper.write("</a:xfrm><a:prstGeom prst=\"rect\"></a:prstGeom></pic:spPr>\n");
 			docHelper.write("</pic:pic>\n");
 			docHelper.write("</a:graphicData>\n");
@@ -993,7 +1033,7 @@ public class JRDocxExporter extends JRAbstractExporter
 	/**
 	 *
 	 */
-	protected String getImagePath(JRRenderable renderer, boolean isLazy, JRExporterGridCell gridCell)
+	public String getImagePath(JRRenderable renderer, boolean isLazy, JRExporterGridCell gridCell)
 	{
 		String imagePath = null;
 
@@ -1001,7 +1041,7 @@ public class JRDocxExporter extends JRAbstractExporter
 		{
 			if (renderer.getType() == JRRenderable.TYPE_IMAGE && rendererToImagePathMap.containsKey(renderer.getId()))
 			{
-				imagePath = (String)rendererToImagePathMap.get(renderer.getId());
+				imagePath = rendererToImagePathMap.get(renderer.getId());
 			}
 			else
 			{
@@ -1218,7 +1258,7 @@ public class JRDocxExporter extends JRAbstractExporter
 
 	protected void restoreBackcolor()
 	{
-		backcolor = (Color) backcolorStack.removeLast();
+		backcolor = backcolorStack.removeLast();
 	}
 
 
