@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -29,13 +29,17 @@
 
 package net.sf.jasperreports.engine.export.ooxml;
 
+import net.sf.jasperreports.engine.JRGenericPrintElement;
+import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRPrintFrame;
 import net.sf.jasperreports.engine.export.ExporterFilter;
+import net.sf.jasperreports.engine.export.GenericElementHandler;
+import net.sf.jasperreports.engine.export.GenericElementHandlerEnviroment;
 import net.sf.jasperreports.engine.util.JRProperties;
 
 /**
  * @author sanda zaharia (shertage@users.sourceforge.net)
- * @version $Id: JRDocxExporterNature.java 3910 2010-07-20 11:10:57Z teodord $
+ * @version $Id: JRDocxExporterNature.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRDocxExporterNature extends JROfficeOpenXmlExporterNature
 {
@@ -52,6 +56,26 @@ public class JRDocxExporterNature extends JROfficeOpenXmlExporterNature
 		this.deepGrid = deepGrid;
 	}
 
+	/**
+	 * 
+	 */
+	public boolean isToExport(JRPrintElement element)
+	{
+		boolean isToExport = true;
+		if (element instanceof JRGenericPrintElement)
+		{
+			JRGenericPrintElement genericElement = (JRGenericPrintElement) element;
+			GenericElementHandler handler = GenericElementHandlerEnviroment.getHandler(
+					genericElement.getGenericType(), JRDocxExporter.DOCX_EXPORTER_KEY);
+			if (handler == null || !handler.toExport(genericElement))
+			{
+				isToExport = false;
+			}
+		}
+
+		return isToExport && super.isToExport(element);
+	}
+
 	/**
 	 * 
 	 */
