@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -29,13 +29,16 @@
 
 package net.sf.jasperreports.engine.export.ooxml;
 
+import java.util.List;
+
 import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.export.ExporterFilter;
 import net.sf.jasperreports.engine.export.ExporterNature;
+import net.sf.jasperreports.engine.util.JRProperties.PropertySuffix;
 
 /**
  * @author sanda zaharia (shertage@users.sourceforge.net)
- * @version $Id: JROfficeOpenXmlExporterNature.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: JROfficeOpenXmlExporterNature.java 4713 2011-10-18 14:55:22Z shertage $
  */
 public abstract class JROfficeOpenXmlExporterNature implements ExporterNature
 {
@@ -109,4 +112,39 @@ public abstract class JROfficeOpenXmlExporterNature implements ExporterNature
 	{
 		return false;
 	}
+	
+	/**
+	 *
+	 */
+	public Boolean getRowAutoFit(JRPrintElement element)
+	{
+		return null;
+	}
+	
+	/**
+	 *
+	 */
+	public Boolean getColumnAutoFit(JRPrintElement element)
+	{
+		return null;
+	}
+
+	/**
+	 *
+	 */
+	public Integer getCustomColumnWidth(JRPrintElement element)
+	{
+		return null;
+	}
+
+	public Float getColumnWidthRatio(JRPrintElement element) 
+	{
+		return null;
+	}
+	
+	public List<PropertySuffix> getRowLevelSuffixes(JRPrintElement element)
+	{
+		return null;
+	}
+
 }
