@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,13 +17,12 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
 package net.sf.jasperreports.engine.export.ooxml;
 
-import java.awt.Color;
 import java.awt.Dimension;
 import java.awt.geom.Dimension2D;
 import java.io.File;
@@ -62,6 +61,7 @@ import net.sf.jasperreports.engine.JasperPrint;
 import net.sf.jasperreports.engine.export.GenericElementHandlerEnviroment;
 import net.sf.jasperreports.engine.export.JRExportProgressMonitor;
 import net.sf.jasperreports.engine.export.JRHyperlinkProducer;
+import net.sf.jasperreports.engine.export.LengthUtil;
 import net.sf.jasperreports.engine.export.zip.ExportZipEntry;
 import net.sf.jasperreports.engine.export.zip.FileBufferedZipEntry;
 import net.sf.jasperreports.engine.type.LineDirectionEnum;
@@ -78,7 +78,7 @@ import org.apache.commons.logging.LogFactory;
 /**
  * Exports a JasperReports document to PPTX format.
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRDocxExporter.java 3502 2010-03-04 11:05:10Z teodord $
+ * @version $Id: JRPptxExporter.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRPptxExporter extends JRAbstractExporter
 {
@@ -106,42 +106,37 @@ public class JRPptxExporter extends JRAbstractExporter
 	/**
 	 *
 	 */
-	protected PptxZip pptxZip = null;
-	protected PptxPresentationHelper presentationHelper = null;
-	protected PptxPresentationRelsHelper presentationRelsHelper = null;
-	protected PptxContentTypesHelper ctHelper = null;
-	protected PptxSlideHelper slideHelper = null;
-	protected PptxSlideRelsHelper slideRelsHelper = null;
-	protected Writer presentationWriter = null;
+	protected PptxZip pptxZip;
+	protected PptxPresentationHelper presentationHelper;
+	protected PptxPresentationRelsHelper presentationRelsHelper;
+	protected PptxContentTypesHelper ctHelper;
+	protected PptxSlideHelper slideHelper;
+	protected PptxSlideRelsHelper slideRelsHelper;
+	protected Writer presentationWriter;
 
-	protected JRExportProgressMonitor progressMonitor = null;
-	protected Map rendererToImagePathMap = null;
-	protected Map imageMaps;
-	protected List imagesToProcess = null;
-//	protected Map hyperlinksMap = null;
+	protected JRExportProgressMonitor progressMonitor;
+	protected Map<String, String> rendererToImagePathMap;
+//	protected Map imageMaps;
+	protected List<JRPrintElementIndex> imagesToProcess;
+//	protected Map hyperlinksMap;
 
-	protected int reportIndex = 0;
-	protected int pageIndex = 0;
-	protected List frameIndexStack = null;
-	protected int elementIndex = 0;
+	protected int reportIndex;
+	protected int pageIndex;
+	protected List<Integer> frameIndexStack;
+	protected int elementIndex;
 	protected boolean startPage;
 
 	/**
 	 * used for counting the total number of sheets
 	 */
-	protected int slideIndex = 0;
+	protected int slideIndex;
 	
-	/**
-	 *
-	 */
-	protected boolean isWrapBreakWord = false;
-
 	/**
 	 * @deprecated
 	 */
-	protected Map fontMap = null;
+	protected Map<String,String> fontMap;
 
-	private PptxRunHelper runHelper = null;
+	private PptxRunHelper runHelper;
 
 
 	protected class ExporterContext extends BaseExporterContext implements JRPptxExporterContext
@@ -196,12 +191,12 @@ public class JRPptxExporter extends JRAbstractExporter
 				setPageRange();
 			}
 
-			rendererToImagePathMap = new HashMap();
-			imageMaps = new HashMap();
-			imagesToProcess = new ArrayList();
+			rendererToImagePathMap = new HashMap<String,String>();
+//			imageMaps = new HashMap();
+			imagesToProcess = new ArrayList<JRPrintElementIndex>();
 //			hyperlinksMap = new HashMap();
 
-			fontMap = (Map) parameters.get(JRExporterParameter.FONT_MAP);
+			fontMap = (Map<String,String>) parameters.get(JRExporterParameter.FONT_MAP);
 
 			setHyperlinkProducerFactory();
 
@@ -267,16 +262,16 @@ public class JRPptxExporter extends JRAbstractExporter
 	/**
 	 *
 	 */
-	public static JRPrintImage getImage(List jasperPrintList, String imageName)
+	public static JRPrintImage getImage(List<JasperPrint> jasperPrintList, String imageName) throws JRException
 	{
 		return getImage(jasperPrintList, getPrintElementIndex(imageName));
 	}
 
 
-	public static JRPrintImage getImage(List jasperPrintList, JRPrintElementIndex imageIndex)
+	public static JRPrintImage getImage(List<JasperPrint> jasperPrintList, JRPrintElementIndex imageIndex) throws JRException
 	{
-		JasperPrint report = (JasperPrint)jasperPrintList.get(imageIndex.getReportIndex());
-		JRPrintPage page = (JRPrintPage)report.getPages().get(imageIndex.getPageIndex());
+		JasperPrint report = jasperPrintList.get(imageIndex.getReportIndex());
+		JRPrintPage page = report.getPages().get(imageIndex.getPageIndex());
 
 		Integer[] elementIndexes = imageIndex.getAddressArray();
 		Object element = page.getElements().get(elementIndexes[0].intValue());
@@ -287,6 +282,15 @@ public class JRPptxExporter extends JRAbstractExporter
 			element = frame.getElements().get(elementIndexes[i].intValue());
 		}
 
+		if(element instanceof JRGenericPrintElement)
+		{
+			JRGenericPrintElement genericPrintElement = (JRGenericPrintElement)element;
+			return ((GenericElementPptxHandler)GenericElementHandlerEnviroment.getHandler(
+					genericPrintElement.getGenericType(), 
+					PPTX_EXPORTER_KEY
+					)).getImage(genericPrintElement);
+		}
+		
 		return (JRPrintImage) element;
 	}
 
@@ -320,9 +324,9 @@ public class JRPptxExporter extends JRAbstractExporter
 
 		for(reportIndex = 0; reportIndex < jasperPrintList.size(); reportIndex++)
 		{
-			setJasperPrint((JasperPrint)jasperPrintList.get(reportIndex));
+			setJasperPrint(jasperPrintList.get(reportIndex));
 
-			List pages = jasperPrint.getPages();
+			List<JRPrintPage> pages = jasperPrint.getPages();
 			if (pages != null && pages.size() > 0)
 			{
 				if (isModeBatch)
@@ -339,7 +343,7 @@ public class JRPptxExporter extends JRAbstractExporter
 						throw new JRException("Current thread interrupted.");
 					}
 
-					page = (JRPrintPage)pages.get(pageIndex);
+					page = pages.get(pageIndex);
 
 					createSlide(null);//FIXMEPPTX
 					
@@ -357,9 +361,9 @@ public class JRPptxExporter extends JRAbstractExporter
 
 		if ((imagesToProcess != null && imagesToProcess.size() > 0))
 		{
-			for(Iterator it = imagesToProcess.iterator(); it.hasNext();)
+			for(Iterator<JRPrintElementIndex> it = imagesToProcess.iterator(); it.hasNext();)
 			{
-				JRPrintElementIndex imageIndex = (JRPrintElementIndex)it.next();
+				JRPrintElementIndex imageIndex = it.next();
 
 				JRPrintImage image = getImage(jasperPrintList, imageIndex);
 				JRRenderable renderer = image.getRenderer();
@@ -423,7 +427,7 @@ public class JRPptxExporter extends JRAbstractExporter
 	 */
 	protected void exportPage(JRPrintPage page) throws JRException
 	{
-		frameIndexStack = new ArrayList();
+		frameIndexStack = new ArrayList<Integer>();
 
 		exportElements(page.getElements());
 		
@@ -480,7 +484,7 @@ public class JRPptxExporter extends JRAbstractExporter
 	/**
 	 *
 	 */
-	protected void exportElements(List elements) throws JRException
+	protected void exportElements(List<JRPrintElement> elements) throws JRException
 	{
 		if (elements != null && elements.size() > 0)
 		{
@@ -489,7 +493,7 @@ public class JRPptxExporter extends JRAbstractExporter
 			{
 				elementIndex = i;
 				
-				element = (JRPrintElement)elements.get(i);
+				element = elements.get(i);
 				
 				if (filter == null || filter.isToExport(element))
 				{
@@ -559,8 +563,8 @@ public class JRPptxExporter extends JRAbstractExporter
 		slideHelper.write("  </p:nvSpPr>\n");
 		slideHelper.write("  <p:spPr>\n");
 		slideHelper.write("    <a:xfrm" + (line.getDirectionValue() == LineDirectionEnum.TOP_DOWN ? " flipV=\"1\"" : "") + ">\n");
-		slideHelper.write("      <a:off x=\"" + Utility.emu(x) + "\" y=\"" + Utility.emu(y) + "\"/>\n");
-		slideHelper.write("      <a:ext cx=\"" + Utility.emu(width) + "\" cy=\"" + Utility.emu(height) + "\"/>\n");
+		slideHelper.write("      <a:off x=\"" + LengthUtil.emu(x) + "\" y=\"" + LengthUtil.emu(y) + "\"/>\n");
+		slideHelper.write("      <a:ext cx=\"" + LengthUtil.emu(width) + "\" cy=\"" + LengthUtil.emu(height) + "\"/>\n");
 		slideHelper.write("    </a:xfrm><a:prstGeom prst=\"line\"><a:avLst/></a:prstGeom>\n");
 		if (line.getModeValue() == ModeEnum.OPAQUE && line.getBackcolor() != null)
 		{
@@ -568,7 +572,7 @@ public class JRPptxExporter extends JRAbstractExporter
 		}
 		if (line.getLinePen().getLineWidth() > 0)
 		{
-			slideHelper.write("  <a:ln w=\"" + Utility.emu(line.getLinePen().getLineWidth()) + "\">\n");
+			slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(line.getLinePen().getLineWidth()) + "\">\n");
 			slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(line.getLinePen().getLineColor()) + "\"/></a:solidFill>\n");
 			slideHelper.write("<a:prstDash val=\"");
 			switch (line.getLinePen().getLineStyleValue())
@@ -621,8 +625,8 @@ public class JRPptxExporter extends JRAbstractExporter
 		slideHelper.write("  </p:nvSpPr>\n");
 		slideHelper.write("  <p:spPr>\n");
 		slideHelper.write("    <a:xfrm>\n");
-		slideHelper.write("      <a:off x=\"" + Utility.emu(rectangle.getX() + getOffsetX()) + "\" y=\"" + Utility.emu(rectangle.getY() + getOffsetY()) + "\"/>\n");
-		slideHelper.write("      <a:ext cx=\"" + Utility.emu(rectangle.getWidth()) + "\" cy=\"" + Utility.emu(rectangle.getHeight()) + "\"/>\n");
+		slideHelper.write("      <a:off x=\"" + LengthUtil.emu(rectangle.getX() + getOffsetX()) + "\" y=\"" + LengthUtil.emu(rectangle.getY() + getOffsetY()) + "\"/>\n");
+		slideHelper.write("      <a:ext cx=\"" + LengthUtil.emu(rectangle.getWidth()) + "\" cy=\"" + LengthUtil.emu(rectangle.getHeight()) + "\"/>\n");
 		slideHelper.write("    </a:xfrm><a:prstGeom prst=\"" + (rectangle.getRadius() == 0 ? "rect" : "roundRect") + "\"><a:avLst/></a:prstGeom>\n"); //FIXMEPPTX radius
 		if (rectangle.getModeValue() == ModeEnum.OPAQUE && rectangle.getBackcolor() != null)
 		{
@@ -630,7 +634,7 @@ public class JRPptxExporter extends JRAbstractExporter
 		}
 		if (rectangle.getLinePen().getLineWidth() > 0)
 		{
-			slideHelper.write("  <a:ln w=\"" + Utility.emu(rectangle.getLinePen().getLineWidth()) + "\">\n");
+			slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(rectangle.getLinePen().getLineWidth()) + "\">\n");
 			slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(rectangle.getLinePen().getLineColor()) + "\"/></a:solidFill>\n");
 			slideHelper.write("<a:prstDash val=\"");
 			switch (rectangle.getLinePen().getLineStyleValue())
@@ -683,8 +687,8 @@ public class JRPptxExporter extends JRAbstractExporter
 		slideHelper.write("  </p:nvSpPr>\n");
 		slideHelper.write("  <p:spPr>\n");
 		slideHelper.write("    <a:xfrm>\n");
-		slideHelper.write("      <a:off x=\"" + Utility.emu(ellipse.getX() + getOffsetX()) + "\" y=\"" + Utility.emu(ellipse.getY() + getOffsetY()) + "\"/>\n");
-		slideHelper.write("      <a:ext cx=\"" + Utility.emu(ellipse.getWidth()) + "\" cy=\"" + Utility.emu(ellipse.getHeight()) + "\"/>\n");
+		slideHelper.write("      <a:off x=\"" + LengthUtil.emu(ellipse.getX() + getOffsetX()) + "\" y=\"" + LengthUtil.emu(ellipse.getY() + getOffsetY()) + "\"/>\n");
+		slideHelper.write("      <a:ext cx=\"" + LengthUtil.emu(ellipse.getWidth()) + "\" cy=\"" + LengthUtil.emu(ellipse.getHeight()) + "\"/>\n");
 		slideHelper.write("    </a:xfrm><a:prstGeom prst=\"ellipse\"><a:avLst/></a:prstGeom>\n");
 		if (ellipse.getModeValue() == ModeEnum.OPAQUE && ellipse.getBackcolor() != null)
 		{
@@ -692,7 +696,7 @@ public class JRPptxExporter extends JRAbstractExporter
 		}
 		if (ellipse.getLinePen().getLineWidth() > 0)
 		{
-			slideHelper.write("  <a:ln w=\"" + Utility.emu(ellipse.getLinePen().getLineWidth()) + "\">\n");
+			slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(ellipse.getLinePen().getLineWidth()) + "\">\n");
 			slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(ellipse.getLinePen().getLineColor()) + "\"/></a:solidFill>\n");
 			slideHelper.write("<a:prstDash val=\"");
 			switch (ellipse.getLinePen().getLineStyleValue())
@@ -830,8 +834,8 @@ public class JRPptxExporter extends JRAbstractExporter
 		slideHelper.write("  </p:nvSpPr>\n");
 		slideHelper.write("  <p:spPr>\n");
 		slideHelper.write("    <a:xfrm rot=\"" + rotation + "\">\n");
-		slideHelper.write("      <a:off x=\"" + Utility.emu(x) + "\" y=\"" + Utility.emu(y) + "\"/>\n");
-		slideHelper.write("      <a:ext cx=\"" + Utility.emu(width) + "\" cy=\"" + Utility.emu(height) + "\"/>\n");
+		slideHelper.write("      <a:off x=\"" + LengthUtil.emu(x) + "\" y=\"" + LengthUtil.emu(y) + "\"/>\n");
+		slideHelper.write("      <a:ext cx=\"" + LengthUtil.emu(width) + "\" cy=\"" + LengthUtil.emu(height) + "\"/>\n");
 		slideHelper.write("    </a:xfrm><a:prstGeom prst=\"rect\"><a:avLst/></a:prstGeom>\n");
 		if (text.getModeValue() == ModeEnum.OPAQUE && text.getBackcolor() != null)
 		{
@@ -839,7 +843,7 @@ public class JRPptxExporter extends JRAbstractExporter
 		}
 		if (text.getLineBox().getPen().getLineWidth() > 0)
 		{
-			slideHelper.write("  <a:ln w=\"" + Utility.emu(text.getLineBox().getPen().getLineWidth()) + "\">\n");
+			slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(text.getLineBox().getPen().getLineWidth()) + "\">\n");
 			slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(text.getLineBox().getPen().getLineColor()) + "\"/></a:solidFill>\n");
 			slideHelper.write("<a:prstDash val=\"");
 			switch (text.getLineBox().getPen().getLineStyleValue())
@@ -868,13 +872,13 @@ public class JRPptxExporter extends JRAbstractExporter
 		slideHelper.write("  </p:spPr>\n");
 		slideHelper.write("  <p:txBody>\n");
 		slideHelper.write("    <a:bodyPr wrap=\"square\" lIns=\"" +
-				Utility.emu(leftPadding) +
+				LengthUtil.emu(leftPadding) +
 				"\" tIns=\"" +
-				Utility.emu(topPadding) +
+				LengthUtil.emu(topPadding) +
 				"\" rIns=\"" +
-				Utility.emu(rightPadding) +
+				LengthUtil.emu(rightPadding) +
 				"\" bIns=\"" +
-				Utility.emu(bottomPadding) +
+				LengthUtil.emu(bottomPadding) +
 				"\" rtlCol=\"0\" anchor=\"");
 		switch (text.getVerticalAlignmentValue())
 		{
@@ -894,12 +898,6 @@ public class JRPptxExporter extends JRAbstractExporter
 		slideHelper.write("\"/>\n");
 		slideHelper.write("    <a:lstStyle/>\n");
 
-//		if (isWrapBreakWord)
-//		{
-//			styleBuffer.append("width: " + gridCell.width + "; ");
-//			styleBuffer.append("word-wrap: break-word; ");
-//		}
-
 //		if (styleBuffer.length() > 0)
 //		{
 //			writer.write(" style=\"");
@@ -933,7 +931,7 @@ public class JRPptxExporter extends JRAbstractExporter
 		slideHelper.write("\">\n");
 		slideHelper.write("<a:lnSpc><a:spcPct");
 		slideHelper.write(" val=\"");
-		switch (text.getLineSpacingValue())
+		switch (text.getParagraph().getLineSpacing())
 		{
 			case DOUBLE:
 				slideHelper.write("200");
@@ -1007,7 +1005,7 @@ public class JRPptxExporter extends JRAbstractExporter
 	/**
 	 *
 	 */
-	protected void exportImage(JRPrintImage image) throws JRException
+	public void exportImage(JRPrintImage image) throws JRException
 	{
 		int leftPadding = image.getLineBox().getLeftPadding().intValue();
 		int topPadding = image.getLineBox().getTopPadding().intValue();//FIXMEDOCX maybe consider border thickness
@@ -1233,7 +1231,7 @@ public class JRPptxExporter extends JRAbstractExporter
 
 			slideHelper.write("<p:pic>\n");
 			slideHelper.write("  <p:nvPicPr>\n");
-			slideHelper.write("    <p:cNvPr id=\"" + image.hashCode() + "\" name=\"Picture\">\n");
+			slideHelper.write("    <p:cNvPr id=\"" + (image.hashCode() > 0 ? image.hashCode() : -image.hashCode()) + "\" name=\"Picture\">\n");
 
 			String href = getHyperlinkURL(image);
 			if (href != null)
@@ -1288,8 +1286,8 @@ public class JRPptxExporter extends JRAbstractExporter
 			slideHelper.write("</p:blipFill>\n");
 			slideHelper.write("  <p:spPr>\n");
 			slideHelper.write("    <a:xfrm>\n");
-			slideHelper.write("      <a:off x=\"" + Utility.emu(image.getX() + getOffsetX()) + "\" y=\"" + Utility.emu(image.getY() + getOffsetY()) + "\"/>\n");
-			slideHelper.write("      <a:ext cx=\"" + Utility.emu(image.getWidth()) + "\" cy=\"" + Utility.emu(image.getHeight()) + "\"/>\n");
+			slideHelper.write("      <a:off x=\"" + LengthUtil.emu(image.getX() + getOffsetX()) + "\" y=\"" + LengthUtil.emu(image.getY() + getOffsetY()) + "\"/>\n");
+			slideHelper.write("      <a:ext cx=\"" + LengthUtil.emu(image.getWidth()) + "\" cy=\"" + LengthUtil.emu(image.getHeight()) + "\"/>\n");
 			slideHelper.write("    </a:xfrm><a:prstGeom prst=\"rect\"><a:avLst/></a:prstGeom>\n");
 			if (image.getModeValue() == ModeEnum.OPAQUE && image.getBackcolor() != null)
 			{
@@ -1297,7 +1295,7 @@ public class JRPptxExporter extends JRAbstractExporter
 			}
 			if (image.getLineBox().getPen().getLineWidth() > 0)
 			{
-				slideHelper.write("  <a:ln w=\"" + Utility.emu(image.getLineBox().getPen().getLineWidth()) + "\">\n");
+				slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(image.getLineBox().getPen().getLineWidth()) + "\">\n");
 				slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(image.getLineBox().getPen().getLineColor()) + "\"/></a:solidFill>\n");
 				slideHelper.write("<a:prstDash val=\"");
 				switch (image.getLineBox().getPen().getLineStyleValue())
@@ -1347,7 +1345,7 @@ public class JRPptxExporter extends JRAbstractExporter
 		{
 			if (renderer.getType() == JRRenderable.TYPE_IMAGE && rendererToImagePathMap.containsKey(renderer.getId()))
 			{
-				imagePath = (String)rendererToImagePathMap.get(renderer.getId());
+				imagePath = rendererToImagePathMap.get(renderer.getId());
 			}
 			else
 			{
@@ -1385,7 +1383,7 @@ public class JRPptxExporter extends JRAbstractExporter
 		StringBuffer sbuffer = new StringBuffer();
 		for (int i = 0; i < frameIndexStack.size(); i++)
 		{
-			Integer frameIndex = (Integer)frameIndexStack.get(i);
+			Integer frameIndex = frameIndexStack.get(i);
 
 			sbuffer.append(frameIndex).append("_");
 		}
@@ -1505,8 +1503,8 @@ public class JRPptxExporter extends JRAbstractExporter
 		slideHelper.write("  </p:nvSpPr>\n");
 		slideHelper.write("  <p:spPr>\n");
 		slideHelper.write("    <a:xfrm>\n");
-		slideHelper.write("      <a:off x=\"" + Utility.emu(frame.getX() + getOffsetX()) + "\" y=\"" + Utility.emu(frame.getY() + getOffsetY()) + "\"/>\n");
-		slideHelper.write("      <a:ext cx=\"" + Utility.emu(frame.getWidth()) + "\" cy=\"" + Utility.emu(frame.getHeight()) + "\"/>\n");
+		slideHelper.write("      <a:off x=\"" + LengthUtil.emu(frame.getX() + getOffsetX()) + "\" y=\"" + LengthUtil.emu(frame.getY() + getOffsetY()) + "\"/>\n");
+		slideHelper.write("      <a:ext cx=\"" + LengthUtil.emu(frame.getWidth()) + "\" cy=\"" + LengthUtil.emu(frame.getHeight()) + "\"/>\n");
 		slideHelper.write("    </a:xfrm><a:prstGeom prst=\"rect\"><a:avLst/></a:prstGeom>\n");
 		if (frame.getModeValue() == ModeEnum.OPAQUE && frame.getBackcolor() != null)
 		{
@@ -1514,7 +1512,7 @@ public class JRPptxExporter extends JRAbstractExporter
 		}
 		if (frame.getLineBox().getPen().getLineWidth() > 0)
 		{
-			slideHelper.write("  <a:ln w=\"" + Utility.emu(frame.getLineBox().getPen().getLineWidth()) + "\">\n");
+			slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(frame.getLineBox().getPen().getLineWidth()) + "\">\n");
 			slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(frame.getLineBox().getPen().getLineColor()) + "\"/></a:solidFill>\n");
 			slideHelper.write("<a:prstDash val=\"");
 			switch (frame.getLineBox().getPen().getLineStyleValue())
@@ -1574,7 +1572,6 @@ public class JRPptxExporter extends JRAbstractExporter
 		if (handler != null)
 		{
 			JRPptxExporterContext exporterContext = new ExporterContext();
-
 			handler.exportElement(exporterContext, element);
 		}
 		else
