@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -40,7 +40,7 @@ import net.sf.jasperreports.engine.type.VerticalAlignEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: CellHelper.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: XlsxCellHelper.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class XlsxCellHelper extends BaseHelper
 {
@@ -124,9 +124,8 @@ public class XlsxCellHelper extends BaseHelper
 			throw new JRRuntimeException(e);
 		}
 
-		String type = handler.getType();
-		
 		write("  <c r=\"" + getColumIndexLetter(colIndex) + (rowIndex + 1) + "\" s=\"" + styleHelper.getCellStyle(gridCell, pattern, locale, isWrapText, isHidden, isLocked) + "\"");
+		String type = handler.getType();
 		if (type != null)
 		{
 			write(" t=\"" + type + "\"");
@@ -331,7 +330,7 @@ class TypeTextValueHandler implements TextValueHandler
 	}
 	
 	public void handle(DateTextValue textValue) throws JRException {
-		type = "d";
+		type = null;//"d"; //mantis #5192 : invalid file in ms office 2010
 	}
 	
 	public void handle(NumberTextValue textValue) throws JRException {
