@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -26,6 +26,7 @@ package net.sf.jasperreports.engine.export.ooxml;
 import java.io.IOException;
 import java.io.Writer;
 import java.util.HashMap;
+import java.util.Locale;
 import java.util.Map;
 
 import net.sf.jasperreports.engine.JRRuntimeException;
@@ -35,36 +36,39 @@ import net.sf.jasperreports.engine.util.FileBufferedWriter;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: ReportStyleHelper.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: XlsxStyleHelper.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class XlsxStyleHelper extends BaseHelper
 {
 	/**
 	 * 
 	 */
+	private FileBufferedWriter formatsWriter = new FileBufferedWriter();
 	private FileBufferedWriter fontsWriter = new FileBufferedWriter();
 	private FileBufferedWriter fillsWriter = new FileBufferedWriter();
 	private FileBufferedWriter bordersWriter = new FileBufferedWriter();
 	private FileBufferedWriter cellXfsWriter = new FileBufferedWriter();
 	
-	private Map styleCache = new HashMap();//FIXMEXLSX use soft cache? check other exporter caches as well
+	private Map<String,Integer> styleCache = new HashMap<String,Integer>();//FIXMEXLSX use soft cache? check other exporter caches as well
 	
-	private XlsxFontHelper fontHelper = null;
-	private XlsxBorderHelper borderHelper = null;
+	private XlsxFormatHelper formatHelper;
+	private XlsxFontHelper fontHelper;
+	private XlsxBorderHelper borderHelper;
 	
-	private boolean isWhitePageBackground = false;
-	private boolean isIgnoreCellBackground = false;
+	private boolean isWhitePageBackground;
+	private boolean isIgnoreCellBackground;
 	
 	/**
 	 * 
 	 */
 	public XlsxStyleHelper(
 		Writer writer, 
-		Map fontMap, 
+		Map<String,String> fontMap, 
 		String exporterKey,
 		boolean isWhitePageBackground,
 		boolean isIgnoreCellBorder,
-		boolean isIgnoreCellBackground
+		boolean isIgnoreCellBackground,
+		boolean isFontSizeFixEnabled		
 		)
 	{
 		super(writer);
@@ -72,22 +76,34 @@ public class XlsxStyleHelper extends BaseHelper
 		this.isWhitePageBackground = isWhitePageBackground;
 		this.isIgnoreCellBackground = isIgnoreCellBackground;
 		
-		fontHelper = new XlsxFontHelper(fontsWriter);
+		formatHelper = new XlsxFormatHelper(formatsWriter);
+		fontHelper = new XlsxFontHelper(fontsWriter, fontMap, exporterKey, isFontSizeFixEnabled);
 		borderHelper = new XlsxBorderHelper(bordersWriter, isIgnoreCellBorder);
 	}
 
 	/**
 	 * 
 	 */
-	public int getCellStyle(JRExporterGridCell gridCell)
+	public int getCellStyle(
+		JRExporterGridCell gridCell, 
+		String pattern, 
+		Locale locale,
+		boolean isWrapText, 
+		boolean isHidden, 
+		boolean isLocked 
+		)
 	{
 		XlsxStyleInfo styleInfo = 
 			new XlsxStyleInfo(
-				fontHelper.getFont(gridCell) + 1,
+				formatHelper.getFormat(pattern) + 1,
+				fontHelper.getFont(gridCell, locale) + 1,
 				borderHelper.getBorder(gridCell) + 1,
-				gridCell
+				gridCell,
+				isWrapText,
+				isHidden,
+				isLocked
 				);
-		Integer styleIndex = (Integer)styleCache.get(styleInfo.getId());
+		Integer styleIndex = styleCache.get(styleInfo.getId());
 		if (styleIndex == null)
 		{
 			styleIndex = Integer.valueOf(styleCache.size() + 1);
@@ -121,15 +137,19 @@ public class XlsxStyleHelper extends BaseHelper
 			}
 			
 			cellXfsWriter.write(
-				"<xf numFmtId=\"" + styleIndex
+				"<xf numFmtId=\"" + styleInfo.formatIndex
 				+ "\" fontId=\"" + styleInfo.fontIndex
 				+ "\" fillId=\"" + (styleIndex.intValue() + 1)
 				+ "\" borderId=\"" + styleInfo.borderIndex
 				+ "\" xfId=\"" + styleIndex + "\">"
-				+ "<alignment wrapText=\"1\""
+				+ "<alignment wrapText=\"" + styleInfo.isWrapText + "\""
 				+ (styleInfo.horizontalAlign == null ? "" : " horizontal=\"" + styleInfo.horizontalAlign + "\"")
 				+ (styleInfo.verticalAlign == null ? "" : " vertical=\"" + styleInfo.verticalAlign + "\"")
-				+ "/></xf>\n");
+//				+ (" shrinkToFit=\"" + styleInfo.isFontSizeFixEnabled + "\"")
+				+ "/>"
+				);
+			cellXfsWriter.write("<protection hidden=\"" + styleInfo.isHidden + "\" locked=\"" + styleInfo.isLocked + "\"/>");
+			cellXfsWriter.write("</xf>\n");
 		}
 		catch (IOException e)
 		{
@@ -145,6 +165,11 @@ public class XlsxStyleHelper extends BaseHelper
 		write("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
 		write("<styleSheet xmlns=\"http://schemas.openxmlformats.org/spreadsheetml/2006/main\">\n");
 		
+		write("<numFmts>\n");// count=\"1\">\n");
+		write("<numFmt numFmtId=\"0\" formatCode=\"General\"/>\n");
+		formatsWriter.writeData(writer);
+		write("</numFmts>\n");
+
 		write("<fonts>\n");// count=\"1\">\n");
 		write("<font><sz val=\"11\"/><color theme=\"1\"/><name val=\"Calibri\"/><family val=\"2\"/><scheme val=\"minor\"/></font>\n");
 		fontsWriter.writeData(writer);
