@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -33,7 +33,7 @@ import java.util.zip.ZipOutputStream;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: AbstractZip.java 3648 2010-03-29 12:09:51Z teodord $
+ * @version $Id: AbstractZip.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public abstract class AbstractZip
 {
@@ -41,7 +41,7 @@ public abstract class AbstractZip
 	/**
 	 * 
 	 */
-	protected List exportZipEntries = new ArrayList();
+	protected List<ExportZipEntry> exportZipEntries = new ArrayList<ExportZipEntry>();
 
 	/**
 	 *
@@ -66,7 +66,7 @@ public abstract class AbstractZip
 		
 		for (int i = 0; i < exportZipEntries.size(); i++) 
 		{
-			ExportZipEntry exportZipEntry = (ExportZipEntry)exportZipEntries.get(i);
+			ExportZipEntry exportZipEntry = exportZipEntries.get(i);
 			ZipEntry zipEntry = new ZipEntry(exportZipEntry.getName());
 			zipos.putNextEntry(zipEntry);
 			exportZipEntry.writeData(zipos);
@@ -83,7 +83,7 @@ public abstract class AbstractZip
 	{
 		for (int i = 0; i < exportZipEntries.size(); i++) 
 		{
-			ExportZipEntry exportZipEntry = (ExportZipEntry)exportZipEntries.get(i);
+			ExportZipEntry exportZipEntry = exportZipEntries.get(i);
 			exportZipEntry.dispose();
 		}
 	}
