@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -41,16 +41,16 @@ import net.sf.jasperreports.engine.JasperReport;
  * The main benefit of this method is that the filling process can be cancelled.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: AsynchronousFillHandle.java 3941 2010-08-20 10:55:10Z teodord $
+ * @version $Id: AsynchronousFillHandle.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class AsynchronousFillHandle
 {	
 	protected final JasperReport jasperReport;
-	protected final Map parameters;
+	protected final Map<String,Object> parameters;
 	protected final JRDataSource dataSource;
 	protected final Connection conn;
 	protected final JRBaseFiller filler;
-	protected final List listeners;
+	protected final List<AsynchronousFilllListener> listeners;
 	protected Thread fillThread;
 	protected boolean started;
 	protected boolean running;
@@ -63,7 +63,7 @@ public class AsynchronousFillHandle
 	
 	protected AsynchronousFillHandle (
 			JasperReport jasperReport,
-			Map parameters,
+			Map<String,Object> parameters,
 			JRDataSource dataSource
 			) throws JRException
 	{
@@ -72,7 +72,7 @@ public class AsynchronousFillHandle
 	
 	protected AsynchronousFillHandle (
 			JasperReport jasperReport,
-			Map parameters,
+			Map<String,Object> parameters,
 			Connection conn
 			) throws JRException
 	{
@@ -81,7 +81,7 @@ public class AsynchronousFillHandle
 	
 	protected AsynchronousFillHandle (
 			JasperReport jasperReport,
-			Map parameters
+			Map<String,Object> parameters
 			) throws JRException
 	{
 		this(jasperReport, parameters, null, null);
@@ -89,7 +89,7 @@ public class AsynchronousFillHandle
 	
 	protected AsynchronousFillHandle (
 			JasperReport jasperReport,
-			Map parameters,
+			Map<String,Object> parameters,
 			JRDataSource dataSource,
 			Connection conn
 			) throws JRException
@@ -99,7 +99,7 @@ public class AsynchronousFillHandle
 		this.dataSource = dataSource;
 		this.conn = conn;
 		this.filler = JRFiller.createFiller(jasperReport);
-		this.listeners = new ArrayList();
+		this.listeners = new ArrayList<AsynchronousFilllListener>();
 		lock = this;
 	}
 
@@ -246,9 +246,9 @@ public class AsynchronousFillHandle
 	
 	protected void notifyFinish(JasperPrint print)
 	{
-		for (Iterator i = listeners.iterator(); i.hasNext();)
+		for (Iterator<AsynchronousFilllListener> i = listeners.iterator(); i.hasNext();)
 		{
-			AsynchronousFilllListener listener = (AsynchronousFilllListener) i.next();
+			AsynchronousFilllListener listener = i.next();
 			listener.reportFinished(print);
 		}
 	}
@@ -256,9 +256,9 @@ public class AsynchronousFillHandle
 	
 	protected void notifyCancel()
 	{
-		for (Iterator i = listeners.iterator(); i.hasNext();)
+		for (Iterator<AsynchronousFilllListener> i = listeners.iterator(); i.hasNext();)
 		{
-			AsynchronousFilllListener listener = (AsynchronousFilllListener) i.next();
+			AsynchronousFilllListener listener =  i.next();
 			listener.reportCancelled();
 		}
 	}
@@ -266,9 +266,9 @@ public class AsynchronousFillHandle
 	
 	protected void notifyError(Throwable e)
 	{
-		for (Iterator i = listeners.iterator(); i.hasNext();)
+		for (Iterator<AsynchronousFilllListener> i = listeners.iterator(); i.hasNext();)
 		{
-			AsynchronousFilllListener listener = (AsynchronousFilllListener) i.next();
+			AsynchronousFilllListener listener = i.next();
 			listener.reportFillError(e);
 		}
 	}
@@ -285,7 +285,7 @@ public class AsynchronousFillHandle
 	 */
 	public static AsynchronousFillHandle createHandle(
 		JasperReport jasperReport,
-		Map parameters,
+		Map<String,Object> parameters,
 		JRDataSource dataSource
 		) throws JRException
 	{
@@ -306,7 +306,7 @@ public class AsynchronousFillHandle
 	 */
 	public static AsynchronousFillHandle createHandle(
 		JasperReport jasperReport,
-		Map parameters,
+		Map<String,Object> parameters,
 		Connection conn
 		) throws JRException
 	{
@@ -326,7 +326,7 @@ public class AsynchronousFillHandle
 	 */
 	public static AsynchronousFillHandle createHandle(
 		JasperReport jasperReport,
-		Map parameters
+		Map<String,Object> parameters
 		) throws JRException
 	{
 		AsynchronousFillHandle filler = new AsynchronousFillHandle(jasperReport, parameters);
