@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2005 - 2009 Works, Inc. All rights reserved.
+ * Copyright (C) 2005 - 2011 Works, Inc. All rights reserved.
  * http://www.works.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -41,7 +41,6 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import java.util.Map.Entry;
 
 import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRRuntimeException;
@@ -58,17 +57,17 @@ import org.apache.commons.logging.LogFactory;
  * Abstract base for LRU and serialization based virtualizer
  *
  * @author John Bindel
- * @version $Id: JRAbstractLRUVirtualizer.java 3717 2010-04-09 10:01:33Z teodord $
+ * @version $Id: JRAbstractLRUVirtualizer.java 4747 2011-10-26 16:59:20Z lucianc $
  */
 public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 {
 	private static final Log log = LogFactory.getLog(JRAbstractLRUVirtualizer.class);
 
-	protected static class CacheReference extends WeakReference
+	protected static class CacheReference extends WeakReference<JRVirtualizable>
 	{
 		private final String id;
 
-		public CacheReference(JRVirtualizable o, ReferenceQueue queue)
+		public CacheReference(JRVirtualizable o, ReferenceQueue<JRVirtualizable> queue)
 		{
 			super(o, queue);
 			id = o.getUID();
@@ -97,22 +96,23 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 
 			protected void removeLRU()
 			{
-				Map.Entry entry = getFirst();
+				Map.Entry<?,?> entry = getFirst();
 				boolean found = isRemovable(entry);
 				if (!found)
 				{
-					Iterator entriesIt = entrySet().iterator();
+					Iterator<Map.Entry<?,?>> entriesIt = entrySet().iterator();
 					entriesIt.next(); //skipping the first, which is already checked
 					while(!found && entriesIt.hasNext())
 					{
-						entry = (Entry) entriesIt.next();
+						entry = entriesIt.next();
 						found = isRemovable(entry);
 					}
 				}
 
 				if (!found)
 				{
-					throw new JRRuntimeException("The virtualizer is used by more contexts than its in-memory cache size " + getMaximumSize());
+					log.warn("The virtualizer is used by more contexts than its in-memory cache size " + getMaximumSize());
+					return;
 				}
 
 				Object key = entry.getKey();
@@ -121,7 +121,7 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 				processRemovedLRU(key,value);
 			}
 
-			protected boolean isRemovable(Map.Entry entry)
+			protected boolean isRemovable(Map.Entry<?,?> entry)
 			{
 				JRVirtualizable value = getMapValue(entry.getValue());
 				return value == null || !lastObjectSet.containsKey(value);
@@ -137,13 +137,13 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 			}
 		}
 
-		private final ReferenceQueue refQueue;
+		private final ReferenceQueue<JRVirtualizable> refQueue;
 		private final LRUScanMap map;
 
 		Cache(int maxSize)
 		{
 			map = new LRUScanMap(maxSize);
-			refQueue = new ReferenceQueue();
+			refQueue = new ReferenceQueue<JRVirtualizable>();
 		}
 
 		protected JRVirtualizable getMapValue(Object val)
@@ -155,14 +155,14 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 			}
 			else
 			{
-				Reference ref = (Reference) val;
+				Reference<JRVirtualizable> ref = (Reference<JRVirtualizable>) val;
 				if (ref.isEnqueued())
 				{
 					o = null;
 				}
 				else
 				{
-					o = (JRVirtualizable) ref.get();
+					o = ref.get();
 				}
 			}
 			return o;
@@ -203,21 +203,21 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 			return getMapValue(map.remove(id));
 		}
 
-		public Iterator idIterator()
+		public Iterator<String> idIterator()
 		{
 			purge();
 
-			final Iterator valsIt = map.values().iterator();
-			return new Iterator()
+			final Iterator<CacheReference> valsIt = map.values().iterator();
+			return new Iterator<String>()
 			{
 				public boolean hasNext()
 				{
 					return valsIt.hasNext();
 				}
 
-				public Object next()
+				public String next()
 				{
-					CacheReference ref = (CacheReference) valsIt.next();
+					CacheReference ref = valsIt.next();
 					return ref.getId();
 				}
 
@@ -246,8 +246,8 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 		return false;
 	}
 
-	protected final Map classLoadersIndexes = new HashMap();
-	protected final List classLoadersList = new ArrayList();
+	protected final Map<ClassLoader,Integer> classLoadersIndexes = new HashMap<ClassLoader,Integer>();
+	protected final List<ClassLoader> classLoadersList = new ArrayList<ClassLoader>();
 
 	protected class ClassLoaderAnnotationObjectOutputStream extends ObjectOutputStream
 	{
@@ -256,7 +256,7 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 			super(out);
 		}
 
-		protected void annotateClass(Class clazz) throws IOException
+		protected void annotateClass(Class<?> clazz) throws IOException
 		{
 			super.annotateClass(clazz);
 
@@ -270,7 +270,7 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 			}
 			else
 			{
-				Integer idx = (Integer) classLoadersIndexes.get(classLoader);
+				Integer idx = classLoadersIndexes.get(classLoader);
 				if (idx == null)
 				{
 					idx = Integer.valueOf(classLoadersList.size());
@@ -291,9 +291,9 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 			super(in);
 		}
 
-		protected Class resolveClass(ObjectStreamClass desc) throws IOException, ClassNotFoundException
+		protected Class<?> resolveClass(ObjectStreamClass desc) throws IOException, ClassNotFoundException
 		{
-			Class clazz;
+			Class<?> clazz;
 			try
 			{
 				clazz = super.resolveClass(desc);
@@ -307,7 +307,7 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 					throw e;
 				}
 
-				ClassLoader loader = (ClassLoader) classLoadersList.get(loaderIdx);
+				ClassLoader loader = classLoadersList.get(loaderIdx);
 				clazz = Class.forName(desc.getName(), false, loader);
 			}
 
@@ -419,11 +419,16 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 	{
 		setLastObject(o);
 		JRVirtualizable old = pagedIn.put(o.getUID(), o);
-		if (old != null)
+		if (old != null && old != o)
 		{
 			pagedIn.put(o.getUID(), old);
 			throw new IllegalStateException("Wrong object stored with UID \"" + o.getUID() + "\"");
 		}
+		
+		if (log.isDebugEnabled())
+		{
+			log.debug("registered object " + o + " with id " + o.getUID());
+		}
 	}
 
 	public void deregisterObject(JRVirtualizable o)
@@ -465,6 +470,11 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 			// We don't really care if someone deregisters an object
 			// that's not registered.
 		}
+		
+		if (log.isDebugEnabled())
+		{
+			log.debug("deregistered object " + o + " with id " + o.getUID());
+		}
 	}
 
 	public synchronized void touch(JRVirtualizable o)
@@ -481,6 +491,11 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 		String uid = o.getUID();
 		if (isPagedOutAndTouch(o, uid))
 		{
+			if (log.isDebugEnabled())
+			{
+				log.debug("internalizing " + uid);
+			}
+			
 			// unvirtualize
 			try
 			{
@@ -492,14 +507,14 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 				throw new JRRuntimeException(e);
 			}
 
-			o.afterInternalization();
-
 			synchronized (this)
 			{
 				setLastObject(o);
 				pagedOut.remove(uid);
 				pagedIn.put(uid, o);
 			}
+
+			o.afterInternalization();
 		}
 	}
 
@@ -523,6 +538,11 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 		String uid = o.getUID();
 		if (!isPagedOut(uid))
 		{
+			if (log.isDebugEnabled())
+			{
+				log.debug("externalizing " + uid);
+			}
+			
 			o.beforeExternalization();
 
 			// virtualize
@@ -568,7 +588,6 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 		try
 		{
 			ObjectOutputStream oos = new ClassLoaderAnnotationObjectOutputStream(out);
-			oos.writeObject(o.getIdentityData());
 			oos.writeObject(o.getVirtualData());
 			oos.flush();
 		}
@@ -594,7 +613,6 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 		try
 		{
 			ObjectInputStream ois = new ClassLoaderAnnotationObjectInputStream(in);
-			o.setIdentityData(ois.readObject());
 			o.setVirtualData(ois.readObject());
 		}
 		catch (IOException e)
@@ -617,9 +635,9 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 	protected final void disposeAll()
 	{
 		// Remove all paged-out swap files.
-		for (Iterator it = pagedOut.keySet().iterator(); it.hasNext();)
+		for (Iterator<String> it = pagedOut.keySet().iterator(); it.hasNext();)
 		{
-			String id = (String) it.next();
+			String id = it.next();
 			try
 			{
 				dispose(id);
@@ -632,9 +650,9 @@ public abstract class JRAbstractLRUVirtualizer implements JRVirtualizer
 			}
 		}
 
-		for (Iterator it = pagedIn.idIterator(); it.hasNext();)
+		for (Iterator<String> it = pagedIn.idIterator(); it.hasNext();)
 		{
-			String id = (String) it.next();
+			String id = it.next();
 			try
 			{
 				dispose(id);
