@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -39,14 +39,14 @@ import net.sf.jasperreports.engine.type.WhenResourceMissingTypeEnum;
  * Base class for the dynamically generated expression evaluator classes.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JREvaluator.java 3717 2010-04-09 10:01:33Z teodord $
+ * @version $Id: JREvaluator.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public abstract class JREvaluator implements DatasetExpressionEvaluator
 {
 	/**
 	 * The resource bundle parameter.
 	 */
-	private JRFillParameter resourceBundle = null;
+	private JRFillParameter resourceBundle;
 	
 	/**
 	 * The resource missing type.
@@ -65,7 +65,7 @@ public abstract class JREvaluator implements DatasetExpressionEvaluator
 	{
 	}
 
-	
+
 	/**
 	 * Initializes the evaluator by setting the parameter, field and variable objects.
 	 * 
@@ -75,15 +75,23 @@ public abstract class JREvaluator implements DatasetExpressionEvaluator
 	 * @param resourceMissingType the resource missing type
 	 * @throws JRException
 	 */
-	public void init(Map parametersMap, Map fieldsMap, Map variablesMap, WhenResourceMissingTypeEnum resourceMissingType) throws JRException
+	public void init(
+			Map<String, JRFillParameter> parametersMap, 
+			Map<String, JRFillField> fieldsMap, 
+			Map<String, JRFillVariable> variablesMap, 
+			WhenResourceMissingTypeEnum resourceMissingType
+			) throws JRException
 	{
 		this.whenResourceMissingType = resourceMissingType;
-		this.resourceBundle = (JRFillParameter)parametersMap.get(JRParameter.REPORT_RESOURCE_BUNDLE);
-		this.locale = (JRFillParameter)parametersMap.get(JRParameter.REPORT_LOCALE);
+		this.resourceBundle = parametersMap.get(JRParameter.REPORT_RESOURCE_BUNDLE);
+		this.locale = parametersMap.get(JRParameter.REPORT_LOCALE);
 		customizedInit(parametersMap, fieldsMap, variablesMap);
 	}
 
 	
+	
+	
+	
 	/**
 	 * Constructs a message using a pattern with one parameter.
 	 * 
@@ -102,7 +110,7 @@ public abstract class JREvaluator implements DatasetExpressionEvaluator
 	 * 
 	 * @param pattern the message pattern
 	 * @param arg0 the first message parameter
-	 * @param arg1 the second message paramter
+	 * @param arg1 the second message parameter
 	 * @return the constructed message
 	 * @see MessageFormat#format(java.lang.Object[],java.lang.StringBuffer, java.text.FieldPosition)
 	 */
@@ -117,7 +125,7 @@ public abstract class JREvaluator implements DatasetExpressionEvaluator
 	 * 
 	 * @param pattern the message pattern
 	 * @param arg0 the first message parameter
-	 * @param arg1 the second message paramter
+	 * @param arg1 the second message parameter
 	 * @param arg2 the third parameter
 	 * @return the constructed message
 	 * @see MessageFormat#format(java.lang.Object[],java.lang.StringBuffer, java.text.FieldPosition)
@@ -314,7 +322,11 @@ public abstract class JREvaluator implements DatasetExpressionEvaluator
 	 * @param variablesMap the variables indexed by name
 	 * @throws JRException
 	 */
-	protected abstract void customizedInit(Map parametersMap, Map fieldsMap, Map variablesMap) throws JRException;
+	protected abstract void customizedInit(
+			Map<String, JRFillParameter> parametersMap, 
+			Map<String, JRFillField> fieldsMap, 
+			Map<String, JRFillVariable> variablesMap
+			) throws JRException;
 
 
 	/**
