@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -44,7 +44,7 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillBand.java 3466 2010-02-22 17:13:21Z teodord $
+ * @version $Id: JRFillBand.java 4732 2011-10-21 09:14:15Z lucianc $
  */
 public class JRFillBand extends JRFillElementContainer implements JRBand, JROriginProvider
 {
@@ -54,27 +54,27 @@ public class JRFillBand extends JRFillElementContainer implements JRBand, JROrig
 	/**
 	 *
 	 */
-	private JRBand parent = null;
+	private JRBand parent;
 
 	private boolean isPrintWhenTrue = true;
 
 	/**
 	 *
 	 */
-	private boolean isNewPageColumn = false;
-	private boolean isFirstWholeOnPageColumn = false;
-	private Map isNewGroupMap = new HashMap();
+	private boolean isNewPageColumn;
+	private boolean isFirstWholeOnPageColumn;
+	private Map<JRGroup,Boolean> isNewGroupMap = new HashMap<JRGroup,Boolean>();
 
-	private Set nowEvaluationTimes;
+	private Set<JREvaluationTime> nowEvaluationTimes;
 	
 	// used by subreports to save values of variables used as return receptacles
 	// so that the values can be restored when the bands gets rewound
-	private Map savedVariableValues = new HashMap();
+	private Map<String,Object> savedVariableValues = new HashMap<String,Object>();
 
-	protected JROrigin origin = null;
+	protected JROrigin origin;
 	
-	private SplitTypeEnum splitType = null;
-	private int breakHeight = 0;
+	private SplitTypeEnum splitType;
+	private int breakHeight;
 
 	
 	/**
@@ -125,7 +125,7 @@ public class JRFillBand extends JRFillElementContainer implements JRBand, JROrig
 
 		initConditionalStyles();
 
-		nowEvaluationTimes = new HashSet();
+		nowEvaluationTimes = new HashSet<JREvaluationTime>();
 	}
 
 
@@ -143,6 +143,11 @@ public class JRFillBand extends JRFillElementContainer implements JRBand, JROrig
 	 */
 	protected void setOrigin(JROrigin origin)
 	{
+		if (log.isDebugEnabled())
+		{
+			log.debug("Origin " + origin + " for band " + getId());
+		}
+		
 		this.origin = origin;
 		this.filler.getJasperPrint().addOrigin(origin);
 	}
@@ -191,7 +196,7 @@ public class JRFillBand extends JRFillElementContainer implements JRBand, JROrig
 	 */
 	protected boolean isNewGroup(JRGroup group)
 	{
-		Boolean value = (Boolean)isNewGroupMap.get(group);
+		Boolean value = isNewGroupMap.get(group);
 
 		if (value == null)
 		{
@@ -218,29 +223,6 @@ public class JRFillBand extends JRFillElementContainer implements JRBand, JROrig
 		return breakHeight;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getSplitType()}.
-	 */
-	public boolean isSplitAllowed()
-	{
-		return parent.isSplitAllowed();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setSplitType(Byte)}.
-	 */
-	public void setSplitAllowed(boolean isSplitAllowed)
-	{
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getSplitTypeValue()}.
-	 */
-	public Byte getSplitType()
-	{
-		return getSplitTypeValue() == null ? null : getSplitTypeValue().getValueByte();
-	}
-
 	/**
 	 *
 	 */
@@ -249,14 +231,6 @@ public class JRFillBand extends JRFillElementContainer implements JRBand, JROrig
 		return splitType;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setSplitType(SplitTypeEnum)}.
-	 */
-	public void setSplitType(Byte splitType)
-	{
-		throw new UnsupportedOperationException();
-	}
-
 	/**
 	 *
 	 */
@@ -426,7 +400,7 @@ public class JRFillBand extends JRFillElementContainer implements JRBand, JROrig
 
 		isFirstWholeOnPageColumn = isNewPageColumn && isOverflow;
 		isNewPageColumn = false;
-		isNewGroupMap = new HashMap();
+		isNewGroupMap = new HashMap<JRGroup,Boolean>();
 
 		JRPrintBand printBand = new JRPrintBand();
 		fillElements(printBand);
@@ -515,10 +489,10 @@ public class JRFillBand extends JRFillElementContainer implements JRBand, JROrig
 	
 	protected void restoreSavedVariables()
 	{
-		for (Iterator it = savedVariableValues.entrySet().iterator(); it.hasNext();)
+		for (Iterator<Map.Entry<String,Object>> it = savedVariableValues.entrySet().iterator(); it.hasNext();)
 		{
-			Map.Entry entry = (Map.Entry) it.next();
-			String variableName = (String) entry.getKey();
+			Map.Entry<String,Object> entry = it.next();
+			String variableName = entry.getKey();
 			Object value = entry.getValue();
 			JRFillVariable variable = filler.getVariable(variableName);
 			variable.setOldValue(value);
