@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -33,7 +33,7 @@ import net.sf.jasperreports.engine.type.BreakTypeEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillBreak.java 3472 2010-02-24 11:02:57Z shertage $
+ * @version $Id: JRFillBreak.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRFillBreak extends JRFillElement implements JRBreak
 {
@@ -76,22 +76,6 @@ public class JRFillBreak extends JRFillElement implements JRBreak
 		return width;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getTypeValue()}.
-	 */
-	public byte getType()
-	{
-		return ((JRBreak)parent).getTypeValue().getValue();
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #setType(BreakTypeEnum)}.
-	 */
-	public void setType(byte type)
-	{
-		throw new UnsupportedOperationException();
-	}
-
 	public BreakTypeEnum getTypeValue()
 	{
 		return ((JRBreak)parent).getTypeValue();
