@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -33,7 +33,6 @@ import net.sf.jasperreports.crosstabs.JRCellContents;
 import net.sf.jasperreports.crosstabs.fill.JRFillCrosstabObjectFactory;
 import net.sf.jasperreports.crosstabs.type.CrosstabColumnPositionEnum;
 import net.sf.jasperreports.crosstabs.type.CrosstabRowPositionEnum;
-import net.sf.jasperreports.engine.JRBox;
 import net.sf.jasperreports.engine.JRDefaultStyleProvider;
 import net.sf.jasperreports.engine.JRElement;
 import net.sf.jasperreports.engine.JRException;
@@ -45,7 +44,6 @@ import net.sf.jasperreports.engine.JRPrintFrame;
 import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.JRStyleSetter;
 import net.sf.jasperreports.engine.type.ModeEnum;
-import net.sf.jasperreports.engine.util.LineBoxWrapper;
 
 import org.apache.commons.collections.ReferenceMap;
 
@@ -53,14 +51,15 @@ import org.apache.commons.collections.ReferenceMap;
  * Crosstab cell contents filler.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRFillCellContents.java 3768 2010-04-26 11:54:22Z lucianc $
+ * @version $Id: JRFillCellContents.java 4648 2011-10-10 12:50:53Z lucianc $
  */
 public class JRFillCellContents extends JRFillElementContainer implements JRCellContents, JRStyleSetter
 {
-	private final Map transformedContentsCache;
-	private final Map boxContentsCache;
+	private final Map<StretchedContents,JRFillCellContents> transformedContentsCache;
+	private final Map<BoxContents,JRFillCellContents> boxContentsCache;
 	private final JRClonePool clonePool;
 	private final JROriginProvider originProvider;
+	private final int elementId;
 	
 	private JRFillCellContents original;
 	
@@ -78,7 +77,7 @@ public class JRFillCellContents extends JRFillElementContainer implements JRCell
 	private CrosstabRowPositionEnum verticalPositionType = CrosstabRowPositionEnum.TOP;
 	private int horizontalSpan;
 	
-	private Map templateFrames;
+	private Map<JRStyle,JRTemplateFrame> templateFrames;
 	
 	private JRDefaultStyleProvider defaultStyleProvider;
 	private JRStyle initStyle;
@@ -93,6 +92,7 @@ public class JRFillCellContents extends JRFillElementContainer implements JRCell
 		
 		parentCell = cell;
 		this.cellType = cellType;
+		elementId = filler.getFillContext().generateFillElementId();
 		
 		lineBox = cell.getLineBox().clone(this);
 		
@@ -111,13 +111,13 @@ public class JRFillCellContents extends JRFillElementContainer implements JRCell
 		setElementOriginProvider(this.originProvider);
 		
 		transformedContentsCache = new ReferenceMap();
-		boxContentsCache = new HashMap();
+		boxContentsCache = new HashMap<BoxContents,JRFillCellContents>();
 		clonePool = new JRClonePool(this, true, true);
 	}
 
 	private void initTemplatesMap()
 	{
-		templateFrames = new HashMap();
+		templateFrames = new HashMap<JRStyle,JRTemplateFrame>();
 	}
 
 	protected JRFillCellContents(JRFillCellContents cellContents, JRFillCloneFactory factory)
@@ -128,6 +128,7 @@ public class JRFillCellContents extends JRFillElementContainer implements JRCell
 		
 		parentCell = cellContents.parentCell;
 		cellType = cellContents.cellType;
+		elementId = cellContents.elementId;
 		
 		lineBox = cellContents.getLineBox().clone(this);
 		
@@ -145,7 +146,7 @@ public class JRFillCellContents extends JRFillElementContainer implements JRCell
 		this.originProvider = cellContents.originProvider;
 		
 		transformedContentsCache = new ReferenceMap();
-		boxContentsCache = new HashMap();
+		boxContentsCache = new HashMap<BoxContents,JRFillCellContents>();
 		clonePool = new JRClonePool(this, true, true);
 		
 		verticalPositionType = cellContents.verticalPositionType;
@@ -156,14 +157,6 @@ public class JRFillCellContents extends JRFillElementContainer implements JRCell
 		return parentCell.getBackcolor();
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public JRBox getBox()
-	{
-		return new LineBoxWrapper(getLineBox());
-	}
-
 	/**
 	 *
 	 */
@@ -223,7 +216,7 @@ public class JRFillCellContents extends JRFillElementContainer implements JRCell
 		}
 		
 		Object key = new BoxContents(copyLeft, copyRight, copyTop);
-		JRFillCellContents boxContents = (JRFillCellContents) boxContentsCache.get(key);
+		JRFillCellContents boxContents = boxContentsCache.get(key);
 		if (boxContents == null)
 		{
 			boxContents = (JRFillCellContents) createClone();
@@ -247,7 +240,7 @@ public class JRFillCellContents extends JRFillElementContainer implements JRCell
 			
 			boxContents.setBox(newBox);
 			
-			boxContentsCache.put(key, boxContents);
+			boxContentsCache.put((BoxContents)key, boxContents);
 		}
 		
 		return boxContents;
@@ -271,13 +264,13 @@ public class JRFillCellContents extends JRFillElementContainer implements JRCell
 		
 		Object key = new StretchedContents(newWidth, newHeight, xPosition, yPosition);
 		
-		JRFillCellContents transformedCell = (JRFillCellContents) transformedContentsCache.get(key);
+		JRFillCellContents transformedCell = transformedContentsCache.get(key);
 		if (transformedCell == null)
 		{
 			transformedCell = (JRFillCellContents) createClone();
 			transformedCell.transform(newWidth, newHeight, xPosition, yPosition);
 			
-			transformedContentsCache.put(key, transformedCell);
+			transformedContentsCache.put((StretchedContents)key, transformedCell);
 		}
 		
 		return transformedCell;
@@ -392,7 +385,7 @@ public class JRFillCellContents extends JRFillElementContainer implements JRCell
 		moveBandBottomElements();
 		removeBlankElements();
 
-		JRTemplatePrintFrame printCell = new JRTemplatePrintFrame(getTemplateFrame());
+		JRTemplatePrintFrame printCell = new JRTemplatePrintFrame(getTemplateFrame(), elementId);
 		printCell.setX(x);
 		printCell.setY(y);
 		printCell.setWidth(width);
@@ -433,11 +426,13 @@ public class JRFillCellContents extends JRFillElementContainer implements JRCell
 	protected JRTemplateFrame getTemplateFrame()
 	{
 		JRStyle style = getStyle();
-		JRTemplateFrame template = (JRTemplateFrame) templateFrames.get(style);
+		JRTemplateFrame template = templateFrames.get(style);
 		if (template == null)
 		{
 			template = new JRTemplateFrame(getOrigin(), 
 					filler.getJasperPrint().getDefaultStyleProvider(), this);
+			
+			template = filler.fillContext.deduplicate(template);
 			templateFrames.put(style, template);
 		}
 		return template;
@@ -467,21 +462,21 @@ public class JRFillCellContents extends JRFillElementContainer implements JRCell
 		
 		if (positionOffset != 0)
 		{
-			List printElements = printCell.getElements();
+			List<JRPrintElement> printElements = printCell.getElements();
 			
 			int positionY = getStretchHeight() - positionOffset;
 			boolean outside = false;
-			for (Iterator it = printElements.iterator(); !outside && it.hasNext();)
+			for (Iterator<JRPrintElement> it = printElements.iterator(); !outside && it.hasNext();)
 			{
-				JRPrintElement element = (JRPrintElement) it.next();
+				JRPrintElement element = it.next();
 				outside = element.getY() + element.getHeight() > positionY;
 			}
 			
 			if (!outside)
 			{
-				for (Iterator it = printElements.iterator(); it.hasNext();)
+				for (Iterator<JRPrintElement> it = printElements.iterator(); it.hasNext();)
 				{
-					JRPrintElement element = (JRPrintElement) it.next();
+					JRPrintElement element = it.next();
 					element.setY(element.getY() + positionOffset);
 				}
 			}
@@ -691,14 +686,6 @@ public class JRFillCellContents extends JRFillElementContainer implements JRCell
 		collectConditionalStyle(initStyle);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getModeValue()}.
-	 */
-	public Byte getMode()
-	{
-		return getModeValue() == null ? null : getModeValue().getValueByte();
-	}
-
 	public ModeEnum getModeValue()
 	{
 		return parentCell.getModeValue();
