@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -67,6 +67,8 @@ import net.sf.jasperreports.charts.fill.JRFillTimePeriodDataset;
 import net.sf.jasperreports.charts.fill.JRFillTimeSeriesDataset;
 import net.sf.jasperreports.charts.fill.JRFillXyDataset;
 import net.sf.jasperreports.charts.fill.JRFillXyzDataset;
+import net.sf.jasperreports.charts.type.AxisPositionEnum;
+import net.sf.jasperreports.charts.type.EdgeEnum;
 import net.sf.jasperreports.charts.util.CategoryChartHyperlinkProvider;
 import net.sf.jasperreports.charts.util.ChartHyperlinkProvider;
 import net.sf.jasperreports.charts.util.ChartUtil;
@@ -78,11 +80,11 @@ import net.sf.jasperreports.charts.util.TimePeriodChartHyperlinkProvider;
 import net.sf.jasperreports.charts.util.TimeSeriesChartHyperlinkProvider;
 import net.sf.jasperreports.charts.util.XYChartHyperlinkProvider;
 import net.sf.jasperreports.engine.JRAbstractChartCustomizer;
-import net.sf.jasperreports.engine.JRBox;
 import net.sf.jasperreports.engine.JRChart;
 import net.sf.jasperreports.engine.JRChartCustomizer;
 import net.sf.jasperreports.engine.JRChartDataset;
 import net.sf.jasperreports.engine.JRChartPlot;
+import net.sf.jasperreports.engine.JRChartPlot.JRSeriesColor;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRExpressionCollector;
@@ -96,13 +98,13 @@ import net.sf.jasperreports.engine.JRPrintImage;
 import net.sf.jasperreports.engine.JRRenderable;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRVisitor;
-import net.sf.jasperreports.engine.JRChartPlot.JRSeriesColor;
-import net.sf.jasperreports.engine.base.JRBaseFont;
+import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
+import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.util.JRClassLoader;
-import net.sf.jasperreports.engine.util.JRPenUtil;
 import net.sf.jasperreports.engine.util.JRProperties;
+import net.sf.jasperreports.engine.util.JRStringUtil;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
-import net.sf.jasperreports.engine.util.LineBoxWrapper;
 
 import org.jfree.chart.JFreeChart;
 import org.jfree.chart.axis.AxisLocation;
@@ -119,7 +121,7 @@ import org.jfree.data.general.Dataset;
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
  * @author Some enhancements by Barry Klawans (bklawans@users.sourceforge.net)
- * @version $Id: JRFillChart.java 3034 2009-08-27 11:58:04Z teodord $
+ * @version $Id: JRFillChart.java 4648 2011-10-10 12:50:53Z lucianc $
  */
 public class JRFillChart extends JRFillElement implements JRChart
 {
@@ -128,29 +130,29 @@ public class JRFillChart extends JRFillElement implements JRChart
 	/**
 	 *
 	 */
-	protected byte chartType = 0;
+	protected byte chartType;
 
 	/**
 	 *
 	 */
-	protected JRFont titleFont = null;
-	protected JRFont subtitleFont = null;
-	protected JRFont legendFont = null;
+	protected JRFont titleFont;
+	protected JRFont subtitleFont;
+	protected JRFont legendFont;
 	protected final JRLineBox lineBox;
 
 	/**
 	 *
 	 */
-	protected JRGroup evaluationGroup = null;
+	protected JRGroup evaluationGroup;
 
-	protected JRFillChartDataset dataset = null;
-	protected JRChartPlot plot = null;
+	protected JRFillChartDataset dataset;
+	protected JRChartPlot plot;
 
-	protected JRRenderable renderer = null;
-	private String anchorName = null;
-	private String hyperlinkReference = null;
-	private String hyperlinkAnchor = null;
-	private Integer hyperlinkPage = null;
+	protected JRRenderable renderer;
+	private String anchorName;
+	private String hyperlinkReference;
+	private String hyperlinkAnchor;
+	private Integer hyperlinkPage;
 	private String hyperlinkTooltip;
 	private JRPrintHyperlinkParameters hyperlinkParameters;
 
@@ -277,9 +279,9 @@ public class JRFillChart extends JRFillElement implements JRChart
 				throw new JRRuntimeException("Chart type not supported.");
 		}
 
-		titleFont = new JRBaseFont(chart, chart.getTitleFont());
-		subtitleFont = new JRBaseFont(chart, chart.getSubtitleFont());
-		legendFont = new JRBaseFont(chart, chart.getLegendFont());
+		titleFont = factory.getFont(chart, chart.getTitleFont());
+		subtitleFont = factory.getFont(chart, chart.getSubtitleFont());
+		legendFont =  factory.getFont(this, chart.getLegendFont());
 		
 		lineBox = chart.getLineBox().clone(this);
 
@@ -288,7 +290,7 @@ public class JRFillChart extends JRFillElement implements JRChart
 		customizerClass = chart.getCustomizerClass();
 		if (customizerClass != null && customizerClass.length() > 0) {
 			try {
-				Class myClass = JRClassLoader.loadClassForName(customizerClass);
+				Class<?> myClass = JRClassLoader.loadClassForName(customizerClass);
 				chartCustomizer = (JRChartCustomizer) myClass.newInstance();
 			} catch (Exception e) {
 				throw new JRRuntimeException("Could not create chart customizer instance.", e);
@@ -317,24 +319,9 @@ public class JRFillChart extends JRFillElement implements JRChart
 	/**
 	 *
 	 */
-	public byte getMode()
-	{
-		return JRStyleResolver.getMode(this, MODE_TRANSPARENT);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getShowLegend()}
-	 */
-	public boolean isShowLegend()
-	{
-		return ((JRChart)parent).isShowLegend();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setShowLegend(Boolean)}
-	 */
-	public void setShowLegend(boolean isShowLegend)
+	public ModeEnum getModeValue()
 	{
+		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
 	}
 
 	/**
@@ -385,9 +372,9 @@ public class JRFillChart extends JRFillElement implements JRChart
 	/**
 	 *
 	 */
-	public byte getEvaluationTime()
+	public EvaluationTimeEnum getEvaluationTimeValue()
 	{
-		return ((JRChart)parent).getEvaluationTime();
+		return ((JRChart)parent).getEvaluationTimeValue();
 	}
 
 	/**
@@ -398,14 +385,6 @@ public class JRFillChart extends JRFillElement implements JRChart
 		return evaluationGroup;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()} 
-	 */
-	public JRBox getBox()
-	{
-		return new LineBoxWrapper(getLineBox());
-	}
-
 	/**
 	 *
 	 */
@@ -414,446 +393,6 @@ public class JRFillChart extends JRFillElement implements JRChart
 		return lineBox;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public byte getBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(getLineBox().getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Byte getOwnBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(getLineBox().getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setBorder(byte border)
-	{
-		JRPenUtil.setLinePenFromPen(border, getLineBox().getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setBorder(Byte border)
-	{
-		JRPenUtil.setLinePenFromPen(border, getLineBox().getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getBorderColor()
-	{
-		return getLineBox().getPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getOwnBorderColor()
-	{
-		return getLineBox().getPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setBorderColor(Color borderColor)
-	{
-		getLineBox().getPen().setLineColor(borderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public int getPadding()
-	{
-		return getLineBox().getPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Integer getOwnPadding()
-	{
-		return getLineBox().getOwnPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setPadding(int padding)
-	{
-		getLineBox().setPadding(padding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setPadding(Integer padding)
-	{
-		getLineBox().setPadding(padding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public byte getTopBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(getLineBox().getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Byte getOwnTopBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(getLineBox().getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setTopBorder(byte topBorder)
-	{
-		JRPenUtil.setLinePenFromPen(topBorder, getLineBox().getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setTopBorder(Byte topBorder)
-	{
-		JRPenUtil.setLinePenFromPen(topBorder, getLineBox().getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getTopBorderColor()
-	{
-		return getLineBox().getTopPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getOwnTopBorderColor()
-	{
-		return getLineBox().getTopPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setTopBorderColor(Color topBorderColor)
-	{
-		getLineBox().getTopPen().setLineColor(topBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public int getTopPadding()
-	{
-		return getLineBox().getTopPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Integer getOwnTopPadding()
-	{
-		return getLineBox().getOwnTopPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setTopPadding(int topPadding)
-	{
-		getLineBox().setTopPadding(topPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setTopPadding(Integer topPadding)
-	{
-		getLineBox().setTopPadding(topPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public byte getLeftBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(getLineBox().getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Byte getOwnLeftBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(getLineBox().getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setLeftBorder(byte leftBorder)
-	{
-		JRPenUtil.setLinePenFromPen(leftBorder, getLineBox().getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setLeftBorder(Byte leftBorder)
-	{
-		JRPenUtil.setLinePenFromPen(leftBorder, getLineBox().getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getLeftBorderColor()
-	{
-		return getLineBox().getLeftPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getOwnLeftBorderColor()
-	{
-		return getLineBox().getLeftPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setLeftBorderColor(Color leftBorderColor)
-	{
-		getLineBox().getLeftPen().setLineColor(leftBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public int getLeftPadding()
-	{
-		return getLineBox().getLeftPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Integer getOwnLeftPadding()
-	{
-		return getLineBox().getOwnLeftPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setLeftPadding(int leftPadding)
-	{
-		getLineBox().setLeftPadding(leftPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setLeftPadding(Integer leftPadding)
-	{
-		getLineBox().setLeftPadding(leftPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public byte getBottomBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(getLineBox().getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Byte getOwnBottomBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(getLineBox().getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setBottomBorder(byte bottomBorder)
-	{
-		JRPenUtil.setLinePenFromPen(bottomBorder, getLineBox().getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setBottomBorder(Byte bottomBorder)
-	{
-		JRPenUtil.setLinePenFromPen(bottomBorder, getLineBox().getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getBottomBorderColor()
-	{
-		return getLineBox().getBottomPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getOwnBottomBorderColor()
-	{
-		return getLineBox().getBottomPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setBottomBorderColor(Color bottomBorderColor)
-	{
-		getLineBox().getBottomPen().setLineColor(bottomBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public int getBottomPadding()
-	{
-		return getLineBox().getBottomPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Integer getOwnBottomPadding()
-	{
-		return getLineBox().getOwnBottomPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setBottomPadding(int bottomPadding)
-	{
-		getLineBox().setBottomPadding(bottomPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setBottomPadding(Integer bottomPadding)
-	{
-		getLineBox().setBottomPadding(bottomPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public byte getRightBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(getLineBox().getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Byte getOwnRightBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(getLineBox().getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setRightBorder(byte rightBorder)
-	{
-		JRPenUtil.setLinePenFromPen(rightBorder, getLineBox().getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setRightBorder(Byte rightBorder)
-	{
-		JRPenUtil.setLinePenFromPen(rightBorder, getLineBox().getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getRightBorderColor()
-	{
-		return getLineBox().getRightPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Color getOwnRightBorderColor()
-	{
-		return getLineBox().getRightPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setRightBorderColor(Color rightBorderColor)
-	{
-		getLineBox().getRightPen().setLineColor(rightBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public int getRightPadding()
-	{
-		return getLineBox().getRightPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public Integer getOwnRightPadding()
-	{
-		return getLineBox().getOwnRightPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setRightPadding(int rightPadding)
-	{
-		getLineBox().setRightPadding(rightPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public void setRightPadding(Integer rightPadding)
-	{
-		getLineBox().setRightPadding(rightPadding);
-	}
-
 	/**
 	 *
 	 */
@@ -863,33 +402,19 @@ public class JRFillChart extends JRFillElement implements JRChart
 	}
 
 	/**
-	 * @deprecated Replaced by {@link #getTitlePositionByte()}
+	 *
 	 */
-	public byte getTitlePosition()
-	{
-		return ((JRChart)parent).getTitlePosition();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setTitlePosition(Byte)}
-	 */
-	public void setTitlePosition(byte titlePosition)
+	public EdgeEnum getTitlePositionValue()
 	{
+		return ((JRChart)parent).getTitlePositionValue();
 	}
 
 	/**
 	 *
 	 */
-	public Byte getTitlePositionByte()
-	{
-		return ((JRChart)parent).getTitlePositionByte();
-	}
-
-	/**
-	 *
-	 */
-	public void setTitlePosition(Byte titlePosition)
+	public void setTitlePosition(EdgeEnum titlePosition)
 	{
+		throw new UnsupportedOperationException();
 	}
 
 	/**
@@ -1015,33 +540,19 @@ public class JRFillChart extends JRFillElement implements JRChart
 	}
 
 	/**
-	 * @deprecated Replaced by {@link #getLegendPositionByte()}
+	 *
 	 */
-	public byte getLegendPosition()
-	{
-		return ((JRChart)parent).getLegendPosition();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setLegendPosition(Byte)}
-	 */
-	public void setLegendPosition(byte legendPosition)
+	public EdgeEnum getLegendPositionValue()
 	{
+		return ((JRChart)parent).getLegendPositionValue();
 	}
 
 	/**
 	 *
 	 */
-	public Byte getLegendPositionByte()
-	{
-		return ((JRChart)parent).getLegendPositionByte();
-	}
-
-	/**
-	 *
-	 */
-	public void setLegendPosition(Byte legendPosition)
+	public void setLegendPosition(EdgeEnum legendPosition)
 	{
+		throw new UnsupportedOperationException();
 	}
 
 	/**
@@ -1061,11 +572,19 @@ public class JRFillChart extends JRFillElement implements JRChart
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getHyperlinkTypeValue()}.
 	 */
 	public byte getHyperlinkType()
 	{
-		return ((JRChart)parent).getHyperlinkType();
+		return getHyperlinkTypeValue().getValue();
+	}
+
+	/**
+	 *
+	 */
+	public HyperlinkTypeEnum getHyperlinkTypeValue()
+	{
+		return ((JRChart)parent).getHyperlinkTypeValue();
 	}
 
 	/**
@@ -1232,13 +751,9 @@ public class JRFillChart extends JRFillElement implements JRChart
 
 		evaluatePrintWhenExpression(evaluation);
 
-		if (
-			(isPrintWhenExpressionNull() ||
-			(!isPrintWhenExpressionNull() &&
-			isPrintWhenTrue()))
-			)
+		if (isPrintWhenExpressionNull() || isPrintWhenTrue())
 		{
-			if (getEvaluationTime() == JRExpression.EVALUATION_TIME_NOW)
+			if (getEvaluationTimeValue() == EvaluationTimeEnum.NOW)
 			{
 				evaluateRenderer(evaluation);
 			}
@@ -1336,7 +851,7 @@ public class JRFillChart extends JRFillElement implements JRChart
 		boolean isToPrint = true;
 		boolean isReprinted = false;
 
-		if (getEvaluationTime() == JRExpression.EVALUATION_TIME_NOW)
+		if (getEvaluationTimeValue() == EvaluationTimeEnum.NOW)
 		{
 			if (isOverflow && isAlreadyPrinted() && !isPrintWhenDetailOverflows())
 			{
@@ -1410,21 +925,21 @@ public class JRFillChart extends JRFillElement implements JRChart
 	 */
 	protected JRPrintElement fill()
 	{
-		JRTemplatePrintImage printImage = new JRTemplatePrintImage(getJRTemplateImage());
+		JRTemplatePrintImage printImage = new JRTemplatePrintImage(getJRTemplateImage(), elementId);
 
 		printImage.setX(getX());
 		printImage.setY(getRelativeY());
 		printImage.setWidth(getWidth());
 		printImage.setHeight(getStretchHeight());
 
-		byte evaluationType = getEvaluationTime();
-		if (evaluationType == JRExpression.EVALUATION_TIME_NOW)
+		EvaluationTimeEnum evaluationTime = getEvaluationTimeValue();
+		if (evaluationTime == EvaluationTimeEnum.NOW)
 		{
 			copy(printImage);
 		}
 		else
 		{
-			filler.addBoundElement(this, printImage, evaluationType, getEvaluationGroup(), band);
+			filler.addBoundElement(this, printImage, evaluationTime, getEvaluationGroup(), band);
 		}
 
 		return printImage;
@@ -1525,7 +1040,7 @@ public class JRFillChart extends JRFillElement implements JRChart
 				}
 				break;
 			case JRChart.CHART_TYPE_GANTT:
-				chartHyperlinkProvider = new CategoryChartHyperlinkProvider(((JRFillGanttDataset)getDataset()).getItemHyperlinks());
+				chartHyperlinkProvider = new XYChartHyperlinkProvider(((JRFillGanttDataset)getDataset()).getItemHyperlinks());
 				break;
 			case JRChart.CHART_TYPE_METER:
 			case JRChart.CHART_TYPE_THERMOMETER:
@@ -1572,7 +1087,7 @@ public class JRFillChart extends JRFillElement implements JRChart
 		MultiAxisChartHyperlinkProvider multiHyperlinkProvider = new MultiAxisChartHyperlinkProvider();
 		
 		// Generate the main plot from the first axes specified.
-		Iterator iter = jrPlot.getAxes().iterator();
+		Iterator<JRChartAxis> iter = jrPlot.getAxes().iterator();
 		if (iter.hasNext())
 		{
 			JRFillChartAxis axis = (JRFillChartAxis)iter.next();
@@ -1592,7 +1107,7 @@ public class JRFillChart extends JRFillElement implements JRChart
 			if (mainPlot instanceof CategoryPlot)
 			{
 				CategoryPlot categoryPlot = (CategoryPlot) mainPlot;
-//				categoryPlot.setRangeAxisLocation(0, getChartAxisLocation(axis));
+				categoryPlot.setRangeAxisLocation(0, getChartAxisLocation(axis));
 				if (axisHyperlinkProvider != null)
 				{
 					multiHyperlinkProvider.addHyperlinkProvider(categoryPlot.getDataset(), 
@@ -1602,7 +1117,7 @@ public class JRFillChart extends JRFillElement implements JRChart
 			else if (mainPlot instanceof XYPlot)
 			{
 				XYPlot xyPlot = (XYPlot) mainPlot;
-//				xyPlot.setRangeAxisLocation(0, getChartAxisLocation(axis));
+				xyPlot.setRangeAxisLocation(0, getChartAxisLocation(axis));
 				if (axisHyperlinkProvider != null)
 				{
 					multiHyperlinkProvider.addHyperlinkProvider(xyPlot.getDataset(), axisHyperlinkProvider);
@@ -1637,7 +1152,7 @@ public class JRFillChart extends JRFillElement implements JRChart
 				// Get the axis and add it to the multi axis chart plot
 				CategoryPlot axisPlot = (CategoryPlot)axisChart.getPlot();
 				mainCatPlot.setRangeAxis(axisNumber, axisPlot.getRangeAxis());
-//				mainCatPlot.setRangeAxisLocation(axisNumber, getChartAxisLocation(chartAxis));
+				mainCatPlot.setRangeAxisLocation(axisNumber, getChartAxisLocation(chartAxis));
 
 				// Add the data set and map it to the recently added axis
 				mainCatPlot.setDataset(axisNumber, axisPlot.getDataset());
@@ -1666,7 +1181,7 @@ public class JRFillChart extends JRFillElement implements JRChart
 				// Get the axis and add it to the multi axis chart plot
 				XYPlot axisPlot = (XYPlot)axisChart.getPlot();
 				mainXyPlot.setRangeAxis(axisNumber, axisPlot.getRangeAxis());
-//				mainXyPlot.setRangeAxisLocation(axisNumber, getChartAxisLocation(chartAxis));
+				mainXyPlot.setRangeAxisLocation(axisNumber, getChartAxisLocation(chartAxis));
 
 				// Add the data set and map it to the recently added axis
 				mainXyPlot.setDataset(axisNumber, axisPlot.getDataset());
@@ -1710,14 +1225,14 @@ public class JRFillChart extends JRFillElement implements JRChart
 	 */
 	private void configureAxisSeriesColors(CategoryItemRenderer renderer, JRChartPlot jrPlot)
 	{
-		SortedSet seriesColors = jrPlot.getSeriesColors();
+		SortedSet<JRSeriesColor> seriesColors = jrPlot.getSeriesColors();
 
 		if (seriesColors != null)
 		{
-			Iterator iter = seriesColors.iterator();
+			Iterator<JRSeriesColor> iter = seriesColors.iterator();
 			while (iter.hasNext())
 			{
-				JRSeriesColor seriesColor = (JRSeriesColor)iter.next();
+				JRSeriesColor seriesColor = iter.next();
 				renderer.setSeriesPaint(seriesColor.getSeriesOrder(), seriesColor.getColor());
 			}
 		}
@@ -1738,14 +1253,14 @@ public class JRFillChart extends JRFillElement implements JRChart
 	 */
 	private void configureAxisSeriesColors(XYItemRenderer renderer, JRChartPlot jrPlot)
 	{
-		SortedSet seriesColors = jrPlot.getSeriesColors();
+		SortedSet<JRSeriesColor> seriesColors = jrPlot.getSeriesColors();
 
 		if (seriesColors != null)
 		{
-			Iterator iter = seriesColors.iterator();
+			Iterator<JRSeriesColor> iter = seriesColors.iterator();
 			while (iter.hasNext())
 			{
-				JRSeriesColor seriesColor = (JRSeriesColor)iter.next();
+				JRSeriesColor seriesColor = iter.next();
 				renderer.setSeriesPaint(seriesColor.getSeriesOrder(), seriesColor.getColor());
 			}
 		}
@@ -1763,8 +1278,9 @@ public class JRFillChart extends JRFillElement implements JRChart
 	protected Range convertRange(JRDataRange dataRange, byte evaluation) throws JRException
 	{
 		if (dataRange == null)
+		{
 			return null;
-
+		}
 		Number low = (Number)evaluateExpression(dataRange.getLowExpression(), evaluation);
 		Number high = (Number)evaluateExpression(dataRange.getHighExpression(), evaluation);
 		return new Range( low != null ? low.doubleValue() : 0.0,
@@ -1783,7 +1299,9 @@ public class JRFillChart extends JRFillElement implements JRChart
 	{
 		String label = interval.getLabel();
 		if (label == null)
+		{
 			label = "";
+		}
 
 		Range range = convertRange(interval.getDataRange(), evaluation);
 
@@ -1798,7 +1316,7 @@ public class JRFillChart extends JRFillElement implements JRChart
 
 	protected AxisLocation getChartAxisLocation(JRFillChartAxis chartAxis)
 	{
-		return chartAxis.getPositionByte() != null && chartAxis.getPositionByte().byteValue() == JRChartAxis.POSITION_RIGHT_OR_BOTTOM
+		return chartAxis.getPositionValue() != null && chartAxis.getPositionValue() == AxisPositionEnum.RIGHT_OR_BOTTOM
 				? AxisLocation.BOTTOM_OR_RIGHT 
 				: AxisLocation.TOP_OR_LEFT;
 	}
@@ -1860,7 +1378,6 @@ public class JRFillChart extends JRFillElement implements JRChart
 		return ((JRChart) parent).getHyperlinkTooltipExpression();
 	}
 
-	
 	class FillChartContext implements ChartContext
 	{
 		private final byte evaluation; 
@@ -1870,6 +1387,10 @@ public class JRFillChart extends JRFillElement implements JRChart
 			this.evaluation = evaluation;
 		}
 		
+		public String evaluateTextExpression(JRExpression expression) throws JRException {
+			return JRStringUtil.getString(JRFillChart.this.evaluateExpression(expression, evaluation));
+		}
+
 		public Object evaluateExpression(JRExpression expression) throws JRException {
 			return JRFillChart.this.evaluateExpression(expression, evaluation);
 		}
@@ -1893,6 +1414,9 @@ public class JRFillChart extends JRFillElement implements JRChart
 		public TimeZone getTimeZone() {
 			return JRFillChart.this.getTimeZone();
 		}
-		
+		public byte getEvaluation() 
+		{
+			return JRFillChart.this.getEvaluationTimeValue().getValue();
+		}
 	}
 }
