@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -28,6 +28,7 @@ import java.util.Collection;
 import java.util.SortedSet;
 
 import net.sf.jasperreports.charts.JRCategoryAxisFormat;
+import net.sf.jasperreports.charts.type.PlotOrientationEnum;
 import net.sf.jasperreports.engine.JRChart;
 import net.sf.jasperreports.engine.JRChartPlot;
 import net.sf.jasperreports.engine.JRExpressionCollector;
@@ -38,7 +39,7 @@ import org.jfree.chart.plot.PlotOrientation;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillChartPlot.java 3610 2010-03-23 10:01:26Z teodord $
+ * @version $Id: JRFillChartPlot.java 4613 2011-09-16 14:41:12Z teodord $
  */
 public class JRFillChartPlot implements JRChartPlot
 {
@@ -47,12 +48,12 @@ public class JRFillChartPlot implements JRChartPlot
 	/**
 	 *
 	 */
-	protected JRChartPlot parent = null;
+	protected JRChartPlot parent;
 
 	/**
 	 *
 	 */
-	protected JRChart chart = null;
+	protected JRChart chart;
 
 
 	/**
@@ -103,66 +104,37 @@ public class JRFillChartPlot implements JRChartPlot
 	}
 
 	/**
-	 *
+	 * @deprecated Replaed by {@link #getOrientationValue()}.
 	 */
 	public PlotOrientation getOrientation()
 	{
-		return parent.getOrientation();
+		return getOrientationValue().getOrientation();
 	}
 	
 	/**
 	 *
 	 */
+	public PlotOrientationEnum getOrientationValue()
+	{
+		return parent.getOrientationValue();
+	}
+	
+	/**
+	 * @deprecated Replaced by {@link #setOrientation(PlotOrientationEnum)}.
+	 */
 	public void setOrientation(PlotOrientation orientation)
+	{
+		setOrientation(PlotOrientationEnum.getByValue(orientation));
+	}
+		
+	/**
+	 *
+	 */
+	public void setOrientation(PlotOrientationEnum orientation)
 	{
 		throw new UnsupportedOperationException();
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getBackgroundAlphaFloat()}
-	 */
-	public float getBackgroundAlpha()
-	{
-		return parent.getBackgroundAlpha();
-	}
-	
-	/**
-	 * @deprecated Replaced by {@link #setBackgroundAlpha(Float)}
-	 */
-	public void setBackgroundAlpha(float BackgroundAlpha)
-	{
-	}
-	
-	/**
-	 * @deprecated Replaced by {@link #getForegroundAlphaFloat()}
-	 */
-	public float getForegroundAlpha()
-	{
-		return parent.getForegroundAlpha();
-	}
-	
-	/**
-	 * @deprecated Replaced by {@link #setForegroundAlpha(Float)}
-	 */
-	public void setForegroundAlpha(float foregroundAlpha)
-	{
-	}
-	
-	/**
-	 * @deprecated Replaced by {@link #getLabelRotationDouble()}
-	 */
-	public double getLabelRotation()
-	{
-		return parent.getLabelRotation();
-	}
-	
-	/**
-	 * @deprecated Replaced by {@link #setLabelRotation(Double)}
-	 */
-	public void setLabelRotation(double labelRotation)
-	{
-	}
-	
 	/**
 	 *
 	 */
@@ -213,7 +185,7 @@ public class JRFillChartPlot implements JRChartPlot
 	 * Returns a list of all the defined series colors.  Every entry in the list is of type JRChartPlot.JRSeriesColor.
 	 * If there are no defined series colors this method will return an empty list, not null. 
 	 */
-	public SortedSet getSeriesColors()
+	public SortedSet<JRSeriesColor> getSeriesColors()
 	{
 		return parent.getSeriesColors();
 	}
@@ -232,7 +204,7 @@ public class JRFillChartPlot implements JRChartPlot
 	{
 	}
 
-	public void setSeriesColors(Collection colors)
+	public void setSeriesColors(Collection<JRSeriesColor> colors)
 	{
 		// NOOP
 	}
