@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -48,7 +48,7 @@ import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
  * A {@link JRComponentElement} which is used during report fill.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRFillComponentElement.java 3505 2010-03-04 14:08:05Z teodord $
+ * @version $Id: JRFillComponentElement.java 4648 2011-10-10 12:50:53Z lucianc $
  */
 public class JRFillComponentElement extends JRFillElement implements JRComponentElement, FillContext
 {
@@ -203,11 +203,21 @@ public class JRFillComponentElement extends JRFillElement implements JRComponent
 		return super.evaluateExpression(expression, evaluation);
 	}
 
+	public JRFillDataset getFillDataset()
+	{
+		return expressionEvaluator.getFillDataset();
+	}
+
 	public JRComponentElement getComponentElement()
 	{
 		return this;
 	}
 
+	public int getElementSourceId()
+	{
+		return elementId;
+	}
+
 	public JROrigin getElementOrigin()
 	{
 		return super.getElementOrigin();
