@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -27,10 +27,12 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Comparator;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.ResourceBundle;
+import java.util.Set;
 
 import net.sf.jasperreports.crosstabs.JRCellContents;
 import net.sf.jasperreports.crosstabs.JRCrosstab;
@@ -53,11 +55,11 @@ import net.sf.jasperreports.crosstabs.fill.JRFillCrosstabObjectFactory;
 import net.sf.jasperreports.crosstabs.fill.JRFillCrosstabParameter;
 import net.sf.jasperreports.crosstabs.fill.JRFillCrosstabRowGroup;
 import net.sf.jasperreports.crosstabs.fill.calculation.BucketDefinition;
+import net.sf.jasperreports.crosstabs.fill.calculation.BucketDefinition.Bucket;
 import net.sf.jasperreports.crosstabs.fill.calculation.BucketingService;
 import net.sf.jasperreports.crosstabs.fill.calculation.CrosstabCell;
 import net.sf.jasperreports.crosstabs.fill.calculation.HeaderCell;
 import net.sf.jasperreports.crosstabs.fill.calculation.MeasureDefinition;
-import net.sf.jasperreports.crosstabs.fill.calculation.BucketDefinition.Bucket;
 import net.sf.jasperreports.crosstabs.fill.calculation.MeasureDefinition.MeasureValue;
 import net.sf.jasperreports.crosstabs.type.CrosstabColumnPositionEnum;
 import net.sf.jasperreports.crosstabs.type.CrosstabPercentageEnum;
@@ -89,7 +91,7 @@ import org.jfree.data.general.Dataset;
  * Fill-time implementation of a {@link net.sf.jasperreports.crosstabs.JRCrosstab crosstab}.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRFillCrosstab.java 3657 2010-03-31 09:34:49Z teodord $
+ * @version $Id: JRFillCrosstab.java 4676 2011-10-11 13:19:23Z lucianc $
  */
 public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROriginProvider
 {
@@ -99,11 +101,11 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 
 	protected JRFillCrosstabRowGroup[] rowGroups;
 
-	protected Map rowGroupsMap;
+	protected Map<String,Integer> rowGroupsMap;
 
 	protected JRFillCrosstabColumnGroup[] columnGroups;
 
-	protected Map columnGroupsMap;
+	protected Map<String,Integer> columnGroupsMap;
 
 	protected JRFillCrosstabMeasure[] measures;
 
@@ -111,14 +113,14 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 
 	protected JRFillVariable[] variables;
 
-	protected Map variablesMap;
+	protected Map<String,JRFillVariable> variablesMap;
 	
 	protected JRFillVariable[][][] totalVariables;
 	protected boolean[][] retrieveTotal;
 
 	protected JRFillCrosstabParameter[] parameters;
 
-	protected Map parametersMap;
+	protected Map<String,JRFillParameter> parametersMap;
 	
 	protected boolean ignoreWidth;
 
@@ -139,7 +141,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 	private CrosstabFiller crosstabFiller;
 	private int overflowStartPage;
 	
-	private List fillElements;
+	private List<JRPrintElement> fillElements;
 	
 	public JRFillCrosstab(JRBaseFiller filler, JRCrosstab crosstab, JRFillObjectFactory factory)
 	{
@@ -165,23 +167,43 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 				JRCellContents.TYPE_NO_DATA_CELL);
 		
 		dataset = factory.getCrosstabDataset(crosstab.getDataset(), this);
+		crosstabEvaluator.setFillDataset(dataset.getFillDataset());
 
 		copyParameters(crosstab, factory);
 		copyVariables(crosstab, crosstabFactory);
-
-		// default value from property
-		this.ignoreWidth = JRProperties.getBooleanProperty(filler.jasperReport, 
-				PROPERTY_IGNORE_WIDTH, false);
-		Boolean crosstabIgnoreWidth = crosstab.getIgnoreWidth();
-		// crosstab attribute overrides property 
-		if (crosstabIgnoreWidth != null)
-		{
-			this.ignoreWidth = crosstabIgnoreWidth.booleanValue();
-		}
 		
 		crosstabFiller = new CrosstabFiller();
 	}
 
+	private boolean isIgnoreWidth(JRBaseFiller filler, JRCrosstab crosstab)
+	{
+		Boolean crosstabIgnoreWidth = crosstab.getIgnoreWidth();
+		// crosstab attribute overrides all 
+		if (crosstabIgnoreWidth != null)
+		{
+			return crosstabIgnoreWidth.booleanValue();
+		}
+		
+		// report level property
+		String reportProperty = filler.jasperReport.getPropertiesMap().getProperty(
+				PROPERTY_IGNORE_WIDTH);
+		if (reportProperty != null)
+		{
+			return JRProperties.asBoolean(reportProperty);
+		}
+		
+		// report pagination parameter from the master filler
+		Boolean ignorePaginationParam = (Boolean) filler.getMasterFiller().getParameterValue(
+				JRParameter.IS_IGNORE_PAGINATION);
+		if (ignorePaginationParam != null && ignorePaginationParam.booleanValue())
+		{
+			return ignorePaginationParam.booleanValue();
+		}
+		
+		// global property
+		return JRProperties.getBooleanProperty(PROPERTY_IGNORE_WIDTH);
+	}
+
 	/**
 	 *
 	 */
@@ -194,7 +216,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 	{
 		JRCrosstabRowGroup[] groups = crosstab.getRowGroups();
 		rowGroups = new JRFillCrosstabRowGroup[groups.length];
-		rowGroupsMap = new HashMap();
+		rowGroupsMap = new HashMap<String,Integer>();
 		for (int i = 0; i < groups.length; ++i)
 		{
 			JRFillCrosstabRowGroup group = factory.getCrosstabRowGroup(groups[i]);
@@ -209,7 +231,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 	{
 		JRCrosstabColumnGroup[] groups = crosstab.getColumnGroups();
 		columnGroups = new JRFillCrosstabColumnGroup[groups.length];
-		columnGroupsMap = new HashMap();
+		columnGroupsMap = new HashMap<String,Integer>();
 		for (int i = 0; i < groups.length; ++i)
 		{
 			JRFillCrosstabColumnGroup group = factory.getCrosstabColumnGroup(groups[i]);
@@ -232,7 +254,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 	{
 		JRCrosstabParameter[] crossParams = crosstab.getParameters();
 		parameters = new JRFillCrosstabParameter[crossParams.length];
-		parametersMap = new HashMap();
+		parametersMap = new HashMap<String,JRFillParameter>();
 		for (int i = 0; i < crossParams.length; i++)
 		{
 			parameters[i] = factory.getCrosstabParameter(crossParams[i]);
@@ -260,14 +282,14 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 	{
 		JRVariable[] vars = crosstab.getVariables();
 		variables = new JRFillVariable[vars.length];
-		variablesMap = new HashMap();
+		variablesMap = new HashMap<String,JRFillVariable>();
 		for (int i = 0; i < variables.length; i++)
 		{
 			variables[i] = factory.getVariable(vars[i]);
 			variablesMap.put(variables[i].getName(), variables[i]);
 		}
 		
-		Map totalVarPos = new HashMap();
+		Map<String,int[]> totalVarPos = new HashMap<String,int[]>();
 		totalVariables = new JRFillVariable[rowGroups.length + 1][columnGroups.length + 1][measures.length];
 		for (int row = 0; row <= rowGroups.length; ++row)
 		{
@@ -281,20 +303,29 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 					for (int m = 0; m < measures.length; m++)
 					{
 						String totalVariableName = JRDesignCrosstab.getTotalVariableName(measures[m], rowGroup, colGroup);
-						totalVariables[row][col][m] = (JRFillVariable) variablesMap.get(totalVariableName);
+						totalVariables[row][col][m] = variablesMap.get(totalVariableName);
 						totalVarPos.put(totalVariableName, new int[]{row, col});
 					}
 				}
 			}
 		}
+		
+		Set<String> measureVars = new HashSet<String>();
+		for (JRFillCrosstabMeasure measure : measures)
+		{
+			measureVars.add(measure.getFillVariable().getName());
+		}
 
 		retrieveTotal = new boolean[rowGroups.length + 1][columnGroups.length + 1];
 		
 		//FIXME avoid this
-		List expressions = JRExpressionCollector.collectExpressions(filler.getJasperReport(), crosstab);
-		for (Iterator iter = expressions.iterator(); iter.hasNext();)
+		JRExpressionCollector collector = JRExpressionCollector.collector(filler.getJasperReport(), crosstab);
+		List<JRExpression> expressions = collector.getExpressions(crosstab);
+		for (Iterator<JRExpression> iter = expressions.iterator(); iter.hasNext();)
 		{
-			JRExpression expression = (JRExpression) iter.next();
+			JRExpression expression = iter.next();
+			Object expressionContext = collector.getExpressionContext(expression);
+			boolean groupHeaderExpression = expressionContext instanceof JRCrosstabGroup;
 			JRExpressionChunk[] chunks = expression.getChunks();
 			if (chunks != null)
 			{
@@ -304,11 +335,19 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 					if (chunk.getType() == JRExpressionChunk.TYPE_VARIABLE)
 					{
 						String varName = chunk.getText();
-						int[] pos = (int[]) totalVarPos.get(varName);
+						int[] pos = totalVarPos.get(varName);
 						if (pos != null)
 						{
 							retrieveTotal[pos[0]][pos[1]] = true;
 						}
+						
+						// if a measure variable is used inside a group header, compute all totals.
+						// in theory we could have a finer grained rule here, but it complicates
+						// the logic without a singnificant gain.
+						if (groupHeaderExpression && (pos != null || measureVars.contains(varName)))
+						{
+							retrieveTotal[0][0] = true;
+						}
 					}
 				}
 			}
@@ -331,7 +370,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 	private BucketingService createService(byte evaluation) throws JRException
 	{
 		boolean hasOrderByExpression = false;
-		List rowBuckets = new ArrayList(rowGroups.length);
+		List<BucketDefinition> rowBuckets = new ArrayList<BucketDefinition>(rowGroups.length);
 		for (int i = 0; i < rowGroups.length; ++i)
 		{
 			JRFillCrosstabRowGroup group = rowGroups[i];
@@ -339,7 +378,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			hasOrderByExpression |= group.getBucket().getOrderByExpression() != null;
 		}
 
-		List colBuckets = new ArrayList(columnGroups.length);
+		List<BucketDefinition> colBuckets = new ArrayList<BucketDefinition>(columnGroups.length);
 		for (int i = 0; i < columnGroups.length; ++i)
 		{
 			JRFillCrosstabColumnGroup group = columnGroups[i];
@@ -348,7 +387,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		}
 
 		percentage = false;
-		List measureList = new ArrayList(measures.length);
+		List<MeasureDefinition> measureList = new ArrayList<MeasureDefinition>(measures.length);
 		for (int i = 0; i < measures.length; ++i)
 		{
 			measureList.add(createServiceMeasure(measures[i]));
@@ -360,8 +399,8 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		// TODO refine this
 		if (percentage || hasOrderByExpression)
 		{
-			((BucketDefinition) rowBuckets.get(0)).setComputeTotal();
-			((BucketDefinition) colBuckets.get(0)).setComputeTotal();
+			rowBuckets.get(0).setComputeTotal();
+			colBuckets.get(0).setComputeTotal();
 		}
 		
 		return new BucketingService(this, rowBuckets, colBuckets, measureList, dataset.isDataPreSorted(), retrieveTotal);
@@ -371,14 +410,14 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 	{
 		JRCrosstabBucket bucket = group.getBucket();
 
-		Comparator comparator = null;
+		Comparator<Object> comparator = null;
 		JRExpression comparatorExpression = bucket.getComparatorExpression();
 		if (comparatorExpression != null)
 		{
-			comparator = (Comparator) evaluateExpression(comparatorExpression, evaluation);
+			comparator = (Comparator<Object>) evaluateExpression(comparatorExpression, evaluation);
 		}
 
-		return new BucketDefinition(bucket.getExpression().getValueClass(),
+		return new BucketDefinition(bucket.getValueClass(),
 				bucket.getOrderByExpression(), comparator, bucket.getOrderValue(), 
 				group.getTotalPositionValue());
 	}
@@ -447,12 +486,14 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			}
 			
 			overflowStartPage = 0;
+
+			ignoreWidth = isIgnoreWidth(filler, parentCrosstab);
 		}
 	}
 
 	protected void initEvaluator(byte evaluation) throws JRException
 	{
-		Map parameterValues = 
+		Map<String,Object> parameterValues = 
 			JRFillSubreport.getParameterValues(
 				filler, 
 				getParametersMapExpression(), 
@@ -466,7 +507,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		ResourceBundle resBdl = (ResourceBundle) parameterValues.get(JRParameter.REPORT_RESOURCE_BUNDLE);
 		if (resBdl == null)
 		{
-			JRFillParameter resourceBundleParam = (JRFillParameter) filler.getParametersMap().get(JRParameter.REPORT_RESOURCE_BUNDLE);
+			JRFillParameter resourceBundleParam = filler.getParametersMap().get(JRParameter.REPORT_RESOURCE_BUNDLE);
 			parameterValues.put(JRParameter.REPORT_RESOURCE_BUNDLE, resourceBundleParam.getValue());
 		}
 		
@@ -568,7 +609,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 	{
 		JRPrintRectangle printRectangle = null;
 		
-		printRectangle = new JRTemplatePrintRectangle(getJRTemplateRectangle());
+		printRectangle = new JRTemplatePrintRectangle(getJRTemplateRectangle(), elementId);
 		printRectangle.setX(getX());
 		printRectangle.setY(getRelativeY());
 		printRectangle.setWidth(getWidth());
@@ -600,12 +641,12 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		return printRectangle;
 	}
 	
-	protected int getXLimit(List printElements)
+	protected int getXLimit(List<JRPrintElement> printElements)
 	{
 		int limit = Integer.MIN_VALUE;
-		for (Iterator it = printElements.iterator(); it.hasNext();)
+		for (Iterator<JRPrintElement> it = printElements.iterator(); it.hasNext();)
 		{
-			JRPrintElement element = (JRPrintElement) it.next();
+			JRPrintElement element = it.next();
 			if (element.getX() + element.getWidth() > limit)
 			{
 				limit = element.getX() + element.getWidth();
@@ -650,16 +691,16 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		overflowStartPage = 0;
 	}
 
-	protected List getPrintElements()
+	protected List<JRPrintElement> getPrintElements()
 	{
 		return fillElements;
 	}
 
-	protected void mirrorPrintElements(List printElements)
+	protected void mirrorPrintElements(List<JRPrintElement> printElements)
 	{
-		for (Iterator it = printElements.iterator(); it.hasNext();)
+		for (Iterator<JRPrintElement> it = printElements.iterator(); it.hasNext();)
 		{
-			JRPrintElement element = (JRPrintElement) it.next();
+			JRPrintElement element = it.next();
 			int mirrorX = getWidth() - element.getX() - element.getWidth();
 			element.setX(mirrorX);
 		}
@@ -801,17 +842,17 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		private int startRowIndex;
 		private int startColumnIndex;
 		private int lastColumnIndex;
-		private List columnHeaders;
+		private List<HeaderCell[]> columnHeaders;
 
-		private List printRows;
+		private List<List<JRPrintElement>> printRows;
 
 		private HeaderCell[] spanHeaders;
 		private int[] spanHeadersStart;
 
-		private List rowYs = new ArrayList();
+		private List<Integer> rowYs = new ArrayList<Integer>();
 		private int rowIdx;
 		
-		private List preparedRow = new ArrayList();
+		private List<JRFillCellContents> preparedRow = new ArrayList<JRFillCellContents>();
 		private int preparedRowHeight;
 		
 		private boolean printRowHeaders;
@@ -824,7 +865,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		{
 			setRowHeadersXOffsets();
 
-			printRows = new ArrayList();
+			printRows = new ArrayList<List<JRPrintElement>>();
 			
 			rowCountVar = (JRFillVariable) variablesMap.get(JRCrosstab.VARIABLE_ROW_COUNT);
 			colCountVar = (JRFillVariable) variablesMap.get(JRCrosstab.VARIABLE_COLUMN_COUNT);
@@ -999,7 +1040,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			}
 			
 			printColumnHeaders = startRowIndex == 0 || isRepeatColumnHeaders();
-			List columnHeaderRows = null;
+			List<List<JRPrintElement>> columnHeaderRows = null;
 			if (printColumnHeaders)
 			{
 				columnHeaderRows = fillColumnHeaders(rowHeadersXOffset, availableHeight - yOffset);
@@ -1052,9 +1093,16 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		}
 
 		
-		protected List getGroupHeaders(int available, int[] offsets, boolean[] breakable, int firstIndex, HeaderCell[][] headersData, JRFillCrosstabGroup[] groups)
+		protected List<HeaderCell[]> getGroupHeaders(
+				int available, 
+				int[] offsets, 
+				boolean[] breakable, 
+				int firstIndex, 
+				HeaderCell[][] headersData, 
+				JRFillCrosstabGroup[] groups
+				)
 		{
-			List headers = new ArrayList();
+			List<HeaderCell[]> headers = new ArrayList<HeaderCell[]>();
 
 			int maxOffset = available + offsets[firstIndex];
 			int lastIndex;
@@ -1087,7 +1135,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			{
 				if (firstIndex > 0)
 				{
-					HeaderCell[] firstHeaders = (HeaderCell[]) headers.get(0);
+					HeaderCell[] firstHeaders = headers.get(0);
 
 					for (int j = 0; j < groups.length; ++j)
 					{
@@ -1122,7 +1170,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 							if (spanIndex >= firstIndex)
 							{
 								HeaderCell spanCell = headersData[j][spanIndex];
-								HeaderCell[] headerCells = (HeaderCell[]) headers.get(spanIndex - firstIndex);
+								HeaderCell[] headerCells = headers.get(spanIndex - firstIndex);
 								headerCells[j] = HeaderCell.createLevelSpanCopy(spanCell, lastIndex - spanIndex);
 							}
 						}
@@ -1182,7 +1230,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 						whenNoDataCell.setY(0);
 						
 						JRPrintFrame printCell = whenNoDataCell.fill();
-						List noDataRow = new ArrayList(1);
+						List<JRPrintElement> noDataRow = new ArrayList<JRPrintElement>(1);
 						noDataRow.add(printCell);
 						addPrintRow(noDataRow);
 						
@@ -1194,7 +1242,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		}
 		
 
-		protected List fillColumnHeaders(int rowHeadersXOffset, int availableHeight) throws JRException
+		protected List<List<JRPrintElement>> fillColumnHeaders(int rowHeadersXOffset, int availableHeight) throws JRException
 		{
 			JRFillCellContents[][] columnHeaderRows = new JRFillCellContents[columnGroups.length][lastColumnIndex - startColumnIndex + 1];
 			
@@ -1218,7 +1266,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			{
 				for (int columnIdx = startColumnIndex; columnIdx < lastColumnIndex; ++columnIdx)
 				{
-					HeaderCell[] headers = (HeaderCell[]) columnHeaders.get(columnIdx - startColumnIndex);
+					HeaderCell[] headers = columnHeaders.get(columnIdx - startColumnIndex);
 					HeaderCell cell = headers[rowIdx];
 					
 					if (cell != null)
@@ -1234,10 +1282,10 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 				}
 
 				int rowStretchHeight = stretchColumnHeadersRow(columnHeaderRows[rowIdx]);
-				rowYs.add(Integer.valueOf(((Integer) rowYs.get(rowIdx)).intValue() + rowStretchHeight));
+				rowYs.add(Integer.valueOf(rowYs.get(rowIdx).intValue() + rowStretchHeight));
 			}
 			
-			List headerRows;
+			List<List<JRPrintElement>> headerRows;
 			if (willOverflow)
 			{
 				headerRows = null;				
@@ -1246,7 +1294,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			else
 			{
 				headerRows = fillColumnHeaders(columnHeaderRows);
-				yOffset += ((Integer) rowYs.get(columnGroups.length)).intValue();
+				yOffset += rowYs.get(columnGroups.length).intValue();
 			}
 
 			resetVariables();
@@ -1311,12 +1359,13 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			
 			JRFillCellContents preparedContents = null;
 			
-			int rowY = ((Integer) rowYs.get(rowIdx)).intValue();
+			int rowY = rowYs.get(rowIdx).intValue();
 			
 			if (availableHeight >=  rowY + height)
 			{
 				setCountVars(-1, columnIdx);
 				setGroupVariables(columnGroups, cell.getBucketValues());
+				setGroupMeasureVariables(cell, false);
 				
 				contents = contents.getTransformedContents(width, height, group.getPositionValue(), CrosstabRowPositionEnum.TOP);
 				boolean firstOnRow = columnIdx == startColumnIndex && (!printRowHeaders || headerCell == null);
@@ -1354,7 +1403,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		
 		private int stretchColumnHeadersRow(JRFillCellContents[] headers)
 		{
-			int rowY = ((Integer) rowYs.get(rowIdx)).intValue();
+			int rowY = rowYs.get(rowIdx).intValue();
 			
 			int rowStretchHeight = 0;
 			for (int j = 0; j < headers.length; j++)
@@ -1366,7 +1415,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 					int startRowY = rowY;
 					if (contents.getVerticalSpan() > 1)
 					{
-						startRowY = ((Integer) rowYs.get(rowIdx - contents.getVerticalSpan() + 1)).intValue();
+						startRowY = rowYs.get(rowIdx - contents.getVerticalSpan() + 1).intValue();
 					}
 					
 					int height = contents.getPrintHeight() - rowY + startRowY;
@@ -1387,7 +1436,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 					int startRowY = rowY;
 					if (contents.getVerticalSpan() > 1)
 					{
-						startRowY = ((Integer) rowYs.get(rowIdx - contents.getVerticalSpan() + 1)).intValue();
+						startRowY = rowYs.get(rowIdx - contents.getVerticalSpan() + 1).intValue();
 					}
 					
 					contents.stretchTo(rowStretchHeight + rowY - startRowY);
@@ -1398,13 +1447,13 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		}
 
 		
-		private List fillColumnHeaders(JRFillCellContents[][] columnHeaderRows) throws JRException
+		private List<List<JRPrintElement>> fillColumnHeaders(JRFillCellContents[][] columnHeaderRows) throws JRException
 		{
-			List headerRows = new ArrayList(columnGroups.length);
+			List<List<JRPrintElement>> headerRows = new ArrayList<List<JRPrintElement>>(columnGroups.length);
 			
 			for (int i = 0; i < columnHeaderRows.length; ++i)
 			{
-				List headerRow = new ArrayList(lastColumnIndex - startColumnIndex);
+				List<JRPrintElement> headerRow = new ArrayList<JRPrintElement>(lastColumnIndex - startColumnIndex);
 				headerRows.add(headerRow);
 				
 				for (int j = 0; j < columnHeaderRows[i].length; j++)
@@ -1457,7 +1506,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 				
 				fillRow();
 				
-				rowYs.add(Integer.valueOf(((Integer) rowYs.get(rowIdx)).intValue() + preparedRowHeight));
+				rowYs.add(Integer.valueOf(rowYs.get(rowIdx).intValue() + preparedRowHeight));
 			}
 			
 			if (rowIdx < cellData.length - startRowIndex)//overflow
@@ -1470,7 +1519,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 				}
 			}
 			
-			yOffset += ((Integer) rowYs.get(rowIdx)).intValue();
+			yOffset += rowYs.get(rowIdx).intValue();
 
 			return rowIdx + startRowIndex;
 		}
@@ -1497,9 +1546,9 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 
 		private void releasePreparedRow() throws JRException
 		{
-			for (Iterator it = preparedRow.iterator(); it.hasNext();)
+			for (Iterator<JRFillCellContents> it = preparedRow.iterator(); it.hasNext();)
 			{
-				JRFillCellContents cell = (JRFillCellContents) it.next();
+				JRFillCellContents cell = it.next();
 				cell.rewind();
 				cell.releaseWorkingClone();
 			}
@@ -1509,17 +1558,17 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 
 		private void fillRow() throws JRException
 		{
-			int rowY = ((Integer) rowYs.get(rowIdx)).intValue();
+			int rowY = rowYs.get(rowIdx).intValue();
 			
-			List rowPrints = new ArrayList(preparedRow.size());
-			for (Iterator it = preparedRow.iterator(); it.hasNext();)
+			List<JRPrintElement> rowPrints = new ArrayList<JRPrintElement>(preparedRow.size());
+			for (Iterator<JRFillCellContents> it = preparedRow.iterator(); it.hasNext();)
 			{
-				JRFillCellContents cell = (JRFillCellContents) it.next();
+				JRFillCellContents cell = it.next();
 				
 				int spanHeight = 0;
 				if (cell.getVerticalSpan() > 1)
 				{
-					spanHeight = rowY - ((Integer) rowYs.get(rowIdx - cell.getVerticalSpan() + 1)).intValue();
+					spanHeight = rowY - rowYs.get(rowIdx - cell.getVerticalSpan() + 1).intValue();
 				}
 				
 				cell.stretchTo(preparedRowHeight + spanHeight);
@@ -1607,7 +1656,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		
 		private boolean prepareDataCell(CrosstabCell data, int column, int availableHeight, int xOffset) throws JRException
 		{
-			int rowY = ((Integer) rowYs.get(rowIdx)).intValue();
+			int rowY = rowYs.get(rowIdx).intValue();
 			
 			JRFillCrosstabCell cell = crossCells[data.getRowTotalGroupIndex()][data.getColumnTotalGroupIndex()];
 			JRFillCellContents contents = cell == null ? null : cell.getFillContents();
@@ -1668,10 +1717,10 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			}
 			
 			int spanHeight = 0;
-			int headerY = ((Integer) rowYs.get(rowIdx - vSpan + 1)).intValue();
+			int headerY = rowYs.get(rowIdx - vSpan + 1).intValue();
 			if (vSpan > 1)
 			{
-				spanHeight += ((Integer) rowYs.get(rowIdx)).intValue() - headerY;
+				spanHeight += rowYs.get(rowIdx).intValue() - headerY;
 			}
 			int rowHeight = spanHeight + preparedRowHeight;
 			
@@ -1684,6 +1733,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			{
 				setCountVars(rowIdx + startRowIndex - vSpan + 1, -1);
 				setGroupVariables(rowGroups, cell.getBucketValues());
+				setGroupMeasureVariables(cell, true);
 
 				if (stretchContents)
 				{
@@ -1789,7 +1839,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 
 				if (!preparedRow.isEmpty())
 				{
-					int lastRowHeight = ((Integer) rowYs.get(rowIdx)).intValue() - ((Integer) rowYs.get(rowIdx - 1)).intValue();
+					int lastRowHeight = rowYs.get(rowIdx).intValue() - rowYs.get(rowIdx - 1).intValue();
 					
 					if (preparedRowHeight > lastRowHeight)//need to stretch already filled row by refilling
 					{
@@ -1808,14 +1858,14 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 
 		private void fillContinuingHeaders(int lastRowHeight) throws JRException
 		{
-			int nextToLastHeaderY = ((Integer) rowYs.get(rowIdx - 1)).intValue();
-			List lastPrintRow = getLastPrintRow();
+			int nextToLastHeaderY = rowYs.get(rowIdx - 1).intValue();
+			List<JRPrintElement> lastPrintRow = getLastPrintRow();
 			
 			for (int j = 0; j < preparedRow.size(); ++j)
 			{
-				JRFillCellContents contents = (JRFillCellContents) preparedRow.get(j);
+				JRFillCellContents contents = preparedRow.get(j);
 				
-				int headerY = ((Integer) rowYs.get(rowIdx - contents.getVerticalSpan())).intValue();
+				int headerY = rowYs.get(rowIdx - contents.getVerticalSpan()).intValue();
 				
 				contents.stretchTo(nextToLastHeaderY - headerY + lastRowHeight);
 				lastPrintRow.add(contents.fill());
@@ -1831,7 +1881,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			prepareRow(xOffset, availableHeight);
 			fillRow();
 			
-			rowYs.add(Integer.valueOf(((Integer) rowYs.get(rowIdx)).intValue() + preparedRowHeight));
+			rowYs.add(Integer.valueOf(rowYs.get(rowIdx).intValue() + preparedRowHeight));
 			++rowIdx;
 		}
 
@@ -1845,10 +1895,10 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 				vSpan += spanHeadersStart[rowGroup] - startRowIndex;
 			}
 
-			int headerY = ((Integer) rowYs.get(rowIdx - vSpan)).intValue();
-			int lastHeaderY = ((Integer) rowYs.get(rowIdx)).intValue();
+			int headerY = rowYs.get(rowIdx - vSpan).intValue();
+			int lastHeaderY = rowYs.get(rowIdx).intValue();
 			int headerHeight = lastHeaderY - headerY;
-			int nextToLastHeaderY = ((Integer) rowYs.get(rowIdx - 1)).intValue();
+			int nextToLastHeaderY = rowYs.get(rowIdx - 1).intValue();
 			int stretchHeight = nextToLastHeaderY - headerY;
 			
 			JRFillCrosstabRowGroup group = rowGroups[rowGroup];
@@ -1862,6 +1912,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			{
 				setCountVars(rowIdx + startRowIndex - vSpan, -1);
 				setGroupVariables(rowGroups, cell.getBucketValues());
+				setGroupMeasureVariables(cell, true);
 
 				if (stretchContents)
 				{
@@ -1901,23 +1952,23 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			return headerOverflow;
 		}
 		
-		protected void addPrintRow(List printRow)
+		protected void addPrintRow(List<JRPrintElement> printRow)
 		{
 			printRows.add(printRow);
 		}
 		
-		protected List getLastPrintRow()
+		protected List<JRPrintElement> getLastPrintRow()
 		{
-			return (List) printRows.get(printRows.size() - 1);
+			return printRows.get(printRows.size() - 1);
 		}
 
-		protected List getPrintElements()
+		protected List<JRPrintElement> getPrintElements()
 		{
-			List prints = new ArrayList();
+			List<JRPrintElement> prints = new ArrayList<JRPrintElement>();
 			
-			for (Iterator it = printRows.iterator(); it.hasNext();)
+			for (Iterator<List<JRPrintElement>> it = printRows.iterator(); it.hasNext();)
 			{
-				List rowPrints = (List) it.next();
+				List<JRPrintElement> rowPrints = it.next();
 				prints.addAll(rowPrints);
 			}
 			
@@ -1939,6 +1990,34 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			}
 		}
 
+		protected void setGroupMeasureVariables(HeaderCell cell, boolean rowGroup)
+		{
+			MeasureValue[][] totals = cell.getTotals();
+			for (int m = 0; m < measures.length; m++)
+			{
+				for (int row = 0; row <= rowGroups.length; row++)
+				{
+					for (int col = 0; col <= columnGroups.length; col++)
+					{
+						// setting the same values for all row/column groups when filling column/row headers
+						MeasureValue[] vals = rowGroup ? totals[row] : totals[col];
+						if (row == rowGroups.length && col == columnGroups.length)
+						{
+							// setting the base measure variable
+							Object value = measureValue(vals, m);
+							measures[m].getFillVariable().setValue(value);
+						}
+						else if (retrieveTotal[row][col])
+						{
+							JRFillVariable totalVar = totalVariables[row][col][m];
+							Object value = measureValue(vals, m);
+							totalVar.setValue(value);
+						}
+					}
+				}
+			}
+		}
+
 		protected void setMeasureVariables(CrosstabCell cell)
 		{
 			MeasureValue[] values = cell.getMesureValues();
@@ -1970,6 +2049,11 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		
 		protected Object measureValue(MeasureValue[] values, int measureIdx)
 		{
+			if (values == null)
+			{
+				return null;
+			}
+			
 			Object value;
 			if (measures[measureIdx].getPercentageType() == CrosstabPercentageEnum.GRAND_TOTAL)
 			{
@@ -2080,22 +2164,6 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		return variables;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getRunDirectionValue()}.
-	 */
-	public byte getRunDirection()
-	{
-		return parentCrosstab.getRunDirectionValue().getValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setRunDirection(RunDirectionEnum)}.
-	 */
-	public void setRunDirection(byte direction)
-	{
-		throw new UnsupportedOperationException();
-	}
-
 	/**
 	 *
 	 */
@@ -2119,20 +2187,17 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 
 	public Boolean getIgnoreWidth()
 	{
-		return Boolean.valueOf(ignoreWidth);
+		return parentCrosstab.getIgnoreWidth();
 	}
 
 	public void setIgnoreWidth(Boolean ignoreWidth)
 	{
-		if (ignoreWidth != null)
-		{
-			setIgnoreWidth(ignoreWidth.booleanValue());
-		}
+		throw new UnsupportedOperationException();
 	}
 
 	public void setIgnoreWidth(boolean ignoreWidth)
 	{
-		this.ignoreWidth = ignoreWidth;
+		throw new UnsupportedOperationException();
 	}
 
 }
