@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,6 +35,8 @@ import java.util.ResourceBundle;
 import java.util.Set;
 import java.util.TimeZone;
 
+import net.sf.jasperreports.engine.DatasetFilter;
+import net.sf.jasperreports.engine.EvaluationType;
 import net.sf.jasperreports.engine.JRAbstractScriptlet;
 import net.sf.jasperreports.engine.JRDataSource;
 import net.sf.jasperreports.engine.JRDataset;
@@ -53,6 +55,9 @@ import net.sf.jasperreports.engine.JRSortField;
 import net.sf.jasperreports.engine.JRVariable;
 import net.sf.jasperreports.engine.JasperCompileManager;
 import net.sf.jasperreports.engine.JasperReport;
+import net.sf.jasperreports.engine.ParameterContributor;
+import net.sf.jasperreports.engine.ParameterContributorContext;
+import net.sf.jasperreports.engine.ParameterContributorFactory;
 import net.sf.jasperreports.engine.design.JRDesignVariable;
 import net.sf.jasperreports.engine.query.JRQueryExecuter;
 import net.sf.jasperreports.engine.query.JRQueryExecuterFactory;
@@ -71,9 +76,9 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRFillDataset.java 3960 2010-09-22 11:27:59Z teodord $
+ * @version $Id: JRFillDataset.java 4770 2011-10-28 10:10:13Z lucianc $
  */
-public class JRFillDataset implements JRDataset
+public class JRFillDataset implements JRDataset, DatasetFillContext
 {
 	
 	private static final Log log = LogFactory.getLog(JRFillDataset.class);
@@ -109,7 +114,7 @@ public class JRFillDataset implements JRDataset
 	/**
 	 * The dataset parameters indexed by name.
 	 */
-	protected Map parametersMap;
+	protected Map<String,JRFillParameter> parametersMap;
 
 	/**
 	 * The dataset fields.
@@ -119,7 +124,7 @@ public class JRFillDataset implements JRDataset
 	/**
 	 * The dataset fields indexed by name.
 	 */
-	protected Map fieldsMap;
+	protected Map<String,JRFillField> fieldsMap;
 	
 	/**
 	 * The dataset variables.
@@ -129,12 +134,12 @@ public class JRFillDataset implements JRDataset
 	/**
 	 * The dataset variables indexed by name.
 	 */
-	protected Map variablesMap;
+	protected Map<String,JRFillVariable> variablesMap;
 	
 	/**
 	 * Set of {@link VariableCalculationReq VariableCalculationReq} objects.
 	 */
-	protected Set variableCalculationReqs;
+	protected Set<VariableCalculationReq> variableCalculationReqs;
 
 	/**
 	 * The element datasets.
@@ -200,7 +205,7 @@ public class JRFillDataset implements JRDataset
 	/**
 	 * The scriptlets used by the dataset.
 	 */
-	protected List scriptlets;
+	protected List<JRAbstractScriptlet> scriptlets;
 
 	/**
 	 *
@@ -213,6 +218,8 @@ public class JRFillDataset implements JRDataset
 	protected Integer reportMaxCount;
 
 	private JRQueryExecuter queryExecuter;
+	
+	protected DatasetFilter filter;
 
 	
 	/**
@@ -251,7 +258,7 @@ public class JRFillDataset implements JRDataset
 		if (jrParameters != null && jrParameters.length > 0)
 		{
 			parameters = new JRFillParameter[jrParameters.length];
-			parametersMap = new HashMap();
+			parametersMap = new HashMap<String,JRFillParameter>();
 			for (int i = 0; i < parameters.length; i++)
 			{
 				parameters[i] = factory.getParameter(jrParameters[i]);
@@ -280,9 +287,9 @@ public class JRFillDataset implements JRDataset
 		JRVariable[] jrVariables = dataset.getVariables();
 		if (jrVariables != null && jrVariables.length > 0)
 		{
-			List variableList = new ArrayList(jrVariables.length * 3);
+			List<JRFillVariable> variableList = new ArrayList<JRFillVariable>(jrVariables.length * 3);
 
-			variablesMap = new HashMap();
+			variablesMap = new HashMap<String,JRFillVariable>();
 			for (int i = 0; i < jrVariables.length; i++)
 			{
 				addVariable(jrVariables[i], variableList, factory);
@@ -293,7 +300,7 @@ public class JRFillDataset implements JRDataset
 	}
 	
 	
-	private JRFillVariable addVariable(JRVariable parentVariable, List variableList, JRFillObjectFactory factory)
+	private JRFillVariable addVariable(JRVariable parentVariable, List<JRFillVariable> variableList, JRFillObjectFactory factory)
 	{
 		JRFillVariable variable = factory.getVariable(parentVariable);
 
@@ -372,10 +379,10 @@ public class JRFillDataset implements JRDataset
 		return helper;
 	}
 
-	private void setVariables(List variableList)
+	private void setVariables(List<JRFillVariable> variableList)
 	{
 		variables = new JRFillVariable[variableList.size()];
-		variables = (JRFillVariable[]) variableList.toArray(variables);
+		variables = variableList.toArray(variables);
 
 		for (int i = 0; i < variables.length; i++)
 		{
@@ -390,7 +397,7 @@ public class JRFillDataset implements JRDataset
 		if (jrFields != null && jrFields.length > 0)
 		{
 			fields = new JRFillField[jrFields.length];
-			fieldsMap = new HashMap();
+			fieldsMap = new HashMap<String,JRFillField>();
 			for (int i = 0; i < fields.length; i++)
 			{
 				fields[i] = factory.getField(jrFields[i]);
@@ -452,17 +459,17 @@ public class JRFillDataset implements JRDataset
 	 * @return the scriptlets list
 	 * @throws JRException
 	 */
-	protected List createScriptlets(Map parameterValues) throws JRException
+	protected List<JRAbstractScriptlet> createScriptlets(Map<String,Object> parameterValues) throws JRException
 	{
 		ScriptletFactoryContext context = new ScriptletFactoryContext(parameterValues, this);
 		
-		scriptlets = new ArrayList();
+		scriptlets = new ArrayList<JRAbstractScriptlet>();
 		
-		List factories = ExtensionsEnvironment.getExtensionsRegistry().getExtensions(ScriptletFactory.class);
-		for (Iterator it = factories.iterator(); it.hasNext();)
+		List<ScriptletFactory> factories = ExtensionsEnvironment.getExtensionsRegistry().getExtensions(ScriptletFactory.class);
+		for (Iterator<ScriptletFactory> it = factories.iterator(); it.hasNext();)
 		{
-			ScriptletFactory factory = (ScriptletFactory)it.next();
-			List tmpScriptlets = factory.getScriplets(context);
+			ScriptletFactory factory = it.next();
+			List<JRAbstractScriptlet> tmpScriptlets = factory.getScriplets(context);
 			if (tmpScriptlets != null)
 			{
 				scriptlets.addAll(tmpScriptlets);
@@ -542,7 +549,7 @@ public class JRFillDataset implements JRDataset
 	 * @param parameterValues the parameter values
 	 * @throws JRException 
 	 */
-	public void setParameterValues(Map parameterValues) throws JRException
+	public void setParameterValues(Map<String,Object> parameterValues) throws JRException
 	{
 		parameterValues.put(JRParameter.REPORT_PARAMETERS_MAP, parameterValues);
 		
@@ -582,7 +589,24 @@ public class JRFillDataset implements JRDataset
 		scriptlets = createScriptlets(parameterValues);
 		delegateScriptlet.setData(parametersMap, fieldsMap, variablesMap, groups);//FIXMESCRIPTLET use some context
 
+		List<ParameterContributor> contributors = getParameterContributors(new ParameterContributorContext(parameterValues, this));//FIXMEJIVE null?
+		if (contributors != null)
+		{
+			for(ParameterContributor contributor : contributors)
+			{
+				contributor.contributeParameters(parameterValues);
+			}
+		}
+		
+		filter = (DatasetFilter) parameterValues.get(JRParameter.FILTER);
+
 		setFillParameterValues(parameterValues);
+		
+		// initialize the filter
+		if (filter != null)
+		{
+			filter.init(this);
+		}
 	}
 	
 	
@@ -620,7 +644,7 @@ public class JRFillDataset implements JRDataset
 	 * @param parameterValues the values map
 	 * @throws JRException
 	 */
-	private void setFillParameterValues(Map parameterValues) throws JRException
+	private void setFillParameterValues(Map<String,Object> parameterValues) throws JRException
 	{
 		if (parameters != null && parameters.length > 0)
 		{
@@ -645,16 +669,39 @@ public class JRFillDataset implements JRDataset
 	}
 
 
+	/**
+	 *
+	 */
+	private static List<ParameterContributor> getParameterContributors(ParameterContributorContext context) throws JRException
+	{
+		List<ParameterContributor> allContributors = null;
+		List<?> factories = ExtensionsEnvironment.getExtensionsRegistry().getExtensions(ParameterContributorFactory.class);
+		if (factories != null && factories.size() > 0)
+		{
+			allContributors = new ArrayList<ParameterContributor>();
+			for (Iterator<?> it = factories.iterator(); it.hasNext();)
+			{
+				ParameterContributorFactory factory = (ParameterContributorFactory)it.next();
+				List<ParameterContributor> contributors = factory.getContributors(context);
+				if (contributors != null)
+				{
+					allContributors.addAll(contributors);
+				}
+			}
+		}
+		return allContributors;
+	}
+
+	
 	/**
 	 * Returns the map of parameter values.
 	 * 
 	 * @return the map of parameter values
 	 */
-	protected Map getParameterValuesMap()
+	protected Map<String,Object> getParameterValuesMap()
 	{
-		JRFillParameter paramValuesParameter = (JRFillParameter) parametersMap.get(
-				JRParameter.REPORT_PARAMETERS_MAP);
-		return (Map) paramValuesParameter.getValue();
+		JRFillParameter paramValuesParameter = parametersMap.get(JRParameter.REPORT_PARAMETERS_MAP);
+		return (Map<String,Object>) paramValuesParameter.getValue();
 	}
 	
 	/**
@@ -703,7 +750,7 @@ public class JRFillDataset implements JRDataset
 	 * @param parameterValues the parameter values
 	 * @param ds the data source
 	 */
-	public void setDatasourceParameterValue(Map parameterValues, JRDataSource ds)
+	public void setDatasourceParameterValue(Map<String,Object> parameterValues, JRDataSource ds)
 	{
 		useDatasourceParamValue = true;
 		
@@ -720,7 +767,7 @@ public class JRFillDataset implements JRDataset
 	 * @param parameterValues the parameter values
 	 * @param conn the connection
 	 */
-	public void setConnectionParameterValue(Map parameterValues, Connection conn)
+	public void setConnectionParameterValue(Map<String,Object> parameterValues, Connection conn)
 	{
 		useConnectionParamValue = true;
 		
@@ -759,10 +806,26 @@ public class JRFillDataset implements JRDataset
 	 */
 	public void start()
 	{
+		// resetting the variables is required for cases such as sort fields which
+		// iterate and calculate variables.
+		resetVariables();
+		
 		reportCount = 0;
 	}
 
 	
+	protected void resetVariables()
+	{
+		if (variables != null)
+		{
+			for (JRFillVariable variable : variables)
+			{
+				variable.reset();
+			}
+		}
+	}
+
+
 	/**
 	 * Moves to the next record in the data source.
 	 * 
@@ -770,25 +833,36 @@ public class JRFillDataset implements JRDataset
 	 * @throws JRException
 	 */
 	public boolean next() throws JRException
+	{
+		return next(true);
+	}
+
+
+	/**
+	 * Moves to the next record in the data source.
+	 * 
+	 * @param filter whether to apply the dataset filter and max count
+	 * @return <code>true</code> if the data source was not exhausted
+	 * @throws JRException
+	 */
+	protected boolean next(boolean filter) throws JRException
 	{
 		boolean hasNext = false;
 
 		if (dataSource != null)
 		{
 			boolean includeRow = true;
-			JRExpression filterExpression = getFilterExpression();
 			do
 			{
-				hasNext = advanceDataSource();
+				hasNext = advanceDataSource(filter);
 				if (hasNext)
 				{
 					setOldValues();
 
 					calculator.estimateVariables();
-					if (filterExpression != null)
+					if (filter)
 					{
-						Boolean filterExprResult = (Boolean) calculator.evaluate(filterExpression, JRExpression.EVALUATION_ESTIMATED);
-						includeRow = filterExprResult != null && filterExprResult.booleanValue();
+						includeRow = evaluateFilter();
 					}
 					
 					if (!includeRow)
@@ -858,13 +932,46 @@ public class JRFillDataset implements JRDataset
 	}
 
 
-	protected boolean advanceDataSource() throws JRException
+	protected boolean advanceDataSource(boolean limit) throws JRException
 	{
 		boolean hasNext;
-		hasNext = (reportMaxCount == null || reportMaxCount.intValue() > reportCount) && dataSource.next();
+		if (limit && reportMaxCount != null && reportCount >= reportMaxCount.intValue())
+		{
+			hasNext = false;
+		}
+		else
+		{
+			hasNext = dataSource.next();
+		}
 		return hasNext;
 	}
 	
+	protected boolean evaluateFilter() throws JRException
+	{
+		boolean includeRow = true;
+		
+		if (filter != null)
+		{
+			includeRow = filter.matches(EvaluationType.ESTIMATED);
+			if (log.isDebugEnabled())
+			{
+				log.debug("Record matched by filter: " + includeRow);
+			}
+		}
+		
+		if (includeRow)
+		{
+			JRExpression filterExpression = getFilterExpression();
+			if (filterExpression != null)
+			{
+				Boolean filterExprResult = (Boolean) calculator.evaluate(
+						filterExpression, JRExpression.EVALUATION_ESTIMATED);
+				includeRow = filterExprResult != null && filterExprResult.booleanValue();
+			}
+		}
+		
+		return includeRow;
+	}
 	
 	/**
 	 * Sets the value of a parameter.
@@ -875,7 +982,7 @@ public class JRFillDataset implements JRDataset
 	 */
 	protected void setParameter(String parameterName, Object value) throws JRException
 	{
-		JRFillParameter parameter = (JRFillParameter) parametersMap.get(parameterName);
+		JRFillParameter parameter = parametersMap.get(parameterName);
 		if (parameter != null)
 		{
 			setParameter(parameter, value);
@@ -892,27 +999,27 @@ public class JRFillDataset implements JRDataset
 	 */
 	protected void setParameter(JRFillParameter parameter, Object value) throws JRException
 	{
-		if (value != null)
-		{
-			if (parameter.getValueClass().isInstance(value))
-			{
-				parameter.setValue(value);
-			}
-			else
-			{
-				throw new JRException(
-					"Incompatible " 
-					+ value.getClass().getName() 
-					+ " value assigned to parameter " 
-					+ parameter.getName() 
-					+ " in the " + getName() + " dataset."
-					);
-			}
-		}
-		else
-		{
+//		if (value != null)
+//		{
+//			if (parameter.getValueClass().isInstance(value))
+//			{
+//				parameter.setValue(value);
+//			}
+//			else
+//			{
+//				throw new JRException(
+//					"Incompatible " 
+//					+ value.getClass().getName() 
+//					+ " value assigned to parameter " 
+//					+ parameter.getName() 
+//					+ " in the " + getName() + " dataset."
+//					);
+//			}
+//		}
+//		else
+//		{
 			parameter.setValue(value);
-		}
+//		}
 	}
 
 	
@@ -924,14 +1031,23 @@ public class JRFillDataset implements JRDataset
 	 */
 	public Object getVariableValue(String variableName)
 	{
-		JRFillVariable var = (JRFillVariable) variablesMap.get(variableName);
+		return getVariableValue(variableName, EvaluationType.DEFAULT);
+	}
+
+	public Object getVariableValue(String variableName, EvaluationType evaluation)
+	{
+		JRFillVariable var = variablesMap.get(variableName);
 		if (var == null)
 		{
 			throw new JRRuntimeException("No such variable " + variableName);
 		}
-		return var.getValue();
+		return var.getValue(evaluation.getType());
 	}
 
+	public JRFillVariable getFillVariable(String variableName)
+	{
+		return variablesMap.get(variableName);
+	}
 	
 	/**
 	 * Returns the value of a parameter.
@@ -954,7 +1070,7 @@ public class JRFillDataset implements JRDataset
 	 */
 	public Object getParameterValue(String parameterName, boolean ignoreMissing)
 	{
-		JRFillParameter param = (JRFillParameter) parametersMap.get(parameterName);
+		JRFillParameter param = parametersMap.get(parameterName);
 		Object value;
 		if (param == null)
 		{
@@ -963,7 +1079,9 @@ public class JRFillDataset implements JRDataset
 				throw new JRRuntimeException("No such parameter " + parameterName);
 			}
 			
-			value = null;//FIXME look into REPORT_PARAMETERS_MAP?  not yet required.
+			// look into REPORT_PARAMETERS_MAP
+			Map<String, Object> valuesMap = getParameterValuesMap();
+			value = valuesMap == null ? null : valuesMap.get(parameterName);
 		}
 		else
 		{
@@ -981,14 +1099,23 @@ public class JRFillDataset implements JRDataset
 	 */
 	public Object getFieldValue(String fieldName)
 	{
-		JRFillField var = (JRFillField) fieldsMap.get(fieldName);
-		if (var == null)
+		return getFieldValue(fieldName, EvaluationType.DEFAULT);
+	}
+	
+	public Object getFieldValue(String fieldName, EvaluationType evaluation)
+	{
+		JRFillField field = fieldsMap.get(fieldName);
+		if (field == null)
 		{
 			throw new JRRuntimeException("No such field " + fieldName);
 		}
-		return var.getValue();
+		return field.getValue(evaluation.getType());
 	}
 	
+	public JRFillField getFillField(String fieldName)
+	{
+		return fieldsMap.get(fieldName);
+	}
 	
 	/**
 	 * Class used to hold expression calculation  requirements.
@@ -1034,7 +1161,7 @@ public class JRFillDataset implements JRDataset
 	{
 		if (variableCalculationReqs == null)
 		{
-			variableCalculationReqs = new HashSet();
+			variableCalculationReqs = new HashSet<VariableCalculationReq>();
 		}
 
 		variableCalculationReqs.add(new VariableCalculationReq(variableName, calculation));
@@ -1050,7 +1177,7 @@ public class JRFillDataset implements JRDataset
 	{
 		if (variableCalculationReqs != null && !variableCalculationReqs.isEmpty())
 		{
-			List variableList = new ArrayList(variables.length * 2);
+			List<JRFillVariable> variableList = new ArrayList<JRFillVariable>(variables.length * 2);
 
 			for (int i = 0; i < variables.length; i++)
 			{
@@ -1063,7 +1190,7 @@ public class JRFillDataset implements JRDataset
 	}
 
 	
-	private void checkVariableCalculationReq(JRFillVariable variable, List variableList, JRFillObjectFactory factory)
+	private void checkVariableCalculationReq(JRFillVariable variable, List<JRFillVariable> variableList, JRFillObjectFactory factory)
 	{
 		if (hasVariableCalculationReq(variable, CalculationEnum.AVERAGE) || hasVariableCalculationReq(variable, CalculationEnum.VARIANCE))
 		{
@@ -1136,7 +1263,7 @@ public class JRFillDataset implements JRDataset
 		return parameters;
 	}
 
-	public Map getParametersMap()
+	public Map<String,JRFillParameter> getParametersMap()
 	{
 		return parametersMap;
 	}
@@ -1177,30 +1304,12 @@ public class JRFillDataset implements JRDataset
 	}
 
 
-	/**
-	 * @deprecated Replaced by {@link #getWhenResourceMissingType()}.
-	 */
-	public byte getWhenResourceMissingType()
-	{
-		return getWhenResourceMissingTypeValue().getValue();
-	}
-
-
 	public WhenResourceMissingTypeEnum getWhenResourceMissingTypeValue()
 	{
 		return whenResourceMissingType;
 	}
 
 
-	/**
-	 * @deprecated Replaced by {@link #setWhenResourceMissingType(WhenResourceMissingTypeEnum)}.
-	 */
-	public void setWhenResourceMissingType(byte whenResourceMissingType)
-	{
-		setWhenResourceMissingType(WhenResourceMissingTypeEnum.getByValue(whenResourceMissingType));
-	}
-
-	
 	public void setWhenResourceMissingType(WhenResourceMissingTypeEnum whenResourceMissingType)
 	{
 		this.whenResourceMissingType = whenResourceMissingType;
@@ -1250,4 +1359,9 @@ public class JRFillDataset implements JRDataset
 	{
 		return calculator.evaluate(expression, evaluation);
 	}
+	
+	public Locale getLocale()
+	{
+		return locale;
+	}
 }
