@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -44,7 +44,7 @@ import org.apache.commons.logging.LogFactory;
  * Class used to instantiate sub datasets.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRFillDatasetRun.java 3506 2010-03-04 14:48:54Z shertage $
+ * @version $Id: JRFillDatasetRun.java 4770 2011-10-28 10:10:13Z lucianc $
  */
 public class JRFillDatasetRun implements JRDatasetRun
 {
@@ -74,7 +74,7 @@ public class JRFillDatasetRun implements JRDatasetRun
 	public JRFillDatasetRun(JRBaseFiller filler, JRDatasetRun datasetRun, JRFillObjectFactory factory)
 	{
 		this(filler, datasetRun, 
-				(JRFillDataset) filler.datasetMap.get(datasetRun.getDatasetName()));
+				filler.datasetMap.get(datasetRun.getDatasetName()));
 		
 		factory.put(datasetRun, this);
 	}
@@ -101,7 +101,7 @@ public class JRFillDatasetRun implements JRDatasetRun
 	 */
 	public void evaluate(JRFillElementDataset elementDataset, byte evaluation) throws JRException
 	{
-		Map parameterValues = 
+		Map<String,Object> parameterValues = 
 			JRFillSubreport.getParameterValues(
 				filler, 
 				parametersMapExpression, 
@@ -127,12 +127,11 @@ public class JRFillDatasetRun implements JRDatasetRun
 
 			copyConnectionParameter(parameterValues);
 			
+			dataset.initCalculator();
 			dataset.setParameterValues(parameterValues);
 			dataset.initDatasource();
 			
 			dataset.filterElementDatasets(elementDataset);
-			
-			dataset.initCalculator();//FIXME too late for cascade param evaluations?
 
 			iterate();
 		}
@@ -143,7 +142,7 @@ public class JRFillDatasetRun implements JRDatasetRun
 		}
 	}
 
-	protected void copyConnectionParameter(Map parameterValues)
+	protected void copyConnectionParameter(Map<String,Object> parameterValues)
 	{
 		JRQuery query = dataset.getQuery();
 		if (query != null)
@@ -153,7 +152,7 @@ public class JRFillDatasetRun implements JRDatasetRun
 					(language.equals("sql") || language.equals("SQL")) &&
 					!parameterValues.containsKey(JRParameter.REPORT_CONNECTION))
 			{
-				JRFillParameter connParam = (JRFillParameter) filler.getParametersMap().get(JRParameter.REPORT_CONNECTION);
+				JRFillParameter connParam = filler.getParametersMap().get(JRParameter.REPORT_CONNECTION);
 				Connection connection = (Connection) connParam.getValue();
 				parameterValues.put(JRParameter.REPORT_CONNECTION, connection);
 			}
@@ -166,11 +165,11 @@ public class JRFillDatasetRun implements JRDatasetRun
 
 		init();
 
-		if (dataset.next())
+		if (advanceDataset())
 		{
 			detail();
 
-			while (dataset.next())
+			while (advanceDataset())
 			{
 				checkInterrupted();
 
@@ -182,6 +181,11 @@ public class JRFillDatasetRun implements JRDatasetRun
 
 	}
 
+	protected boolean advanceDataset() throws JRException
+	{
+		return dataset.next();
+	}
+
 	
 	protected void checkInterrupted()
 	{
