@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -61,7 +61,7 @@ import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillElement.java 3941 2010-08-20 10:55:10Z teodord $
+ * @version $Id: JRFillElement.java 4732 2011-10-21 09:14:15Z lucianc $
  */
 public abstract class JRFillElement implements JRElement, JRFillCloneable, JRStyleSetter
 {
@@ -71,7 +71,7 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	 *
 	 */
 	protected JRElement parent;
-	protected Map templates = new HashMap();
+	protected Map<JRStyle,JRTemplateElement> templates = new HashMap<JRStyle,JRTemplateElement>();
 
 	/**
 	 *
@@ -93,6 +93,8 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	protected JRFillBand band;
 	
 	protected JROriginProvider originProvider;
+	
+	protected int elementId;
 
 	/**
 	 *
@@ -102,7 +104,7 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	private boolean isToPrint = true;
 	private boolean isReprinted;
 	private boolean isAlreadyPrinted;
-	private Collection dependantElements = new ArrayList();
+	private Collection<JRElement> dependantElements = new ArrayList<JRElement>();
 	private int relativeY;
 	private int stretchHeight;
 
@@ -116,7 +118,7 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	protected byte currentEvaluation;
 	
 	// used by elements that support evaluationTime=Auto
-	protected Map delayedEvaluationsMap;
+	protected Map<JREvaluationTime,DelayedEvaluations> delayedEvaluationsMap;
 
 	protected JRFillElementContainer conditionalStylesContainer;
 	
@@ -156,6 +158,8 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 			this.filler = filler;
 			this.expressionEvaluator = factory.getExpressionEvaluator();
 			this.defaultStyleProvider = factory.getDefaultStyleProvider();
+			
+			elementId = filler.assignElementId(this);
 
 			/*   */
 			printWhenGroupChanges = factory.getGroup(element.getPrintWhenGroupChanges());
@@ -182,6 +186,8 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 		this.expressionEvaluator = element.expressionEvaluator;
 		this.defaultStyleProvider = element.defaultStyleProvider;
 		this.originProvider = element.originProvider;
+		
+		elementId = element.elementId;
 
 		/*   */
 		printWhenGroupChanges = element.printWhenGroupChanges;
@@ -220,14 +226,6 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 		return parent.getKey();
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getPositionTypeValue()}.
-	 */
-	public byte getPositionType()
-	{
-		return getPositionTypeValue().getValue();
-	}
-
 	/**
 	 *
 	 */
@@ -236,14 +234,6 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 		return parent.getPositionTypeValue();//FIXME optimize this by consolidating style properties
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setPositionType(PositionTypeEnum)}.
-	 */
-	public void setPositionType(byte positionType)
-	{
-		throw new UnsupportedOperationException();
-	}
-
 	/**
 	 *
 	 */
@@ -252,22 +242,6 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 		throw new UnsupportedOperationException();
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getStretchTypeValue()}.
-	 */
-	public byte getStretchType()
-	{
-		return parent.getStretchType();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setStretchType(StretchTypeEnum)}.
-	 */
-	public void setStretchType(byte stretchType)
-	{
-		throw new UnsupportedOperationException();
-	}
-
 	/**
 	 *
 	 */
@@ -299,22 +273,6 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	{
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getModeValue()}.
-	 */
-	public byte getMode()
-	{
-		return getModeValue().getValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getOwnModeValue()}.
-	 */
-	public Byte getOwnMode()
-	{
-		return getOwnModeValue() == null ? null : getOwnModeValue().getValueByte();
-	}
-
 	/**
 	 *
 	 */
@@ -331,20 +289,6 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 		return parent.getOwnModeValue();
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setMode(ModeEnum)}.
-	 */
-	public void setMode(byte mode)
-	{
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setMode(ModeEnum)}.
-	 */
-	public void setMode(Byte mode)
-	{
-	}
-
 	/**
 	 *
 	 */
@@ -626,7 +570,7 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	/**
 	 *
 	 */
-	protected Collection getDependantElements()
+	protected Collection<JRElement> getDependantElements()
 	{
 		return dependantElements;
 	}
@@ -777,6 +721,9 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 			template = createElementTemplate();
 			transferProperties(template);
 			
+			// deduplicate to previously created identical objects
+			template = filler.fillContext.deduplicate(template);
+			
 			registerTemplate(style, template);
 		}
 		return template;
@@ -848,12 +795,12 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	 */
 	protected void moveDependantElements()
 	{
-		Collection elements = getDependantElements();
+		Collection<JRElement> elements = getDependantElements();
 		if (elements != null && elements.size() > 0)
 		{
 			JRFillElement element = null;
 			int diffY = 0;
-			for(Iterator it = elements.iterator(); it.hasNext();)
+			for(Iterator<JRElement> it = elements.iterator(); it.hasNext();)
 			{
 				element = (JRFillElement)it.next();
 
@@ -1004,13 +951,13 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	{
 		private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 
-		final Set fields;
-		final Set variables;
+		final Set<String> fields;
+		final Set<String> variables;
 
 		DelayedEvaluations()
 		{
-			fields = new HashSet();
-			variables = new HashSet();
+			fields = new HashSet<String>();
+			variables = new HashSet<String>();
 		}
 	}
 
@@ -1018,7 +965,7 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	{
 		if (getEvaluationTimeValue() == EvaluationTimeEnum.AUTO && delayedEvaluationsMap == null)
 		{
-			delayedEvaluationsMap = new HashMap();
+			delayedEvaluationsMap = new HashMap<JREvaluationTime,DelayedEvaluations>();
 			collectDelayedEvaluations();
 		}
 	}
@@ -1101,7 +1048,7 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 
 	private DelayedEvaluations getDelayedEvaluations(JREvaluationTime time)
 	{
-		DelayedEvaluations delayedEvaluations = (DelayedEvaluations) delayedEvaluationsMap.get(time);
+		DelayedEvaluations delayedEvaluations = delayedEvaluationsMap.get(time);
 		if (delayedEvaluations == null)
 		{
 			delayedEvaluations = new DelayedEvaluations();
@@ -1153,9 +1100,9 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	
 	protected void initDelayedEvaluationPrint(JRRecordedValuesPrintElement printElement) throws JRException
 	{
-		for (Iterator it = delayedEvaluationsMap.keySet().iterator(); it.hasNext();)
+		for (Iterator<JREvaluationTime> it = delayedEvaluationsMap.keySet().iterator(); it.hasNext();)
 		{
-			JREvaluationTime evaluationTime = (JREvaluationTime) it.next();
+			JREvaluationTime evaluationTime = it.next();
 			if (!evaluationTime.equals(JREvaluationTime.EVALUATION_TIME_NOW))
 			{
 				filler.addBoundElement(this, printElement, evaluationTime);
@@ -1176,18 +1123,18 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 		JRRecordedValues recordedValues = printElement.getRecordedValues();
 		if (!recordedValues.lastEvaluationTime())
 		{
-			DelayedEvaluations delayedEvaluations = (DelayedEvaluations) delayedEvaluationsMap.get(evaluationTime);
+			DelayedEvaluations delayedEvaluations = delayedEvaluationsMap.get(evaluationTime);
 			
-			for (Iterator it = delayedEvaluations.fields.iterator(); it.hasNext();)
+			for (Iterator<String> it = delayedEvaluations.fields.iterator(); it.hasNext();)
 			{
-				String fieldName = (String) it.next();
+				String fieldName = it.next();
 				JRFillField field = getField(fieldName);
 				recordedValues.recordFieldValue(fieldName, field.getValue(evaluation));
 			}
 
-			for (Iterator it = delayedEvaluations.variables.iterator(); it.hasNext();)
+			for (Iterator<String> it = delayedEvaluations.variables.iterator(); it.hasNext();)
 			{
-				String variableName = (String) it.next();
+				String variableName = it.next();
 				JRFillVariable variable = getVariable(variableName);
 				recordedValues.recordVariableValue(variableName, variable.getValue(evaluation));
 			}
@@ -1207,26 +1154,26 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	
 	private void overwriteWithRecordedValues(JRRecordedValues recordedValues, byte evaluation)
 	{
-		Map fieldValues = recordedValues.getRecordedFieldValues();
+		Map<String,Object> fieldValues = recordedValues.getRecordedFieldValues();
 		if (fieldValues != null)
 		{
-			for (Iterator it = fieldValues.entrySet().iterator(); it.hasNext();)
+			for (Iterator<Map.Entry<String,Object>> it = fieldValues.entrySet().iterator(); it.hasNext();)
 			{
-				Map.Entry entry = (Map.Entry) it.next();
-				String fieldName = (String) entry.getKey();
+				Map.Entry<String,Object> entry = it.next();
+				String fieldName = entry.getKey();
 				Object fieldValue = entry.getValue();
 				JRFillField field = getField(fieldName);
 				field.overwriteValue(fieldValue, evaluation);
 			}
 		}
 		
-		Map variableValues = recordedValues.getRecordedVariableValues();
+		Map<String,Object> variableValues = recordedValues.getRecordedVariableValues();
 		if (variableValues != null)
 		{
-			for (Iterator it = variableValues.entrySet().iterator(); it.hasNext();)
+			for (Iterator<Map.Entry<String,Object>> it = variableValues.entrySet().iterator(); it.hasNext();)
 			{
-				Map.Entry entry = (Map.Entry) it.next();
-				String variableName = (String) entry.getKey();
+				Map.Entry<String,Object> entry = it.next();
+				String variableName = entry.getKey();
 				Object variableValue = entry.getValue();
 				JRFillVariable variable = getVariable(variableName);
 				variable.overwriteValue(variableValue, evaluation);
@@ -1236,23 +1183,23 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 
 	private void restoreValues(JRRecordedValues recordedValues, byte evaluation)
 	{
-		Map fieldValues = recordedValues.getRecordedFieldValues();
+		Map<String,Object> fieldValues = recordedValues.getRecordedFieldValues();
 		if (fieldValues != null)
 		{
-			for (Iterator it = fieldValues.keySet().iterator(); it.hasNext();)
+			for (Iterator<String> it = fieldValues.keySet().iterator(); it.hasNext();)
 			{
-				String fieldName = (String) it.next();
+				String fieldName = it.next();
 				JRFillField field = getField(fieldName);
 				field.restoreValue(evaluation);
 			}
 		}
 		
-		Map variableValues = recordedValues.getRecordedVariableValues();
+		Map<String,Object> variableValues = recordedValues.getRecordedVariableValues();
 		if (variableValues != null)
 		{
-			for (Iterator it = variableValues.keySet().iterator(); it.hasNext();)
+			for (Iterator<String> it = variableValues.keySet().iterator(); it.hasNext();)
 			{
-				String variableName = (String) it.next();
+				String variableName = it.next();
 				JRFillVariable variable = getVariable(variableName);
 				variable.restoreValue(evaluation);
 			}
@@ -1308,7 +1255,7 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	 */
 	protected JRTemplateElement getTemplate(JRStyle style)
 	{
-		return (JRTemplateElement) templates.get(style);
+		return templates.get(style);
 	}
 
 	/**
