@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -41,7 +41,6 @@ import net.sf.jasperreports.engine.JRFrame;
 import net.sf.jasperreports.engine.JROrigin;
 import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRPrintElementContainer;
-import net.sf.jasperreports.engine.JRReportFont;
 import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.base.JRBaseStyle;
 import net.sf.jasperreports.engine.type.PositionTypeEnum;
@@ -54,23 +53,23 @@ import net.sf.jasperreports.engine.util.JRStyleResolver;
  * This is the base for band, frame and crosstab cell fillers.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRFillElementContainer.java 3813 2010-05-19 19:35:39Z teodord $
+ * @version $Id: JRFillElementContainer.java 4747 2011-10-26 16:59:20Z lucianc $
  */
 public abstract class JRFillElementContainer extends JRFillElementGroup
 {
 	protected JRBaseFiller filler;
 	
-	private JRFillElement[] ySortedElements = null;
-	private JRFillElement[] stretchElements = null;
-	private JRFillElement[] bandBottomElements = null;
-	private JRFillElement[] removableElements = null;
+	private JRFillElement[] ySortedElements;
+	private JRFillElement[] stretchElements;
+	private JRFillElement[] bandBottomElements;
+	private JRFillElement[] removableElements;
 	
-	private boolean willOverflow = false;
-	protected boolean isOverflow = false;
+	private boolean willOverflow;
+	protected boolean isOverflow;
 	
-	private int stretchHeight = 0;
-	private int firstY = 0;
-	protected JRFillElement firstYElement = null;
+	private int stretchHeight;
+	private int firstY;
+	protected JRFillElement firstYElement;
 	
 	protected final JRFillExpressionEvaluator expressionEvaluator;
 	
@@ -79,8 +78,8 @@ public abstract class JRFillElementContainer extends JRFillElementGroup
 	/**
 	 *
 	 */
-	protected Set stylesToEvaluate = new HashSet();
-	protected Map evaluatedStyles = new HashMap();
+	protected Set<JRStyle> stylesToEvaluate = new HashSet<JRStyle>();
+	protected Map<JRStyle,JRStyle> evaluatedStyles = new HashMap<JRStyle,JRStyle>();
 	
 	protected boolean hasPrintWhenOverflowElement;
 	
@@ -113,19 +112,19 @@ public abstract class JRFillElementContainer extends JRFillElementGroup
 		}
 		else
 		{
-			List deepElementsList = new ArrayList(elements.length);
+			List<JRFillElement> deepElementsList = new ArrayList<JRFillElement>(elements.length);
 			collectDeepElements(elements, deepElementsList);
 			deepElements = new JRFillElement[deepElementsList.size()];
 			deepElementsList.toArray(deepElements);
 		}
 	}
 
-	private static void collectDeepElements(JRElement[] elements, List deepElementsList)
+	private static void collectDeepElements(JRElement[] elements, List<JRFillElement> deepElementsList)
 	{
 		for (int i = 0; i < elements.length; i++)
 		{
 			JRElement element = elements[i];
-			deepElementsList.add(element);
+			deepElementsList.add((JRFillElement)element);
 			
 			if (element instanceof JRFillFrame)
 			{
@@ -141,10 +140,10 @@ public abstract class JRFillElementContainer extends JRFillElementGroup
 		
 		if (elements != null && elements.length > 0)
 		{
-			List sortedElemsList = new ArrayList();
-			List stretchElemsList = new ArrayList();
-			List bandBottomElemsList = new ArrayList();
-			List removableElemsList = new ArrayList();
+			List<JRFillElement> sortedElemsList = new ArrayList<JRFillElement>();
+			List<JRFillElement> stretchElemsList = new ArrayList<JRFillElement>();
+			List<JRFillElement> bandBottomElemsList = new ArrayList<JRFillElement>();
+			List<JRFillElement> removableElemsList = new ArrayList<JRFillElement>();
 			for(int i = 0; i < elements.length; i++)
 			{
 				JRFillElement element = elements[i];
@@ -585,30 +584,24 @@ public abstract class JRFillElementContainer extends JRFillElementGroup
 						{
 							JRFillSubreport subreport = (JRFillSubreport)element;
 							
-							List fonts = subreport.subreportFiller.getJasperPrint().getFontsList();
-							for(int j = 0; j < fonts.size(); j++)
-							{
-								filler.getJasperPrint().addFont((JRReportFont)fonts.get(j), true);
-							}
-							
-							List styles = subreport.subreportFiller.getJasperPrint().getStylesList();
+							List<JRStyle> styles = subreport.subreportFiller.getJasperPrint().getStylesList();
 							for(int j = 0; j < styles.size(); j++)
 							{
-								filler.addPrintStyle((JRStyle)styles.get(j));
+								filler.addPrintStyle(styles.get(j));
 							}
 							
-							List origins = subreport.subreportFiller.getJasperPrint().getOriginsList();
+							List<JROrigin> origins = subreport.subreportFiller.getJasperPrint().getOriginsList();
 							for(int j = 0; j < origins.size(); j++)
 							{
-								filler.getJasperPrint().addOrigin((JROrigin)origins.get(j));
+								filler.getJasperPrint().addOrigin(origins.get(j));
 							}
 							
-							Collection printElements = subreport.getPrintElements();
+							Collection<JRPrintElement> printElements = subreport.getPrintElements();
 							addSubElements(printContainer, element, printElements);
 						}
 						else if (element instanceof JRFillCrosstab)
 						{
-							List printElements = ((JRFillCrosstab) element).getPrintElements();
+							List<JRPrintElement> printElements = ((JRFillCrosstab) element).getPrintElements();
 							addSubElements(printContainer, element, printElements);
 						}
 					}
@@ -621,17 +614,26 @@ public abstract class JRFillElementContainer extends JRFillElementGroup
 	}
 
 
-	protected void addSubElements(JRPrintElementContainer printContainer, JRFillElement element, Collection printElements)
+	protected void addSubElements(JRPrintElementContainer printContainer, JRFillElement element, Collection<JRPrintElement> printElements)
 	{
-		JRPrintElement printElement;
-		if (printElements != null && printElements.size() > 0)
+		if (printContainer instanceof JRPrintBand)
 		{
-			for(Iterator it = printElements.iterator(); it.hasNext();)
+			// adding the subelements as whole lists to bands so that we don't need
+			// another virtualized list at print band level
+			((JRPrintBand) printContainer).addOffsetElements(printElements, 
+					element.getX(), element.getRelativeY());
+		}
+		else
+		{
+			if (printElements != null && printElements.size() > 0)
 			{
-				printElement = (JRPrintElement)it.next();
-				printElement.setX(element.getX() + printElement.getX());
-				printElement.setY(element.getRelativeY() + printElement.getY());
-				printContainer.addElement(printElement);
+				for(Iterator<JRPrintElement> it = printElements.iterator(); it.hasNext();)
+				{
+					JRPrintElement printElement =it.next();
+					printElement.setX(element.getX() + printElement.getX());
+					printElement.setY(element.getRelativeY() + printElement.getY());
+					printContainer.addElement(printElement);
+				}
 			}
 		}
 	}
@@ -709,9 +711,9 @@ public abstract class JRFillElementContainer extends JRFillElementGroup
 
 	protected void evaluateConditionalStyles(byte evaluation) throws JRException
 	{
-		for (Iterator it = stylesToEvaluate.iterator(); it.hasNext();) 
+		for (Iterator<JRStyle> it = stylesToEvaluate.iterator(); it.hasNext();) 
 		{
-			evaluateConditionalStyle((JRStyle) it.next(), evaluation);
+			evaluateConditionalStyle(it.next(), evaluation);
 		}
 	}
 
@@ -721,23 +723,27 @@ public abstract class JRFillElementContainer extends JRFillElementGroup
 		JRStyle consolidatedStyle = initialStyle;
 
 		StringBuffer code = new StringBuffer();
-		List condStylesToApply = new ArrayList();
+		List<JRStyle> condStylesToApply = new ArrayList<JRStyle>();
 		
 		boolean anyTrue = buildConsolidatedStyle(initialStyle, evaluation, code, condStylesToApply);
 		
 		if (anyTrue)
 		{
 			String consolidatedStyleName = initialStyle.getName() + "|" + code.toString();
-			consolidatedStyle = (JRStyle)filler.getJasperPrint().getStylesMap().get(consolidatedStyleName);
+			consolidatedStyle = filler.getJasperPrint().getStylesMap().get(consolidatedStyleName);
 			if (consolidatedStyle == null)
 			{
-				consolidatedStyle = new JRBaseStyle(consolidatedStyleName);
+				JRBaseStyle style = new JRBaseStyle(consolidatedStyleName);
 				for (int j = condStylesToApply.size() - 1; j >= 0; j--)
 				{
-					JRStyleResolver.appendStyle(consolidatedStyle, (JRStyle)condStylesToApply.get(j));
+					JRStyleResolver.appendStyle(style, condStylesToApply.get(j));
 				}
 
-				filler.addPrintStyle(consolidatedStyle);
+				// deduplicate to previously created identical instances
+				style = filler.fillContext.deduplicate(style);
+				filler.addPrintStyle(style);
+				
+				consolidatedStyle = style;
 			}
 		}
 
@@ -747,7 +753,7 @@ public abstract class JRFillElementContainer extends JRFillElementGroup
 	}
 
 
-	protected boolean buildConsolidatedStyle(JRStyle style, byte evaluation, StringBuffer code, List condStylesToApply) throws JRException
+	protected boolean buildConsolidatedStyle(JRStyle style, byte evaluation, StringBuffer code, List<JRStyle> condStylesToApply) throws JRException
 	{
 		boolean anyTrue = false;
 		
@@ -795,7 +801,7 @@ public abstract class JRFillElementContainer extends JRFillElementGroup
 
 	public JRStyle getEvaluatedConditionalStyle(JRStyle parentStyle)
 	{
-		return (JRStyle) evaluatedStyles.get(parentStyle);
+		return evaluatedStyles.get(parentStyle);
 	}
 	
 	protected final void setElementOriginProvider(JROriginProvider originProvider)
