@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,13 +17,12 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
 package net.sf.jasperreports.engine.fill;
 
-import net.sf.jasperreports.engine.JRBand;
 import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRGroup;
 import net.sf.jasperreports.engine.JROrigin;
@@ -35,7 +34,7 @@ import net.sf.jasperreports.engine.type.FooterPositionEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillGroup.java 3941 2010-08-20 10:55:10Z teodord $
+ * @version $Id: JRFillGroup.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRFillGroup implements JRGroup
 {
@@ -205,14 +204,6 @@ public class JRFillGroup implements JRGroup
 	{
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getFooterPositionValue()}.
-	 */
-	public byte getFooterPosition()
-	{
-		return getFooterPositionValue().getValue();
-	}
-		
 	/**
 	 *
 	 */
@@ -221,14 +212,6 @@ public class JRFillGroup implements JRGroup
 		return parent.getFooterPositionValue();
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #setFooterPosition(FooterPositionEnum)}.
-	 */
-	public void setFooterPosition(byte footerPosition)
-	{
-		throw new UnsupportedOperationException();
-	}
-		
 	/**
 	 *
 	 */
@@ -252,19 +235,6 @@ public class JRFillGroup implements JRGroup
 	{
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getGroupHeaderSection()}.
-	 */
-	public JRBand getGroupHeader()
-	{
-		return 
-			groupHeaderSection == null 
-			|| groupHeaderSection.getBands() == null 
-			|| groupHeaderSection.getBands().length == 0 
-				? null 
-				: (JRBand)groupHeaderSection.getBands()[0];
-	}
-		
 	/**
 	 *
 	 */
@@ -273,19 +243,6 @@ public class JRFillGroup implements JRGroup
 		return groupHeaderSection;
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getGroupFooterSection()}.
-	 */
-	public JRBand getGroupFooter()
-	{
-		return 
-			groupFooterSection == null 
-			|| groupFooterSection.getBands() == null 
-			|| groupFooterSection.getBands().length == 0 
-				? null 
-				: (JRBand)groupFooterSection.getBands()[0];
-	}
-		
 	/**
 	 *
 	 */
