@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,20 +17,18 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
 package net.sf.jasperreports.engine.fill;
 
-import java.awt.Color;
 import java.awt.Image;
 import java.awt.geom.Dimension2D;
 import java.io.File;
 import java.io.InputStream;
 import java.net.URL;
 
-import net.sf.jasperreports.engine.JRBox;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRExpressionCollector;
@@ -52,12 +50,11 @@ import net.sf.jasperreports.engine.type.OnErrorTypeEnum;
 import net.sf.jasperreports.engine.type.ScaleImageEnum;
 import net.sf.jasperreports.engine.type.VerticalAlignEnum;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
-import net.sf.jasperreports.engine.util.LineBoxWrapper;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillImage.java 3833 2010-05-27 14:16:59Z teodord $
+ * @version $Id: JRFillImage.java 4648 2011-10-10 12:50:53Z lucianc $
  */
 public class JRFillImage extends JRFillGraphicElement implements JRImage
 {
@@ -66,20 +63,20 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	/**
 	 *
 	 */
-	private JRGroup evaluationGroup = null;
+	private JRGroup evaluationGroup;
 
 	/**
 	 *
 	 */
-	private JRRenderable renderer = null;
+	private JRRenderable renderer;
 	private boolean hasOverflowed;
 	private Integer imageHeight;
 	private Integer imageWidth;
 	private Integer imageX;
-	private String anchorName = null;
-	private String hyperlinkReference = null;
-	private String hyperlinkAnchor = null;
-	private Integer hyperlinkPage = null;
+	private String anchorName;
+	private String hyperlinkReference;
+	private String hyperlinkAnchor;
+	private Integer hyperlinkPage;
 	private String hyperlinkTooltip;
 	private JRPrintHyperlinkParameters hyperlinkParameters;
 	protected final JRLineBox lineBox;
@@ -120,38 +117,6 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getScaleImageValue()}.
-	 */
-	public byte getScaleImage()
-	{
-		return getScaleImageValue().getValue();
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #getOwnScaleImageValue()}.
-	 */
-	public Byte getOwnScaleImage()
-	{
-		return getOwnScaleImageValue() == null ? null : getOwnScaleImageValue().getValueByte();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
-	 */
-	public void setScaleImage(byte scaleImage)
-	{
-		throw new UnsupportedOperationException();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
-	 */
-	public void setScaleImage(Byte scaleImage)
-	{
-		throw new UnsupportedOperationException();
-	}
-
 	/**
 	 * 
 	 */
@@ -173,22 +138,6 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		throw new UnsupportedOperationException();
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getHorizontalAlignmentValue()}.
-	 */
-	public byte getHorizontalAlignment()
-	{
-		return getHorizontalAlignmentValue().getValue();
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #getOwnHorizontalAlignmentValue()}.
-	 */
-	public Byte getOwnHorizontalAlignment()
-	{
-		return getOwnHorizontalAlignmentValue() == null ? null : getOwnHorizontalAlignmentValue().getValueByte();
-	}
-
 	/**
 	 *
 	 */
@@ -202,22 +151,6 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		return ((JRImage)this.parent).getOwnHorizontalAlignmentValue();
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
-	 */
-	public void setHorizontalAlignment(byte horizontalAlignment)
-	{
-		throw new UnsupportedOperationException();
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
-	 */
-	public void setHorizontalAlignment(Byte horizontalAlignment)
-	{
-		throw new UnsupportedOperationException();
-	}
-		
 	/**
 	 *
 	 */
@@ -226,22 +159,6 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		throw new UnsupportedOperationException();
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getVerticalAlignmentValue()}.
-	 */
-	public byte getVerticalAlignment()
-	{
-		return getVerticalAlignmentValue().getValue();
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #getOwnVerticalAlignmentValue()}.
-	 */
-	public Byte getOwnVerticalAlignment()
-	{
-		return getOwnVerticalAlignmentValue() == null ? null : getOwnVerticalAlignmentValue().getValueByte();
-	}
-
 	/**
 	 *
 	 */
@@ -255,22 +172,6 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		return ((JRImage)this.parent).getOwnVerticalAlignmentValue();
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
-	 */
-	public void setVerticalAlignment(byte verticalAlignment)
-	{
-		throw new UnsupportedOperationException();
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
-	 */
-	public void setVerticalAlignment(Byte verticalAlignment)
-	{
-		throw new UnsupportedOperationException();
-	}
-		
 	/**
 	 *
 	 */
@@ -280,7 +181,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getUsingCache()}.
 	 */
 	public boolean isUsingCache()
 	{
@@ -288,13 +189,21 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getUsingCache()}.
 	 */
 	public Boolean isOwnUsingCache()
 	{
 		return ((JRImage)this.parent).isOwnUsingCache();
 	}
 		
+	/**
+	 *
+	 */
+	public Boolean getUsingCache()
+	{
+		return ((JRImage)this.parent).getUsingCache();
+	}
+		
 	/**
 	 *
 	 */
@@ -324,22 +233,6 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	{
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getOnErrorTypeValue()}.
-	 */
-	public byte getOnErrorType()
-	{
-		return getOnErrorTypeValue().getValue();
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #setOnErrorType(OnErrorTypeEnum)}.
-	 */
-	public void setOnErrorType(byte onErrorType)
-	{
-		throw new UnsupportedOperationException();
-	}
-
 	/**
 	 *
 	 */
@@ -356,14 +249,6 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		throw new UnsupportedOperationException();
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getEvaluationTimeValue()}.
-	 */
-	public byte getEvaluationTime()
-	{
-		return getEvaluationTimeValue().getValue();
-	}
-		
 	/**
 	 *
 	 */
@@ -380,14 +265,6 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		return this.evaluationGroup;
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public JRBox getBox()
-	{
-		return new LineBoxWrapper(getLineBox());
-	}
-
 	/**
 	 *
 	 */
@@ -396,446 +273,6 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		return lineBox;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getBorder()
-	{
-		return getBox().getBorder();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnBorder()
-	{
-		return getBox().getOwnBorder();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBorder(byte border)
-	{
-		getBox().setBorder(border);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBorder(Byte border)
-	{
-		getBox().setBorder(border);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getBorderColor()
-	{
-		return getBox().getBorderColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnBorderColor()
-	{
-		return getBox().getOwnBorderColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBorderColor(Color borderColor)
-	{
-		getBox().setBorderColor(borderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getPadding()
-	{
-		return getBox().getPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnPadding()
-	{
-		return getBox().getOwnPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setPadding(int padding)
-	{
-		getBox().setPadding(padding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setPadding(Integer padding)
-	{
-		getBox().setPadding(padding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getTopBorder()
-	{
-		return getBox().getTopBorder();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnTopBorder()
-	{
-		return getBox().getOwnTopBorder();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopBorder(byte topBorder)
-	{
-		getBox().setTopBorder(topBorder);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopBorder(Byte topBorder)
-	{
-		getBox().setTopBorder(topBorder);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getTopBorderColor()
-	{
-		return getBox().getTopBorderColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnTopBorderColor()
-	{
-		return getBox().getOwnTopBorderColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopBorderColor(Color topBorderColor)
-	{
-		getBox().setTopBorderColor(topBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getTopPadding()
-	{
-		return getBox().getTopPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnTopPadding()
-	{
-		return getBox().getOwnTopPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopPadding(int topPadding)
-	{
-		getBox().setTopPadding(topPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopPadding(Integer topPadding)
-	{
-		getBox().setTopPadding(topPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getLeftBorder()
-	{
-		return getBox().getLeftBorder();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnLeftBorder()
-	{
-		return getBox().getOwnLeftBorder();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftBorder(byte leftBorder)
-	{
-		getBox().setLeftBorder(leftBorder);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftBorder(Byte leftBorder)
-	{
-		getBox().setLeftBorder(leftBorder);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getLeftBorderColor()
-	{
-		return getBox().getLeftBorderColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnLeftBorderColor()
-	{
-		return getBox().getOwnLeftBorderColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftBorderColor(Color leftBorderColor)
-	{
-		getBox().setLeftBorderColor(leftBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getLeftPadding()
-	{
-		return getBox().getLeftPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnLeftPadding()
-	{
-		return getBox().getOwnLeftPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftPadding(int leftPadding)
-	{
-		getBox().setLeftPadding(leftPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftPadding(Integer leftPadding)
-	{
-		getBox().setLeftPadding(leftPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getBottomBorder()
-	{
-		return getBox().getBottomBorder();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnBottomBorder()
-	{
-		return getBox().getOwnBottomBorder();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomBorder(byte bottomBorder)
-	{
-		getBox().setBottomBorder(bottomBorder);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomBorder(Byte bottomBorder)
-	{
-		getBox().setBottomBorder(bottomBorder);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getBottomBorderColor()
-	{
-		return getBox().getBottomBorderColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnBottomBorderColor()
-	{
-		return getBox().getOwnBottomBorderColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomBorderColor(Color bottomBorderColor)
-	{
-		getBox().setBottomBorderColor(bottomBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getBottomPadding()
-	{
-		return getBox().getBottomPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnBottomPadding()
-	{
-		return getBox().getOwnBottomPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomPadding(int bottomPadding)
-	{
-		getBox().setBottomPadding(bottomPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomPadding(Integer bottomPadding)
-	{
-		getBox().setBottomPadding(bottomPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getRightBorder()
-	{
-		return getBox().getRightBorder();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnRightBorder()
-	{
-		return getBox().getOwnRightBorder();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightBorder(byte rightBorder)
-	{
-		getBox().setRightBorder(rightBorder);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightBorder(Byte rightBorder)
-	{
-		getBox().setRightBorder(rightBorder);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getRightBorderColor()
-	{
-		return getBox().getRightBorderColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnRightBorderColor()
-	{
-		return getBox().getOwnRightBorderColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightBorderColor(Color rightBorderColor)
-	{
-		getBox().setRightBorderColor(rightBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getRightPadding()
-	{
-		return getBox().getRightPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnRightPadding()
-	{
-		return getBox().getOwnRightPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightPadding(int rightPadding)
-	{
-		getBox().setRightPadding(rightPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightPadding(Integer rightPadding)
-	{
-		getBox().setRightPadding(rightPadding);
-	}
-
 	/**
 	 * @deprecated Replaced by {@link #getHyperlinkTypeValue()}.
 	 */
@@ -1023,55 +460,67 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		Object source = evaluateExpression(expression, evaluation);
 		if (source != null)
 		{
-			if (isUsingCache() && filler.fillContext.hasLoadedImage(source))
+			Boolean isUsingCache = getUsingCache();
+			if (isUsingCache == null)
+			{
+				isUsingCache = source instanceof String;
+			}
+			
+			if (isUsingCache && filler.fillContext.hasLoadedImage(source))
 			{
 				newRenderer = filler.fillContext.getLoadedImage(source).getRenderer();
 			}
 			else
 			{
-				Class expressionClass = expression.getValueClass();
-				
-				if (Image.class.getName().equals(expressionClass.getName()))
+				if (source instanceof Image)
 				{
 					Image img = (Image) source;
 					newRenderer = JRImageRenderer.getInstance(img, getOnErrorTypeValue());
 				}
-				else if (InputStream.class.getName().equals(expressionClass.getName()))
+				else if (source instanceof InputStream)
 				{
 					InputStream is = (InputStream) source;
 					newRenderer = JRImageRenderer.getInstance(is, getOnErrorTypeValue());
 				}
-				else if (URL.class.getName().equals(expressionClass.getName()))
+				else if (source instanceof URL)
 				{
 					URL url = (URL) source;
 					newRenderer = JRImageRenderer.getInstance(url, getOnErrorTypeValue());
 				}
-				else if (File.class.getName().equals(expressionClass.getName()))
+				else if (source instanceof File)
 				{
 					File file = (File) source;
 					newRenderer = JRImageRenderer.getInstance(file, getOnErrorTypeValue());
 				}
-				else if (String.class.getName().equals(expressionClass.getName()))
+				else if (source instanceof String)
 				{
 					String location = (String) source;
 					newRenderer = 
 						JRImageRenderer.getInstance(
 							location, 
 							getOnErrorTypeValue(), 
-							isLazy(), 
-							filler.reportClassLoader,
-							filler.urlHandlerFactory,
-							filler.fileResolver
+							isLazy()//, 
+//							filler.reportClassLoader,
+//							filler.urlHandlerFactory,
+//							filler.fileResolver
 							);
 				}
-				else if (JRRenderable.class.getName().equals(expressionClass.getName()))
+				else if (source instanceof JRRenderable)
 				{
 					newRenderer = (JRRenderable) source;
 				}
-
-				if (isUsingCache())
+				else
 				{
-					JRPrintImage img = new JRTemplatePrintImage(getJRTemplateImage());
+					newRenderer = 
+						JRImageRenderer.getOnErrorRenderer(
+							getOnErrorTypeValue(), 
+							new JRException("Unknown image source class " + source.getClass().getName())
+							);
+				}
+
+				if (isUsingCache)
+				{
+					JRPrintImage img = new JRTemplatePrintImage(getJRTemplateImage(), elementId);
 					img.setRenderer(newRenderer);
 					filler.fillContext.registerLoadedImage(source, img);
 				}
@@ -1319,11 +768,11 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		JRRecordedValuesPrintImage recordedValuesImage;
 		if (isEvaluateAuto())
 		{
-			printImage = recordedValuesImage = new JRRecordedValuesPrintImage(getJRTemplateImage());
+			printImage = recordedValuesImage = new JRRecordedValuesPrintImage(getJRTemplateImage(), elementId);
 		}
 		else
 		{
-			printImage = new JRTemplatePrintImage(getJRTemplateImage());
+			printImage = new JRTemplatePrintImage(getJRTemplateImage(), elementId);
 			recordedValuesImage = null;
 		}
 		
@@ -1397,10 +846,14 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		evaluateImage(evaluation);
 
 		JRPrintImage printImage = (JRPrintImage) element;
-		int padding = printImage.getLineBox().getBottomPadding().intValue() 
-				+ printImage.getLineBox().getTopPadding().intValue();
-		fitImage(getHeight() - padding, false, 
-				printImage.getHorizontalAlignmentValue());
+
+		if (getScaleImageValue() == ScaleImageEnum.REAL_SIZE)//to avoid get dimension and thus unnecessarily load the image
+		{
+			int padding = printImage.getLineBox().getBottomPadding().intValue() 
+			+ printImage.getLineBox().getTopPadding().intValue();
+			fitImage(getHeight() - padding, false, 
+					printImage.getHorizontalAlignmentValue());
+		}
 		
 		copy(printImage);
 	}
