@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -33,7 +33,7 @@ import net.sf.jasperreports.engine.type.LineDirectionEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillLine.java 3583 2010-03-12 11:35:40Z shertage $
+ * @version $Id: JRFillLine.java 4648 2011-10-10 12:50:53Z lucianc $
  */
 public class JRFillLine extends JRFillGraphicElement implements JRLine
 {
@@ -58,22 +58,6 @@ public class JRFillLine extends JRFillGraphicElement implements JRLine
 	}
 
 
-	/**
-	 * @deprecated Replaced by {@link #getDirectionValue()}.
-	 */
-	public byte getDirection()
-	{
-		return ((JRLine)this.parent).getDirection();
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #setDirection(LineDirectionEnum)}.
-	 */
-	public void setDirection(byte direction)
-	{
-		throw new UnsupportedOperationException();
-	}
-
 	/**
 	 * 
 	 */
@@ -129,7 +113,7 @@ public class JRFillLine extends JRFillGraphicElement implements JRLine
 	 */
 	protected JRPrintElement fill()
 	{
-		JRTemplatePrintLine printLine = new JRTemplatePrintLine(this.getJRTemplateLine());
+		JRTemplatePrintLine printLine = new JRTemplatePrintLine(this.getJRTemplateLine(), elementId);
 		printLine.setX(this.getX());
 		printLine.setY(this.getRelativeY());
 		printLine.setWidth(getWidth());
