@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -117,7 +117,6 @@ import net.sf.jasperreports.engine.JRImage;
 import net.sf.jasperreports.engine.JRLine;
 import net.sf.jasperreports.engine.JRParameter;
 import net.sf.jasperreports.engine.JRRectangle;
-import net.sf.jasperreports.engine.JRReportFont;
 import net.sf.jasperreports.engine.JRReportTemplate;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRSection;
@@ -130,7 +129,6 @@ import net.sf.jasperreports.engine.JRSubreportReturnValue;
 import net.sf.jasperreports.engine.JRTextField;
 import net.sf.jasperreports.engine.JRVariable;
 import net.sf.jasperreports.engine.base.JRBaseConditionalStyle;
-import net.sf.jasperreports.engine.base.JRBaseReportFont;
 import net.sf.jasperreports.engine.base.JRBaseStyle;
 
 import org.apache.commons.collections.SequencedHashMap;
@@ -140,7 +138,7 @@ import org.apache.commons.collections.SequencedHashMap;
  * A factory used to instantiate fill objects based on compiled report objects.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillObjectFactory.java 3806 2010-05-18 10:02:44Z lucianc $
+ * @version $Id: JRFillObjectFactory.java 4647 2011-10-06 10:19:07Z lucianc $
  */
 public class JRFillObjectFactory extends JRAbstractObjectFactory
 {
@@ -149,22 +147,22 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 	/**
 	 *
 	 */
-	protected JRBaseFiller filler = null;
+	protected JRBaseFiller filler;
 	private JRFillExpressionEvaluator evaluator;
 
 	private JRFillObjectFactory parentFiller;
 	
-//	private JRFont defaultFont = null;
+//	private JRFont defaultFont;
 
-	private List elementDatasets = new ArrayList();
-	private Map elementDatasetMap = new HashMap();
+	private List<JRFillElementDataset> elementDatasets = new ArrayList<JRFillElementDataset>();
+	private Map<String,List<JRFillElementDataset>> elementDatasetMap = new HashMap<String,List<JRFillElementDataset>>();
 	
-	private Map delayedStyleSettersByName = new HashMap();
+	private Map<String,List<JRStyleSetter>> delayedStyleSettersByName = new HashMap<String,List<JRStyleSetter>>();
 	
 	protected static class StylesList
 	{
-		private final List styles = new ArrayList();
-		private final Map stylesIdx = new HashMap();
+		private final List<JRStyle> styles = new ArrayList<JRStyle>();
+		private final Map<String,Integer> stylesIdx = new HashMap<String,Integer>();
 		
 		public boolean containsStyle(String name)
 		{
@@ -173,8 +171,8 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 		
 		public JRStyle getStyle(String name)
 		{
-			Integer idx = (Integer) stylesIdx.get(name);
-			return idx == null ? null : (JRStyle) styles.get(idx.intValue());
+			Integer idx = stylesIdx.get(name);
+			return idx == null ? null : styles.get(idx.intValue());
 		}
 		
 		public void addStyle(JRStyle style)
@@ -185,12 +183,12 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 		
 		public void renamed(String oldName, String newName)
 		{
-			Integer idx = (Integer) stylesIdx.remove(oldName);
+			Integer idx = stylesIdx.remove(oldName);
 			stylesIdx.put(newName, idx);
 		}
 	}
 	
-	private Set originalStyleList;
+	private Set<JRStyle> originalStyleList;
 	private StylesList stylesMap = new StylesList();
 
 
@@ -237,21 +235,21 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 	 */
 	protected JRFillChartDataset[] getDatasets()
 	{
-		return (JRFillChartDataset[]) elementDatasets.toArray(new JRFillChartDataset[elementDatasets.size()]);
+		return elementDatasets.toArray(new JRFillChartDataset[elementDatasets.size()]);
 	}
 
 
 	protected JRFillElementDataset[] getElementDatasets(JRDataset dataset)
 	{
 		JRFillElementDataset[] elementDatasetsArray;
-		List elementDatasetsList;
+		List<JRFillElementDataset> elementDatasetsList;
 		if (dataset.isMainDataset())
 		{
 			elementDatasetsList = elementDatasets;
 		}
 		else
 		{
-			elementDatasetsList = (List) elementDatasetMap.get(dataset.getName());
+			elementDatasetsList = elementDatasetMap.get(dataset.getName());
 		}
 
 		if (elementDatasetsList == null || elementDatasetsList.size() == 0)
@@ -268,35 +266,14 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 	}
 
 
-	/**
-	 *
-	 */
-	@SuppressWarnings("deprecation")
-	public JRReportFont getReportFont(JRReportFont font)
-	{
-		JRBaseReportFont fillFont = null;
-
-		if (font != null)
-		{
-			fillFont = (JRBaseReportFont)get(font);
-			if (fillFont == null)
-			{
-				fillFont = new JRBaseReportFont(font);
-				put(font, fillFont);
-			}
-		}
-
-		return fillFont;
-	}
-	
 	protected void registerDelayedStyleSetter(JRStyleSetter delayedSetter, String styleName)
 	{
 		if (parentFiller == null)
 		{
-			List setters = (List) delayedStyleSettersByName.get(styleName);
+			List<JRStyleSetter> setters = delayedStyleSettersByName.get(styleName);
 			if (setters == null)
 			{
-				setters = new ArrayList();
+				setters = new ArrayList<JRStyleSetter>();
 				delayedStyleSettersByName.put(styleName, setters);
 			}
 			
@@ -322,16 +299,20 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 		}
 	}
 	
-	public JRStyle getStyle(JRStyle style)
+	public JRBaseStyle getStyle(JRStyle style)
 	{
 		JRBaseStyle fillStyle = null;
 
 		if (style != null)
 		{
-			fillStyle = (JRBaseStyle)get(style);
+			fillStyle = (JRBaseStyle) get(style);
 			if (fillStyle == null)
 			{
 				fillStyle = new JRBaseStyle(style, this);
+				
+				// deduplicate to previously created identical instances
+				fillStyle = filler.fillContext.deduplicate(fillStyle);
+				
 				put(style, fillStyle);
 				
 				if (originalStyleList != null && originalStyleList.contains(style))
@@ -392,40 +373,6 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 	}
 
 
-	/**
-	 *
-	 *
-	protected JRBaseFont getFont(JRFont font)
-	{
-		JRBaseFont fillFont = null;
-
-		if (font != null)
-		{
-			fillFont = (JRBaseFont)get(font);
-			if (fillFont == null)
-			{
-				fillFont =
-					new JRBaseFont(
-						filler.getJasperPrint().getDefaultStyleProvider(),
-						getReportFont(font.getReportFont()),
-						font
-						);
-				put(font, fillFont);
-			}
-		}
-		else
-		{
-			if (defaultFont == null)
-			{
-				defaultFont = new JRBaseFont();
-			}
-			fillFont = getFont(defaultFont);
-		}
-
-		return fillFont;
-	}
-
-
 	/**
 	 *
 	 */
@@ -1381,7 +1328,7 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 	 */
 	public void registerElementDataset(JRFillElementDataset elementDataset)
 	{
-		List elementDatasetsList;
+		List<JRFillElementDataset> elementDatasetsList;
 		JRDatasetRun datasetRun = elementDataset.getDatasetRun();
 		if (datasetRun == null)
 		{
@@ -1390,10 +1337,10 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 		else
 		{
 			String datasetName = datasetRun.getDatasetName();
-			elementDatasetsList = (List) elementDatasetMap.get(datasetName);
+			elementDatasetsList = elementDatasetMap.get(datasetName);
 			if (elementDatasetsList == null)
 			{
-				elementDatasetsList = new ArrayList();
+				elementDatasetsList = new ArrayList<JRFillElementDataset>();
 				elementDatasetMap.put(datasetName, elementDatasetsList);
 			}
 		}
@@ -1521,19 +1468,19 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 		return fillTemplate;
 	}
 	
-	public List setStyles(List styles)
+	public List<JRStyle> setStyles(List<JRStyle> styles)
 	{
-		originalStyleList = new HashSet(styles);
+		originalStyleList = new HashSet<JRStyle>(styles);
 		
 		//filtering requested styles
-		Set requestedStyles = collectRequestedStyles(styles);
+		Set<JRStyle> requestedStyles = collectRequestedStyles(styles);
 		
 		//collect used styles
-		Map usedStylesMap = new SequencedHashMap();
-		Map allStylesMap = new HashMap();
-		for (Iterator it = styles.iterator(); it.hasNext();)
+		Map<JRStyle,Object> usedStylesMap = new SequencedHashMap();
+		Map<String,JRStyle> allStylesMap = new HashMap<String,JRStyle>();
+		for (Iterator<JRStyle> it = styles.iterator(); it.hasNext();)
 		{
-			JRStyle style = (JRStyle) it.next();
+			JRStyle style = it.next();
 			if (requestedStyles.contains(style))
 			{
 				collectUsedStyles(style, usedStylesMap, allStylesMap);
@@ -1541,10 +1488,10 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 			allStylesMap.put(style.getName(), style);
 		}
 		
-		List includedStyles = new ArrayList();
-		for (Iterator it = usedStylesMap.keySet().iterator(); it.hasNext();)
+		List<JRStyle> includedStyles = new ArrayList<JRStyle>();
+		for (Iterator<JRStyle> it = usedStylesMap.keySet().iterator(); it.hasNext();)
 		{
-			JRStyle style = (JRStyle) it.next();
+			JRStyle style = it.next();
 			JRStyle newStyle = getStyle(style);
 			
 			includedStyles.add(newStyle);
@@ -1559,12 +1506,12 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 		return includedStyles;
 	}
 
-	protected Set collectRequestedStyles(List externalStyles)
+	protected Set<JRStyle> collectRequestedStyles(List<JRStyle> externalStyles)
 	{
-		Map requestedStylesMap = new HashMap();
-		for (Iterator it = externalStyles.iterator(); it.hasNext();)
+		Map<String,JRStyle> requestedStylesMap = new HashMap<String,JRStyle>();
+		for (Iterator<JRStyle> it = externalStyles.iterator(); it.hasNext();)
 		{
-			JRStyle style = (JRStyle) it.next();
+			JRStyle style = it.next();
 			String name = style.getName();
 			if (delayedStyleSettersByName.containsKey(name))
 			{
@@ -1572,10 +1519,10 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 			}
 		}
 		
-		return new HashSet(requestedStylesMap.values());
+		return new HashSet<JRStyle>(requestedStylesMap.values());
 	}
 
-	protected void collectUsedStyles(JRStyle style, Map usedStylesMap, Map allStylesMap)
+	protected void collectUsedStyles(JRStyle style, Map<JRStyle,Object> usedStylesMap, Map<String,JRStyle> allStylesMap)
 	{
 		if (!usedStylesMap.containsKey(style) && originalStyleList.contains(style))
 		{
@@ -1585,7 +1532,7 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 				String parentName = style.getStyleNameReference();
 				if (parentName != null)
 				{
-					parent = (JRStyle) allStylesMap.get(parentName);
+					parent = allStylesMap.get(parentName);
 					if (parent == null)
 					{
 						throw new JRRuntimeException("Style " + parentName + " not found");
@@ -1604,12 +1551,12 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 	
 	protected void useDelayedStyle(JRStyle style)
 	{
-		List delayedSetters = (List) delayedStyleSettersByName.remove(style.getName());
+		List<JRStyleSetter> delayedSetters = delayedStyleSettersByName.remove(style.getName());
 		if (delayedSetters != null)
 		{
-			for (Iterator it = delayedSetters.iterator(); it.hasNext();)
+			for (Iterator<JRStyleSetter> it = delayedSetters.iterator(); it.hasNext();)
 			{
-				JRStyleSetter setter = (JRStyleSetter) it.next();
+				JRStyleSetter setter = it.next();
 				setter.setStyle(style);
 			}
 		}
@@ -1620,9 +1567,9 @@ public class JRFillObjectFactory extends JRAbstractObjectFactory
 		if (!delayedStyleSettersByName.isEmpty())
 		{
 			StringBuffer errorMsg = new StringBuffer("Could not resolve style(s): ");
-			for (Iterator it = delayedStyleSettersByName.keySet().iterator(); it.hasNext();)
+			for (Iterator<String> it = delayedStyleSettersByName.keySet().iterator(); it.hasNext();)
 			{
-				String name = (String) it.next();
+				String name = it.next();
 				errorMsg.append(name);
 				errorMsg.append(", ");
 			}
