@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -44,7 +44,7 @@ import org.apache.commons.logging.LogFactory;
  * Used to evaluate template source expressions.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRFillReportTemplate.java 3659 2010-03-31 10:20:49Z shertage $
+ * @version $Id: JRFillReportTemplate.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRFillReportTemplate implements JRReportTemplate
 {
@@ -78,20 +78,19 @@ public class JRFillReportTemplate implements JRReportTemplate
 		}
 		else
 		{
-			Class sourceType = sourceExpression.getValueClass();
-			if (JRTemplate.class.isAssignableFrom(sourceType))
+			if (source instanceof JRTemplate)
 			{
 				template = (JRTemplate) source;
 			}
 			else
 			{
-				template = loadTemplate(source, sourceType, filler.fillContext);
+				template = loadTemplate(source, filler.fillContext);
 			}
 		}
 		return template;
 	}
 
-	protected static JRTemplate loadTemplate(Object source, Class sourceType, JRFillContext fillContext) throws JRException
+	protected static JRTemplate loadTemplate(Object source, JRFillContext fillContext) throws JRException
 	{
 		JRTemplate template;
 		if (fillContext.hasLoadedTemplate(source))
@@ -105,25 +104,25 @@ public class JRFillReportTemplate implements JRReportTemplate
 				log.debug("Loading styles template from " + source);
 			}
 			
-			if (String.class.equals(sourceType))
+			if (source instanceof String)
 			{
 				template = JRXmlTemplateLoader.load((String) source);
 			}
-			else if (File.class.isAssignableFrom(sourceType))
+			else if (source instanceof File)
 			{
 				template = JRXmlTemplateLoader.load((File) source);
 			}
-			else if (URL.class.isAssignableFrom(sourceType))
+			else if (source instanceof URL)
 			{
 				template = JRXmlTemplateLoader.load((URL) source);
 			}
-			else if (InputStream.class.isAssignableFrom(sourceType))
+			else if (source instanceof InputStream)
 			{
 				template = JRXmlTemplateLoader.load((InputStream) source);
 			}
 			else
 			{
-				throw new JRRuntimeException("Unknown template source class " + sourceType.getName());
+				throw new JRRuntimeException("Unknown template source class " + source.getClass().getName());
 			}
 			
 			fillContext.registerLoadedTemplate(source, template);
