@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -31,7 +31,7 @@ import net.sf.jasperreports.engine.JRScriptlet;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillScriptlet.java 3034 2009-08-27 11:58:04Z teodord $
+ * @version $Id: JRFillScriptlet.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRFillScriptlet implements JRScriptlet
 {
@@ -40,12 +40,12 @@ public class JRFillScriptlet implements JRScriptlet
 	/**
 	 *
 	 */
-	protected JRScriptlet parent = null;
+	protected JRScriptlet parent;
 
 	/**
 	 *
 	 */
-	private JRAbstractScriptlet scriptlet = null;
+	private JRAbstractScriptlet scriptlet;
 
 
 	/**
@@ -88,7 +88,7 @@ public class JRFillScriptlet implements JRScriptlet
 	/**
 	 *
 	 */
-	public Class getValueClass()
+	public Class<?> getValueClass()
 	{
 		return parent.getValueClass();
 	}
