@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -44,7 +44,6 @@ import net.sf.jasperreports.engine.JRParameter;
 import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRPrintPage;
 import net.sf.jasperreports.engine.JRPrintRectangle;
-import net.sf.jasperreports.engine.JRReport;
 import net.sf.jasperreports.engine.JRRewindableDataSource;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRScriptlet;
@@ -55,13 +54,19 @@ import net.sf.jasperreports.engine.JRVariable;
 import net.sf.jasperreports.engine.JRVisitor;
 import net.sf.jasperreports.engine.JasperCompileManager;
 import net.sf.jasperreports.engine.JasperReport;
+import net.sf.jasperreports.engine.ReportContext;
+import net.sf.jasperreports.engine.base.JRVirtualPrintPage;
 import net.sf.jasperreports.engine.design.JRDesignSubreportReturnValue;
 import net.sf.jasperreports.engine.design.JRValidationException;
+import net.sf.jasperreports.engine.design.JRValidationFault;
 import net.sf.jasperreports.engine.design.JRVerifier;
+import net.sf.jasperreports.engine.type.CalculationEnum;
+import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.util.JRLoader;
 import net.sf.jasperreports.engine.util.JRProperties;
 import net.sf.jasperreports.engine.util.JRSingletonCache;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
+import net.sf.jasperreports.repo.RepositoryUtil;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -69,43 +74,45 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillSubreport.java 3034 2009-08-27 11:58:04Z teodord $
+ * @version $Id: JRFillSubreport.java 4747 2011-10-26 16:59:20Z lucianc $
  */
 public class JRFillSubreport extends JRFillElement implements JRSubreport
 {
 
 	private static final Log log = LogFactory.getLog(JRFillSubreport.class);
 	
-	private static final JRSingletonCache runnerFactoryCache = new JRSingletonCache(JRSubreportRunnerFactory.class);
+	private static final JRSingletonCache<JRSubreportRunnerFactory> runnerFactoryCache = 
+			new JRSingletonCache<JRSubreportRunnerFactory>(JRSubreportRunnerFactory.class);
 
 	/**
 	 *
 	 */
-	private Map parameterValues = null;
-	private JRSubreportParameter[] parameters = null;
-	private Connection connection = null;
-	private JRDataSource dataSource = null;
-	private JasperReport jasperReport = null;
+	private Map<String, Object> parameterValues;
+	private JRSubreportParameter[] parameters;
+	private Connection connection;
+	private JRDataSource dataSource;
+	private JasperReport jasperReport;
+	private Object source;
 
-	private Map loadedEvaluators = null;
+	private Map<JasperReport,JREvaluator> loadedEvaluators;
 	
 	/**
 	 * Values to be copied from the subreport.
 	 */
-	private JRFillSubreportReturnValue[] returnValues = null;
+	private JRFillSubreportReturnValue[] returnValues;
 
 	/**
 	 *
 	 */
-	protected JRBaseFiller subreportFiller = null;
-	private JRPrintPage printPage = null;
+	protected JRBaseFiller subreportFiller;
+	private JRPrintPage printPage;
 
 	private JRSubreportRunner runner;
 	
 	/**
 	 * Set of checked reports.
 	 */
-	private Set checkedReports;
+	private Set<JasperReport> checkedReports;
 
 
 	/**
@@ -123,7 +130,7 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 		JRSubreportReturnValue[] subrepReturnValues = subreport.getReturnValues();
 		if (subrepReturnValues != null)
 		{
-			List returnValuesList = new ArrayList(subrepReturnValues.length * 2);
+			List<JRFillSubreportReturnValue> returnValuesList = new ArrayList<JRFillSubreportReturnValue>(subrepReturnValues.length * 2);
 			
 			returnValues = new JRFillSubreportReturnValue[subrepReturnValues.length];
 			for (int i = 0; i < subrepReturnValues.length; i++)
@@ -135,21 +142,21 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 			returnValuesList.toArray(returnValues);
 		}
 		
-		loadedEvaluators = new HashMap();
-		checkedReports = new HashSet();
+		loadedEvaluators = new HashMap<JasperReport,JREvaluator>();
+		checkedReports = new HashSet<JasperReport>();
 	}
 
 
 	/**
 	 *
 	 */
-	public byte getMode()
+	public ModeEnum getModeValue()
 	{
-		return JRStyleResolver.getMode(this, MODE_TRANSPARENT);
+		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getUsingCache()}.
 	 */
 	public boolean isUsingCache()
 	{
@@ -157,12 +164,18 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	}
 		
 	/**
-	 * @deprecated Replaced by {@link #setUsingCache(Boolean)}.
+	 *
 	 */
-	public void setUsingCache(boolean isUsingCache)
+	public boolean usingCache()
 	{
+		Boolean isUsingCache = getUsingCache();
+		if (isUsingCache == null)
+		{
+			return source instanceof String;
+		}
+		return isUsingCache.booleanValue();
 	}
-
+		
 	public Boolean isRunToBottom()
 	{
 		return ((JRSubreport) parent).isRunToBottom();
@@ -232,9 +245,9 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	/**
 	 *
 	 */
-	protected Collection getPrintElements()
+	protected Collection<JRPrintElement> getPrintElements()
 	{
-		Collection printElements = null;
+		Collection<JRPrintElement> printElements = null;
 		
 		if (printPage != null)
 		{
@@ -257,16 +270,72 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 		evaluatePrintWhenExpression(evaluation);
 		evaluateProperties(evaluation);
 
-		if (
-			(isPrintWhenExpressionNull() ||
-			(!isPrintWhenExpressionNull() && 
-			isPrintWhenTrue()))
-			)
+		if (isPrintWhenExpressionNull() || isPrintWhenTrue())
 		{
 			evaluateSubreport(evaluation);
 		}
 	}
 
+	protected JasperReport evaluateReport(byte evaluation) throws JRException
+	{
+		JasperReport report = null;
+		
+		JRExpression expression = getExpression();
+		source = evaluateExpression(expression, evaluation);
+		if (source != null) // FIXME put some default broken image like in browsers
+		{
+			Boolean isUsingCache = getUsingCache();
+			if (isUsingCache == null)
+			{
+				isUsingCache = source instanceof String;
+			}
+			
+			if (isUsingCache && filler.fillContext.hasLoadedSubreport(source))
+			{
+				report = filler.fillContext.getLoadedSubreport(source);
+			}
+			else
+			{
+				if (source instanceof net.sf.jasperreports.engine.JasperReport)
+				{
+					report = (JasperReport)source;
+				}
+				else if (source instanceof java.io.InputStream)
+				{
+					report = (JasperReport)JRLoader.loadObject((InputStream)source);
+				}
+				else if (source instanceof java.net.URL)
+				{
+					report = (JasperReport)JRLoader.loadObject((URL)source);
+				}
+				else if (source instanceof java.io.File)
+				{
+					report = (JasperReport)JRLoader.loadObject((File)source);
+				}
+				else if (source instanceof java.lang.String)
+				{
+					report = RepositoryUtil.getReport((String)source);
+//						(JasperReport)JRLoader.loadObjectFromLocation(
+//							(String)source, 
+//							filler.reportClassLoader,
+//							filler.urlHandlerFactory,
+//							filler.fileResolver
+//							);
+				}
+				else
+				{
+					throw new JRRuntimeException("Unknown subreport source class " + source.getClass().getName());
+				}
+				
+				if (isUsingCache)
+				{
+					filler.fillContext.registerLoadedSubreport(source, report);
+				}
+			}
+		}
+		
+		return report;
+	}
 
 	/**
 	 *
@@ -275,125 +344,96 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 		byte evaluation
 		) throws JRException
 	{
-		JRExpression expression = getExpression();
-		Object source = evaluateExpression(expression, evaluation);
-		if (source != null) // FIXME put some default broken image like in browsers
-		{
-			JREvaluator evaluator = null;
-			
-			if (isUsingCache() && filler.fillContext.hasLoadedSubreport(source))
-			{
-				jasperReport = filler.fillContext.getLoadedSubreport(source);
-				evaluator = (JREvaluator)loadedEvaluators.get(jasperReport);
-
-				if (evaluator == null)
-				{
-					evaluator = JasperCompileManager.loadEvaluator(jasperReport);
-					loadedEvaluators.put(jasperReport, evaluator);
-				}
-			}
-			else
-			{
-				Class expressionClass = expression.getValueClass();
-				
-				if (expressionClass.equals(net.sf.jasperreports.engine.JasperReport.class))
-				{
-					jasperReport = (JasperReport)source;
-				}
-				else if (expressionClass.equals(java.io.InputStream.class))
-				{
-					jasperReport = (JasperReport)JRLoader.loadObject((InputStream)source);
-				}
-				else if (expressionClass.equals(java.net.URL.class))
-				{
-					jasperReport = (JasperReport)JRLoader.loadObject((URL)source);
-				}
-				else if (expressionClass.equals(java.io.File.class))
-				{
-					jasperReport = (JasperReport)JRLoader.loadObject((File)source);
-				}
-				else if (expressionClass.equals(java.lang.String.class))
-				{
-					jasperReport = 
-						(JasperReport)JRLoader.loadObjectFromLocation(
-							(String)source, 
-							filler.reportClassLoader,
-							filler.urlHandlerFactory,
-							filler.fileResolver
-							);
-				}
-				
-				if (jasperReport != null)
-				{
-					evaluator = JasperCompileManager.loadEvaluator(jasperReport);
-				}
-				
-				if (isUsingCache())
-				{
-					filler.fillContext.registerLoadedSubreport(source, jasperReport);
-					loadedEvaluators.put(jasperReport, evaluator);
-				}
-			}
-			
-			if (jasperReport != null)
-			{
-				/*   */
-				expression = getConnectionExpression();
-				connection = (Connection) evaluateExpression(expression, evaluation);
+		jasperReport = evaluateReport(evaluation);
 		
-				/*   */
-				expression = getDataSourceExpression();
-				dataSource = (JRDataSource) evaluateExpression(expression, evaluation);
-				
-				parameterValues = 
-					getParameterValues(
-						filler, 
-						getParametersMapExpression(), 
-						getParameters(), 
-						evaluation, 
-						false, 
-						jasperReport.getResourceBundle() != null,//hasResourceBundle 
-						jasperReport.getFormatFactoryClass() != null//hasFormatFactory
-						);
-
-				if (subreportFiller != null)
-				{
-					filler.unregisterSubfiller(subreportFiller);
-				}
+		if (jasperReport != null)
+		{
+			/*   */
+			connection = (Connection) evaluateExpression(
+					getConnectionExpression(), evaluation);
 	
-				/*   */
-				initSubreportFiller(evaluator);
-				
-				validateReport();
-				
-				saveReturnVariables();
+			/*   */
+			dataSource = (JRDataSource) evaluateExpression(
+					getDataSourceExpression(), evaluation);
+			
+			parameterValues = 
+				evaluateParameterValues(evaluation);
+
+			if (subreportFiller != null)
+			{
+				filler.unregisterSubfiller(subreportFiller);
 			}
+
+			/*   */
+			DatasetExpressionEvaluator evaluator = loadReportEvaluator();
+			initSubreportFiller(evaluator);
+			
+			validateReport();
+			
+			saveReturnVariables();
 		}
 	}
 
+	protected Map<String, Object> evaluateParameterValues(byte evaluation) throws JRException
+	{
+		return getParameterValues(
+			filler, 
+			getParametersMapExpression(), 
+			getParameters(), 
+			evaluation, 
+			false, 
+			jasperReport.getResourceBundle() != null,//hasResourceBundle 
+			jasperReport.getFormatFactoryClass() != null//hasFormatFactory
+			);
+	}
 
-	protected void initSubreportFiller(JREvaluator evaluator) throws JRException
+	protected DatasetExpressionEvaluator loadReportEvaluator() throws JRException
+	{
+		DatasetExpressionEvaluator evaluator = null;
+		if (isUsingCache())
+		{
+			evaluator = loadedEvaluators.get(jasperReport);
+		}
+		if (evaluator == null)
+		{
+			evaluator = createEvaluator();
+			if (isUsingCache())
+			{
+				loadedEvaluators.put(jasperReport, (JREvaluator)evaluator);
+			}
+		}
+		return evaluator;
+	}
+
+
+	protected DatasetExpressionEvaluator createEvaluator() throws JRException
+	{
+		return JasperCompileManager.loadEvaluator(jasperReport);
+	}
+
+
+	protected void initSubreportFiller(DatasetExpressionEvaluator evaluator) throws JRException
 	{
 		if (log.isDebugEnabled())
 		{
 			log.debug("Fill " + filler.fillerId + ": creating subreport filler");
 		}
 		
-		switch (jasperReport.getPrintOrder())
+		switch (jasperReport.getPrintOrderValue())
 		{
-			case JRReport.PRINT_ORDER_HORIZONTAL :
+			case HORIZONTAL :
 			{
 				subreportFiller = new JRHorizontalFiller(jasperReport, evaluator, this);
 				break;
 			}
-			case JRReport.PRINT_ORDER_VERTICAL :
+			case VERTICAL :
 			{
 				subreportFiller = new JRVerticalFiller(jasperReport, evaluator, this);
 				break;
 			}
 			default :
 			{
-				throw new JRRuntimeException("Unkown print order " + jasperReport.getPrintOrder() + ".");
+				throw new JRRuntimeException("Unkown print order " + jasperReport.getPrintOrderValue().getValue() + ".");
 			}
 		}
 		
@@ -414,7 +454,6 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 		}
 	}
 
-
 	/**
 	 * Utility method used for constructing a parameter values map for subreports, sub datasets and crosstabs.
 	 * 
@@ -428,7 +467,7 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	 * @return the parameter values map
 	 * @throws JRException
 	 */
-	public static Map getParameterValues(
+	public static Map<String, Object> getParameterValues(
 			JRBaseFiller filler, 
 			JRExpression parametersMapExpression, 
 			JRDatasetParameter[] subreportParameters, 
@@ -438,10 +477,41 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 			boolean removeFormatFactory
 			) throws JRException
 	{
-		Map parameterValues = null;
+		return getParameterValues(filler, filler.getExpressionEvaluator(), 
+				parametersMapExpression, subreportParameters, evaluation, 
+				ignoreNullExpressions, removeResourceBundle, removeFormatFactory);
+	}
+
+	/**
+	 * Utility method used for constructing a parameter values map for subreports, sub datasets and crosstabs.
+	 * 
+	 * @param filler report filler
+	 * @param expressionEvaluator expression evaluator
+	 * @param parametersMapExpression expression that yields bulk parameter values map
+	 * @param subreportParameters list of individual parameter values
+	 * @param evaluation evaluation type
+	 * @param ignoreNullExpressions whether to ignore individual parameter value expressions
+	 * @param removeResourceBundle whether to remove the {@link JRParameter#REPORT_RESOURCE_BUNDLE REPORT_RESOURCE_BUNDLE}
+	 * 	value from the bulk values map
+	 * @return the parameter values map
+	 * @throws JRException
+	 */
+	public static Map<String, Object> getParameterValues(
+			//TODO using the filler or current dataset?
+			JRBaseFiller filler, 
+			JRFillExpressionEvaluator expressionEvaluator,
+			JRExpression parametersMapExpression, 
+			JRDatasetParameter[] subreportParameters, 
+			byte evaluation, 
+			boolean ignoreNullExpressions, 
+			boolean removeResourceBundle,
+			boolean removeFormatFactory
+			) throws JRException
+	{
+		Map<String, Object> parameterValues = null;
 		if (parametersMapExpression != null)
 		{
-			parameterValues = (Map) filler.evaluateExpression(parametersMapExpression, evaluation);
+			parameterValues = (Map<String, Object>) expressionEvaluator.evaluate(parametersMapExpression, evaluation);
 		}		
 		
 		if (parameterValues != null)
@@ -450,7 +520,7 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 			if (parameterValues == filler.getParameterValuesMap())
 			{
 				//create a clone of the map so that the master map is not altered
-				parameterValues = new HashMap(parameterValues);
+				parameterValues = new HashMap<String, Object>(parameterValues);
 			}
 			
 			//parameterValues.remove(JRParameter.REPORT_LOCALE);
@@ -475,18 +545,21 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 			{
 				for(int i = 0; i < scriptlets.length; i++)
 				{
-					parameterValues.remove(scriptlets[i].getName() + "_SCRIPTLET");
+					parameterValues.remove(scriptlets[i].getName() 
+							+ JRScriptlet.SCRIPTLET_PARAMETER_NAME_SUFFIX);
 				}
 			}
 			parameterValues.remove(JRParameter.REPORT_VIRTUALIZER);
 			//parameterValues.remove(JRParameter.REPORT_CLASS_LOADER);
 			parameterValues.remove(JRParameter.IS_IGNORE_PAGINATION);
+			parameterValues.remove(JRParameter.SORT_FIELDS);
+			parameterValues.remove(JRParameter.FILTER);
 			parameterValues.remove(JRParameter.REPORT_PARAMETERS_MAP);
 		}
 		
 		if (parameterValues == null)
 		{
-			parameterValues = new HashMap();
+			parameterValues = new HashMap<String, Object>();
 		}
 		
 		/*   */
@@ -498,7 +571,7 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 				JRExpression expression = subreportParameters[i].getExpression();
 				if (expression != null || !ignoreNullExpressions)
 				{
-					parameterValue = filler.evaluateExpression(expression, evaluation);
+					parameterValue = expressionEvaluator.evaluate(expression, evaluation);
 					if (parameterValue == null)
 					{
 						parameterValues.remove(subreportParameters[i].getName());
@@ -547,6 +620,16 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 			parameterValues.put(JRParameter.REPORT_FILE_RESOLVER, filler.fileResolver);
 		}
 		
+		if (!parameterValues.containsKey(JRParameter.REPORT_CONTEXT))
+		{
+			ReportContext context = (ReportContext) filler.getMainDataset().getParameterValue(
+					JRParameter.REPORT_CONTEXT, true);
+			if (context != null)
+			{
+				parameterValues.put(JRParameter.REPORT_CONTEXT, context);
+			}
+		}
+		
 		return parameterValues;
 	}
 
@@ -608,6 +691,14 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 			rewind();
 		}
 		
+		if (printPage instanceof JRVirtualPrintPage)
+		{
+			// if the previous page was virtualized, dispose it as soon as possible.
+			// this normally already happened when we added the elements to the master page,
+			// but there are cases (e.g. overflow) when a page is not added to the master.
+			((JRVirtualPrintPage) printPage).dispose();
+		}
+		
 		subreportFiller.setPageHeight(availableHeight - getRelativeY());
 
 		synchronized (subreportFiller)
@@ -690,7 +781,7 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 			}
 		}// synchronized
 		
-		Collection printElements = getPrintElements();
+		Collection<JRPrintElement> printElements = getPrintElements();
 		if (
 			(printElements == null || printElements.size() == 0) &&
 			isRemoveLineWhenBlank() //FIXME if the line won't be removed, the background does not appear
@@ -713,22 +804,7 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 			return;
 		}
 		
-		if (log.isDebugEnabled())
-		{
-			log.debug("Fill " + filler.fillerId + ": cancelling " + subreportFiller.fillerId);
-		}
-		
-		// marking the subreport filler for interruption
-		subreportFiller.setInterrupted(true);
-		
-		synchronized (subreportFiller)
-		{
-			// forcing the creation of a new thread and a new subreport filler
-			runner.cancel();
-			runner.reset();
-		}
-
-		filler.unregisterSubfiller(subreportFiller);
+		cancelSubreportFill();
 		
 		initSubreportFiller(null);//FIXME used cached evaluator
 
@@ -748,12 +824,33 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	}
 
 
+	protected void cancelSubreportFill() throws JRException
+	{
+		if (log.isDebugEnabled())
+		{
+			log.debug("Fill " + filler.fillerId + ": cancelling " + subreportFiller.fillerId);
+		}
+		
+		// marking the subreport filler for interruption
+		subreportFiller.setInterrupted(true);
+		
+		synchronized (subreportFiller)
+		{
+			// forcing the creation of a new thread and a new subreport filler
+			runner.cancel();
+			runner.reset();
+		}
+
+		filler.unregisterSubfiller(subreportFiller);
+	}
+
+
 	/**
 	 *
 	 */
 	protected JRPrintElement fill()
 	{
-		JRPrintRectangle printRectangle = new JRTemplatePrintRectangle(getJRTemplateRectangle());
+		JRPrintRectangle printRectangle = new JRTemplatePrintRectangle(getJRTemplateRectangle(), elementId);
 
 		printRectangle.setX(getX());
 		printRectangle.setY(getRelativeY());
@@ -781,35 +878,39 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	}
 	
 
-	private JRFillSubreportReturnValue addReturnValue (JRSubreportReturnValue parentReturnValue, List returnValueList, JRFillObjectFactory factory)
+	private JRFillSubreportReturnValue addReturnValue (
+			JRSubreportReturnValue parentReturnValue, 
+			List<JRFillSubreportReturnValue> returnValueList, 
+			JRFillObjectFactory factory
+			)
 	{
 		JRFillSubreportReturnValue returnValue = factory.getSubreportReturnValue(parentReturnValue);
 		
-		byte calculation = returnValue.getCalculation();
+		CalculationEnum calculation = returnValue.getCalculationValue();
 		switch (calculation)
 		{
-			case JRVariable.CALCULATION_AVERAGE:
-			case JRVariable.CALCULATION_VARIANCE:
+			case AVERAGE:
+			case VARIANCE:
 			{
-				JRSubreportReturnValue countVal = createHelperReturnValue(parentReturnValue, "_COUNT", JRVariable.CALCULATION_COUNT);
+				JRSubreportReturnValue countVal = createHelperReturnValue(parentReturnValue, "_COUNT", CalculationEnum.COUNT);
 				addReturnValue(countVal, returnValueList, factory);
 
-				JRSubreportReturnValue sumVal = createHelperReturnValue(parentReturnValue, "_SUM", JRVariable.CALCULATION_SUM);
+				JRSubreportReturnValue sumVal = createHelperReturnValue(parentReturnValue, "_SUM", CalculationEnum.SUM);
 				addReturnValue(sumVal, returnValueList, factory);
 
 				filler.addVariableCalculationReq(returnValue.getToVariable(), calculation);
 
 				break;
 			}
-			case JRVariable.CALCULATION_STANDARD_DEVIATION:
+			case STANDARD_DEVIATION:
 			{
-				JRSubreportReturnValue varianceVal = createHelperReturnValue(parentReturnValue, "_VARIANCE", JRVariable.CALCULATION_VARIANCE);
+				JRSubreportReturnValue varianceVal = createHelperReturnValue(parentReturnValue, "_VARIANCE", CalculationEnum.VARIANCE);
 				addReturnValue(varianceVal, returnValueList, factory);
 				
 				filler.addVariableCalculationReq(returnValue.getToVariable(), calculation);
 				break;
 			}
-			case JRVariable.CALCULATION_DISTINCT_COUNT:
+			case DISTINCT_COUNT:
 			{
 				JRSubreportReturnValue countVal = createDistinctCountHelperReturnValue(parentReturnValue);
 				addReturnValue(countVal, returnValueList, factory);
@@ -825,7 +926,7 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	}
 
 	
-	protected JRSubreportReturnValue createHelperReturnValue(JRSubreportReturnValue returnValue, String nameSuffix, byte calculation)
+	protected JRSubreportReturnValue createHelperReturnValue(JRSubreportReturnValue returnValue, String nameSuffix, CalculationEnum calculation)
 	{
 		JRDesignSubreportReturnValue helper = new JRDesignSubreportReturnValue();
 		helper.setToVariable(returnValue.getToVariable() + nameSuffix);
@@ -842,7 +943,7 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 		JRDesignSubreportReturnValue helper = new JRDesignSubreportReturnValue();
 		helper.setToVariable(returnValue.getToVariable() + "_DISTINCT_COUNT");
 		helper.setSubreportVariable(returnValue.getSubreportVariable());
-		helper.setCalculation(JRVariable.CALCULATION_NOTHING);
+		helper.setCalculation(CalculationEnum.NOTHING);
 		helper.setIncrementerFactoryClassName(helper.getIncrementerFactoryClassName());//FIXME shouldn't it be returnValue? tests required
 		
 		return helper;
@@ -942,7 +1043,7 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 			}
 			while (parentFiller != null);
 			
-			List brokenRules = new ArrayList();
+			List<JRValidationFault> brokenRules = new ArrayList<JRValidationFault>();
 			JRVerifier.verifyBandHeights(brokenRules, 
 					jasperReport, pageHeight, topMargin, bottomMargin);
 			
@@ -985,8 +1086,8 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 				
 				JRVariable variable = filler.getVariable(returnValue.getToVariable());
 				if (
-					returnValue.getCalculation() == JRVariable.CALCULATION_COUNT
-					|| returnValue.getCalculation() == JRVariable.CALCULATION_DISTINCT_COUNT
+					returnValue.getCalculationValue() == CalculationEnum.COUNT
+					|| returnValue.getCalculationValue() == CalculationEnum.DISTINCT_COUNT
 					)
 				{
 					if (!Number.class.isAssignableFrom(variable.getValueClass()))
@@ -1013,12 +1114,21 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	}
 
 
+	/**
+	 * @deprecated Replaced by {@link #getUsingCache()}.
+	 */
 	public Boolean isOwnUsingCache()
 	{
 		return ((JRSubreport)parent).isOwnUsingCache();
 	}
 
 
+	public Boolean getUsingCache()
+	{
+		return ((JRSubreport)parent).getUsingCache();
+	}
+
+
 	public void setUsingCache(Boolean isUsingCache)
 	{
 	}
@@ -1037,6 +1147,11 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 		{
 			throw new JRException("Property \"" + JRSubreportRunnerFactory.SUBREPORT_RUNNER_FACTORY + "\" must be set");
 		}
-		return (JRSubreportRunnerFactory) runnerFactoryCache.getCachedInstance(factoryClassName);
+		return runnerFactoryCache.getCachedInstance(factoryClassName);
+	}
+
+	protected int getContentsStretchHeight()
+	{
+		return subreportFiller.getCurrentPageStretchHeight();
 	}
 }
