@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -27,7 +27,6 @@ import java.text.DecimalFormat;
 import java.text.Format;
 import java.text.SimpleDateFormat;
 
-import net.sf.jasperreports.engine.JRElement;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRExpressionCollector;
@@ -38,13 +37,17 @@ import net.sf.jasperreports.engine.JRPrintHyperlinkParameters;
 import net.sf.jasperreports.engine.JRPrintText;
 import net.sf.jasperreports.engine.JRTextField;
 import net.sf.jasperreports.engine.JRVisitor;
+import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
+import net.sf.jasperreports.engine.type.PositionTypeEnum;
+import net.sf.jasperreports.engine.type.RotationEnum;
 import net.sf.jasperreports.engine.util.JRDataUtils;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillTextField.java 3194 2009-11-11 11:11:28Z lucianc $
+ * @version $Id: JRFillTextField.java 4648 2011-10-10 12:50:53Z lucianc $
  */
 public class JRFillTextField extends JRFillTextElement implements JRTextField
 {
@@ -53,15 +56,30 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 	/**
 	 *
 	 */
-	private JRGroup evaluationGroup = null;
+	private JRGroup evaluationGroup;
 
 	/**
 	 *
 	 */
-	private String anchorName = null;
-	private String hyperlinkReference = null;
-	private String hyperlinkAnchor = null;
-	private Integer hyperlinkPage = null;
+	private Object value;
+
+	/**
+	 *
+	 */
+	private TextFormat textFormat;
+
+	/**
+	 * 
+	 */
+	private String pattern;
+
+	/**
+	 *
+	 */
+	private String anchorName;
+	private String hyperlinkReference;
+	private String hyperlinkAnchor;
+	private Integer hyperlinkPage;
 	private String hyperlinkTooltip;
 	private JRPrintHyperlinkParameters hyperlinkParameters;
 
@@ -106,17 +124,29 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 	/**
 	 *
 	 */
-	public byte getEvaluationTime()
+	public EvaluationTimeEnum getEvaluationTimeValue()
 	{
-		return ((JRTextField)parent).getEvaluationTime();
+		return ((JRTextField)parent).getEvaluationTimeValue();
 	}
 		
+	/**
+	 *
+	 */
+	protected TextFormat getTextFormat()
+	{
+		return textFormat;
+	}
+
 	/**
 	 *
 	 */
 	public String getPattern()
 	{
-		return JRStyleResolver.getPattern(this);
+		if (getPatternExpression() == null)
+		{
+			return JRStyleResolver.getPattern(this);
+		}
+		return pattern;
 	}
 		
 	public String getOwnPattern()
@@ -162,11 +192,19 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getHyperlinkTypeValue()}.
 	 */
 	public byte getHyperlinkType()
 	{
-		return ((JRTextField)parent).getHyperlinkType();
+		return getHyperlinkTypeValue().getValue();
+	}
+
+	/**
+	 *
+	 */
+	public HyperlinkTypeEnum getHyperlinkTypeValue()
+	{
+		return ((JRTextField)parent).getHyperlinkTypeValue();
 	}
 		
 	/**
@@ -201,6 +239,14 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 		return ((JRTextField)parent).getExpression();
 	}
 
+	/**
+	 *
+	 */
+	public JRExpression getPatternExpression()
+	{
+		return ((JRTextField)parent).getPatternExpression();
+	}
+
 	/**
 	 *
 	 */
@@ -234,6 +280,14 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 	}
 
 		
+	/**
+	 *
+	 */
+	protected Object getValue()
+	{
+		return value;
+	}
+
 	/**
 	 *
 	 */
@@ -290,40 +344,43 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 				filler.getJasperPrint().getDefaultStyleProvider(), 
 				this
 				);
-		setTemplatePattern(template);
 		return template;
 	}
 
 
-	protected void setTemplatePattern(JRTemplateText template)
+	protected void evaluateTextFormat(Format format, Object value)
 	{
-		if (getExpression() != null)
+		if (value != null)
+//		if (getExpression() != null)
 		{
-			Class valueClass = getExpression().getValueClass();
-			if (!String.class.equals(valueClass))
+			if (!(value instanceof String))
 			{
-				template.setValueClassName(valueClass.getName());
+				SimpleTextFormat simpleTextFormat = new SimpleTextFormat();
+				
+				simpleTextFormat.setValueClassName(value.getClass().getName());
 
-				String pattern = getTemplatePattern();
+				String pattern = getTemplatePattern(format, value);
 				if (pattern != null)
 				{
-					template.setPattern(pattern);
+					simpleTextFormat.setPattern(pattern);
 				}
 				
 				if (!filler.hasMasterFormatFactory())
 				{
-					template.setFormatFactoryClass(filler.getFormatFactory().getClass().getName());
+					simpleTextFormat.setFormatFactoryClass(filler.getFormatFactory().getClass().getName());
 				}
 				
 				if (!filler.hasMasterLocale())
 				{
-					template.setLocaleCode(JRDataUtils.getLocaleCode(filler.getLocale()));
+					simpleTextFormat.setLocaleCode(JRDataUtils.getLocaleCode(filler.getLocale()));
 				}
 
-				if (!filler.hasMasterTimeZone() && java.util.Date.class.isAssignableFrom(valueClass))
+				if (!filler.hasMasterTimeZone() && value instanceof java.util.Date)
 				{
-					template.setTimeZoneId(JRDataUtils.getTimeZoneId(filler.getTimeZone()));
+					simpleTextFormat.setTimeZoneId(JRDataUtils.getTimeZoneId(filler.getTimeZone()));
 				}
+				
+				textFormat = simpleTextFormat;
 			}
 		}
 	}
@@ -342,11 +399,7 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 		
 		evaluatePrintWhenExpression(evaluation);
 
-		if (
-			(isPrintWhenExpressionNull() ||
-			(!isPrintWhenExpressionNull() && 
-			isPrintWhenTrue()))
-			)
+		if (isPrintWhenExpressionNull() || isPrintWhenTrue())
 		{
 			if (isEvaluateNow())
 			{
@@ -365,26 +418,41 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 	{
 		evaluateProperties(evaluation);
 		
-		Object textFieldValue = evaluateExpression(getExpression(), evaluation);
+		value = evaluateExpression(getExpression(), evaluation);
+		
+		String strValue = null;
 
-		if (textFieldValue == null)
+		pattern = (String) evaluateExpression(getPatternExpression(), evaluation);
+
+		if (value == null)
 		{
 			if (isBlankWhenNull())
 			{
-				textFieldValue = "";
+				strValue = "";
+			}
+			else
+			{
+				strValue = null;
 			}
 		}
 		else
 		{
-			Format format = getFormat();
-			if (format != null)
+			Format format = getFormat(value);
+
+			evaluateTextFormat(format, value);
+
+			if (format == null)
 			{
-				textFieldValue = format.format(textFieldValue);
+				strValue = value.toString();
+			}
+			else
+			{
+				strValue = format.format(value);
 			}
 		}
 
 		String oldRawText = getRawText();
-		String newRawText = processMarkupText(String.valueOf(textFieldValue));
+		String newRawText = processMarkupText(String.valueOf(strValue));
 
 		setRawText(newRawText);
 		resetTextChunk();
@@ -427,7 +495,7 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 		{
 			if (isOverflow)
 			{
-				if (getPositionType() == JRElement.POSITION_TYPE_FIX_RELATIVE_TO_BOTTOM)
+				if (getPositionTypeValue() == PositionTypeEnum.FIX_RELATIVE_TO_BOTTOM)
 				{
 					// the content of the band bottom text fields is not
 					// consumed during overflows, because they only appear on the last overflow
@@ -437,7 +505,7 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 				if (
 					getTextEnd() >= getText().length()
 					|| !isStretchWithOverflow()
-					|| getRotation() != ROTATION_NONE
+					|| !getRotationValue().equals(RotationEnum.NONE)
 					)
 				{
 					// there is no more text left in the text field to overflow
@@ -460,17 +528,17 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 							isToPrint = false;
 						}
 					}
-					else
-					{
-						// the text field did not print on the previous page.
-						// we let it go since it is its first time anyway
-					}
-				}
-				else
-				{
-					// there is text left inside the stretchable text field.
-					// we simply let it go
+//					else
+//					{
+//						// the text field did not print on the previous page.
+//						// we let it go since it is its first time anyway
+//					}
 				}
+//				else
+//				{
+//					// there is text left inside the stretchable text field.
+//					// we simply let it go
+//				}
 
 				if (
 					isToPrint &&
@@ -516,7 +584,7 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 
 						if (
 							isStretchWithOverflow()
-							&& getRotation() == ROTATION_NONE
+							&& getRotationValue().equals(RotationEnum.NONE)
 							)
 						{
 							// the text field is allowed to stretch downwards in order to
@@ -610,17 +678,17 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 	 */
 	protected JRPrintElement fill() throws JRException
 	{
-		byte evaluationType = getEvaluationTime();
+		EvaluationTimeEnum evaluationTime = getEvaluationTimeValue();
 		
 		JRTemplatePrintText text;
 		JRRecordedValuesPrintText recordedValuesText;
 		if (isEvaluateAuto())
 		{
-			text = recordedValuesText = new JRRecordedValuesPrintText(getJRTemplateText());
+			text = recordedValuesText = new JRRecordedValuesPrintText(getJRTemplateText(), elementId);
 		}
 		else
 		{
-			text = new JRTemplatePrintText(getJRTemplateText());
+			text = new JRTemplatePrintText(getJRTemplateText(), elementId);
 			recordedValuesText = null;
 		}
 		
@@ -635,7 +703,7 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 //		{
 //			text.setHeight(getHeight());
 //		}
-		text.setRunDirection(getRunDirection());
+		text.setRunDirection(getRunDirectionValue());
 
 		if (isEvaluateNow())
 		{
@@ -647,7 +715,7 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 		}
 		else
 		{
-			filler.addBoundElement(this, text, evaluationType, getEvaluationGroup(), band);
+			filler.addBoundElement(this, text, evaluationTime, getEvaluationGroup(), band);
 		}
 
 		return text;
@@ -659,12 +727,16 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 	 */
 	protected void copy(JRPrintText text)
 	{
-		text.setLineSpacingFactor(getLineSpacingFactor());
-		text.setLeadingOffset(getLeadingOffset());
+		//text.setLineSpacingFactor(getLineSpacingFactor());
+		//text.setLeadingOffset(getLeadingOffset());
 		text.setTextHeight(getTextHeight());
 		//FIXME rotation and run direction?
 
+		text.setValue(getValue());
+		
 		setPrintText(text);
+		
+		text.setTextFormat(getTextFormat());//FIXMEFORMAT why do we set this always, even when pattern is fixed.
 
 		text.setAnchorName(getAnchorName());
 		text.setHyperlinkReference(getHyperlinkReference());
@@ -680,22 +752,17 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 	/**
 	 *
 	 */
-	protected Format getFormat()//FIXMEFORMAT optimize this with an interface
+	protected Format getFormat(Object value)//FIXMEFORMAT optimize this with an interface
 	{
 		Format format = null;
 
-		JRExpression valueExpression = getExpression();
-		if (valueExpression != null)
+		if (value instanceof java.util.Date)
 		{
-			Class valueClass = valueExpression.getValueClass();
-			if (java.util.Date.class.isAssignableFrom(valueClass))
-			{
-				format = filler.getDateFormat(getPattern());
-			}
-			else if (java.lang.Number.class.isAssignableFrom(valueClass))
-			{
-				format = filler.getNumberFormat(getPattern());
-			}
+			format = filler.getDateFormat(getPattern());
+		}
+		else if (value instanceof java.lang.Number)
+		{
+			format = filler.getNumberFormat(getPattern());
 		}
 		
 		return format;
@@ -704,28 +771,23 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 	/**
 	 *
 	 */
-	protected String getTemplatePattern()//FIXMEFORMAT optimize this with an interface
+	protected String getTemplatePattern(Format format, Object value)//FIXMEFORMAT optimize this with an interface
 	{
 		String pattern = null;
 		String originalPattern = getPattern();
-		Format format = getFormat();
-		JRExpression valueExpression = getExpression();
-		if (format != null && valueExpression != null)
+
+		if (value instanceof java.util.Date)
 		{
-			Class valueClass = valueExpression.getValueClass();
-			if (java.util.Date.class.isAssignableFrom(valueClass))
+			if (format instanceof SimpleDateFormat)
 			{
-				if (format instanceof SimpleDateFormat)
-				{
-					pattern = ((SimpleDateFormat) format).toPattern();
-				}
+				pattern = ((SimpleDateFormat) format).toPattern();
 			}
-			else if (Number.class.isAssignableFrom(valueClass))
+		}
+		else if (value instanceof Number)
+		{
+			if (format instanceof DecimalFormat)
 			{
-				if (format instanceof DecimalFormat)
-				{
-					pattern = ((DecimalFormat) format).toPattern();
-				}
+				pattern = ((DecimalFormat) format).toPattern();
 			}
 		}
 		
@@ -781,6 +843,7 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 		super.collectDelayedEvaluations();
 		
 		collectDelayedEvaluations(getExpression());
+		collectDelayedEvaluations(getPatternExpression());
 		collectDelayedEvaluations(getAnchorNameExpression());
 		collectDelayedEvaluations(getHyperlinkReferenceExpression());
 		collectDelayedEvaluations(getHyperlinkAnchorExpression());
@@ -809,7 +872,7 @@ public class JRFillTextField extends JRFillTextElement implements JRTextField
 	protected boolean canOverflow()
 	{
 		return isStretchWithOverflow()
-				&& getRotation() == ROTATION_NONE
+				&& getRotationValue().equals(RotationEnum.NONE)
 				&& isEvaluateNow()
 				&& filler.isBandOverFlowAllowed();
 	}
