@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -33,7 +33,7 @@ import net.sf.jasperreports.engine.type.ResetTypeEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillVariable.java 3510 2010-03-05 10:38:28Z shertage $
+ * @version $Id: JRFillVariable.java 4764 2011-10-28 08:49:51Z lucianc $
  */
 public class JRFillVariable implements JRVariable, JRCalculable
 {
@@ -42,23 +42,23 @@ public class JRFillVariable implements JRVariable, JRCalculable
 	/**
 	 *
 	 */
-	protected JRVariable parent = null;
+	protected JRVariable parent;
 
 	/**
 	 *
 	 */
-	private JRGroup resetGroup = null;
-	private JRGroup incrementGroup = null;
+	private JRGroup resetGroup;
+	private JRGroup incrementGroup;
 
 	/**
 	 *
 	 */
-	private Object previousOldValue = null;
-	private Object oldValue = null;
-	private Object estimatedValue = null;
-	private Object incrementedValue = null;
-	private Object value = null;
-	private boolean isInitialized = false;
+	private Object previousOldValue;
+	private Object oldValue;
+	private Object estimatedValue;
+	private Object incrementedValue;
+	private Object value;
+	private boolean isInitialized;
 	private Object savedValue;
 	
 	private JRFillVariable[] helperVariables;
@@ -66,7 +66,7 @@ public class JRFillVariable implements JRVariable, JRCalculable
 	/**
 	 *
 	 */
-	private JRIncrementer incrementer = null;
+	private JRIncrementer incrementer;
 
 
 	/**
@@ -88,6 +88,18 @@ public class JRFillVariable implements JRVariable, JRCalculable
 	}
 
 
+	protected void reset()
+	{
+		previousOldValue = null;
+		oldValue = null;
+		estimatedValue = null;
+		incrementedValue = null;
+		value = null;
+		isInitialized = false;
+		savedValue = null;
+	}
+
+
 	/**
 	 *
 	 */
@@ -99,7 +111,7 @@ public class JRFillVariable implements JRVariable, JRCalculable
 	/**
 	 *
 	 */
-	public Class getValueClass()
+	public Class<?> getValueClass()
 	{
 		return parent.getValueClass();
 	}
@@ -115,7 +127,7 @@ public class JRFillVariable implements JRVariable, JRCalculable
 	/**
 	 *
 	 */
-	public Class getIncrementerFactoryClass()
+	public Class<?> getIncrementerFactoryClass()
 	{
 		return parent.getIncrementerFactoryClass();
 	}
@@ -144,14 +156,6 @@ public class JRFillVariable implements JRVariable, JRCalculable
 		return parent.getInitialValueExpression();
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getResetTypeValue()}
-	 */
-	public byte getResetType()
-	{
-		return getResetTypeValue().getValue();
-	}
-		
 	/**
 	 *
 	 */
@@ -160,14 +164,6 @@ public class JRFillVariable implements JRVariable, JRCalculable
 		return parent.getResetTypeValue();
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getIncrementTypeValue()}
-	 */
-	public byte getIncrementType()
-	{
-		return getIncrementTypeValue().getValue();
-	}
-		
 	/**
 	 *
 	 */
@@ -176,14 +172,6 @@ public class JRFillVariable implements JRVariable, JRCalculable
 		return parent.getIncrementTypeValue();
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getCalculationValue()}
-	 */
-	public byte getCalculation()
-	{
-		return getCalculationValue().getValue();
-	}
-		
 	/**
 	 *
 	 */
@@ -304,7 +292,7 @@ public class JRFillVariable implements JRVariable, JRCalculable
 	{
 		if (incrementer == null)
 		{
-			Class incrementerFactoryClass = getIncrementerFactoryClass();
+			Class<?> incrementerFactoryClass = getIncrementerFactoryClass();
 			
 			JRIncrementerFactory incrementerFactory;
 			if (incrementerFactoryClass == null)
@@ -316,7 +304,7 @@ public class JRFillVariable implements JRVariable, JRCalculable
 				incrementerFactory = JRIncrementerFactoryCache.getInstance(incrementerFactoryClass); 
 			}
 			
-			incrementer = incrementerFactory.getIncrementer(getCalculation());
+			incrementer = incrementerFactory.getIncrementer(getCalculationValue().getValue());
 		}
 		
 		return incrementer;
