@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -34,7 +34,7 @@ import net.sf.jasperreports.engine.JasperReport;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFiller.java 3713 2010-04-08 11:06:05Z teodord $
+ * @version $Id: JRFiller.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public final class JRFiller
 {
@@ -45,7 +45,7 @@ public final class JRFiller
 	 */
 	public static JasperPrint fillReport(
 		JasperReport jasperReport,
-		Map parameters,
+		Map<String,Object> parameters,
 		Connection conn
 		) throws JRException
 	{
@@ -71,7 +71,7 @@ public final class JRFiller
 	 */
 	public static JasperPrint fillReport(
 		JasperReport jasperReport,
-		Map parameters,
+		Map<String,Object> parameters,
 		JRDataSource dataSource
 		) throws JRException
 	{
@@ -109,7 +109,7 @@ public final class JRFiller
 	 * @return the filled report
 	 * @throws JRException
 	 */
-	public static JasperPrint fillReport(JasperReport jasperReport, Map parameters) throws JRException
+	public static JasperPrint fillReport(JasperReport jasperReport, Map<String,Object> parameters) throws JRException
 	{
 		JRBaseFiller filler = createFiller(jasperReport);
 
