@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2005 - 2009 Works, Inc. All rights reserved.
+ * Copyright (C) 2005 - 2011 Works, Inc. All rights reserved.
  * http://www.works.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -43,11 +43,11 @@ import net.sf.jasperreports.engine.JRVirtualizable;
  * GZips the pages that it doesn't need, but keeps them in memory.
  * 
  * @author John Bindel
- * @version $Id: JRGzipVirtualizer.java 3716 2010-04-08 19:57:14Z teodord $
+ * @version $Id: JRGzipVirtualizer.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRGzipVirtualizer extends JRAbstractLRUVirtualizer
 {
-	private final Map zippedData;
+	private final Map<String,byte[]> zippedData;
 
 	/**
 	 * @param maxSize
@@ -94,7 +94,7 @@ public class JRGzipVirtualizer extends JRAbstractLRUVirtualizer
 	protected void pageIn(JRVirtualizable o) throws IOException {
 		GZIPInputStream gis = null;
 		try {
-			byte[] data = (byte[]) zippedData.get(o.getUID());
+			byte[] data = zippedData.get(o.getUID());
 			if (data == null) {
 				throw new JRRuntimeException("No data found for object with UID " + o.getUID());
 			}
