@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -42,7 +42,7 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRHorizontalFiller.java 3953 2010-09-20 13:54:34Z teodord $
+ * @version $Id: JRHorizontalFiller.java 4747 2011-10-26 16:59:20Z lucianc $
  */
 public class JRHorizontalFiller extends JRBaseFiller
 {
@@ -237,11 +237,6 @@ public class JRHorizontalFiller extends JRBaseFiller
 			//{
 				printPageStretchHeight = offsetY + bottomMargin;
 			//}
-
-			if (fillContext.isUsingVirtualizer())
-			{
-				removePageIdentityDataProvider();
-			}
 		}
 
 		if (fillContext.isIgnorePagination())
@@ -794,7 +789,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 
 			for(int i = 0; i < detailBands.length; i++)
 			{
-				JRFillBand detailBand = (JRFillBand)detailBands[i];
+				JRFillBand detailBand = detailBands[i];
 
 				detailBand.evaluatePrintWhenExpression(JRExpression.EVALUATION_DEFAULT);
 
@@ -1201,7 +1196,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 			}
 
 			/*   */
-			fillSummaryOverflow(printBand);
+			fillSummaryOverflow();
 			
 			//DONE
 		}
@@ -1275,7 +1270,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 			offsetY += printBand.getHeight();
 
 			/*   */
-			fillSummaryOverflow(printBand);
+			fillSummaryOverflow();
 		}
 		
 		//DONE
@@ -1337,7 +1332,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				}
 				
 				/*   */
-				fillSummaryOverflow(printBand);
+				fillSummaryOverflow();
 
 				//DONE
 			}
@@ -1399,7 +1394,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				offsetY += printBand.getHeight();
 
 				/*   */
-				fillSummaryOverflow(printBand);
+				fillSummaryOverflow();
 				
 				//DONE
 			}
@@ -1457,7 +1452,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 			offsetY += printBand.getHeight();
 
 			/*   */
-			fillSummaryOverflow(printBand);
+			fillSummaryOverflow();
 			
 			//DONE
 		}
@@ -1516,7 +1511,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				}
 
 				/*   */
-				fillSummaryOverflow(printBand);
+				fillSummaryOverflow();
 				
 				//DONE
 			}
@@ -1606,7 +1601,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				}
 
 				/*   */
-				fillSummaryOverflow(printBand);
+				fillSummaryOverflow();
 				
 				//DONE
 			}
@@ -1669,7 +1664,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				offsetY += printBand.getHeight();
 
 				/*   */
-				fillSummaryOverflow(printBand);
+				fillSummaryOverflow();
 			}
 			
 			//DONE
@@ -1734,7 +1729,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 					offsetY += printBand.getHeight();
 
 					/*   */
-					fillSummaryOverflow(printBand);
+					fillSummaryOverflow();
 				}
 				
 				//DONE
@@ -1776,7 +1771,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 					}
 
 					/*   */
-					fillSummaryOverflow(printBand);
+					fillSummaryOverflow();
 				}
 				else
 				{
@@ -1792,7 +1787,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 	/**
 	 *
 	 */
-	private void fillSummaryOverflow(JRPrintBand printBand) throws JRException
+	private void fillSummaryOverflow() throws JRException
 	{
 		while (summary.willOverflow())
 		{
@@ -1815,7 +1810,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				fillPageHeader(JRExpression.EVALUATION_DEFAULT);
 			}
 			
-			printBand = summary.fill(pageHeight - bottomMargin - offsetY - (isSummaryWithPageHeaderAndFooter?pageFooter.getHeight():0));
+			JRPrintBand printBand = summary.fill(pageHeight - bottomMargin - offsetY - (isSummaryWithPageHeaderAndFooter?pageFooter.getHeight():0));
 
 			fillBand(printBand);
 			offsetY += printBand.getHeight();
@@ -1905,21 +1900,11 @@ public class JRHorizontalFiller extends JRBaseFiller
 				printPageStretchHeight = offsetY + bottomMargin;
 			//}
 
-			if (fillContext.isUsingVirtualizer())
-			{
-				removePageIdentityDataProvider();
-			}
-
 			suspendSubreportRunner();
 		}
 
 		printPage = newPage();
 
-		if (isSubreport() && fillContext.isUsingVirtualizer())
-		{
-			addPageIdentityDataProvider();
-		}
-
 		if (isResetPageNumber)
 		{
 			calculator.getPageNumber().setValue(Integer.valueOf(1));
@@ -1989,17 +1974,25 @@ public class JRHorizontalFiller extends JRBaseFiller
 		calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 		scriptlet.callAfterPageInit();
 
+		if (
+			keepTogetherSavePoint != null
+			&& !keepTogetherSavePoint.isNewPage 
+			)
+		{
+			keepTogetherSavePoint.removeContent();
+		}
+
 		addPage(isResetPageNumber);
 
 		fillPageHeader(evalNextPage);
 
 		fillColumnHeaders(evalNextPage);
 
-		if (keepTogetherSavePoint != null)
-		{
-			moveKeepTogetherSavePointContent();
-		}
-		else if (isReprintGroupHeaders)
+		boolean savePointContentMoved = moveKeepTogetherSavePointContent();
+		if (
+			!savePointContentMoved
+			&& isReprintGroupHeaders
+			)
 		{
 			fillGroupHeadersReprint(evalNextPage);
 		}
@@ -2169,18 +2162,12 @@ public class JRHorizontalFiller extends JRBaseFiller
 	 */
 	protected void fillBand(JRPrintBand band)
 	{
-		java.util.List elements = band.getElements();
-
-		if (elements != null && elements.size() > 0)
+		for(Iterator<JRPrintElement> it = band.iterateElements(); it.hasNext();)
 		{
-			JRPrintElement element = null;
-			for(Iterator it = elements.iterator(); it.hasNext();)
-			{
-				element = (JRPrintElement)it.next();
-				element.setX(element.getX() + offsetX);
-				element.setY(element.getY() + offsetY);
-				printPage.addElement(element);
-			}
+			JRPrintElement element = it.next();
+			element.setX(element.getX() + offsetX);
+			element.setY(element.getY() + offsetY);
+			printPage.addElement(element);
 		}
 	}
 
