@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -32,7 +32,7 @@ import org.apache.commons.collections.ReferenceMap;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRIncrementerFactoryCache.java 3713 2010-04-08 11:06:05Z teodord $
+ * @version $Id: JRIncrementerFactoryCache.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public final class JRIncrementerFactoryCache
 {
@@ -41,16 +41,16 @@ public final class JRIncrementerFactoryCache
 	/**
 	 *
 	 */
-	private static Map factoriesMap = 
+	private static Map<Class<?>,JRIncrementerFactory> factoriesMap = 
 		new ReferenceMap(ReferenceMap.WEAK, ReferenceMap.HARD);
 
 
 	/**
 	 *
 	 */
-	public static synchronized JRIncrementerFactory getInstance(Class factoryClass)
+	public static synchronized JRIncrementerFactory getInstance(Class<?> factoryClass)
 	{
-		JRIncrementerFactory incrementerFactory = (JRIncrementerFactory)factoriesMap.get(factoryClass);
+		JRIncrementerFactory incrementerFactory = factoriesMap.get(factoryClass);
 
 		if (incrementerFactory == null)
 		{
