@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -31,6 +31,8 @@ import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRGroup;
 import net.sf.jasperreports.engine.JRParameter;
 import net.sf.jasperreports.engine.JasperReport;
+import net.sf.jasperreports.repo.RepositoryUtil;
+import net.sf.jasperreports.repo.SimpleRepositoryContext;
 
 
 /**
@@ -38,7 +40,7 @@ import net.sf.jasperreports.engine.JasperReport;
  * without actually filling it.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRParameterDefaultValuesEvaluator.java 3713 2010-04-08 11:06:05Z teodord $
+ * @version $Id: JRParameterDefaultValuesEvaluator.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public final class JRParameterDefaultValuesEvaluator
 {
@@ -51,9 +53,9 @@ public final class JRParameterDefaultValuesEvaluator
 	 * @return a map containing parameter values indexed by parameter names
 	 * @throws JRException
 	 */
-	public static Map evaluateParameterDefaultValues(JasperReport report, Map initialParameters) throws JRException
+	public static Map<String,Object> evaluateParameterDefaultValues(JasperReport report, Map<String,Object> initialParameters) throws JRException
 	{
-		Map valuesMap = initialParameters == null ? new HashMap() : new HashMap(initialParameters);
+		Map<String,Object> valuesMap = initialParameters == null ? new HashMap<String,Object>() : new HashMap<String,Object>(initialParameters);
 		
 		valuesMap.put(JRParameter.JASPER_REPORT, report);
 		
@@ -63,13 +65,13 @@ public final class JRParameterDefaultValuesEvaluator
 		fillDataset.createCalculator(report);
 		fillDataset.initCalculator();
 
-		JRResourcesFillUtil.ResourcesFillContext resourcesContext = 
-			JRResourcesFillUtil.setResourcesFillContext(valuesMap);
+		RepositoryUtil.setRepositoryContext(new SimpleRepositoryContext(valuesMap));
+
 		try
 		{
 			fillDataset.setParameterValues(valuesMap);
 			
-			Map parameterValues = new HashMap();
+			Map<String,Object> parameterValues = new HashMap<String,Object>();
 			JRParameter[] parameters = reportDataset.getParameters();
 			for (int i = 0; i < parameters.length; i++)
 			{
@@ -86,7 +88,7 @@ public final class JRParameterDefaultValuesEvaluator
 		}
 		finally
 		{
-			JRResourcesFillUtil.revertResourcesFillContext(resourcesContext);
+			RepositoryUtil.revertRepositoryContext();
 		}
 	}
 	
