@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -29,18 +29,20 @@ import java.util.Map;
 import net.sf.jasperreports.engine.JRParameter;
 import net.sf.jasperreports.engine.util.FileResolver;
 import net.sf.jasperreports.engine.util.JRResourcesUtil;
+import net.sf.jasperreports.repo.RepositoryUtil;
 
 /**
  * Resources utility class used for report fills.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRResourcesFillUtil.java 3713 2010-04-08 11:06:05Z teodord $
+ * @version $Id: JRResourcesFillUtil.java 4595 2011-09-08 15:55:10Z teodord $
  * @see JRResourcesUtil
+ * @deprecated Replaced by {@link RepositoryUtil}.
  */
 public final class JRResourcesFillUtil
 {
 	
-	public static ResourcesFillContext setResourcesFillContext(Map parameterValues)
+	public static ResourcesFillContext setResourcesFillContext(Map<String,Object> parameterValues)
 	{
 		ResourcesFillContext context = new ResourcesFillContext();
 		
