@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -28,7 +28,7 @@ import net.sf.jasperreports.engine.type.CalculationEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRShortIncrementerFactory.java 3693 2010-04-06 14:43:13Z shertage $
+ * @version $Id: JRShortIncrementerFactory.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public final class JRShortIncrementerFactory extends JRAbstractExtendedIncrementerFactory
 {
@@ -63,16 +63,6 @@ public final class JRShortIncrementerFactory extends JRAbstractExtendedIncrement
 	}
 
 
-	/**
-	 * @deprecated Replaced by {@link #getExtendedIncrementer(CalculationEnum)}
-	 */
-	public JRExtendedIncrementer getExtendedIncrementer(byte calculation)
-	{
-		
-		return getExtendedIncrementer(CalculationEnum.getByValue(calculation));
-	}
-
-
 	/**
 	 *
 	 */
