@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -38,13 +38,13 @@ import net.sf.jasperreports.engine.util.JRSwapFile;
  * A virtualizer that uses a single swap file to serialize virtual data.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRSwapFileVirtualizer.java 3659 2010-03-31 10:20:49Z shertage $
+ * @version $Id: JRSwapFileVirtualizer.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRSwapFileVirtualizer extends JRAbstractLRUVirtualizer
 {
 	private final JRSwapFile swap;
 	private final boolean swapOwner;
-	private final Map handles;
+	private final Map<String,JRSwapFile.SwapHandle> handles;
 	
 	
 	/**
@@ -76,7 +76,7 @@ public class JRSwapFileVirtualizer extends JRAbstractLRUVirtualizer
 
 		this.swap = swap;
 		this.swapOwner = swapOwner;
-		handles = Collections.synchronizedMap(new HashMap());
+		handles = Collections.synchronizedMap(new HashMap<String,JRSwapFile.SwapHandle>());
 	}
 
 	protected void pageOut(JRVirtualizable o) throws IOException
@@ -101,7 +101,7 @@ public class JRSwapFileVirtualizer extends JRAbstractLRUVirtualizer
 
 	protected void pageIn(JRVirtualizable o) throws IOException
 	{
-		JRSwapFile.SwapHandle handle = (JRSwapFile.SwapHandle) handles.get(o.getUID());
+		JRSwapFile.SwapHandle handle = handles.get(o.getUID());
 		byte[] data = swap.read(handle, !isReadOnly(o));
 
 		readData(o, new ByteArrayInputStream(data));
@@ -114,7 +114,7 @@ public class JRSwapFileVirtualizer extends JRAbstractLRUVirtualizer
 
 	protected void dispose(String id)
 	{
-		JRSwapFile.SwapHandle handle = (JRSwapFile.SwapHandle) handles.remove(id);
+		JRSwapFile.SwapHandle handle = handles.remove(id);
 		if (handle != null)
 		{
 			swap.free(handle);
