@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -32,13 +32,14 @@ import net.sf.jasperreports.engine.JRLine;
 import net.sf.jasperreports.engine.JROrigin;
 import net.sf.jasperreports.engine.base.JRBasePen;
 import net.sf.jasperreports.engine.type.LineDirectionEnum;
+import net.sf.jasperreports.engine.util.ObjectUtils;
 
 
 /**
  * Line element information shared by multiple print line objects.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRTemplateLine.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRTemplateLine.java 4647 2011-10-06 10:19:07Z lucianc $
  * @see JRTemplatePrintLine
  */
 public class JRTemplateLine extends JRTemplateGraphicElement
@@ -91,22 +92,6 @@ public class JRTemplateLine extends JRTemplateGraphicElement
 		setDirection(line.getDirectionValue());
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getDirectionValue()}.
-	 */
-	public byte getDirection()
-	{
-		return getDirectionValue().getValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setDirection(LineDirectionEnum)}.
-	 */
-	public void setDirection(byte direction)
-	{
-		setDirection(LineDirectionEnum.getByValue(direction));
-	}
-
 	/**
 	 * 
 	 */
@@ -143,4 +128,29 @@ public class JRTemplateLine extends JRTemplateGraphicElement
 		
 	}
 
+
+	public int getHashCode()
+	{
+		ObjectUtils.HashCode hash = ObjectUtils.hash();
+		addGraphicHash(hash);
+		return hash.getHashCode();
+	}
+
+
+	public boolean isIdentical(Object object)
+	{
+		if (this == object)
+		{
+			return true;
+		}
+		
+		if (!(object instanceof JRTemplateLine))
+		{
+			return false;
+		}
+		
+		JRTemplateLine template = (JRTemplateLine) object;
+		return graphicIdentical(template);
+	}
+
 }
