@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -29,7 +29,6 @@ import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRPen;
 import net.sf.jasperreports.engine.JRPrintGraphicElement;
 import net.sf.jasperreports.engine.type.FillEnum;
-import net.sf.jasperreports.engine.util.JRPenUtil;
 
 
 /**
@@ -38,7 +37,7 @@ import net.sf.jasperreports.engine.util.JRPenUtil;
  * store common attributes. 
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRTemplatePrintGraphicElement.java 3833 2010-05-27 14:16:59Z teodord $
+ * @version $Id: JRTemplatePrintGraphicElement.java 4648 2011-10-10 12:50:53Z lucianc $
  */
 public class JRTemplatePrintGraphicElement extends JRTemplatePrintElement implements JRPrintGraphicElement
 {
@@ -52,12 +51,22 @@ public class JRTemplatePrintGraphicElement extends JRTemplatePrintElement implem
 
 	/**
 	 *
+	 * @deprecated provide a source Id via {@link #JRTemplatePrintGraphicElement(JRTemplateGraphicElement, int)}
 	 */
 	protected JRTemplatePrintGraphicElement(JRTemplateGraphicElement graphicElement)
 	{
 		super(graphicElement);
 	}
 
+	/**
+	 *
+	 * @param sourceElementId the Id of the source element
+	 */
+	protected JRTemplatePrintGraphicElement(JRTemplateGraphicElement graphicElement, int sourceElementId)
+	{
+		super(graphicElement, sourceElementId);
+	}
+
 	/**
 	 *
 	 */
@@ -66,70 +75,6 @@ public class JRTemplatePrintGraphicElement extends JRTemplatePrintElement implem
 		return ((JRTemplateGraphicElement)template).getLinePen();
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getLinePen()}
-	 */
-	public byte getPen()
-	{
-		return JRPenUtil.getPenFromLinePen(getLinePen());
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #getLinePen()}
-	 */
-	public Byte getOwnPen()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(getLinePen());
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #getLinePen()}
-	 */
-	public void setPen(byte pen)
-	{
-		setPen(new Byte(pen));
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #getLinePen()}
-	 */
-	public void setPen(Byte pen)
-	{
-		JRPenUtil.setLinePenFromPen(pen, getLinePen());
-	}
-		
-
-	/**
-	 * @deprecated Replaced by {@link #getFillValue()}
-	 */
-	public byte getFill()
-	{
-		return getFillValue().getValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getOwnFillValue()}
-	 */
-	public Byte getOwnFill()
-	{
-		return getOwnFillValue() == null ? null : getOwnFillValue().getValueByte();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setFill(FillEnum)}
-	 */
-	public void setFill(byte fill)
-	{
-		throw new UnsupportedOperationException();
-	}
-	
-	/**
-	 * @deprecated Replaced by {@link #setFill(FillEnum)}
-	 */
-	public void setFill(Byte fill)
-	{
-		throw new UnsupportedOperationException();
-	}
 
 	/**
 	 * 
