@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,7 +35,7 @@ import net.sf.jasperreports.engine.type.LineDirectionEnum;
  * store common attributes. 
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRTemplatePrintLine.java 3991 2010-10-12 20:10:55Z lucianc $
+ * @version $Id: JRTemplatePrintLine.java 4648 2011-10-10 12:50:53Z lucianc $
  */
 public class JRTemplatePrintLine extends JRTemplatePrintGraphicElement implements JRPrintLine
 {
@@ -51,27 +51,24 @@ public class JRTemplatePrintLine extends JRTemplatePrintGraphicElement implement
 	 * Creates a print line element.
 	 * 
 	 * @param line the template line that the element will use
+	 * @deprecated provide a source Id via {@link #JRTemplatePrintLine(JRTemplateLine, int)}
 	 */
 	public JRTemplatePrintLine(JRTemplateLine line)
 	{
 		super(line);
 	}
-	
-	/**
-	 * @deprecated Replaced by {@link #getDirectionValue()}.
-	 */
-	public byte getDirection()
-	{
-		return getDirectionValue().getValue();
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #setDirection(LineDirectionEnum)}.
-	 */
-	public void setDirection(byte direction)
-	{
-	}
 
+	/**
+	 * Creates a print line element.
+	 * 
+	 * @param line the template line that the element will use
+	 * @param sourceElementId the Id of the source element
+	 */
+	public JRTemplatePrintLine(JRTemplateLine line, int sourceElementId)
+	{
+		super(line, sourceElementId);
+	}
+	
 	/**
 	 * 
 	 */
