@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -28,7 +28,6 @@ import java.io.IOException;
 import java.io.ObjectInputStream;
 
 import net.sf.jasperreports.engine.JRAlignment;
-import net.sf.jasperreports.engine.JRBox;
 import net.sf.jasperreports.engine.JRCommonText;
 import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRDefaultStyleProvider;
@@ -36,12 +35,13 @@ import net.sf.jasperreports.engine.JRFont;
 import net.sf.jasperreports.engine.JRHyperlinkHelper;
 import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JROrigin;
-import net.sf.jasperreports.engine.JRReportFont;
+import net.sf.jasperreports.engine.JRParagraph;
 import net.sf.jasperreports.engine.JRStaticText;
 import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.JRTextElement;
 import net.sf.jasperreports.engine.JRTextField;
 import net.sf.jasperreports.engine.base.JRBaseLineBox;
+import net.sf.jasperreports.engine.base.JRBaseParagraph;
 import net.sf.jasperreports.engine.type.HorizontalAlignEnum;
 import net.sf.jasperreports.engine.type.HyperlinkTargetEnum;
 import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
@@ -50,19 +50,18 @@ import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.type.RotationEnum;
 import net.sf.jasperreports.engine.type.VerticalAlignEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
-import net.sf.jasperreports.engine.util.JRPenUtil;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
-import net.sf.jasperreports.engine.util.LineBoxWrapper;
+import net.sf.jasperreports.engine.util.ObjectUtils;
 
 
 /**
  * Text element information shared by multiple print text objects.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRTemplateText.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: JRTemplateText.java 4647 2011-10-06 10:19:07Z lucianc $
  * @see JRTemplatePrintText
  */
-public class JRTemplateText extends JRTemplateElement implements JRAlignment, JRBox, JRFont, JRCommonText
+public class JRTemplateText extends JRTemplateElement implements JRAlignment, JRFont, JRCommonText, TextFormat
 {
 
 
@@ -77,7 +76,6 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 	private HorizontalAlignEnum horizontalAlignmentValue;
 	private VerticalAlignEnum verticalAlignmentValue;
 	private RotationEnum rotationValue;
-	private LineSpacingEnum lineSpacingValue;
 	private String markup;
 	private String linkType;
 	private String linkTarget;
@@ -86,8 +84,8 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 	 *
 	 */
 	protected JRLineBox lineBox;
+	protected JRParagraph paragraph;
 
-	protected JRReportFont reportFont;
 	protected String fontName;
 	protected Boolean isBold;
 	protected Boolean isItalic;
@@ -137,6 +135,7 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 		super(origin, defaultStyleProvider);
 		
 		lineBox = new JRBaseLineBox(this);
+		paragraph = new JRBaseParagraph(this);
 	}
 	
 	/**
@@ -166,9 +165,8 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 		super.setElement(textElement);
 
 		copyLineBox(textElement.getLineBox());
+		copyParagraph(textElement.getParagraph());
 		
-		reportFont = textElement.getReportFont();
-
 		fontName = textElement.getOwnFontName();
 		isBold = textElement.isOwnBold();
 		isItalic = textElement.isOwnItalic();
@@ -182,7 +180,6 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 		horizontalAlignmentValue = textElement.getOwnHorizontalAlignmentValue();
 		verticalAlignmentValue = textElement.getOwnVerticalAlignmentValue();
 		rotationValue = textElement.getOwnRotationValue();
-		lineSpacingValue = textElement.getOwnLineSpacingValue();
 		markup = textElement.getOwnMarkup();
 	}
 
@@ -196,22 +193,16 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 		lineBox = box.clone(this);
 	}
 
-	
 	/**
+	 * Copies paragraph attributes.
 	 * 
+	 * @param prg the object to copy attributes from
 	 */
-	protected JRFont getBaseFont()
+	public void copyParagraph(JRParagraph prg)
 	{
-		if (reportFont != null)
-		{
-			return reportFont;
-		}
-		if (defaultStyleProvider != null)
-		{
-			return defaultStyleProvider.getDefaultFont();
-		}
-		return null;
+		paragraph = prg.clone(this);
 	}
+
 	
 	/**
 	 *
@@ -221,30 +212,6 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getHorizontalAlignment()}.
-	 */
-	public byte getTextAlignment()
-	{
-		return getHorizontalAlignment();
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #getHorizontalAlignmentValue()}.
-	 */
-	public byte getHorizontalAlignment()
-	{
-		return getHorizontalAlignmentValue().getValue();
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #getOwnHorizontalAlignmentValue()}.
-	 */
-	public Byte getOwnHorizontalAlignment()
-	{
-		return getOwnHorizontalAlignmentValue() == null ? null : getOwnHorizontalAlignmentValue().getValueByte();
-	}
-		
 	/**
 	 *
 	 */
@@ -261,22 +228,6 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 		return horizontalAlignmentValue;
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
-	 */
-	public void setHorizontalAlignment(byte horizontalAlignment)
-	{
-		setHorizontalAlignment(HorizontalAlignEnum.getByValue(horizontalAlignment));
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
-	 */
-	public void setHorizontalAlignment(Byte horizontalAlignment)
-	{
-		setHorizontalAlignment(HorizontalAlignEnum.getByValue(horizontalAlignment));
-	}
-		
 	/**
 	 *
 	 */
@@ -285,22 +236,6 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 		this.horizontalAlignmentValue = horizontalAlignmentValue;
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #getVerticalAlignmentValue()}.
-	 */
-	public byte getVerticalAlignment()
-	{
-		return getVerticalAlignmentValue().getValue();
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #getOwnVerticalAlignmentValue()}.
-	 */
-	public Byte getOwnVerticalAlignment()
-	{
-		return getOwnVerticalAlignmentValue() == null ? null : getOwnVerticalAlignmentValue().getValueByte();
-	}
-		
 	/**
 	 *
 	 */
@@ -317,22 +252,6 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 		return verticalAlignmentValue;
 	}
 		
-	/**
-	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
-	 */
-	public void setVerticalAlignment(byte verticalAlignment)
-	{
-		setVerticalAlignment(VerticalAlignEnum.getByValue(verticalAlignment));
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
-	 */
-	public void setVerticalAlignment(Byte verticalAlignment)
-	{
-		setVerticalAlignment(VerticalAlignEnum.getByValue(verticalAlignment));
-	}
-		
 	/**
 	 *
 	 */
@@ -341,38 +260,6 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 		this.verticalAlignmentValue = verticalAlignmentValue;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getRotationValue()}.
-	 */
-	public byte getRotation()
-	{
-		return getRotationValue().getValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getOwnRotationValue()}.
-	 */
-	public Byte getOwnRotation()
-	{
-		return getOwnRotationValue() == null? null : getOwnRotationValue().getValueByte();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setRotation(RotationEnum)}.
-	 */
-	public void setRotation(byte rotation)
-	{
-		setRotation(RotationEnum.getByValue(rotation));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setRotation(RotationEnum)}.
-	 */
-	public void setRotation(Byte rotation)
-	{
-		setRotation(RotationEnum.getByValue(rotation));
-	}
-
 	/**
 	 *
 	 */
@@ -408,87 +295,27 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 	}
 
 	/**
-	 * @deprecated Replaced by {@link #getLineSpacingValue()}.
-	 */
-	public byte getLineSpacing()
-	{
-		return getLineSpacingValue().getValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getOwnLineSpacingValue()}.
-	 */
-	public Byte getOwnLineSpacing()
-	{
-		return getOwnLineSpacingValue() == null? null : getOwnLineSpacingValue().getValueByte();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setLineSpacing(LineSpacingEnum)}.
-	 */
-	public void setLineSpacing(byte lineSpacing)
-	{
-		setLineSpacing(LineSpacingEnum.getByValue(lineSpacing));
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setLineSpacing(LineSpacingEnum)}.
-	 */
-	public void setLineSpacing(Byte lineSpacing)
-	{
-		setLineSpacing(LineSpacingEnum.getByValue(lineSpacing));
-	}
-
-	/**
-	 *
+	 * @deprecated Replaced by {@link JRParagraph#getLineSpacing()}.
 	 */
 	public LineSpacingEnum getLineSpacingValue()
 	{
-		return JRStyleResolver.getLineSpacingValue(this);
+		return getParagraph().getLineSpacing();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link JRParagraph#getOwnLineSpacing()}.
 	 */
 	public LineSpacingEnum getOwnLineSpacingValue()
 	{
-		return this.lineSpacingValue;
+		return getParagraph().getOwnLineSpacing();
 	}
 
 	/**
-	 * Sets the text line spacing.
-	 * 
-	 * This methods allows <code>null</code>
-	 * to be set.  In this case, the line spacing is inherited from the report
-	 * style associated with the template. 
-	 * 
-	 * @param lineSpacingValue a <code>null</code> value or one of 
-	 * 	<ul>
-	 * 		<li>{@link LineSpacingEnum#SINGLE}</li>
-	 * 		<li>{@link LineSpacingEnum#ONE_AND_HALF}</li>
-	 * 		<li>{@link LineSpacingEnum#DOUBLE}</li>
-	 * 	</ul>
+	 * @deprecated Replaced by {@link JRParagraph#setLineSpacing(LineSpacingEnum)}.
 	 */
-	public void setLineSpacing(LineSpacingEnum lineSpacingValue)
+	public void setLineSpacing(LineSpacingEnum lineSpacing)
 	{
-		this.lineSpacingValue = lineSpacingValue;
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getMarkup()}
-	 */
-	public boolean isStyledText()
-	{
-		return JRCommonText.MARKUP_STYLED_TEXT.equals(getMarkup());
-	}
-		
-	/**
-	 * @deprecated Replaced by {@link #getOwnMarkup()}
-	 */
-	public Boolean isOwnStyledText()
-	{
-		String mkp = getOwnMarkup();
-		return JRCommonText.MARKUP_STYLED_TEXT.equals(mkp) ? Boolean.TRUE : (mkp == null ? null : Boolean.FALSE);
+		getParagraph().setLineSpacing(lineSpacing);
 	}
 
 	/**
@@ -515,14 +342,6 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 		this.markup = markup;
 	}
 	
-	/**
-	 * @deprecated Replaced by {@link #getLineBox()}
-	 */
-	public JRBox getBox()
-	{
-		return new LineBoxWrapper(getLineBox());
-	}
-
 	/**
 	 *
 	 */
@@ -531,6 +350,14 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 		return lineBox;
 	}
 		
+	/**
+	 *
+	 */
+	public JRParagraph getParagraph()
+	{
+		return paragraph;
+	}
+		
 	/**
 	 * @deprecated
 	 */
@@ -540,14 +367,6 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 	}
 
 	
-	/**
-	 * @deprecated Replaced by {@link #getHyperlinkTypeValue()}.
-	 */
-	public byte getHyperlinkType()
-	{
-		return getHyperlinkTypeValue().getValue();
-	}
-
 	/**
 	 * Retrieves the hyperlink type for the element.
 	 * <p>
@@ -588,22 +407,6 @@ O	 * When hyperlink is of custom type, {@link HyperlinkTypeEnum#CUSTOM CUSTOM} i
 		return JRHyperlinkHelper.getHyperlinkTargetValue(getLinkTarget());
 	}
 	
-	/**
-	 *
-	 */
-	public JRReportFont getReportFont()
-	{
-		return reportFont;
-	}
-
-	/**
-	 *
-	 */
-	public void setReportFont(JRReportFont reportFont)
-	{
-		this.reportFont = reportFont;
-	}
-
 	/**
 	 *
 	 */
@@ -795,38 +598,6 @@ O	 * When hyperlink is of custom type, {@link HyperlinkTypeEnum#CUSTOM CUSTOM} i
 		this.fontSize = fontSize;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getFontSize()}.
-	 */
-	public int getSize()
-	{
-		return getFontSize();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getOwnFontSize()}.
-	 */
-	public Integer getOwnSize()
-	{
-		return getOwnFontSize();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setFontSize(int)}.
-	 */
-	public void setSize(int size)
-	{
-		setFontSize(size);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #setFontSize(Integer)}.
-	 */
-	public void setSize(Integer size)
-	{
-		setFontSize(size);
-	}
-
 	/**
 	 *
 	 */
@@ -1039,447 +810,6 @@ O	 * When hyperlink is of custom type, {@link HyperlinkTypeEnum#CUSTOM CUSTOM} i
 	{
 		return getForecolor();
 	}
-
-	
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(lineBox.getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBorder(byte border)
-	{
-		JRPenUtil.setLinePenFromPen(border, lineBox.getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBorder(Byte border)
-	{
-		JRPenUtil.setLinePenFromPen(border, lineBox.getPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getBorderColor()
-	{
-		return lineBox.getPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnBorderColor()
-	{
-		return lineBox.getPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBorderColor(Color borderColor)
-	{
-		lineBox.getPen().setLineColor(borderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getPadding()
-	{
-		return lineBox.getPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnPadding()
-	{
-		return lineBox.getOwnPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setPadding(int padding)
-	{
-		lineBox.setPadding(padding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setPadding(Integer padding)
-	{
-		lineBox.setPadding(padding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getTopBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(lineBox.getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnTopBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopBorder(byte topBorder)
-	{
-		JRPenUtil.setLinePenFromPen(topBorder, lineBox.getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopBorder(Byte topBorder)
-	{
-		JRPenUtil.setLinePenFromPen(topBorder, lineBox.getTopPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getTopBorderColor()
-	{
-		return lineBox.getTopPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnTopBorderColor()
-	{
-		return lineBox.getTopPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopBorderColor(Color topBorderColor)
-	{
-		lineBox.getTopPen().setLineColor(topBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getTopPadding()
-	{
-		return lineBox.getTopPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnTopPadding()
-	{
-		return lineBox.getOwnTopPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopPadding(int topPadding)
-	{
-		lineBox.setTopPadding(topPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setTopPadding(Integer topPadding)
-	{
-		lineBox.setTopPadding(topPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getLeftBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(lineBox.getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnLeftBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftBorder(byte leftBorder)
-	{
-		JRPenUtil.setLinePenFromPen(leftBorder, lineBox.getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftBorder(Byte leftBorder)
-	{
-		JRPenUtil.setLinePenFromPen(leftBorder, lineBox.getLeftPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getLeftBorderColor()
-	{
-		return lineBox.getLeftPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnLeftBorderColor()
-	{
-		return lineBox.getLeftPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftBorderColor(Color leftBorderColor)
-	{
-		lineBox.getLeftPen().setLineColor(leftBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getLeftPadding()
-	{
-		return lineBox.getLeftPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnLeftPadding()
-	{
-		return lineBox.getOwnLeftPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftPadding(int leftPadding)
-	{
-		lineBox.setLeftPadding(leftPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setLeftPadding(Integer leftPadding)
-	{
-		lineBox.setLeftPadding(leftPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getBottomBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(lineBox.getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnBottomBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomBorder(byte bottomBorder)
-	{
-		JRPenUtil.setLinePenFromPen(bottomBorder, lineBox.getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomBorder(Byte bottomBorder)
-	{
-		JRPenUtil.setLinePenFromPen(bottomBorder, lineBox.getBottomPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getBottomBorderColor()
-	{
-		return lineBox.getBottomPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnBottomBorderColor()
-	{
-		return lineBox.getBottomPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomBorderColor(Color bottomBorderColor)
-	{
-		lineBox.getBottomPen().setLineColor(bottomBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getBottomPadding()
-	{
-		return lineBox.getBottomPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnBottomPadding()
-	{
-		return lineBox.getOwnBottomPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomPadding(int bottomPadding)
-	{
-		lineBox.setBottomPadding(bottomPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setBottomPadding(Integer bottomPadding)
-	{
-		lineBox.setBottomPadding(bottomPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public byte getRightBorder()
-	{
-		return JRPenUtil.getPenFromLinePen(lineBox.getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Byte getOwnRightBorder()
-	{
-		return JRPenUtil.getOwnPenFromLinePen(lineBox.getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightBorder(byte rightBorder)
-	{
-		JRPenUtil.setLinePenFromPen(rightBorder, lineBox.getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightBorder(Byte rightBorder)
-	{
-		JRPenUtil.setLinePenFromPen(rightBorder, lineBox.getRightPen());
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getRightBorderColor()
-	{
-		return lineBox.getRightPen().getLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Color getOwnRightBorderColor()
-	{
-		return lineBox.getRightPen().getOwnLineColor();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightBorderColor(Color rightBorderColor)
-	{
-		lineBox.getRightPen().setLineColor(rightBorderColor);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public int getRightPadding()
-	{
-		return lineBox.getRightPadding().intValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public Integer getOwnRightPadding()
-	{
-		return lineBox.getOwnRightPadding();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightPadding(int rightPadding)
-	{
-		lineBox.setRightPadding(rightPadding);
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getBox()}
-	 */
-	public void setRightPadding(Integer rightPadding)
-	{
-		lineBox.setRightPadding(rightPadding);
-	}
 	
 
 	/*
@@ -1502,6 +832,10 @@ O	 * When hyperlink is of custom type, {@link HyperlinkTypeEnum#CUSTOM CUSTOM} i
 	 * @deprecated
 	 */
 	private Byte lineSpacing;
+	/**
+	 * @deprecated
+	 */
+	private LineSpacingEnum lineSpacingValue;
 	/**
 	 * @deprecated
 	 */
@@ -1645,5 +979,79 @@ O	 * When hyperlink is of custom type, {@link HyperlinkTypeEnum#CUSTOM CUSTOM} i
 		{
 			 linkTarget = JRHyperlinkHelper.getLinkTarget(HyperlinkTargetEnum.getByValue(hyperlinkTarget));
 		}
+
+		if (paragraph == null)
+		{
+			paragraph = new JRBaseParagraph(this);
+			paragraph.setLineSpacing(lineSpacingValue);
+			lineSpacingValue = null;
+		}
+	}
+
+	public int getHashCode()
+	{
+		ObjectUtils.HashCode hash = ObjectUtils.hash();
+		addTemplateHash(hash);
+		hash.add(horizontalAlignmentValue);
+		hash.add(verticalAlignmentValue);
+		hash.add(rotationValue);
+		hash.add(markup);
+		hash.add(linkType);
+		hash.add(linkTarget);
+		hash.addIdentical(lineBox);
+		hash.addIdentical(paragraph);
+		hash.add(fontName);
+		hash.add(isBold);
+		hash.add(isItalic);
+		hash.add(isUnderline);
+		hash.add(isStrikeThrough);
+		hash.add(fontSize);
+		hash.add(pdfFontName);
+		hash.add(pdfEncoding);
+		hash.add(isPdfEmbedded);
+		hash.add(valueClassName);
+		hash.add(pattern);
+		hash.add(formatFactoryClass);
+		hash.add(localeCode);
+		hash.add(timeZoneId);
+		return hash.getHashCode();
+	}
+
+	public boolean isIdentical(Object object)
+	{
+		if (this == object)
+		{
+			return true;
+		}
+		
+		if (!(object instanceof JRTemplateText))
+		{
+			return false;
+		}
+		
+		JRTemplateText template = (JRTemplateText) object;
+		return templateIdentical(template)
+				&& ObjectUtils.equals(horizontalAlignmentValue, template.horizontalAlignmentValue)
+				&& ObjectUtils.equals(verticalAlignmentValue, template.verticalAlignmentValue)
+				&& ObjectUtils.equals(rotationValue, template.rotationValue)
+				&& ObjectUtils.equals(markup, template.markup)
+				&& ObjectUtils.equals(linkType, template.linkType)
+				&& ObjectUtils.equals(linkTarget, template.linkTarget)
+				&& ObjectUtils.identical(lineBox, template.lineBox)
+				&& ObjectUtils.identical(paragraph, template.paragraph)
+				&& ObjectUtils.equals(fontName, template.fontName)
+				&& ObjectUtils.equals(isBold, template.isBold)
+				&& ObjectUtils.equals(isItalic, template.isItalic)
+				&& ObjectUtils.equals(isUnderline, template.isUnderline)
+				&& ObjectUtils.equals(isStrikeThrough, template.isStrikeThrough)
+				&& ObjectUtils.equals(fontSize, template.fontSize)
+				&& ObjectUtils.equals(pdfFontName, template.pdfFontName)
+				&& ObjectUtils.equals(pdfEncoding, template.pdfEncoding)
+				&& ObjectUtils.equals(isPdfEmbedded, template.isPdfEmbedded)
+				&& ObjectUtils.equals(valueClassName, template.valueClassName)
+				&& ObjectUtils.equals(pattern, template.pattern)
+				&& ObjectUtils.equals(formatFactoryClass, template.formatFactoryClass)
+				&& ObjectUtils.equals(localeCode, template.localeCode)
+				&& ObjectUtils.equals(timeZoneId, template.timeZoneId);
 	}
 }
