@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -25,15 +25,16 @@ package net.sf.jasperreports.engine.fill;
 
 import java.util.Iterator;
 
-import net.sf.jasperreports.engine.JRBand;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRGroup;
 import net.sf.jasperreports.engine.JRPrintElement;
-import net.sf.jasperreports.engine.JRReport;
 import net.sf.jasperreports.engine.JRRuntimeException;
-import net.sf.jasperreports.engine.JRVariable;
 import net.sf.jasperreports.engine.JasperReport;
+import net.sf.jasperreports.engine.type.FooterPositionEnum;
+import net.sf.jasperreports.engine.type.IncrementTypeEnum;
+import net.sf.jasperreports.engine.type.ResetTypeEnum;
+import net.sf.jasperreports.engine.type.RunDirectionEnum;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -41,7 +42,7 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRVerticalFiller.java 3210 2009-11-23 16:11:16Z teodord $
+ * @version $Id: JRVerticalFiller.java 4747 2011-10-26 16:59:20Z lucianc $
  */
 public class JRVerticalFiller extends JRBaseFiller
 {
@@ -69,13 +70,23 @@ public class JRVerticalFiller extends JRBaseFiller
 	/**
 	 *
 	 */
-	protected JRVerticalFiller(JasperReport jasperReport, JREvaluator evaluator, JRFillSubreport parentElement) throws JRException
+	protected JRVerticalFiller(JasperReport jasperReport, 
+			DatasetExpressionEvaluator evaluator, 
+			JRFillSubreport parentElement) throws JRException
 	{
 		super(jasperReport, evaluator, parentElement);
 
 		setPageHeight(pageHeight);
 	}
 
+	/**
+	 *
+	 */
+	protected JRVerticalFiller(JasperReport jasperReport, JREvaluator evaluator, JRFillSubreport parentElement) throws JRException
+	{
+		this(jasperReport, (DatasetExpressionEvaluator) evaluator, parentElement);
+	}
+
 
 	/**
 	 *
@@ -86,15 +97,22 @@ public class JRVerticalFiller extends JRBaseFiller
 
 		columnFooterOffsetY = pageHeight - bottomMargin;
 		if (pageFooter != null)
+		{
 			columnFooterOffsetY -= pageFooter.getHeight();
+		}
 		if (columnFooter != null)
+		{
 			columnFooterOffsetY -= columnFooter.getHeight();
-
+		}
 		lastPageColumnFooterOffsetY = pageHeight - bottomMargin;
 		if (lastPageFooter != null)//FIXMENOW testing with null is awkward since bands can never be null, but rather equal to missingFillBand
+		{
 			lastPageColumnFooterOffsetY -= lastPageFooter.getHeight();
+		}
 		if (columnFooter != null)
+		{
 			lastPageColumnFooterOffsetY -= columnFooter.getHeight();
+		}
 	}
 
 
@@ -125,7 +143,7 @@ public class JRVerticalFiller extends JRBaseFiller
 
 			switch (whenNoDataType)
 			{
-				case JRReport.WHEN_NO_DATA_TYPE_ALL_SECTIONS_NO_DETAIL :
+				case ALL_SECTIONS_NO_DETAIL :
 				{
 					if (log.isDebugEnabled())
 					{
@@ -133,7 +151,7 @@ public class JRVerticalFiller extends JRBaseFiller
 					}
 
 					scriptlet.callBeforeReportInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_REPORT);
+					calculator.initializeVariables(ResetTypeEnum.REPORT, IncrementTypeEnum.REPORT);
 					scriptlet.callAfterReportInit();
 
 					printPage = newPage();
@@ -157,7 +175,7 @@ public class JRVerticalFiller extends JRBaseFiller
 
 					break;
 				}
-				case JRReport.WHEN_NO_DATA_TYPE_BLANK_PAGE :
+				case BLANK_PAGE :
 				{
 					if (log.isDebugEnabled())
 					{
@@ -168,7 +186,7 @@ public class JRVerticalFiller extends JRBaseFiller
 					addPage(printPage);
 					break;
 				}
-				case JRReport.WHEN_NO_DATA_TYPE_NO_DATA_SECTION:
+				case NO_DATA_SECTION:
 				{
 					if (log.isDebugEnabled())
 					{
@@ -176,7 +194,7 @@ public class JRVerticalFiller extends JRBaseFiller
 					}
 
 					scriptlet.callBeforeReportInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_REPORT);
+					calculator.initializeVariables(ResetTypeEnum.REPORT, IncrementTypeEnum.REPORT);
 					scriptlet.callAfterReportInit();
 
 					printPage = newPage();
@@ -191,7 +209,7 @@ public class JRVerticalFiller extends JRBaseFiller
 					break;
 
 				}
-				case JRReport.WHEN_NO_DATA_TYPE_NO_PAGES :
+				case NO_PAGES :
 				default :
 				{
 					if (log.isDebugEnabled())
@@ -211,11 +229,6 @@ public class JRVerticalFiller extends JRBaseFiller
 			//{
 				printPageStretchHeight = offsetY + bottomMargin;
 			//}
-
-			if (fillContext.isUsingVirtualizer())
-			{
-				removePageIdentityDataProvider();
-			}
 		}
 
 		if (fillContext.isIgnorePagination())
@@ -231,7 +244,7 @@ public class JRVerticalFiller extends JRBaseFiller
 	private void fillReportStart() throws JRException
 	{
 		scriptlet.callBeforeReportInit();
-		calculator.initializeVariables(JRVariable.RESET_TYPE_REPORT);
+		calculator.initializeVariables(ResetTypeEnum.REPORT, IncrementTypeEnum.REPORT);
 		scriptlet.callAfterReportInit();
 
 		printPage = newPage();
@@ -264,7 +277,7 @@ public class JRVerticalFiller extends JRBaseFiller
 
 		resolveGroupBoundElements(JRExpression.EVALUATION_OLD, false);
 		scriptlet.callBeforeGroupInit();
-		calculator.initializeVariables(JRVariable.RESET_TYPE_GROUP);
+		calculator.initializeVariables(ResetTypeEnum.GROUP, IncrementTypeEnum.GROUP);
 		scriptlet.callAfterGroupInit();
 
 		fillGroupHeaders(false);
@@ -315,7 +328,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -332,7 +345,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -351,7 +364,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -390,7 +403,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				resolveColumnBoundElements(evaluation);
 				resolvePageBoundElements(evaluation);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -461,6 +474,8 @@ public class JRVerticalFiller extends JRBaseFiller
 				--reattempts;
 			}
 
+			setOffsetX();
+
 			boolean filled = fillBandNoOverflow(columnHeader, evaluation);
 
 			for (int i = 0; !filled && i < reattempts; ++i)
@@ -470,11 +485,11 @@ public class JRVerticalFiller extends JRBaseFiller
 					resolveGroupBoundElements(evaluation, false);
 					resolveColumnBoundElements(evaluation);
 					scriptlet.callBeforeColumnInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_COLUMN);
+					calculator.initializeVariables(ResetTypeEnum.COLUMN, IncrementTypeEnum.COLUMN);
 					scriptlet.callAfterColumnInit();
 
 					columnIndex += 1;
-					offsetX = leftMargin + columnIndex * (columnSpacing + columnWidth);
+					setOffsetX();
 					offsetY = columnHeaderOffsetY;
 
 					setColumnNumberVar();
@@ -486,7 +501,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				resolveColumnBoundElements(evaluation);
 				resolvePageBoundElements(evaluation);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -568,45 +583,42 @@ public class JRVerticalFiller extends JRBaseFiller
 				);
 		}
 
-		JRBand[] groupHeaderBands = groupHeaderSection.getBands();
-		if (groupHeaderBands != null)
+		JRFillBand[] groupHeaderBands = groupHeaderSection.getFillBands();
+		for(int i = 0; i < groupHeaderBands.length; i++)
 		{
-			for(int i = 0; i < groupHeaderBands.length; i++)
+			JRFillBand groupHeaderBand = groupHeaderBands[i];
+
+			groupHeaderBand.evaluatePrintWhenExpression(JRExpression.EVALUATION_DEFAULT);
+
+			if (groupHeaderBand.isToPrint())
 			{
-				JRFillBand groupHeaderBand = (JRFillBand)groupHeaderBands[i];
-
-				groupHeaderBand.evaluatePrintWhenExpression(JRExpression.EVALUATION_DEFAULT);
-
-				if (groupHeaderBand.isToPrint())
+				while (
+					groupHeaderBand.getBreakHeight() > columnFooterOffsetY - offsetY ||
+					group.getMinHeightToStartNewPage() > columnFooterOffsetY - offsetY
+					)
 				{
-					while (
-						groupHeaderBand.getBreakHeight() > columnFooterOffsetY - offsetY ||
-						group.getMinHeightToStartNewPage() > columnFooterOffsetY - offsetY
-						)
-					{
-						fillColumnBreak(
-							evalPrevPage,
-							JRExpression.EVALUATION_DEFAULT
-							);
-					}
+					fillColumnBreak(
+						evalPrevPage,
+						JRExpression.EVALUATION_DEFAULT
+						);
 				}
+			}
 
-				if (i == 0)
-				{
-					setNewGroupInBands(group);
+			if (i == 0)
+			{
+				setNewGroupInBands(group);
 
-					group.setFooterPrinted(false);
-				}
+				group.setFooterPrinted(false);
+			}
 
-				if (groupHeaderBand.isToPrint())
-				{
-					SavePoint newSavePoint = fillColumnBand(groupHeaderBand, JRExpression.EVALUATION_DEFAULT);
-					
-					savePoint = advanceSavePoint(savePoint, newSavePoint);
+			if (groupHeaderBand.isToPrint())
+			{
+				SavePoint newSavePoint = fillColumnBand(groupHeaderBand, JRExpression.EVALUATION_DEFAULT);
+				
+				savePoint = advanceSavePoint(savePoint, newSavePoint);
 
-					isFirstPageBand = false;
-					isFirstColumnBand = false;
-				}
+				isFirstPageBand = false;
+				isFirstColumnBand = false;
 			}
 		}
 
@@ -659,30 +671,27 @@ public class JRVerticalFiller extends JRBaseFiller
 		{
 			JRFillSection groupHeaderSection = (JRFillSection)group.getGroupHeaderSection();
 
-			JRBand[] groupHeaderBands = groupHeaderSection.getBands();
-			if (groupHeaderBands != null)
+			JRFillBand[] groupHeaderBands = groupHeaderSection.getFillBands();
+			for(int i = 0; i < groupHeaderBands.length; i++)
 			{
-				for(int i = 0; i < groupHeaderBands.length; i++)
+				JRFillBand groupHeaderBand = groupHeaderBands[i];
+
+				groupHeaderBand.evaluatePrintWhenExpression(evaluation);
+
+				if (groupHeaderBand.isToPrint())
 				{
-					JRFillBand groupHeaderBand = (JRFillBand)groupHeaderBands[i];
-
-					groupHeaderBand.evaluatePrintWhenExpression(evaluation);
-
-					if (groupHeaderBand.isToPrint())
+					while (
+						groupHeaderBand.getBreakHeight() > columnFooterOffsetY - offsetY 
+						|| group.getMinHeightToStartNewPage() > columnFooterOffsetY - offsetY
+						)
 					{
-						while (
-							groupHeaderBand.getBreakHeight() > columnFooterOffsetY - offsetY 
-							|| group.getMinHeightToStartNewPage() > columnFooterOffsetY - offsetY
-							)
-						{
-							fillColumnBreak(evaluation, evaluation);
-						}
-
-						fillColumnBand(groupHeaderBand, evaluation);
-
-						isFirstPageBand = false;
-						isFirstColumnBand = false;
+						fillColumnBreak(evaluation, evaluation);
 					}
+
+					fillColumnBand(groupHeaderBand, evaluation);
+
+					isFirstPageBand = false;
+					isFirstColumnBand = false;
 				}
 			}
 		}
@@ -704,31 +713,28 @@ public class JRVerticalFiller extends JRBaseFiller
 			calculator.estimateVariables();
 		}
 
-		JRBand[] detailBands = detailSection.getBands();
-		if (detailBands != null)
+		JRFillBand[] detailBands = detailSection.getFillBands();
+		for(int i = 0; i < detailBands.length; i++)
 		{
-			for(int i = 0; i < detailBands.length; i++)
+			JRFillBand detailBand = detailBands[i];
+			
+			detailBand.evaluatePrintWhenExpression(JRExpression.EVALUATION_ESTIMATED);
+
+			if (detailBand.isToPrint())
 			{
-				JRFillBand detailBand = (JRFillBand)detailBands[i];
-				
-				detailBand.evaluatePrintWhenExpression(JRExpression.EVALUATION_ESTIMATED);
-
-				if (detailBand.isToPrint())
+				while (
+					detailBand.getBreakHeight() > columnFooterOffsetY - offsetY
+					)
 				{
-					while (
-						detailBand.getBreakHeight() > columnFooterOffsetY - offsetY
-						)
-					{
-						byte evalPrevPage = (isNewGroup?JRExpression.EVALUATION_DEFAULT:JRExpression.EVALUATION_OLD);
+					byte evalPrevPage = (isNewGroup?JRExpression.EVALUATION_DEFAULT:JRExpression.EVALUATION_OLD);
 
-						fillColumnBreak(
-							evalPrevPage,
-							JRExpression.EVALUATION_DEFAULT
-							);
-					}
-					
-					break;
+					fillColumnBreak(
+						evalPrevPage,
+						JRExpression.EVALUATION_DEFAULT
+						);
 				}
+				
+				break;
 			}
 		}
 
@@ -740,7 +746,7 @@ public class JRVerticalFiller extends JRBaseFiller
 		{
 			for(int i = 0; i < detailBands.length; i++)
 			{
-				JRFillBand detailBand = (JRFillBand)detailBands[i];
+				JRFillBand detailBand = detailBands[i];
 						
 				detailBand.evaluatePrintWhenExpression(JRExpression.EVALUATION_DEFAULT);
 
@@ -782,26 +788,26 @@ public class JRVerticalFiller extends JRBaseFiller
 					// its footer position is completely irrelevant
 					if (newSavePoint != null)
 					{
-						switch (group.getFooterPosition())
+						switch (group.getFooterPositionValue())
 						{
-							case JRGroup.FOOTER_POSITION_STACK_AT_BOTTOM:
+							case STACK_AT_BOTTOM:
 							{
 								savePoint = advanceSavePoint(savePoint, newSavePoint);
 
 								if (savePoint != null)
 								{
-									savePoint.footerPosition = JRGroup.FOOTER_POSITION_STACK_AT_BOTTOM;
+									savePoint.footerPosition = FooterPositionEnum.STACK_AT_BOTTOM;
 								}
 
 								break;
 							}
-							case JRGroup.FOOTER_POSITION_FORCE_AT_BOTTOM:
+							case FORCE_AT_BOTTOM:
 							{
 								savePoint = advanceSavePoint(savePoint, newSavePoint);
 
 								if (savePoint != null)
 								{
-									moveSavePointContent(savePoint);
+									savePoint.moveSavePointContent();
 									offsetY = columnFooterOffsetY;
 								}
 
@@ -809,13 +815,13 @@ public class JRVerticalFiller extends JRBaseFiller
 
 								break;
 							}
-							case JRGroup.FOOTER_POSITION_COLLATE_AT_BOTTOM:
+							case COLLATE_AT_BOTTOM:
 							{
 								savePoint = advanceSavePoint(savePoint, newSavePoint);
 
 								break;
 							}
-							case JRGroup.FOOTER_POSITION_NORMAL:
+							case NORMAL:
 							default:
 							{
 								if (savePoint != null)
@@ -832,7 +838,7 @@ public class JRVerticalFiller extends JRBaseFiller
 										// we just move the marker on the existing save point,
 										// but only if was a "StackAtBottom" one
 										
-										if (savePoint.footerPosition == JRGroup.FOOTER_POSITION_STACK_AT_BOTTOM)
+										if (savePoint.footerPosition == FooterPositionEnum.STACK_AT_BOTTOM)
 										{
 											savePoint.saveHeightOffset(newSavePoint.heightOffset);
 										}
@@ -847,7 +853,7 @@ public class JRVerticalFiller extends JRBaseFiller
 										// page/column break occurred, so the move operation 
 										// must be performed on the previous save point, regardless 
 										// whether it was a "StackAtBottom" or a "CollateAtBottom"
-										moveSavePointContent(savePoint);
+										savePoint.moveSavePointContent();
 										savePoint = null;
 									}
 								}
@@ -874,7 +880,7 @@ public class JRVerticalFiller extends JRBaseFiller
 			
 			if (savePoint != null)
 			{
-				moveSavePointContent(savePoint);
+				savePoint.moveSavePointContent();
 				offsetY = columnFooterOffsetY;
 			}
 		}
@@ -895,32 +901,29 @@ public class JRVerticalFiller extends JRBaseFiller
 			log.debug("Fill " + fillerId + ": " + group.getName() + " footer");
 		}
 
-		JRBand[] groupFooterBands = groupFooterSection.getBands();
-		if (groupFooterBands != null)
+		JRFillBand[] groupFooterBands = groupFooterSection.getFillBands();
+		for(int i = 0; i < groupFooterBands.length; i++)
 		{
-			for(int i = 0; i < groupFooterBands.length; i++)
+			JRFillBand groupFooterBand = groupFooterBands[i];
+			
+			groupFooterBand.evaluatePrintWhenExpression(evaluation);
+
+			if (groupFooterBand.isToPrint())
 			{
-				JRFillBand groupFooterBand = (JRFillBand)groupFooterBands[i];
-				
-				groupFooterBand.evaluatePrintWhenExpression(evaluation);
-
-				if (groupFooterBand.isToPrint())
+				if (
+					groupFooterBand.getBreakHeight() > columnFooterOffsetY - offsetY
+					)
 				{
-					if (
-						groupFooterBand.getBreakHeight() > columnFooterOffsetY - offsetY
-						)
-					{
-						fillColumnBreak(evaluation, evaluation);
-					}
-
-					SavePoint newSavePoint = fillColumnBand(groupFooterBand, evaluation);
-					newSavePoint.footerPosition = group.getFooterPosition();
-					
-					savePoint = advanceSavePoint(savePoint, newSavePoint);
-					
-					isFirstPageBand = false;
-					isFirstColumnBand = false;
+					fillColumnBreak(evaluation, evaluation);
 				}
+
+				SavePoint newSavePoint = fillColumnBand(groupFooterBand, evaluation);
+				newSavePoint.footerPosition = group.getFooterPositionValue();
+				
+				savePoint = advanceSavePoint(savePoint, newSavePoint);
+				
+				isFirstPageBand = false;
+				isFirstColumnBand = false;
 			}
 		}
 
@@ -944,6 +947,8 @@ public class JRVerticalFiller extends JRBaseFiller
 			log.debug("Fill " + fillerId + ": column footer");
 		}
 
+		setOffsetX();
+		
 		/*
 		if (!isSubreport)
 		{
@@ -1014,6 +1019,8 @@ public class JRVerticalFiller extends JRBaseFiller
 			log.debug("Fill " + fillerId + ": summary");
 		}
 
+		offsetX = leftMargin;
+		
 		if (lastPageFooter == missingFillBand)
 		{
 			if (
@@ -1071,7 +1078,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -1101,7 +1108,7 @@ public class JRVerticalFiller extends JRBaseFiller
 					resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 					resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 					scriptlet.callBeforePageInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+					calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 					scriptlet.callAfterPageInit();
 
 					addPage(false);
@@ -1119,7 +1126,7 @@ public class JRVerticalFiller extends JRBaseFiller
 			}
 
 			/*   */
-			fillSummaryOverflow(printBand);
+			fillSummaryOverflow();
 			
 			//DONE
 		}
@@ -1151,7 +1158,7 @@ public class JRVerticalFiller extends JRBaseFiller
 			resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 			resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 			scriptlet.callBeforePageInit();
-			calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+			calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 			scriptlet.callAfterPageInit();
 
 			addPage(false);
@@ -1176,7 +1183,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -1193,7 +1200,7 @@ public class JRVerticalFiller extends JRBaseFiller
 			offsetY += printBand.getHeight();
 
 			/*   */
-			fillSummaryOverflow(printBand);
+			fillSummaryOverflow();
 		}
 		
 		//DONE
@@ -1229,7 +1236,7 @@ public class JRVerticalFiller extends JRBaseFiller
 					resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 					resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 					scriptlet.callBeforePageInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+					calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 					scriptlet.callAfterPageInit();
 
 					addPage(false);
@@ -1255,7 +1262,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				}
 				
 				/*   */
-				fillSummaryOverflow(printBand);
+				fillSummaryOverflow();
 
 				//DONE
 			}
@@ -1284,7 +1291,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -1303,7 +1310,7 @@ public class JRVerticalFiller extends JRBaseFiller
 					resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 					resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 					scriptlet.callBeforePageInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+					calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 					scriptlet.callAfterPageInit();
 
 					addPage(false);
@@ -1317,7 +1324,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				offsetY += printBand.getHeight();
 
 				/*   */
-				fillSummaryOverflow(printBand);
+				fillSummaryOverflow();
 				
 				//DONE
 			}
@@ -1342,7 +1349,7 @@ public class JRVerticalFiller extends JRBaseFiller
 			resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 			resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 			scriptlet.callBeforePageInit();
-			calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+			calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 			scriptlet.callAfterPageInit();
 
 			addPage(false);
@@ -1361,7 +1368,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -1375,7 +1382,7 @@ public class JRVerticalFiller extends JRBaseFiller
 			offsetY += printBand.getHeight();
 
 			/*   */
-			fillSummaryOverflow(printBand);
+			fillSummaryOverflow();
 			
 			//DONE
 		}
@@ -1413,7 +1420,7 @@ public class JRVerticalFiller extends JRBaseFiller
 					resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 					resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 					scriptlet.callBeforePageInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+					calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 					scriptlet.callAfterPageInit();
 
 					addPage(false);
@@ -1434,7 +1441,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				}
 
 				/*   */
-				fillSummaryOverflow(printBand);
+				fillSummaryOverflow();
 				
 				//DONE
 			}
@@ -1475,7 +1482,7 @@ public class JRVerticalFiller extends JRBaseFiller
 						resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 						resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 						scriptlet.callBeforePageInit();
-						calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+						calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 						scriptlet.callAfterPageInit();
 
 						addPage(false);
@@ -1524,7 +1531,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				}
 
 				/*   */
-				fillSummaryOverflow(printBand);
+				fillSummaryOverflow();
 				
 				//DONE
 			}
@@ -1560,7 +1567,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -1575,7 +1582,7 @@ public class JRVerticalFiller extends JRBaseFiller
 					resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 					resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 					scriptlet.callBeforePageInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+					calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 					scriptlet.callAfterPageInit();
 
 					addPage(false);
@@ -1587,7 +1594,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				offsetY += printBand.getHeight();
 
 				/*   */
-				fillSummaryOverflow(printBand);
+				fillSummaryOverflow();
 			}
 			
 			//DONE
@@ -1602,7 +1609,7 @@ public class JRVerticalFiller extends JRBaseFiller
 			resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 			resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 			scriptlet.callBeforePageInit();
-			calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+			calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 			scriptlet.callAfterPageInit();
 
 			addPage(false);
@@ -1625,7 +1632,7 @@ public class JRVerticalFiller extends JRBaseFiller
 					resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 					resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 					scriptlet.callBeforePageInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+					calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 					scriptlet.callAfterPageInit();
 
 					addPage(false);
@@ -1640,7 +1647,7 @@ public class JRVerticalFiller extends JRBaseFiller
 						resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 						resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 						scriptlet.callBeforePageInit();
-						calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+						calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 						scriptlet.callAfterPageInit();
 
 						addPage(false);
@@ -1652,7 +1659,7 @@ public class JRVerticalFiller extends JRBaseFiller
 					offsetY += printBand.getHeight();
 
 					/*   */
-					fillSummaryOverflow(printBand);
+					fillSummaryOverflow();
 				}
 				
 				//DONE
@@ -1675,7 +1682,7 @@ public class JRVerticalFiller extends JRBaseFiller
 						resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 						resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 						scriptlet.callBeforePageInit();
-						calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+						calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 						scriptlet.callAfterPageInit();
 
 						addPage(false);
@@ -1694,7 +1701,7 @@ public class JRVerticalFiller extends JRBaseFiller
 					}
 
 					/*   */
-					fillSummaryOverflow(printBand);
+					fillSummaryOverflow();
 				}
 				else
 				{
@@ -1710,7 +1717,7 @@ public class JRVerticalFiller extends JRBaseFiller
 	/**
 	 *
 	 */
-	private void fillSummaryOverflow(JRPrintBand printBand) throws JRException
+	private void fillSummaryOverflow() throws JRException
 	{
 		while (summary.willOverflow())
 		{
@@ -1723,7 +1730,7 @@ public class JRVerticalFiller extends JRBaseFiller
 			resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 			resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 			scriptlet.callBeforePageInit();
-			calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+			calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 			scriptlet.callAfterPageInit();
 
 			addPage(false);
@@ -1733,7 +1740,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				fillPageHeader(JRExpression.EVALUATION_DEFAULT);
 			}
 			
-			printBand = summary.fill(pageHeight - bottomMargin - offsetY - (isSummaryWithPageHeaderAndFooter?pageFooter.getHeight():0));
+			JRPrintBand printBand = summary.fill(pageHeight - bottomMargin - offsetY - (isSummaryWithPageHeaderAndFooter?pageFooter.getHeight():0));
 
 			fillBand(printBand);
 			offsetY += printBand.getHeight();
@@ -1751,7 +1758,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -1823,29 +1830,19 @@ public class JRVerticalFiller extends JRBaseFiller
 				printPageStretchHeight = offsetY + bottomMargin;
 			//}
 
-			if (fillContext.isUsingVirtualizer())
-			{
-				removePageIdentityDataProvider();
-			}
-
 			suspendSubreportRunner();
 		}
 
 		printPage = newPage();
 
-		if (isSubreport() && fillContext.isUsingVirtualizer())
-		{
-			addPageIdentityDataProvider();
-		}
-
 		if (isResetPageNumber)
 		{
-			calculator.getPageNumber().setValue(new Integer(1));
+			calculator.getPageNumber().setValue(Integer.valueOf(1));
 		}
 		else
 		{
 			calculator.getPageNumber().setValue(
-				new Integer(((Number)calculator.getPageNumber().getValue()).intValue() + 1)
+				Integer.valueOf(((Number)calculator.getPageNumber().getValue()).intValue() + 1)
 				);
 		}
 
@@ -1871,7 +1868,7 @@ public class JRVerticalFiller extends JRBaseFiller
 	private void setColumnNumberVar()
 	{
 		JRFillVariable columnNumber = calculator.getColumnNumber();
-		columnNumber.setValue(new Integer(columnIndex + 1));
+		columnNumber.setValue(Integer.valueOf(columnIndex + 1));
 		columnNumber.setOldValue(columnNumber.getValue());
 	}
 
@@ -1905,20 +1902,28 @@ public class JRVerticalFiller extends JRBaseFiller
 		resolveColumnBoundElements(evalPrevPage);
 		resolvePageBoundElements(evalPrevPage);
 		scriptlet.callBeforePageInit();
-		calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+		calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 		scriptlet.callAfterPageInit();
 
+		if (
+			keepTogetherSavePoint != null
+			&& !keepTogetherSavePoint.isNewPage 
+			)
+		{
+			keepTogetherSavePoint.removeContent();
+		}
+
 		addPage(isResetPageNumber);
 
 		fillPageHeader(evalNextPage);
 
 		fillColumnHeader(evalNextPage);
 
-		if (keepTogetherSavePoint != null)
-		{
-			moveKeepTogetherSavePointContent();
-		}
-		else if (isReprintGroupHeaders)
+		boolean savePointContentMoved = moveKeepTogetherSavePointContent();
+		if (
+			!savePointContentMoved
+			&& isReprintGroupHeaders
+			)
 		{
 			fillGroupHeadersReprint(evalNextPage);
 		}
@@ -1951,21 +1956,26 @@ public class JRVerticalFiller extends JRBaseFiller
 			resolveGroupBoundElements(evalPrevPage, false);
 			resolveColumnBoundElements(evalPrevPage);
 			scriptlet.callBeforeColumnInit();
-			calculator.initializeVariables(JRVariable.RESET_TYPE_COLUMN);
+			calculator.initializeVariables(ResetTypeEnum.COLUMN, IncrementTypeEnum.COLUMN);
 			scriptlet.callAfterColumnInit();
 
+			if (
+				keepTogetherSavePoint != null
+				&& !keepTogetherSavePoint.isNewColumn 
+				)
+			{
+				keepTogetherSavePoint.removeContent();
+			}
+
 			columnIndex += 1;
-			offsetX = leftMargin + columnIndex * (columnSpacing + columnWidth);
+			setOffsetX();
 			offsetY = columnHeaderOffsetY;
 
 			setColumnNumberVar();
 
 			fillColumnHeader(evalNextPage);
 
-			if (keepTogetherSavePoint != null)
-			{
-				moveKeepTogetherSavePointContent();
-			}
+			moveKeepTogetherSavePointContent();
 		}
 	}
 
@@ -2075,18 +2085,12 @@ public class JRVerticalFiller extends JRBaseFiller
 	 */
 	protected void fillBand(JRPrintBand band)
 	{
-		java.util.List elements = band.getElements();
-
-		if (elements != null && elements.size() > 0)
+		for(Iterator<JRPrintElement> it = band.iterateElements(); it.hasNext();)
 		{
-			JRPrintElement element = null;
-			for(Iterator it = elements.iterator(); it.hasNext();)
-			{
-				element = (JRPrintElement)it.next();
-				element.setX(element.getX() + offsetX);
-				element.setY(element.getY() + offsetY);
-				printPage.addElement(element);
-			}
+			JRPrintElement element = it.next();
+			element.setX(element.getX() + offsetX);
+			element.setY(element.getY() + offsetY);
+			printPage.addElement(element);
 		}
 	}
 
@@ -2165,6 +2169,7 @@ public class JRVerticalFiller extends JRBaseFiller
 		}
 	}
 
+	
 	/**
 	 *
 	 */
@@ -2194,7 +2199,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 				
 				addPage(false);
@@ -2211,7 +2216,7 @@ public class JRVerticalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 				
 				addPage(false);
@@ -2226,4 +2231,21 @@ public class JRVerticalFiller extends JRBaseFiller
 		}
 	}
 
+	
+	/**
+	 *
+	 */
+	private void setOffsetX()
+	{
+		if (columnDirection == RunDirectionEnum.RTL)
+		{
+			offsetX = pageWidth - rightMargin - columnWidth - columnIndex * (columnSpacing + columnWidth);
+		}
+		else
+		{
+			offsetX = leftMargin + columnIndex * (columnSpacing + columnWidth);
+		}
+	}
+
+	
 }
