@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -27,25 +27,30 @@ import java.awt.font.FontRenderContext;
 import java.awt.font.LineBreakMeasurer;
 import java.awt.font.TextLayout;
 import java.text.AttributedCharacterIterator;
+import java.text.AttributedCharacterIterator.Attribute;
 import java.text.AttributedString;
 import java.text.BreakIterator;
 import java.text.CharacterIterator;
-import java.text.AttributedCharacterIterator.Attribute;
 import java.util.ArrayList;
 import java.util.Iterator;
+import java.util.List;
 import java.util.Map;
 import java.util.StringTokenizer;
 
 import net.sf.jasperreports.engine.JRCommonText;
+import net.sf.jasperreports.engine.JRParagraph;
 import net.sf.jasperreports.engine.JRPrintText;
 import net.sf.jasperreports.engine.JRPropertiesHolder;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRTextElement;
-import net.sf.jasperreports.engine.export.TextRenderer;
+import net.sf.jasperreports.engine.TabStop;
+import net.sf.jasperreports.engine.export.AbstractTextRenderer;
+import net.sf.jasperreports.engine.export.AwtTextRenderer;
 import net.sf.jasperreports.engine.util.DelegatePropertiesHolder;
 import net.sf.jasperreports.engine.util.JRProperties;
+import net.sf.jasperreports.engine.util.JRStringUtil;
 import net.sf.jasperreports.engine.util.JRStyledText;
-import net.sf.jasperreports.engine.util.MaxFontSizeFinder;
+import net.sf.jasperreports.engine.util.ParagraphUtil;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -55,25 +60,19 @@ import org.apache.commons.logging.LogFactory;
  * Default text measurer implementation.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: TextMeasurer.java 3940 2010-08-20 10:35:15Z teodord $
+ * @version $Id: TextMeasurer.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class TextMeasurer implements JRTextMeasurer
 {
-
 	private static final Log log = LogFactory.getLog(TextMeasurer.class);
 
-	/**
-	 *
-	 */
-	private static final FontRenderContext FONT_RENDER_CONTEXT = TextRenderer.LINE_BREAK_FONT_RENDER_CONTEXT;
-
 	private JRCommonText textElement;
 	private JRPropertiesHolder propertiesHolder;
 
 	/**
 	 * 
 	 */
-	private MaxFontSizeFinder maxFontSizeFinder;
+	//private MaxFontSizeFinder maxFontSizeFinder;
 	
 	private int width;
 	private int height;
@@ -81,12 +80,12 @@ public class TextMeasurer implements JRTextMeasurer
 	private int leftPadding;
 	private int bottomPadding;
 	private int rightPadding;
-	private float lineSpacing;
+	private JRParagraph jrParagraph;
 
-	private float formatWidth;
+	//private float formatWidth;
 	private int maxHeight;
 	private boolean canOverflow;
-	private Map globalAttributes;
+	private Map<Attribute,Object> globalAttributes;
 	private TextMeasuredState measuredState;
 	private TextMeasuredState prevMeasuredState;
 	
@@ -96,15 +95,13 @@ public class TextMeasurer implements JRTextMeasurer
 		
 		protected int textOffset;
 		protected int lines;
-		protected int fontSizeSum;
-		protected int firstLineMaxFontSize;
+		protected int paragraphStartLine;
 		protected float textHeight;
-		protected float firstLineLeading;
 		protected boolean isLeftToRight = true;
 		protected String textSuffix;
 		
 		protected int lastOffset;
-		protected ArrayList lineBreakOffsets;
+		protected ArrayList<Integer> lineBreakOffsets;
 		
 		public TextMeasuredState(boolean saveLineBreakOffsets)
 		{
@@ -126,20 +123,6 @@ public class TextMeasurer implements JRTextMeasurer
 			return textHeight;
 		}
 		
-		public float getLineSpacingFactor()
-		{
-			if (lines > 0)
-			{
-				return textHeight / fontSizeSum;
-			}
-			return 0;
-		}
-		
-		public float getLeadingOffset()
-		{
-			return firstLineLeading - firstLineMaxFontSize * getLineSpacingFactor();
-		}
-
 		public String getTextSuffix()
 		{
 			return textSuffix;
@@ -155,7 +138,7 @@ public class TextMeasurer implements JRTextMeasurer
 				//might be a performance problem on very large texts
 				if (lineBreakOffsets != null)
 				{
-					clone.lineBreakOffsets = (ArrayList) lineBreakOffsets.clone();
+					clone.lineBreakOffsets = (ArrayList<Integer>) lineBreakOffsets.clone();
 				}
 				
 				return clone;
@@ -173,7 +156,7 @@ public class TextMeasurer implements JRTextMeasurer
 			{
 				if (lineBreakOffsets == null)
 				{
-					lineBreakOffsets = new ArrayList();
+					lineBreakOffsets = new ArrayList<Integer>();
 				}
 
 				int breakOffset = textOffset - lastOffset;
@@ -204,7 +187,7 @@ public class TextMeasurer implements JRTextMeasurer
 			boolean overflow = false;
 			for (int i = 0; i < offsets.length; i++)
 			{
-				int offset = ((Integer) lineBreakOffsets.get(i)).intValue();
+				int offset = lineBreakOffsets.get(i).intValue();
 				if (offset > Short.MAX_VALUE)
 				{
 					if (log.isWarnEnabled())
@@ -252,9 +235,12 @@ public class TextMeasurer implements JRTextMeasurer
 	/**
 	 * 
 	 */
-	protected void initialize(JRStyledText styledText,
-			int remainingTextStart,
-			int availableStretchHeight, boolean canOverflow)
+	protected void initialize(
+		JRStyledText styledText,
+		int remainingTextStart,
+		int availableStretchHeight, 
+		boolean canOverflow
+		)
 	{
 		width = textElement.getWidth();
 		height = textElement.getHeight();
@@ -263,6 +249,8 @@ public class TextMeasurer implements JRTextMeasurer
 		leftPadding = textElement.getLineBox().getLeftPadding().intValue();
 		bottomPadding = textElement.getLineBox().getBottomPadding().intValue();
 		rightPadding = textElement.getLineBox().getRightPadding().intValue();
+		
+		jrParagraph = textElement.getParagraph();
 
 		switch (textElement.getRotationValue())
 		{
@@ -304,34 +292,10 @@ public class TextMeasurer implements JRTextMeasurer
 			}
 		}
 		
-		/*   */
-		switch (textElement.getLineSpacingValue())
-		{
-			case SINGLE : 
-			{
-				lineSpacing = 1f;
-				break;
-			}
-			case ONE_AND_HALF : 
-			{
-				lineSpacing = 1.5f;
-				break;
-			}
-			case DOUBLE : 
-			{
-				lineSpacing = 2f;
-				break;
-			}
-			default : 
-			{
-				lineSpacing = 1f;
-			}
-		}
+		//maxFontSizeFinder = MaxFontSizeFinder.getInstance(!JRCommonText.MARKUP_NONE.equals(textElement.getMarkup()));
 
-		maxFontSizeFinder = MaxFontSizeFinder.getInstance(!JRCommonText.MARKUP_NONE.equals(textElement.getMarkup()));
-
-		formatWidth = width - leftPadding - rightPadding;
-		formatWidth = formatWidth < 0 ? 0 : formatWidth;
+//		formatWidth = width - leftPadding - rightPadding;
+//		formatWidth = formatWidth < 0 ? 0 : formatWidth;
 		maxHeight = height + availableStretchHeight - topPadding - bottomPadding;
 		maxHeight = maxHeight < 0 ? 0 : maxHeight;
 		this.canOverflow = canOverflow;
@@ -372,6 +336,7 @@ public class TextMeasurer implements JRTextMeasurer
 		StringTokenizer tkzer = new StringTokenizer(remainingText, "\n", true);
 
 		boolean rendered = true;
+		// text is split into paragraphs, using the newline character as delimiter
 		while(tkzer.hasMoreTokens() && rendered) 
 		{
 			String token = tkzer.nextToken();
@@ -433,15 +398,24 @@ public class TextMeasurer implements JRTextMeasurer
 					).getIterator();
 		}
 
-		LineBreakMeasurer lineMeasurer = new LineBreakMeasurer(paragraph, FONT_RENDER_CONTEXT);
+		List<Integer> tabIndexes = JRStringUtil.getTabIndexes(lastParagraphText);
 		
+		int[] currentTabHolder = new int[]{0};
+		TabStop[] nextTabStopHolder = new TabStop[]{null};
+		boolean[] requireNextWordHolder = new boolean[]{false};
+
+		LineBreakMeasurer lineMeasurer = new LineBreakMeasurer(paragraph, getFontRenderContext());
+		
+		measuredState.paragraphStartLine = measuredState.lines;
 		measuredState.textOffset = lastParagraphStart;
 		
 		boolean rendered = true;
 		boolean renderedLine = false;
+
+		// the paragraph is measured one line at a time
 		while (lineMeasurer.getPosition() < paragraph.getEndIndex() && rendered)
 		{
-			rendered = renderNextLine(lineMeasurer, paragraph);
+			rendered = renderNextLine(lineMeasurer, paragraph, tabIndexes, currentTabHolder, nextTabStopHolder, requireNextWordHolder);
 			renderedLine = renderedLine || rendered;
 		}
 		
@@ -456,9 +430,12 @@ public class TextMeasurer implements JRTextMeasurer
 		return rendered;
 	}
 	
-	protected void processLastTruncatedRow(AttributedCharacterIterator allParagraphs,
-			String paragraphText, int paragraphOffset,
-			boolean lineTruncated)
+	protected void processLastTruncatedRow(
+		AttributedCharacterIterator allParagraphs,
+		String paragraphText, 
+		int paragraphOffset,
+		boolean lineTruncated
+		)
 	{
 		if (lineTruncated && isToTruncateAtChar())
 		{
@@ -468,21 +445,29 @@ public class TextMeasurer implements JRTextMeasurer
 		appendTruncateSuffix(allParagraphs);
 	}
 
-	protected void truncateLastLineAtChar(AttributedCharacterIterator allParagraphs, String paragraphText, int paragraphOffset)
+	protected void truncateLastLineAtChar(
+		AttributedCharacterIterator allParagraphs, 
+		String paragraphText, 
+		int paragraphOffset
+		)
 	{
 		//truncate the original line at char
 		measuredState = prevMeasuredState.cloneState();
-		AttributedCharacterIterator lineParagraph = new AttributedString(
+		AttributedCharacterIterator lineParagraph = 
+			new AttributedString(
 				allParagraphs, 
 				measuredState.textOffset,
-				paragraphOffset + paragraphText.length()).getIterator();
-		LineBreakMeasurer lineMeasurer = new LineBreakMeasurer(
+				paragraphOffset + paragraphText.length()
+				).getIterator();
+		LineBreakMeasurer lineMeasurer = 
+			new LineBreakMeasurer(
 				lineParagraph, 
 				BreakIterator.getCharacterInstance(), 
-				FONT_RENDER_CONTEXT);
+				getFontRenderContext()
+				);
 		//render again the last line
 		//if the line does not fit now, it will remain empty
-		renderNextLine(lineMeasurer, lineParagraph);
+		renderNextLine(lineMeasurer, lineParagraph, null, new int[]{0}, new TabStop[]{null}, new boolean[]{false});
 	}
 
 	protected void appendTruncateSuffix(AttributedCharacterIterator allParagraphs)
@@ -516,15 +501,21 @@ public class TextMeasurer implements JRTextMeasurer
 			AttributedString attributedText = new AttributedString(text);
 			
 			//set original attributes for the text part
-			AttributedCharacterIterator lineAttributes = new AttributedString(
+			AttributedCharacterIterator lineAttributes = 
+				new AttributedString(
 					allParagraphs, 
 					measuredState.textOffset,
-					measuredState.textOffset + linePosition).getIterator();
+					measuredState.textOffset + linePosition
+					).getIterator();
 			setAttributes(attributedText, lineAttributes, 0);
 			
 			//set global attributes for the suffix part
-			setAttributes(attributedText, globalAttributes, 
-					text.length() - truncateSuffx.length(), text.length());
+			setAttributes(
+				attributedText, 
+				globalAttributes, 
+				text.length() - truncateSuffx.length(), 
+				text.length()
+				);
 			
 			AttributedCharacterIterator lineParagraph = attributedText.getIterator();
 			
@@ -532,12 +523,14 @@ public class TextMeasurer implements JRTextMeasurer
 				isToTruncateAtChar() 
 				? BreakIterator.getCharacterInstance() 
 				: BreakIterator.getLineInstance();
-			LineBreakMeasurer lineMeasurer = new LineBreakMeasurer(
+			LineBreakMeasurer lineMeasurer = 
+				new LineBreakMeasurer(
 					lineParagraph,
 					breakIterator,
-					FONT_RENDER_CONTEXT);
+					getFontRenderContext()
+					);
 
-			if (renderNextLine(lineMeasurer, lineParagraph))
+			if (renderNextLine(lineMeasurer, lineParagraph, null, new int[]{0}, new TabStop[]{null}, new boolean[]{false}))
 			{
 				int lastPos = lineMeasurer.getPosition();
 				//test if the entire suffix fit
@@ -604,42 +597,203 @@ public class TextMeasurer implements JRTextMeasurer
 		return truncateSuffx;
 	}
 	
-	protected boolean renderNextLine(LineBreakMeasurer lineMeasurer, AttributedCharacterIterator paragraph)
+	protected boolean renderNextLine(LineBreakMeasurer lineMeasurer, AttributedCharacterIterator paragraph, List<Integer> tabIndexes, int[] currentTabHolder, TabStop[] nextTabStopHolder, boolean[] requireNextWordHolder)
 	{
+		boolean lineComplete = false;
+
 		int lineStartPosition = lineMeasurer.getPosition();
+		
+		float maxAscent = 0;
+		float maxDescent = 0;
+		float maxLeading = 0;
+		int characterCount = 0;
+		boolean isLeftToRight = true;
+		
+		// each line is split into segments, using the tab character as delimiter
+		List<TabSegment> segments = new ArrayList<TabSegment>(1);
 
-		TextLayout layout = lineMeasurer.nextLayout(formatWidth);
+		TabSegment oldSegment = null;
+		TabSegment crtSegment = null;
 
-		float newTextHeight = measuredState.textHeight + layout.getLeading() + lineSpacing * layout.getAscent();
-		boolean fits = newTextHeight + layout.getDescent() <= maxHeight;
+		// splitting the current line into tab segments
+		while (!lineComplete)
+		{
+			// the current segment limit is either the next tab character or the paragraph end 
+			int tabIndexOrEndIndex = (tabIndexes == null || currentTabHolder[0] >= tabIndexes.size() ? paragraph.getEndIndex() : tabIndexes.get(currentTabHolder[0]) + 1);
+			
+			float startX = (lineMeasurer.getPosition() == 0 ? textElement.getParagraph().getFirstLineIndent() : 0) + leftPadding;
+			float endX = width - textElement.getParagraph().getRightIndent() - rightPadding;
+			endX = endX < startX ? startX : endX;
+			//formatWidth = endX - startX;
+			//formatWidth = endX;
+
+			int startIndex = lineMeasurer.getPosition();
+
+			float rightX = 0;
+
+			if (segments.size() == 0)
+			{
+				rightX = startX;
+				//nextTabStop = nextTabStop;
+			}
+			else
+			{
+				rightX = oldSegment.rightX;
+				nextTabStopHolder[0] = ParagraphUtil.getNextTabStop(jrParagraph, endX, rightX);
+			}
+
+			//float availableWidth = formatWidth - ParagraphUtil.getSegmentOffset(nextTabStopHolder[0], rightX); // nextTabStop can be null here; and that's OK
+			float availableWidth = endX - textElement.getParagraph().getLeftIndent() - ParagraphUtil.getSegmentOffset(nextTabStopHolder[0], rightX); // nextTabStop can be null here; and that's OK
+			
+			// creating a text layout object for each tab segment 
+			TextLayout layout = 
+				lineMeasurer.nextLayout(
+					availableWidth,
+					tabIndexOrEndIndex,
+					requireNextWordHolder[0]
+					);
+			
+			if (layout != null)
+			{
+				maxAscent = Math.max(maxAscent, layout.getAscent());
+				maxDescent = Math.max(maxDescent, layout.getDescent());
+				maxLeading = Math.max(maxLeading, layout.getLeading());
+				characterCount += layout.getCharacterCount();
+				isLeftToRight = isLeftToRight && layout.isLeftToRight();
+
+				//creating the current segment
+				crtSegment = new TabSegment();
+				crtSegment.layout = layout;
+
+				float leftX = ParagraphUtil.getLeftX(nextTabStopHolder[0], layout.getAdvance()); // nextTabStop can be null here; and that's OK
+				if (rightX > leftX)
+				{
+					crtSegment.leftX = rightX;
+					crtSegment.rightX = rightX + layout.getAdvance();
+				}
+				else
+				{
+					crtSegment.leftX = leftX;
+					// we need this special tab stop based utility call because adding the advance to leftX causes rounding issues
+					crtSegment.rightX = ParagraphUtil.getRightX(nextTabStopHolder[0], layout.getAdvance()); // nextTabStop can be null here; and that's OK
+				}
+
+				segments.add(crtSegment);
+			}
+			
+			requireNextWordHolder[0] = true;
+
+			if (lineMeasurer.getPosition() == tabIndexOrEndIndex)
+			{
+				// the segment limit was a tab; going to the next tab
+				currentTabHolder[0] = currentTabHolder[0] + 1;
+			}
+			
+			if (lineMeasurer.getPosition() == paragraph.getEndIndex())
+			{
+				// the segment limit was the paragraph end; line completed and next line should start at normal zero x offset
+				lineComplete = true;
+				nextTabStopHolder[0] = null;
+			}
+			else
+			{
+				// there is paragraph text remaining 
+				if (lineMeasurer.getPosition() == tabIndexOrEndIndex)
+				{
+					// the segment limit was a tab
+					if (crtSegment.rightX >= ParagraphUtil.getLastTabStop(jrParagraph, endX).getPosition())
+					{
+						// current segment stretches out beyond the last tab stop; line complete
+						lineComplete = true;
+						// next line should should start at first tab stop indent
+						nextTabStopHolder[0] = ParagraphUtil.getFirstTabStop(jrParagraph, endX);
+					}
+//					else
+//					{
+//						//nothing; this leaves lineComplete=false
+//					}
+				}
+				else
+				{
+					// the segment did not fit entirely
+					lineComplete = true;
+					if (layout == null)
+					{
+						// nothing fitted; next line should start at first tab stop indent
+						if (nextTabStopHolder[0].getPosition() == ParagraphUtil.getFirstTabStop(jrParagraph, endX).getPosition())//FIXMETAB check based on segments.size()
+						{
+							// at second attempt we give up to avoid infinite loop
+							nextTabStopHolder[0] = null;
+							requireNextWordHolder[0] = false;
+							
+							//provide dummy maxFontSize because it is used for the line height of this empty line when attempting drawing below
+				 			AttributedString tmpText = 
+								new AttributedString(
+									paragraph, 
+									startIndex, 
+									startIndex + 1
+									);
+				 			LineBreakMeasurer lbm = new LineBreakMeasurer(tmpText.getIterator(), getFontRenderContext());
+				 			TextLayout tlyt = lbm.nextLayout(100);//FIXME what is this? why 100?
+							maxAscent = tlyt.getAscent();
+							maxDescent = tlyt.getDescent();
+							maxLeading = tlyt.getLeading();
+						}
+						else
+						{
+							nextTabStopHolder[0] = ParagraphUtil.getFirstTabStop(jrParagraph, endX);
+						}
+					}
+					else
+					{
+						// something fitted
+						nextTabStopHolder[0] = null;
+						requireNextWordHolder[0] = false;
+					}
+				}
+			}
+
+			oldSegment = crtSegment;
+		}
+		
+		float lineHeight = AbstractTextRenderer.getLineHeight(measuredState.lines == 0, jrParagraph, maxLeading, maxAscent);
+		
+		if (measuredState.lines == 0) //FIXMEPARA
+		//if (measuredState.paragraphStartLine == measuredState.lines)
+		{
+			lineHeight += jrParagraph.getSpacingBefore().intValue();
+		}
+		
+		float newTextHeight = measuredState.textHeight + lineHeight;
+		boolean fits = newTextHeight + maxDescent <= maxHeight;
 		if (fits)
 		{
 			prevMeasuredState = measuredState.cloneState();
 			
-			measuredState.isLeftToRight = measuredState.isLeftToRight && layout.isLeftToRight();
+			measuredState.isLeftToRight = isLeftToRight;//run direction is per layout; but this is the best we can do for now
 			measuredState.textHeight = newTextHeight;
 			measuredState.lines++;
 
-			measuredState.fontSizeSum += 
-				maxFontSizeFinder.findMaxFontSize(
-					new AttributedString(
-						paragraph, 
-						lineStartPosition, 
-						lineStartPosition + layout.getCharacterCount()
-						).getIterator(),
-					textElement.getFontSize()
-					);
+//			measuredState.fontSizeSum += 
+//				maxFontSizeFinder.findMaxFontSize(
+//					new AttributedString(
+//						paragraph, 
+//						lineStartPosition, 
+//						lineStartPosition + characterCount
+//						).getIterator(),
+//					textElement.getFontSize()
+//					);
 
-			if (measuredState.lines == 1)
-			{
-				measuredState.firstLineLeading = measuredState.textHeight;
-				measuredState.firstLineMaxFontSize = measuredState.fontSizeSum;
-			}
+//			if (measuredState.lines == 1)
+//			{
+//				measuredState.firstLineLeading = measuredState.textHeight;
+//				measuredState.firstLineMaxFontSize = measuredState.fontSizeSum;
+//			}
 
 			// here is the Y offset where we would draw the line
 			//lastDrawPosY = drawPosY;
 			//
-			measuredState.textHeight += layout.getDescent();
+			measuredState.textHeight += maxDescent;
 			
 			measuredState.textOffset += lineMeasurer.getPosition() - lineStartPosition;
 			
@@ -648,6 +802,10 @@ public class TextMeasurer implements JRTextMeasurer
 				//if not the last line in a paragraph, save the line break position
 				measuredState.addLineBreak();
 			}
+//			else //FIXMEPARA
+//			{
+//				measuredState.textHeight += jrParagraph.getSpacingAfter().intValue();
+//			}
 		}
 		
 		return fits;
@@ -659,38 +817,63 @@ public class TextMeasurer implements JRTextMeasurer
 	}
 	
 	protected void setAttributes(
-			AttributedString string,
-			AttributedCharacterIterator attributes, 
-			int stringOffset)
+		AttributedString string,
+		AttributedCharacterIterator attributes, 
+		int stringOffset
+		)
 	{
 		for (char c = attributes.first(); c != CharacterIterator.DONE; c = attributes.next())
 		{
-			for (Iterator it = attributes.getAttributes().entrySet().iterator(); it.hasNext();)
+			for (Iterator<Map.Entry<Attribute,Object>> it = attributes.getAttributes().entrySet().iterator(); it.hasNext();)
 			{
-				Map.Entry attributeEntry = (Map.Entry) it.next();
-				AttributedCharacterIterator.Attribute attribute = (Attribute) attributeEntry.getKey();
+				Map.Entry<Attribute,Object> attributeEntry = it.next();
+				AttributedCharacterIterator.Attribute attribute = attributeEntry.getKey();
 				if (attributes.getRunStart(attribute) == attributes.getIndex())
 				{
 					Object attributeValue = attributeEntry.getValue();
-					string.addAttribute(attribute, attributeValue, 
-							attributes.getIndex() + stringOffset,
-							attributes.getRunLimit(attribute) + stringOffset);
+					string.addAttribute(
+						attribute, 
+						attributeValue, 
+						attributes.getIndex() + stringOffset,
+						attributes.getRunLimit(attribute) + stringOffset
+						);
 				}
 			}
 		}
 	}
 	
 	protected void setAttributes(
-			AttributedString string,
-			Map attributes, 
-			int startIndex, int endIndex)
+		AttributedString string,
+		Map<Attribute,Object> attributes, 
+		int startIndex, 
+		int endIndex
+		)
 	{
-		for (Iterator it = attributes.entrySet().iterator(); it.hasNext();)
+		for (Iterator<Map.Entry<Attribute,Object>> it = attributes.entrySet().iterator(); it.hasNext();)
 		{
-			Map.Entry entry = (Map.Entry) it.next();
-			AttributedCharacterIterator.Attribute attribute = (Attribute) entry.getKey();
+			Map.Entry<Attribute,Object> entry = it.next();
+			Attribute attribute = entry.getKey();
 			Object attributeValue = entry.getValue();
 			string.addAttribute(attribute, attributeValue, startIndex, endIndex);
 		}
 	}
+
+	
+
+	/**
+	 * 
+	 */
+	public FontRenderContext getFontRenderContext()
+	{
+		return AwtTextRenderer.LINE_BREAK_FONT_RENDER_CONTEXT;
+	}
+
+	
+}
+
+class TabSegment
+{
+	public TextLayout layout;
+	public float leftX;
+	public float rightX;
 }
