@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,15 +17,19 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
 package net.sf.jasperreports.engine.fonts;
 
+import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
+import java.io.OutputStream;
+import java.io.OutputStreamWriter;
+import java.io.Writer;
 import java.lang.ref.SoftReference;
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -40,7 +44,7 @@ import javax.xml.parsers.ParserConfigurationException;
 
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRRuntimeException;
-import net.sf.jasperreports.engine.util.JRLoader;
+import net.sf.jasperreports.repo.RepositoryUtil;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -56,11 +60,17 @@ import org.xml.sax.SAXParseException;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRStyledTextParser.java 3082 2009-10-02 12:11:22Z teodord $
+ * @version $Id: SimpleFontExtensionHelper.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public final class SimpleFontExtensionHelper implements ErrorHandler
 {
 	private static final Log log = LogFactory.getLog(SimpleFontExtensionHelper.class);
+	
+	/**
+	 * Default XML output encoding.
+	 */
+	public static final String DEFAULT_ENCODING = "UTF-8";
+	
 
 	/**
 	 *
@@ -82,7 +92,7 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 	/**
 	 * Thread local soft cache of instances.
 	 */
-	private static final ThreadLocal threadInstances = new ThreadLocal();
+	private static final ThreadLocal<SoftReference<SimpleFontExtensionHelper>> threadInstances = new ThreadLocal<SoftReference<SimpleFontExtensionHelper>>();
 	
 	/**
 	 * Return a cached instance.
@@ -92,15 +102,15 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 	public static SimpleFontExtensionHelper getInstance()
 	{
 		SimpleFontExtensionHelper instance = null;
-		SoftReference instanceRef = (SoftReference) threadInstances.get();
+		SoftReference<SimpleFontExtensionHelper> instanceRef = threadInstances.get();
 		if (instanceRef != null)
 		{
-			instance = (SimpleFontExtensionHelper) instanceRef.get();
+			instance = instanceRef.get();
 		}
 		if (instance == null)
 		{
 			instance = new SimpleFontExtensionHelper();
-			threadInstances.set(new SoftReference(instance));
+			threadInstances.set(new SoftReference<SimpleFontExtensionHelper>(instance));
 		}
 		return instance;
 	}
@@ -108,7 +118,7 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 	/**
 	 *
 	 */
-	private DocumentBuilder documentBuilder = null;
+	private DocumentBuilder documentBuilder;
 
 
 	/**
@@ -132,13 +142,13 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 	/**
 	 *
 	 */
-	public List loadFontFamilies(String file)
+	public List<FontFamily> loadFontFamilies(String file)
 	{
 		InputStream is = null; 
 		
 		try
 		{
-			is = JRLoader.getLocationInputStream(file);
+			is = RepositoryUtil.getInputStream(file);
 			return loadFontFamilies(is);
 		}
 		catch (JRException e)
@@ -163,9 +173,9 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 	/**
 	 *
 	 */
-	public List loadFontFamilies(InputStream is)
+	public List<FontFamily> loadFontFamilies(InputStream is)
 	{
-		List fontFamilies = null;
+		List<FontFamily> fontFamilies = null;
 
 		try
 		{
@@ -188,9 +198,9 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 	/**
 	 *
 	 */
-	private List parseFontFamilies(Node fontFamiliesNode) throws SAXException
+	private List<FontFamily> parseFontFamilies(Node fontFamiliesNode) throws SAXException
 	{
-		List fontFamilies = new ArrayList();
+		List<FontFamily> fontFamilies = new ArrayList<FontFamily>();
 		
 		NodeList nodeList = fontFamiliesNode.getChildNodes();
 		for(int i = 0; i < nodeList.getLength(); i++)
@@ -269,9 +279,9 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 	/**
 	 *
 	 */
-	private Map parseExportFonts(Node exportFontsNode) throws SAXException
+	private Map<String,String> parseExportFonts(Node exportFontsNode) throws SAXException
 	{
-		Map exportFonts = new HashMap();
+		Map<String,String> exportFonts = new HashMap<String,String>();
 		
 		NodeList nodeList = exportFontsNode.getChildNodes();
 		for(int i = 0; i < nodeList.getLength(); i++)
@@ -297,9 +307,275 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 	/**
 	 *
 	 */
-	private Set parseLocales(Node localesNode) throws SAXException
+	public static String getFontsXml(List<FontFamily> fontFamilies)
 	{
-		Set locales = new HashSet();
+		StringBuffer buffer = null;
+		
+		if(fontFamilies != null)
+		{
+			buffer = new StringBuffer();
+			buffer.append("<?xml version=\"1.0\" encoding=\"" + DEFAULT_ENCODING + "\"?>\n");
+			buffer.append("<fontFamilies>\n");
+			for (FontFamily fontFamily : fontFamilies)
+			{
+				addFontFamily(buffer, fontFamily);
+			}
+			buffer.append("</fontFamilies>\n");
+			return buffer.toString();
+		}
+		else
+		{
+			log.error("There are no font families in the list.");
+			return null;
+		}
+	}
+
+	/**
+	 *
+	 */
+	private static void addFontFamily(StringBuffer buffer, FontFamily fontFamily) 
+	{
+		if(fontFamily != null)
+		{
+			if(fontFamily.getName() == null)
+			{
+				log.error("Font family name is required.");
+				return;
+			}
+			
+			String indent = "  ";
+			buffer.append(indent + "<fontFamily name=\"" + fontFamily.getName() + "\">\n");
+			indent = "    ";
+			
+			if(fontFamily.getNormalFace() != null)
+			{
+				buffer.append(indent + "<normal>" + fontFamily.getNormalFace().getFile() +"</normal>\n");
+			}
+			if(fontFamily.getBoldFace() != null)
+			{
+				buffer.append(indent + "<bold>" + fontFamily.getBoldFace().getFile() +"</bold>\n");
+				
+			}
+			if(fontFamily.getItalicFace() != null)
+			{
+				buffer.append(indent + "<italic>" + fontFamily.getItalicFace().getFile() +"</italic>\n");
+				
+			}
+			if(fontFamily.getBoldItalicFace() != null)
+			{
+				buffer.append(indent + "<boldItalic>" + fontFamily.getBoldItalicFace().getFile() +"</boldItalic>\n");
+			}
+			if(fontFamily.getPdfEncoding() != null)
+			{
+				buffer.append(indent + "<pdfEncoding>" + fontFamily.getPdfEncoding() +"</pdfEncoding>\n");
+				
+			}
+			if(fontFamily.isPdfEmbedded() != null)
+			{
+				buffer.append(indent + "<pdfEmbedded>" + fontFamily.isPdfEmbedded() +"</pdfEmbedded>\n");
+				
+			}
+			
+			if(fontFamily instanceof SimpleFontFamily)
+			{
+				SimpleFontFamily simpleFontFamily = (SimpleFontFamily)fontFamily;
+				
+				Map<String, String> exportFonts = simpleFontFamily.getExportFonts();
+				
+				if(exportFonts != null)
+				{
+					buffer.append(indent + "<exportFonts>\n");
+					indent = "      ";
+					for(String key : exportFonts.keySet())
+					{
+						buffer.append(indent + "<export key=\"" + key +"\">" + exportFonts.get(key) + "</export>\n");
+					}
+					indent = "    ";
+					buffer.append(indent + "</exportFonts>\n");
+				}
+				
+				Set<String> locales = simpleFontFamily.getLocales();
+				
+				if(locales != null)
+				{
+					buffer.append(indent + "<locales>\n");
+					indent = "      ";
+					for(String locale : locales)
+					{
+						buffer.append(indent + "<locale>" + locale + "</locale>\n");
+					}
+					indent = "    ";
+					buffer.append(indent + "</locales>\n");
+				}
+			}
+			indent = "  ";
+			buffer.append(indent + "</fontFamily>\n\n");
+		}		
+		else
+		{
+			log.info("Null font family encountered.");
+		}
+	}
+	
+
+	/**
+	 *
+	 */
+	public static void writeFontsXml(
+		String destFileName,
+		List<FontFamily> fontFamilies
+		) throws JRException
+	{
+		FileOutputStream fos = null;
+
+		try
+		{
+			fos = new FileOutputStream(destFileName);
+			writeFontsXml(fos, fontFamilies);
+		}
+		catch (IOException e)
+		{
+			throw new JRException("Error writing to file : " + destFileName, e);
+		}
+		finally
+		{
+			if (fos != null)
+			{
+				try
+				{
+					fos.close();
+				}
+				catch(IOException e)
+				{
+				}
+			}
+		}
+	}
+
+
+	/**
+	 *
+	 */
+	public static void writeFontsXml(
+		OutputStream outputStream,
+		List<FontFamily> fontFamilies
+		) throws JRException
+	{
+		Writer out = null;
+		try
+		{
+			out = new OutputStreamWriter(outputStream, DEFAULT_ENCODING);
+			out.write(getFontsXml(fontFamilies));
+			out.flush();
+		}
+		catch (Exception e)
+		{
+			throw new JRException("Error writing to OutputStream : ", e);
+		}
+	}
+
+
+	/**
+	 *
+	 */
+	public static void writeFontExtensionsProperties(String fontsXmlLocation, String destFileName) throws JRException
+	{
+		FileOutputStream fos = null;
+
+		try
+		{
+			fos = new FileOutputStream(destFileName, false);
+			writeFontExtensionsProperties(fontsXmlLocation, fos);
+		}
+		catch (IOException e)
+		{
+			throw new JRException("Error writing to file : " + destFileName, e);
+		}
+		finally
+		{
+			if (fos != null)
+			{
+				try
+				{
+					fos.close();
+				}
+				catch(IOException e)
+				{
+				}
+			}
+		}
+	}
+
+
+	/**
+	 *
+	 */
+	public static void writeFontExtensionsProperties(String fontFamiliesPropertyValue, OutputStream outputStream) throws JRException
+	{
+		writeFontExtensionsProperties(
+				SimpleFontExtensionsRegistryFactory.PROPERTY_SIMPLE_FONT_FAMILIES_REGISTRY_FACTORY,
+				SimpleFontExtensionsRegistryFactory.class.getName(),
+				SimpleFontExtensionsRegistryFactory.SIMPLE_FONT_FAMILIES_PROPERTY_PREFIX +	"location", 
+				fontFamiliesPropertyValue,
+				outputStream);
+	}
+
+
+	/**
+	 *
+	 */
+	public static void writeFontExtensionsProperties(
+			String fontRegistryFactoryPropertyName, 
+			String fontRegistryFactoryPropertyValue, 
+			String fontFamiliesPropertyName, 
+			String fontFamiliesPropertyValue, 
+			OutputStream outputStream
+			) throws JRException
+	{
+		Writer out = null;
+		try
+		{
+			out = new OutputStreamWriter(outputStream, DEFAULT_ENCODING);
+			out.write(
+					fontRegistryFactoryPropertyName + 
+					"=" + 
+					fontRegistryFactoryPropertyValue + 
+					"\n"
+					);
+			out.write(
+					fontFamiliesPropertyName +
+					"=" + 
+					fontFamiliesPropertyValue + 
+					"\n"
+					);
+			out.flush();
+		}
+		catch (Exception e)
+		{
+			throw new JRException("Error writing to OutputStream : ", e);
+		}
+		finally
+		{
+			if (out != null)
+			{
+				try
+				{
+					out.close();
+				}
+				catch(IOException e)
+				{
+				}
+			}
+		}
+	}
+
+
+	/**
+	 *
+	 */
+	private Set<String> parseLocales(Node localesNode) throws SAXException
+	{
+		Set<String> locales = new HashSet<String>();
 		
 		NodeList nodeList = localesNode.getChildNodes();
 		for(int i = 0; i < nodeList.getLength(); i++)
