@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -46,7 +46,7 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRPrinterAWT.java 3689 2010-04-06 11:33:27Z shertage $
+ * @version $Id: JRPrinterAWT.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRPrinterAWT implements Printable
 {
@@ -55,8 +55,8 @@ public class JRPrinterAWT implements Printable
 	/**
 	 *
 	 */
-	private JasperPrint jasperPrint = null;
-	private int pageOffset = 0;
+	private JasperPrint jasperPrint;
+	private int pageOffset;
 
 
 	/**
