@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -30,15 +30,17 @@ import java.util.List;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.util.JRProperties;
 import net.sf.jasperreports.engine.util.JRSingletonCache;
+import net.sf.jasperreports.engine.util.JRProperties.PropertySuffix;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: DefaultQueryExecuterFactoryBundle.java 3687 2010-04-06 09:50:42Z shertage $
+ * @version $Id: DefaultQueryExecuterFactoryBundle.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public final class DefaultQueryExecuterFactoryBundle implements QueryExecuterFactoryBundle
 {
-	private static final JRSingletonCache cache = new JRSingletonCache(JRQueryExecuterFactory.class);
+	private static final JRSingletonCache<JRQueryExecuterFactory> cache = 
+			new JRSingletonCache<JRQueryExecuterFactory>(JRQueryExecuterFactory.class);
 	
 	private static final DefaultQueryExecuterFactoryBundle INSTANCE = new DefaultQueryExecuterFactoryBundle();
 	
@@ -59,14 +61,14 @@ public final class DefaultQueryExecuterFactoryBundle implements QueryExecuterFac
 	 */
 	public String[] getLanguages()
 	{
-		List languages = new ArrayList();
-		List properties = JRProperties.getProperties(JRQueryExecuterFactory.QUERY_EXECUTER_FACTORY_PREFIX);
-		for (Iterator it = properties.iterator(); it.hasNext();)
+		List<String> languages = new ArrayList<String>();
+		List<PropertySuffix> properties = JRProperties.getProperties(JRQueryExecuterFactory.QUERY_EXECUTER_FACTORY_PREFIX);
+		for (Iterator<PropertySuffix> it = properties.iterator(); it.hasNext();)
 		{
-			JRProperties.PropertySuffix property = (JRProperties.PropertySuffix) it.next();
+			PropertySuffix property = it.next();
 			languages.add(property.getSuffix());
 		}
-		return (String[])languages.toArray(new String[languages.size()]);
+		return languages.toArray(new String[languages.size()]);
 	}
 
 	/**
@@ -77,10 +79,10 @@ public final class DefaultQueryExecuterFactoryBundle implements QueryExecuterFac
 		String factoryClassName = JRProperties.getProperty(JRQueryExecuterFactory.QUERY_EXECUTER_FACTORY_PREFIX + language);
 		if (factoryClassName == null)
 		{
-			throw new JRException("No query executer factory class registered for " + language + " queries.");
+			return null;
 		}
 		
-		return (JRQueryExecuterFactory) cache.getCachedInstance(factoryClassName);
+		return cache.getCachedInstance(factoryClassName);
 	}
 
 }
