@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,28 +17,34 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
 package net.sf.jasperreports.engine.query;
 
 import java.lang.reflect.Array;
+import java.lang.reflect.Constructor;
 import java.math.BigDecimal;
 import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Types;
+import java.util.Calendar;
 import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.TimeZone;
+
+import javax.sql.rowset.CachedRowSet;
 
 import net.sf.jasperreports.engine.JRDataSource;
 import net.sf.jasperreports.engine.JRDataset;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRParameter;
+import net.sf.jasperreports.engine.JRPropertiesHolder;
 import net.sf.jasperreports.engine.JRResultSetDataSource;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRValueParameter;
@@ -54,7 +60,7 @@ import org.apache.commons.logging.LogFactory;
  * This query executer implementation offers built-in support for SQL queries.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRJdbcQueryExecuter.java 3674 2010-04-02 08:18:15Z shertage $
+ * @version $Id: JRJdbcQueryExecuter.java 4605 2011-09-14 06:58:37Z teodord $
  */
 public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 {
@@ -63,6 +69,19 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 	protected static final String CLAUSE_ID_IN = "IN";
 	protected static final String CLAUSE_ID_NOTIN = "NOTIN";
 	
+	protected static final String CLAUSE_ID_EQUAL = "EQUAL";
+	protected static final String CLAUSE_ID_NOTEQUAL = "NOTEQUAL";
+	
+	protected static final String CLAUSE_ID_LESS = "LESS";
+	protected static final String CLAUSE_ID_GREATER = "GREATER";
+	protected static final String CLAUSE_ID_LESS_OR_EQUAL = "LESS]";
+	protected static final String CLAUSE_ID_GREATER_OR_EQUAL = "[GREATER";
+	
+	protected static final String CLAUSE_ID_BETWEEN = "BETWEEN";
+	protected static final String CLAUSE_ID_BETWEEN_CLOSED = "[BETWEEN]";
+	protected static final String CLAUSE_ID_BETWEEN_LEFT_CLOSED = "[BETWEEN";
+	protected static final String CLAUSE_ID_BETWEEN_RIGHT_CLOSED = "BETWEEN]";
+	
 	protected static final String TYPE_FORWARD_ONLY = "forwardOnly";
 	protected static final String TYPE_SCROLL_INSENSITIVE = "scrollInsensitive";
 	protected static final String TYPE_SCROLL_SENSITIVE = "scrollSensitive";
@@ -72,23 +91,28 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 	
 	protected static final String HOLD_CURSORS_OVER_COMMIT = "hold";
 	protected static final String CLOSE_CURSORS_AT_COMMIT = "close";
+	
+	protected static final String CACHED_ROWSET_CLASS = "com.sun.rowset.CachedRowSetImpl";
 
-	private Connection connection;
+	protected Connection connection;
 	
 	/**
 	 * The statement used to fire the query.
 	 */
-	private PreparedStatement statement;
-
-	private ResultSet resultSet;
+	protected PreparedStatement statement;
 
+	protected ResultSet resultSet;
 	
-	public JRJdbcQueryExecuter(JRDataset dataset, Map parameters)
+	private boolean isCachedRowSet;
+
+	private TimeZone timeZone;
+	private boolean timeZoneOverride;
+	
+	public JRJdbcQueryExecuter(JRDataset dataset, Map<String,? extends JRValueParameter> parameters)
 	{
 		super(dataset, parameters);
 		
 		connection = (Connection) getParameterValue(JRParameter.REPORT_CONNECTION);
-
 		if (connection == null)
 		{
 			if (log.isWarnEnabled())
@@ -97,6 +121,10 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 			}
 		}
 		
+		isCachedRowSet = getBooleanParameterOrProperty(JRJdbcQueryExecuterFactory.PROPERTY_CACHED_ROWSET, false);
+		
+		setTimeZone();
+
 		registerFunctions();
 		
 		parseQuery();		
@@ -111,7 +139,34 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 	protected void registerFunctions()
 	{
 		registerClauseFunction(CLAUSE_ID_IN, JRSqlInClause.instance());
-		registerClauseFunction(CLAUSE_ID_NOTIN, JRSqlNotInClause.instance());		
+		registerClauseFunction(CLAUSE_ID_NOTIN, JRSqlNotInClause.instance());	
+		
+		registerClauseFunction(CLAUSE_ID_EQUAL, JRSqlEqualClause.instance());		
+		registerClauseFunction(CLAUSE_ID_NOTEQUAL, JRSqlNotEqualClause.instance());		
+		
+		registerClauseFunction(CLAUSE_ID_LESS, JRSqlLessOrGreaterClause.instance());		
+		registerClauseFunction(CLAUSE_ID_GREATER, JRSqlLessOrGreaterClause.instance());		
+		registerClauseFunction(CLAUSE_ID_LESS_OR_EQUAL, JRSqlLessOrGreaterClause.instance());		
+		registerClauseFunction(CLAUSE_ID_GREATER_OR_EQUAL, JRSqlLessOrGreaterClause.instance());
+		
+		registerClauseFunction(CLAUSE_ID_BETWEEN, JRSqlBetweenClause.instance());	
+		registerClauseFunction(CLAUSE_ID_BETWEEN_CLOSED, JRSqlBetweenClause.instance());	
+		registerClauseFunction(CLAUSE_ID_BETWEEN_LEFT_CLOSED, JRSqlBetweenClause.instance());	
+		registerClauseFunction(CLAUSE_ID_BETWEEN_RIGHT_CLOSED, JRSqlBetweenClause.instance());	
+	}
+
+	protected void setTimeZone()
+	{
+		String timezoneId = (String) getParameterValue(JRJdbcQueryExecuterFactory.PROPERTY_TIME_ZONE, true);
+		if (timezoneId != null)
+		{
+			timeZoneOverride = true;
+		}
+		else
+		{
+			timezoneId = JRProperties.getProperty(dataset, JRJdbcQueryExecuterFactory.PROPERTY_TIME_ZONE);
+		}
+		timeZone = timezoneId == null || timezoneId.length() == 0 ? null : TimeZone.getTimeZone(timezoneId);
 	}
 
 
@@ -126,7 +181,7 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 	 */
 	public JRDataSource createDatasource() throws JRException
 	{
-		JRDataSource dataSource = null;
+		JRResultSetDataSource dataSource = null;
 		
 		createStatement();
 		
@@ -134,9 +189,40 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 		{
 			try
 			{
-				resultSet = statement.executeQuery();
-				
+				if(isCachedRowSet)
+				{
+					try
+					{
+						Class<? extends CachedRowSet> clazz = (Class<? extends CachedRowSet>)Class.forName(CACHED_ROWSET_CLASS);
+						Constructor<? extends CachedRowSet> constructor = (Constructor<? extends CachedRowSet>)clazz.getConstructor();
+						resultSet = constructor.newInstance();
+					}
+					catch (Exception e)
+					{
+						throw new JRRuntimeException(e);
+					}
+					
+					((CachedRowSet)resultSet).populate(statement.executeQuery());
+					
+					try
+					{
+						statement.close();
+					}
+					catch (SQLException e)
+					{
+						log.error("Error while closing statement.", e);
+					}
+					finally
+					{
+						statement = null;
+					}
+				}
+				else
+				{
+					resultSet = statement.executeQuery();
+				}
 				dataSource = new JRResultSetDataSource(resultSet);
+				dataSource.setTimeZone(timeZone, timeZoneOverride);
 			}
 			catch (SQLException e)
 			{
@@ -217,15 +303,15 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 					statement.setMaxRows(reportMaxCount.intValue());
 				}
 
-				List parameterNames = getCollectedParameters();
+				List<QueryParameter> parameterNames = getCollectedParameters();
 				if (!parameterNames.isEmpty())
 				{
 					for(int i = 0, paramIdx = 1; i < parameterNames.size(); i++)
 					{
-						QueryParameter queryParameter = (QueryParameter) parameterNames.get(i);
+						QueryParameter queryParameter = parameterNames.get(i);
 						if (queryParameter.isMulti())
 						{
-							paramIdx += setStatementMultiParameters(paramIdx, queryParameter.getName());
+							paramIdx += setStatementMultiParameters(paramIdx, queryParameter.getName(), queryParameter.isIgnoreNulls());
 						}
 						else
 						{
@@ -243,10 +329,15 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 	}
 
 
+	public ResultSet getResultSet() {
+		return resultSet;
+	}
+
+
 	protected void setStatementParameter(int parameterIndex, String parameterName) throws SQLException
 	{
 		JRValueParameter parameter = getValueParameter(parameterName);
-		Class clazz = parameter.getValueClass();
+		Class<?> clazz = parameter.getValueClass();
 		Object parameterValue = parameter.getValue();
 		
 		if (log.isDebugEnabled())
@@ -254,51 +345,61 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 			log.debug("Parameter #" + parameterIndex + " (" + parameterName + " of type " + clazz.getName() + "): " + parameterValue);
 		}
 
-		setStatementParameter(parameterIndex, clazz, parameterValue);
+		setStatementParameter(parameterIndex, clazz, parameterValue, parameter);
 	}
 
 
-	protected int setStatementMultiParameters(int parameterIndex, String parameterName) throws SQLException
+	protected int setStatementMultiParameters(int parameterIndex, String parameterName, boolean ignoreNulls) throws SQLException
 	{
-		Object paramValue = getParameterValue(parameterName);
-		
+		JRValueParameter parameter = getValueParameter(parameterName);
+		Object paramValue = parameter.getValue();
 		int count;
+		int index = 0;
 		if (paramValue.getClass().isArray())
 		{
 			int arrayCount = Array.getLength(paramValue);
 			for (count = 0; count < arrayCount; ++count)
 			{
 				Object value = Array.get(paramValue, count);
-				setStatementMultiParameter(parameterIndex + count, parameterName, count, value);
+				if(!ignoreNulls || value != null)
+				{
+					setStatementMultiParameter(parameterIndex + index, parameterName, count, value, parameter);
+					++index;
+				}
 			}
 		}
-		else if (paramValue instanceof Collection)
+		else if (paramValue instanceof Collection<?>)
 		{
-			Collection values = (Collection) paramValue;
+			Collection<?> values = (Collection<?>) paramValue;
 			count = 0;
-			for (Iterator it = values.iterator(); it.hasNext(); ++count)
+			for (Iterator<?> it = values.iterator(); it.hasNext(); ++count)
 			{
 				Object value = it.next();
-				setStatementMultiParameter(parameterIndex + count, parameterName, count, value);
+				
+				if(!ignoreNulls || value != null)
+				{
+					setStatementMultiParameter(parameterIndex + index, parameterName, count, value, parameter);
+					++index;
+				}
 			}
 		}
 		else
 		{
 			throw new JRRuntimeException("Multi parameter value is not array nor collection.");
 		}
-		
-		return count;
+		return index;
 	}
 
 	
-	protected void setStatementMultiParameter(int parameterIndex, String parameterName, int valueIndex, Object value) throws SQLException
+	protected void setStatementMultiParameter(int parameterIndex, String parameterName, int valueIndex, Object value,
+			JRPropertiesHolder properties) throws SQLException
 	{
 		if (value == null)
 		{
 			throw new JRRuntimeException("Multi parameters cannot contain null values.");
 		}
 		
-		Class type = value.getClass();
+		Class<?> type = value.getClass();
 		
 		if (log.isDebugEnabled())
 		{
@@ -306,11 +407,12 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 					" (" + parameterName + "[" + valueIndex + "] of type " + type.getName() + "): " + value);
 		}
 		
-		setStatementParameter(parameterIndex, type, value);
+		setStatementParameter(parameterIndex, type, value, properties);
 	}
 
 	
-	protected void setStatementParameter(int parameterIndex, Class parameterType, Object parameterValue) throws SQLException
+	protected void setStatementParameter(int parameterIndex, Class<?> parameterType, Object parameterValue,
+			JRPropertiesHolder properties) throws SQLException
 	{
 		if (java.lang.Boolean.class.isAssignableFrom(parameterType))
 		{
@@ -413,36 +515,15 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 		}
 		else if (java.sql.Timestamp.class.isAssignableFrom(parameterType))
 		{
-			if (parameterValue == null)
-			{
-				statement.setNull(parameterIndex, Types.TIMESTAMP);
-			}
-			else
-			{
-				statement.setTimestamp( parameterIndex, (java.sql.Timestamp)parameterValue );
-			}
+			setTimestamp(parameterIndex, parameterValue, properties);
 		}
 		else if (java.sql.Time.class.isAssignableFrom(parameterType))
 		{
-			if (parameterValue == null)
-			{
-				statement.setNull(parameterIndex, Types.TIME);
-			}
-			else
-			{
-				statement.setTime( parameterIndex, (java.sql.Time)parameterValue );
-			}
+			setTime(parameterIndex, parameterValue, properties);
 		}
 		else if (java.util.Date.class.isAssignableFrom(parameterType))
 		{
-			if (parameterValue == null)
-			{
-				statement.setNull(parameterIndex, Types.DATE);
-			}
-			else
-			{
-				statement.setDate( parameterIndex, new java.sql.Date( ((java.util.Date)parameterValue).getTime() ) );
-			}
+			setDate(parameterIndex, parameterValue, properties);
 		}
 		else
 		{
@@ -457,6 +538,102 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 		}
 	}
 
+
+	protected void setTimestamp(int parameterIndex, Object parameterValue, JRPropertiesHolder properties)
+			throws SQLException
+	{
+		if (parameterValue == null)
+		{
+			statement.setNull(parameterIndex, Types.TIMESTAMP);
+		}
+		else
+		{
+			Calendar cal = getParameterCalendar(properties);
+			if (cal == null)
+			{
+				statement.setTimestamp(parameterIndex, (java.sql.Timestamp) parameterValue);
+			}
+			else
+			{
+				statement.setTimestamp(parameterIndex, (java.sql.Timestamp) parameterValue, cal);
+			}
+		}
+	}
+
+
+	protected void setTime(int parameterIndex, Object parameterValue, JRPropertiesHolder properties)
+			throws SQLException
+	{
+		if (parameterValue == null)
+		{
+			statement.setNull(parameterIndex, Types.TIME);
+		}
+		else
+		{
+			Calendar cal = getParameterCalendar(properties);
+			if (cal == null)
+			{
+				statement.setTime(parameterIndex, (java.sql.Time) parameterValue);
+			}
+			else
+			{
+				statement.setTime(parameterIndex, (java.sql.Time) parameterValue, cal);
+			}
+		}
+	}
+
+
+	protected void setDate(int parameterIndex, Object parameterValue, JRPropertiesHolder properties)
+			throws SQLException
+	{
+		if (parameterValue == null)
+		{
+			statement.setNull(parameterIndex, Types.DATE);
+		}
+		else
+		{
+			Calendar cal = getParameterCalendar(properties);
+			if (cal == null)
+			{
+				statement.setDate(parameterIndex, new java.sql.Date(((java.util.Date)parameterValue).getTime()));
+			}
+			else
+			{
+				statement.setDate(parameterIndex, new java.sql.Date(((java.util.Date)parameterValue).getTime()), cal);
+			}
+		}
+	}
+
+	protected Calendar getParameterCalendar(JRPropertiesHolder properties)
+	{
+		TimeZone tz;
+		if (timeZoneOverride)
+		{
+			// if we have a parameter, use it
+			tz = timeZone;
+		}
+		else
+		{
+			if (properties.hasProperties() && properties.getPropertiesMap().containsProperty(
+					JRJdbcQueryExecuterFactory.PROPERTY_TIME_ZONE))
+			{
+				// read the parameter level property
+				String timezoneId = JRProperties.getProperty(properties, 
+						JRJdbcQueryExecuterFactory.PROPERTY_TIME_ZONE);
+				tz = (timezoneId == null || timezoneId.length() == 0) ? null 
+						: TimeZone.getTimeZone(timezoneId);
+			}
+			else
+			{
+				// dataset/default property
+				tz = timeZone;
+			}
+		}
+
+		// using default JVM locale for the calendar
+		Calendar cal = tz == null ? null : Calendar.getInstance(tz);
+		return cal;
+	}
 	
 	/* (non-Javadoc)
 	 * @see net.sf.jasperreports.engine.util.JRQueryExecuter#close()
