@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -32,7 +32,7 @@ import org.apache.commons.logging.LogFactory;
  * Utility methods for {@link BigDecimal} handling.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: BigDecimalUtils.java 3712 2010-04-08 09:53:09Z teodord $
+ * @version $Id: BigDecimalUtils.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public final class BigDecimalUtils
 {
@@ -51,7 +51,7 @@ public final class BigDecimalUtils
 		BigDecimalHandler handler;
 		try
 		{
-			Class handlerClass = Class.forName(
+			Class<?> handlerClass = Class.forName(
 					"net.sf.jasperreports.engine.util.Java15BigDecimalHandler");
 			handler = (BigDecimalHandler) handlerClass.newInstance();
 		}
