@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -29,7 +29,7 @@ import net.sf.jasperreports.engine.JRRuntimeException;
  * Class utilities.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: ClassUtils.java 3712 2010-04-08 09:53:09Z teodord $
+ * @version $Id: ClassUtils.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public final class ClassUtils
 {
@@ -46,11 +46,11 @@ public final class ClassUtils
 	 * @throws JRRuntimeException if the class cannot be loaded or instantiated,
 	 * or if it does not implement the expected type
 	 */
-	public static final Object instantiateClass(String className, Class expectedType)
+	public static final Object instantiateClass(String className, Class<?> expectedType)
 	{
 		try
 		{
-			Class clazz = JRClassLoader.loadClassForName(className);
+			Class<?> clazz = JRClassLoader.loadClassForName(className);
 			if (!expectedType.isAssignableFrom(clazz))
 			{
 				throw new JRRuntimeException("Class " + className 
