@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -27,11 +27,13 @@ import java.awt.Color;
 
 import net.sf.jasperreports.engine.JRBox;
 import net.sf.jasperreports.engine.JRLineBox;
+import net.sf.jasperreports.engine.base.JRBoxPen;
+import net.sf.jasperreports.engine.type.RotationEnum;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBoxUtil.java 3713 2010-04-08 11:06:05Z teodord $
+ * @version $Id: JRBoxUtil.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public final class JRBoxUtil
 {
@@ -39,10 +41,15 @@ public final class JRBoxUtil
 	/**
 	 * 
 	 */
-	public static JRLineBox clone(JRLineBox box, boolean keepLeft, boolean keepRight, boolean keepTop, boolean keepBottom, JRLineBox complementaryBox)
+	public static JRLineBox copyBordersNoPadding(JRLineBox box, boolean keepLeft, boolean keepRight, boolean keepTop, boolean keepBottom, JRLineBox complementaryBox)
 	{
 		JRLineBox clone = box.clone(box.getBoxContainer());
 		
+		clone.setTopPadding(0);
+		clone.setLeftPadding(0);
+		clone.setBottomPadding(0);
+		clone.setRightPadding(0);
+		
 		//FIXMEBORDER does not copy padding correctly, if we only test line width
 		if (!keepLeft || box.getLeftPen().getLineWidth().floatValue() <= 0f)
 		{
@@ -50,7 +57,7 @@ public final class JRBoxUtil
 			{
 				clone.getLeftPen().setLineWidth(complementaryBox.getLeftPen().getLineWidth());
 				clone.getLeftPen().setLineColor(complementaryBox.getLeftPen().getLineColor());
-				clone.setLeftPadding(complementaryBox.getLeftPadding());
+				//clone.setLeftPadding(complementaryBox.getLeftPadding());
 			}
 			else
 			{
@@ -64,7 +71,7 @@ public final class JRBoxUtil
 			{
 				clone.getRightPen().setLineWidth(complementaryBox.getRightPen().getLineWidth());
 				clone.getRightPen().setLineColor(complementaryBox.getRightPen().getLineColor());
-				clone.setRightPadding(complementaryBox.getRightPadding());
+				//clone.setRightPadding(complementaryBox.getRightPadding());
 			}
 			else
 			{
@@ -78,7 +85,7 @@ public final class JRBoxUtil
 			{
 				clone.getTopPen().setLineWidth(complementaryBox.getTopPen().getLineWidth());
 				clone.getTopPen().setLineColor(complementaryBox.getTopPen().getLineColor());
-				clone.setTopPadding(complementaryBox.getTopPadding());
+				//clone.setTopPadding(complementaryBox.getTopPadding());
 			}
 			else
 			{
@@ -92,7 +99,7 @@ public final class JRBoxUtil
 			{
 				clone.getBottomPen().setLineWidth(complementaryBox.getBottomPen().getLineWidth());
 				clone.getBottomPen().setLineColor(complementaryBox.getBottomPen().getLineColor());
-				clone.setBottomPadding(complementaryBox.getBottomPadding());
+				//clone.setBottomPadding(complementaryBox.getBottomPadding());
 			}
 			else
 			{
@@ -173,6 +180,81 @@ public final class JRBoxUtil
 	}
 	
 
+	/**
+	 * 
+	 */
+	public static void rotate(JRLineBox box, RotationEnum rotation)
+	{
+		switch (rotation)
+		{
+			case LEFT : 
+			{
+				JRBoxPen topPen = box.getTopPen();
+				Integer topPadding = box.getTopPadding();
+				
+				box.copyTopPen(box.getLeftPen());
+				box.setTopPadding(box.getLeftPadding());
+
+				box.copyLeftPen(box.getBottomPen());
+				box.setLeftPadding(box.getBottomPadding());
+				
+				box.copyBottomPen(box.getRightPen());
+				box.setBottomPadding(box.getRightPadding());
+				
+				box.copyRightPen(topPen);
+				box.setRightPadding(topPadding);
+
+				break;
+			}
+			case RIGHT : 
+			{
+				JRBoxPen topPen = box.getTopPen();
+				Integer topPadding = box.getTopPadding();
+				
+				box.copyTopPen(box.getRightPen());
+				box.setTopPadding(box.getRightPadding());
+
+				box.copyRightPen(box.getBottomPen());
+				box.setRightPadding(box.getBottomPadding());
+
+				box.copyBottomPen(box.getLeftPen());
+				box.setBottomPadding(box.getLeftPadding());
+
+				box.copyLeftPen(topPen);
+				box.setLeftPadding(topPadding);
+				
+				break;
+			}
+			case UPSIDE_DOWN : 
+			{
+				JRBoxPen topPen = box.getTopPen();
+				Integer topPadding = box.getTopPadding();
+				
+				box.copyTopPen(box.getBottomPen());
+				box.setTopPadding(box.getBottomPadding());
+
+				box.copyBottomPen(topPen);
+				box.setBottomPadding(topPadding);
+				
+				JRBoxPen leftPen = box.getLeftPen();
+				Integer leftPadding = box.getLeftPadding();
+				
+				box.copyLeftPen(box.getRightPen());
+				box.setLeftPadding(box.getRightPadding());
+
+				box.copyRightPen(leftPen);
+				box.setRightPadding(leftPadding);
+
+				break;
+			}
+			case NONE :
+			default :
+			{
+			}
+		}
+	}
+	
+
 	/**
 	 * 
 	 */
