@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -44,7 +44,7 @@ import org.apache.commons.logging.LogFactory;
  *  <p/>
  * @see org.apache.commons.beanutils.locale.converters.DateLocaleConverter
  * @author szaharia
- * @version $Id: JRDateLocaleConverter.java 3674 2010-04-02 08:18:15Z shertage $
+ * @version $Id: JRDateLocaleConverter.java 4595 2011-09-08 15:55:10Z teodord $
  */
 
 public class JRDateLocaleConverter extends DateLocaleConverter 
@@ -53,7 +53,7 @@ public class JRDateLocaleConverter extends DateLocaleConverter
 	private static Log log = LogFactory.getLog(DateLocaleConverter.class);
 	
 	// holds the timezone's ID
-	private TimeZone timeZone = null;
+	private TimeZone timeZone;
 
 
 	/**
