@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -53,7 +53,7 @@ import net.sf.jasperreports.engine.JRRuntimeException;
  * </p> 
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRProperties.java 3712 2010-04-08 09:53:09Z teodord $
+ * @version $Id: JRProperties.java 4750 2011-10-27 07:09:22Z lucianc $
  */
 public final class JRProperties
 {
@@ -131,16 +131,6 @@ public final class JRProperties
 	 */
 	public static final String QUERY_EXECUTER_FACTORY_PREFIX = PROPERTY_PREFIX + "query.executer.factory.";
 	
-	/**
-	 * @deprecated Replaced by {@link net.sf.jasperreports.engine.fill.JRSubreportRunnerFactory#SUBREPORT_RUNNER_FACTORY}.
-	 */
-	public static final String SUBREPORT_RUNNER_FACTORY = PROPERTY_PREFIX + "subreport.runner.factory";
-	
-	/**
-	 * @deprecated Replaced by {@link net.sf.jasperreports.engine.export.JRPdfExporterParameter#PROPERTY_FORCE_LINEBREAK_POLICY}.
-	 */
-	public static final String PDF_FORCE_LINEBREAK_POLICY = PROPERTY_PREFIX + "export.pdf.force.linebreak.policy";
-	
 	protected static Properties props;
 	
 	protected static Properties savedProps;
@@ -512,13 +502,13 @@ public final class JRProperties
 	 * @param prefix the key prefix
 	 * @return a list of {@link PropertySuffix PropertySuffix} objects containing the suffix of the key and the value
 	 */
-	public static List getProperties (String prefix)
+	public static List<PropertySuffix> getProperties (String prefix)
 	{
 		int prefixLength = prefix.length();
-		List values = new ArrayList();
-		for (Enumeration names = props.propertyNames(); names.hasMoreElements();)
+		List<PropertySuffix> values = new ArrayList<PropertySuffix>();
+		for (Enumeration<String> names = (Enumeration<String>)props.propertyNames(); names.hasMoreElements();)
 		{
-			String name = (String) names.nextElement();
+			String name = names.nextElement();
 			if (name.startsWith(prefix))
 			{
 				String suffix = name.substring(prefixLength);
@@ -540,7 +530,7 @@ public final class JRProperties
 	 * @return a list of {@link PropertySuffix PropertySuffix} objects containing the suffix of the key and the value
 	 * @see #getAllProperties(JRPropertiesHolder, String)
 	 */
-	public static List getProperties(JRPropertiesHolder propertiesHolder, String prefix)
+	public static List<PropertySuffix> getProperties(JRPropertiesHolder propertiesHolder, String prefix)
 	{
 		return getProperties(getOwnProperties(propertiesHolder), prefix);
 	}
@@ -554,7 +544,7 @@ public final class JRProperties
 	 * @return a list of {@link PropertySuffix PropertySuffix} objects containing the suffix of the key and the value
 	 * @see #getProperties(JRPropertiesHolder, String)
 	 */
-	public static List getAllProperties(JRPropertiesHolder propertiesHolder, String prefix)
+	public static List<PropertySuffix> getAllProperties(JRPropertiesHolder propertiesHolder, String prefix)
 	{
 		return getAllProperties(getOwnProperties(propertiesHolder), prefix);
 	}
@@ -570,10 +560,10 @@ public final class JRProperties
 	 * @return a list of {@link PropertySuffix PropertySuffix} objects containing the suffix of the key and the value
 	 * @see #getAllProperties(JRPropertiesMap, String)
 	 */
-	public static List getProperties(JRPropertiesMap propertiesMap, String prefix)
+	public static List<PropertySuffix> getProperties(JRPropertiesMap propertiesMap, String prefix)
 	{
 		int prefixLength = prefix.length();
-		List values = new ArrayList();
+		List<PropertySuffix> values = new ArrayList<PropertySuffix>();
 		if (propertiesMap != null)
 		{
 			String[] propertyNames = propertiesMap.getPropertyNames();
@@ -600,11 +590,11 @@ public final class JRProperties
 	 * @return a list of {@link PropertySuffix PropertySuffix} objects containing the suffix of the key and the value
 	 * @see #getProperties(JRPropertiesMap, String)
 	 */
-	public static List getAllProperties(JRPropertiesMap propertiesMap, String prefix)
+	public static List<PropertySuffix> getAllProperties(JRPropertiesMap propertiesMap, String prefix)
 	{
-		List own = getProperties(propertiesMap, prefix);
-		List global = getProperties(prefix);
-		List collected;
+		List<PropertySuffix> own = getProperties(propertiesMap, prefix);
+		List<PropertySuffix> global = getProperties(prefix);
+		List<PropertySuffix> collected;
 		if (own.isEmpty())
 		{
 			collected = global;
@@ -613,16 +603,16 @@ public final class JRProperties
 		{
 			if (!global.isEmpty())
 			{
-				Set ownSuffixes = new HashSet();
-				for (Iterator it = own.iterator(); it.hasNext();)
+				Set<String> ownSuffixes = new HashSet<String>();
+				for (Iterator<PropertySuffix> it = own.iterator(); it.hasNext();)
 				{
-					PropertySuffix prop = (PropertySuffix) it.next();
+					PropertySuffix prop = it.next();
 					ownSuffixes.add(prop.getSuffix());
 				}
 				
-				for (Iterator it = global.iterator(); it.hasNext();)
+				for (Iterator<PropertySuffix> it = global.iterator(); it.hasNext();)
 				{
-					PropertySuffix prop = (PropertySuffix) it.next();
+					PropertySuffix prop = it.next();
 					if (!ownSuffixes.contains(prop.getSuffix()))
 					{
 						own.add(prop);
@@ -662,6 +652,42 @@ public final class JRProperties
 		
 		return value;
 	}
+
+	/**
+	 * Returns the value of a property, looking for it in several properties holders
+	 * and then in the system properties.
+	 * 
+	 * @param key the key
+	 * @param propertiesHolders the properties holders
+	 * @return the property value
+	 */
+	public static String getProperty (String key, JRPropertiesHolder ... propertiesHolders)
+	{
+		String value = null;
+		main: for (JRPropertiesHolder propertiesHolder : propertiesHolders)
+		{
+			while (propertiesHolder != null)
+			{
+				if (propertiesHolder.hasProperties())
+				{
+					String prop = propertiesHolder.getPropertiesMap().getProperty(key);
+					if (prop != null)
+					{
+						value = prop;
+						break main;
+					}
+				}
+				propertiesHolder = propertiesHolder.getParentProperties();
+			}
+		}
+		
+		if (value == null)
+		{
+			value = props.getProperty(key);
+		}
+		
+		return value;
+	}
 	
 	/**
 	 * Returns the value of a property, looking first in the supplied properties map
@@ -918,17 +944,17 @@ public final class JRProperties
 	protected static void transfer(JRPropertiesMap source,
 			JRPropertiesHolder destination, String tranferPropertiesPrefix)
 	{
-		List transferPrefixProps = getProperties(tranferPropertiesPrefix);
-		for (Iterator prefixIt = transferPrefixProps.iterator(); prefixIt.hasNext();)
+		List<PropertySuffix> transferPrefixProps = getProperties(tranferPropertiesPrefix);
+		for (Iterator<PropertySuffix> prefixIt = transferPrefixProps.iterator(); prefixIt.hasNext();)
 		{
-			JRProperties.PropertySuffix transferPrefixProp = (JRProperties.PropertySuffix) prefixIt.next();
+			JRProperties.PropertySuffix transferPrefixProp = prefixIt.next();
 			String transferPrefix = transferPrefixProp.getValue();
 			if (transferPrefix != null && transferPrefix.length() > 0)
 			{
-				List transferProps = getProperties(source, transferPrefix);
-				for (Iterator propIt = transferProps.iterator(); propIt.hasNext();)
+				List<PropertySuffix> transferProps = getProperties(source, transferPrefix);
+				for (Iterator<PropertySuffix> propIt = transferProps.iterator(); propIt.hasNext();)
 				{
-					JRProperties.PropertySuffix property = (JRProperties.PropertySuffix) propIt.next();
+					JRProperties.PropertySuffix property = propIt.next();
 					String value = property.getValue();
 					destination.getPropertiesMap().setProperty(property.getKey(), value);
 				}
