@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -37,7 +37,7 @@ import java.util.ResourceBundle;
  * Provides methods for resource resolution via class loaders or URL stream handlers.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRResourcesUtil.java 3717 2010-04-09 10:01:33Z teodord $
+ * @version $Id: JRResourcesUtil.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public final class JRResourcesUtil
 {
@@ -455,8 +455,9 @@ public final class JRResourcesUtil
 	 * @param clsLoader a class loader
 	 * @param clazz a class
 	 * @return the resource URL if found
+	 * @deprecated Replaced by {@link #findClassLoaderResource(String, ClassLoader)}.
 	 */
-	public static URL findClassLoaderResource(String location, ClassLoader clsLoader, Class clazz)
+	public static URL findClassLoaderResource(String location, ClassLoader clsLoader, Class<?> clazz)
 	{
 		ClassLoader classLoader = getClassLoader(clsLoader);
 		
@@ -493,6 +494,58 @@ public final class JRResourcesUtil
 		return url;
 	}
 
+	/**
+	 * Attempts to find a resource using a class loader.
+	 * <p/>
+	 * The following sources are tried:
+	 * <ul>
+	 * 	<li>the class loader returned by {@link #getClassLoader(ClassLoader) <code>getClassLoader(classLoader)</code>}</li>
+	 * 	<li>the context class loader</li>
+	 * 	<li><code>JRLoader.class.getClassLoader()</code></li>
+	 * 	<li><code>JRLoader.class.getResource()</code></li>
+	 * </ul>
+	 * 
+	 * @param location the resource name
+	 * @param clsLoader a class loader
+	 * @return the resource URL if found
+	 */
+	public static URL findClassLoaderResource(String location, ClassLoader clsLoader)
+	{
+		ClassLoader classLoader = getClassLoader(clsLoader);
+		
+		URL url = null;
+		
+		if (classLoader != null)
+		{
+			url = classLoader.getResource(location);
+		}
+		
+		if (url == null)
+		{
+			classLoader = Thread.currentThread().getContextClassLoader();
+
+			if (classLoader != null)
+			{
+				url = classLoader.getResource(location);
+			}
+
+			if (url == null)
+			{
+				classLoader = JRLoader.class.getClassLoader();
+				if (classLoader == null)
+				{
+					url = JRLoader.class.getResource("/" + location);
+				}
+				else
+				{
+					url = classLoader.getResource(location);
+				}
+			}
+		}
+		
+		return url;
+	}
+
 	/**
 	 * Loads a resource bundle for a given base name and locale.
 	 * 
