@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -40,13 +40,13 @@ import net.sf.jasperreports.engine.JRCommonRectangle;
 import net.sf.jasperreports.engine.JRCommonText;
 import net.sf.jasperreports.engine.JRDefaultStyleProvider;
 import net.sf.jasperreports.engine.JRFont;
-import net.sf.jasperreports.engine.JRImage;
 import net.sf.jasperreports.engine.JRLineBox;
+import net.sf.jasperreports.engine.JRParagraph;
 import net.sf.jasperreports.engine.JRPen;
-import net.sf.jasperreports.engine.JRReportFont;
 import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.JRStyleContainer;
 import net.sf.jasperreports.engine.JRTextField;
+import net.sf.jasperreports.engine.TabStop;
 import net.sf.jasperreports.engine.base.JRBoxPen;
 import net.sf.jasperreports.engine.type.FillEnum;
 import net.sf.jasperreports.engine.type.HorizontalAlignEnum;
@@ -60,7 +60,7 @@ import net.sf.jasperreports.engine.type.VerticalAlignEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRStyleResolver.java 4004 2010-10-25 06:49:40Z teodord $
+ * @version $Id: JRStyleResolver.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public final class JRStyleResolver
 {
@@ -70,25 +70,7 @@ public final class JRStyleResolver
 	/**
 	 *
 	 */
-	private static JRFont getBaseFont(JRFont font)
-	{
-		JRReportFont reportFont = font.getReportFont();
-		if (reportFont != null)
-		{
-			return reportFont;
-		}
-		JRDefaultStyleProvider defaultStyleProvider = font.getDefaultStyleProvider();
-		if (defaultStyleProvider != null)
-		{
-			return defaultStyleProvider.getDefaultFont();
-		}
-		return null;
-	}
-	
-	/**
-	 *
-	 */
-	private static JRStyle getBaseStyle(JRStyleContainer styleContainer)
+	public static JRStyle getBaseStyle(JRStyleContainer styleContainer)
 	{
 		if (styleContainer != null)
 		{
@@ -107,23 +89,6 @@ public final class JRStyleResolver
 	}
 
 
-	/**
-	 * @deprecated Replaced by {@link #getMode(JRCommonElement, ModeEnum)}.
-	 */
-	public static byte getMode(JRCommonElement element, byte defaultMode)
-	{
-		return getMode(element, ModeEnum.getByValue(defaultMode)).getValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getModeValue(JRStyle)}.
-	 */
-	public static Byte getMode(JRStyle style)
-	{
-		ModeEnum mode = getModeValue(style);
-		return mode == null ? null : mode.getValueByte();
-	}
-
 	/**
 	 *
 	 */
@@ -324,14 +289,6 @@ public final class JRStyleResolver
 		return defaultLineWidth;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getLineStyleValue(JRPen)}.
-	 */
-	public static Byte getLineStyle(JRPen pen)
-	{
-		return getLineStyleValue(pen).getValueByte();
-	}
-
 	/**
 	 *
 	 */
@@ -354,14 +311,6 @@ public final class JRStyleResolver
 		return LineStyleEnum.SOLID;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getLineStyleValue(JRBoxPen)}
-	 */
-	public static Byte getLineStyle(JRBoxPen boxPen)
-	{
-		return getLineStyleValue(boxPen).getValueByte();
-	}
-
 	/**
 	 *
 	 */
@@ -438,22 +387,6 @@ public final class JRStyleResolver
 		return defaultColor;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getFillValue(JRCommonGraphicElement)}.
-	 */
-	public static byte getFill(JRCommonGraphicElement element)
-	{
-		return getFillValue(element).getValue();
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getFillValue(JRStyle)}.
-	 */
-	public static Byte getFill(JRStyle style)
-	{
-		return getFillValue(style).getValueByte();
-	}
-
 	/**
 	 *
 	 */
@@ -534,46 +467,6 @@ public final class JRStyleResolver
 		return null;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getScaleImageValue(JRCommonImage)}
-	 */
-	public static byte getScaleImage(JRCommonImage image)
-	{
-		Byte ownScaleImage = image.getOwnScaleImage();
-		if (ownScaleImage != null)
-		{
-			return ownScaleImage.byteValue();
-		}
-		JRStyle baseStyle = getBaseStyle(image);
-		if (baseStyle != null)
-		{
-			Byte scaleImage = baseStyle.getScaleImage();
-			if (scaleImage != null)
-			{
-				return scaleImage.byteValue();
-			}
-		}
-		return JRImage.SCALE_IMAGE_RETAIN_SHAPE;
-	}
-
-	/**
-	 * @deprecated Replaced by {@link #getScaleImageValue(JRStyle)}
-	 */
-	public static Byte getScaleImage(JRStyle style)
-	{
-		Byte ownScaleImage = style.getOwnScaleImage();
-		if (ownScaleImage != null)
-		{
-			return ownScaleImage;
-		}
-		JRStyle baseStyle = getBaseStyle(style);
-		if (baseStyle != null )
-		{
-			return baseStyle.getScaleImage();
-		}
-		return null;
-	}
-
 	/**
 	 *
 	 */
@@ -614,14 +507,6 @@ public final class JRStyleResolver
 		return null;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getHorizontalAlignmentValue(JRAlignment)}.
-	 */
-	public static byte getHorizontalAlignment(JRAlignment alignment)
-	{
-		return getHorizontalAlignmentValue(alignment).getValue();
-	}
-
 	/**
 	 *
 	 */
@@ -644,15 +529,6 @@ public final class JRStyleResolver
 		return HorizontalAlignEnum.LEFT;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getHorizontalAlignmentValue(JRStyle)}.
-	 */
-	public static Byte getHorizontalAlignment(JRStyle style)
-	{
-		HorizontalAlignEnum horizontalAlign = getHorizontalAlignmentValue(style); 
-		return horizontalAlign == null ? null : horizontalAlign.getValueByte();
-	}
-
 	/**
 	 *
 	 */
@@ -671,14 +547,6 @@ public final class JRStyleResolver
 		return null;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getVerticalAlignmentValue(JRAlignment)}.
-	 */
-	public static byte getVerticalAlignment(JRAlignment alignment)
-	{
-		return getVerticalAlignmentValue(alignment).getValue();
-	}
-
 	/**
 	 *
 	 */
@@ -729,20 +597,179 @@ public final class JRStyleResolver
 	}
 
 	/**
-	 * @deprecated Replaced by {@link #getRotationValue(JRCommonText)}.
+	 *
 	 */
-	public static byte getRotation(JRCommonText element)
+	public static Float getLineSpacingSize(JRParagraph paragraph)
 	{
-		return getRotationValue(element).getValue();
+		Float ownLineSpacingSize = paragraph.getOwnLineSpacingSize();
+		if (ownLineSpacingSize != null)
+		{
+			return ownLineSpacingSize;
+		}
+		JRStyle style = getBaseStyle(paragraph);
+		if (style != null)
+		{
+			Float lineSpacingSize = style.getParagraph().getLineSpacingSize();
+			if (lineSpacingSize != null)
+			{
+				return lineSpacingSize;
+			}
+		}
+		return JRProperties.getFloatProperty(JRParagraph.DEFAULT_LINE_SPACING_SIZE);
 	}
 
 	/**
-	 * @deprecated Replaced by {@link #getRotationValue(JRStyle)}.
+	 *
 	 */
-	public static Byte getRotation(JRStyle style)
+	public static Integer getFirstLineIndent(JRParagraph paragraph)
 	{
-		RotationEnum rotation = getRotationValue(style);
-		return rotation == null ? null : rotation.getValueByte();
+		Integer ownFirstLineIndent = paragraph.getOwnFirstLineIndent();
+		if (ownFirstLineIndent != null)
+		{
+			return ownFirstLineIndent;
+		}
+		JRStyle style = getBaseStyle(paragraph);
+		if (style != null)
+		{
+			Integer firstLineIndent = style.getParagraph().getFirstLineIndent();
+			if (firstLineIndent != null)
+			{
+				return firstLineIndent;
+			}
+		}
+		return JRProperties.getIntegerProperty(JRParagraph.DEFAULT_FIRST_LINE_INDENT);
+	}
+
+	/**
+	 *
+	 */
+	public static Integer getLeftIndent(JRParagraph paragraph)
+	{
+		Integer ownLeftIndent = paragraph.getOwnLeftIndent();
+		if (ownLeftIndent != null)
+		{
+			return ownLeftIndent;
+		}
+		JRStyle style = getBaseStyle(paragraph);
+		if (style != null)
+		{
+			Integer leftIndent = style.getParagraph().getLeftIndent();
+			if (leftIndent != null)
+			{
+				return leftIndent;
+			}
+		}
+		return JRProperties.getIntegerProperty(JRParagraph.DEFAULT_LEFT_INDENT);
+	}
+
+	/**
+	 *
+	 */
+	public static Integer getRightIndent(JRParagraph paragraph)
+	{
+		Integer ownRightIndent = paragraph.getOwnRightIndent();
+		if (ownRightIndent != null)
+		{
+			return ownRightIndent;
+		}
+		JRStyle style = getBaseStyle(paragraph);
+		if (style != null)
+		{
+			Integer rightIndent = style.getParagraph().getRightIndent();
+			if (rightIndent != null)
+			{
+				return rightIndent;
+			}
+		}
+		return JRProperties.getIntegerProperty(JRParagraph.DEFAULT_RIGHT_INDENT);
+	}
+
+	/**
+	 *
+	 */
+	public static Integer getSpacingBefore(JRParagraph paragraph)
+	{
+		Integer ownSpacingBefore = paragraph.getOwnSpacingBefore();
+		if (ownSpacingBefore != null)
+		{
+			return ownSpacingBefore;
+		}
+		JRStyle style = getBaseStyle(paragraph);
+		if (style != null)
+		{
+			Integer spacingBefore = style.getParagraph().getSpacingBefore();
+			if (spacingBefore != null)
+			{
+				return spacingBefore;
+			}
+		}
+		return JRProperties.getIntegerProperty(JRParagraph.DEFAULT_SPACING_BEFORE);
+	}
+
+	/**
+	 *
+	 */
+	public static Integer getSpacingAfter(JRParagraph paragraph)
+	{
+		Integer ownSpacingAfter = paragraph.getOwnSpacingAfter();
+		if (ownSpacingAfter != null)
+		{
+			return ownSpacingAfter;
+		}
+		JRStyle style = getBaseStyle(paragraph);
+		if (style != null)
+		{
+			Integer spacingAfter = style.getParagraph().getSpacingAfter();
+			if (spacingAfter != null)
+			{
+				return spacingAfter;
+			}
+		}
+		return JRProperties.getIntegerProperty(JRParagraph.DEFAULT_SPACING_AFTER);
+	}
+
+	/**
+	 *
+	 */
+	public static Integer getTabStopWidth(JRParagraph paragraph)
+	{
+		Integer ownTabStopWidth = paragraph.getOwnTabStopWidth();
+		if (ownTabStopWidth != null)
+		{
+			return ownTabStopWidth;
+		}
+		JRStyle style = getBaseStyle(paragraph);
+		if (style != null)
+		{
+			Integer tabStopWidth = style.getParagraph().getTabStopWidth();
+			if (tabStopWidth != null)
+			{
+				return tabStopWidth;
+			}
+		}
+		return JRProperties.getIntegerProperty(JRParagraph.DEFAULT_TAB_STOP_WIDTH);
+	}
+
+	/**
+	 *
+	 */
+	public static TabStop[] getTabStops(JRParagraph paragraph)
+	{
+		TabStop[] ownTabStops = paragraph.getOwnTabStops();
+		if (ownTabStops != null)
+		{
+			return ownTabStops;
+		}
+		JRStyle style = getBaseStyle(paragraph);
+		if (style != null)
+		{
+			TabStop[] tabStops = style.getParagraph().getTabStops();
+			if (tabStops != null)
+			{
+				return tabStops;
+			}
+		}
+		return null;
 	}
 
 	/**
@@ -786,60 +813,41 @@ public final class JRStyleResolver
 	}
 
 	/**
-	 * @deprecated Replaced by {@link #getLineSpacingValue(JRCommonText)}.
+	 * @deprecated Replaced by {@link #getLineSpacing(JRParagraph)}.
 	 */
-	public static byte getLineSpacing(JRCommonText element)
+	public static LineSpacingEnum getLineSpacingValue(JRCommonText element)
 	{
-		return getLineSpacingValue(element).getValue();
+		return getLineSpacing(element.getParagraph());
 	}
 
 	/**
-	 * @deprecated Replaced by {@link #getLineSpacingValue(JRStyle)}.
+	 * @deprecated Replaced by {@link #getLineSpacing(JRParagraph)}.
 	 */
-	public static Byte getLineSpacing(JRStyle style)
+	public static LineSpacingEnum getLineSpacingValue(JRStyle style)
 	{
-		LineSpacingEnum lineSpacing = getLineSpacingValue(style);
-		return lineSpacing == null ? null : lineSpacing.getValueByte();
+		return getLineSpacing(style.getParagraph());
 	}
 
 	/**
 	 * 
 	 */
-	public static LineSpacingEnum getLineSpacingValue(JRCommonText element)
+	public static LineSpacingEnum getLineSpacing(JRParagraph paragraph)
 	{
-		LineSpacingEnum ownLineSpacing = element.getOwnLineSpacingValue();
+		LineSpacingEnum ownLineSpacing = paragraph.getOwnLineSpacing();
 		if (ownLineSpacing != null)
 		{
 			return ownLineSpacing;
 		}
-		JRStyle baseStyle = getBaseStyle(element);
+		JRStyle baseStyle = getBaseStyle(paragraph);
 		if (baseStyle != null)
 		{
-			LineSpacingEnum lineSpacing = baseStyle.getLineSpacingValue();
+			LineSpacingEnum lineSpacing = baseStyle.getParagraph().getLineSpacing();
 			if (lineSpacing != null)
 			{
 				return lineSpacing;
 			}
 		}
-		return LineSpacingEnum.SINGLE;
-	}
-
-	/**
-	 * 
-	 */
-	public static LineSpacingEnum getLineSpacingValue(JRStyle style)
-	{
-		LineSpacingEnum ownLineSpacing = style.getOwnLineSpacingValue();
-		if (ownLineSpacing != null)
-		{
-			return ownLineSpacing;
-		}
-		JRStyle baseStyle = getBaseStyle(style);
-		if (baseStyle != null)
-		{
-			return baseStyle.getLineSpacingValue();
-		}
-		return null;
+		return LineSpacingEnum.SINGLE;//FIXMENOW could we make all enums in default props?
 	}
 
 	/**
@@ -968,15 +976,6 @@ public final class JRStyleResolver
 		{
 			return ownFontName;
 		}
-		JRFont baseFont = getBaseFont(font);
-		if (baseFont != null)
-		{
-			String fontName = baseFont.getFontName();
-			if (fontName != null)
-			{
-				return fontName;
-			}
-		}
 		JRStyle baseStyle = getBaseStyle(font);
 		if (baseStyle != null)
 		{
@@ -1021,11 +1020,6 @@ public final class JRStyleResolver
 		{
 			return ownBold.booleanValue();
 		}
-		JRFont baseFont = getBaseFont(font);
-		if (baseFont != null)
-		{
-			return baseFont.isBold();
-		}
 		JRStyle baseStyle = getBaseStyle(font);
 		if (baseStyle != null)
 		{
@@ -1066,11 +1060,6 @@ public final class JRStyleResolver
 		{
 			return ownItalic.booleanValue();
 		}
-		JRFont baseFont = getBaseFont(font);
-		if (baseFont != null)
-		{
-			return baseFont.isItalic();
-		}
 		JRStyle baseStyle = getBaseStyle(font);
 		if (baseStyle != null)
 		{
@@ -1111,11 +1100,6 @@ public final class JRStyleResolver
 		{
 			return ownUnderline.booleanValue();
 		}
-		JRFont baseFont = getBaseFont(font);
-		if (baseFont != null)
-		{
-			return baseFont.isUnderline();
-		}
 		JRStyle baseStyle = getBaseStyle(font);
 		if (baseStyle != null)
 		{
@@ -1156,11 +1140,6 @@ public final class JRStyleResolver
 		{
 			return ownStrikeThrough.booleanValue();
 		}
-		JRFont baseFont = getBaseFont(font);
-		if (baseFont != null)
-		{
-			return baseFont.isStrikeThrough();
-		}
 		JRStyle baseStyle = getBaseStyle(font);
 		if (baseStyle != null)
 		{
@@ -1200,11 +1179,6 @@ public final class JRStyleResolver
 		{
 			return ownFontSize.intValue();
 		}
-		JRFont baseFont = getBaseFont(font);
-		if (baseFont != null)
-		{
-			return baseFont.getFontSize();
-		}
 		JRStyle baseStyle = getBaseStyle(font);
 		if (baseStyle != null)
 		{
@@ -1245,15 +1219,6 @@ public final class JRStyleResolver
 		{
 			return ownPdfFontName;
 		}
-		JRFont baseFont = getBaseFont(font);
-		if (baseFont != null)
-		{
-			String pdfFontName = baseFont.getPdfFontName();
-			if (pdfFontName != null)
-			{
-				return pdfFontName;
-			}
-		}
 		JRStyle baseStyle = getBaseStyle(font);
 		if (baseStyle != null)
 		{
@@ -1298,15 +1263,6 @@ public final class JRStyleResolver
 		{
 			return ownPdfEncoding;
 		}
-		JRFont baseFont = getBaseFont(font);
-		if (baseFont != null)
-		{
-			String pdfEncoding = baseFont.getPdfEncoding();
-			if (pdfEncoding != null)
-			{
-				return pdfEncoding;
-			}
-		}
 		JRStyle baseStyle = getBaseStyle(font);
 		if (baseStyle != null)
 		{
@@ -1351,11 +1307,6 @@ public final class JRStyleResolver
 		{
 			return ownPdfEmbedded.booleanValue();
 		}
-		JRFont baseFont = getBaseFont(font);
-		if (baseFont != null)
-		{
-			return baseFont.isPdfEmbedded();
-		}
 		JRStyle baseStyle = getBaseStyle(font);
 		if (baseStyle != null)
 		{
@@ -1557,15 +1508,12 @@ public final class JRStyleResolver
 			destStyle.setVerticalAlignment(srcStyle.getOwnVerticalAlignmentValue());
 		}
 		appendBox(destStyle.getLineBox(), srcStyle.getLineBox());
+		appendParagraph(destStyle.getParagraph(), srcStyle.getParagraph());
 
 		if (srcStyle.getOwnRotationValue() != null)
 		{
 			destStyle.setRotation(srcStyle.getOwnRotationValue());
 		}
-		if (srcStyle.getOwnLineSpacingValue() != null)
-		{
-			destStyle.setLineSpacing(srcStyle.getOwnLineSpacingValue());
-		}
 		if (srcStyle.getOwnMarkup() != null)
 		{
 			destStyle.setMarkup(srcStyle.getOwnMarkup());
@@ -1664,6 +1612,37 @@ public final class JRStyleResolver
 		}
 	}
 
+	/**
+	 * Merges two paragraphs, by appending the properties of the source paragraph to the ones of the destination paragraph.
+	 */
+	private static void appendParagraph(JRParagraph destParagraph, JRParagraph srcParagraph)
+	{
+		if (srcParagraph.getOwnLineSpacing() != null)
+		{
+			destParagraph.setLineSpacing(srcParagraph.getOwnLineSpacing());
+		}
+		if (srcParagraph.getOwnLeftIndent() != null)
+		{
+			destParagraph.setLeftIndent(srcParagraph.getOwnLeftIndent());
+		}
+		if (srcParagraph.getOwnRightIndent() != null)
+		{
+			destParagraph.setRightIndent(srcParagraph.getOwnRightIndent());
+		}
+		if (srcParagraph.getOwnSpacingBefore() != null)
+		{
+			destParagraph.setSpacingBefore(srcParagraph.getOwnSpacingBefore());
+		}
+		if (srcParagraph.getOwnSpacingAfter() != null)
+		{
+			destParagraph.setSpacingAfter(srcParagraph.getOwnSpacingAfter());
+		}
+		if (srcParagraph.getOwnTabStopWidth() != null)
+		{
+			destParagraph.setTabStopWidth(srcParagraph.getOwnTabStopWidth());
+		}
+	}
+
 	/**
 	 *
 	 */
