@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -28,6 +28,7 @@ import java.awt.font.TextAttribute;
 import java.awt.geom.AffineTransform;
 import java.text.AttributedCharacterIterator;
 import java.text.AttributedString;
+import java.text.AttributedCharacterIterator.Attribute;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -42,7 +43,7 @@ import net.sf.jasperreports.engine.JRRuntimeException;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRStyledText.java 3939 2010-08-20 09:52:00Z teodord $
+ * @version $Id: JRStyledText.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRStyledText implements Cloneable
 {
@@ -57,7 +58,7 @@ public class JRStyledText implements Cloneable
 		System.getProperty("java.version").startsWith("1.6") 
 		&& JRProperties.getBooleanProperty(PROPERTY_AWT_SUPERSCRIPT_FIX_ENABLED);
 	
-	private static final Set FONT_ATTRS = new HashSet();
+	private static final Set<Attribute> FONT_ATTRS = new HashSet<Attribute>();
 	static
 	{
 		FONT_ATTRS.add(TextAttribute.FAMILY);
@@ -71,10 +72,10 @@ public class JRStyledText implements Cloneable
 	 *
 	 */
 	private StringBuffer sbuffer = new StringBuffer();
-	private List runs = new ArrayList();
+	private List<Run> runs = new ArrayList<Run>();
 	private AttributedString attributedString;
 	private AttributedString awtAttributedString;
-	private Map globalAttributes;
+	private Map<Attribute,Object> globalAttributes;
 	private Locale locale;
 
 	
@@ -151,7 +152,7 @@ public class JRStyledText implements Cloneable
 
 			for(int i = runs.size() - 1; i >= 0; i--)
 			{
-				Run run = (Run)runs.get(i);
+				Run run = runs.get(i);
 				if (run.startIndex != run.endIndex && run.attributes != null)
 				{
 					attributedString.addAttributes(run.attributes, run.startIndex, run.endIndex);
@@ -163,12 +164,7 @@ public class JRStyledText implements Cloneable
 	}
 
 	/**
-	 * Returns an attributed string that only contains standard Java text
-	 * attributes; JasperReports specific text attributes of the styled text
-	 * are ignored.
-	 * 
-	 * @return an attributed string that only contains standard Java text
-	 * attributes
+	 * Returns an attributed string that contains the AWT font attribute, as the font is actually loaded.
 	 */
 	public AttributedString getAwtAttributedString(boolean ignoreMissingFont)
 	{
@@ -178,25 +174,29 @@ public class JRStyledText implements Cloneable
 
 			for(int i = runs.size() - 1; i >= 0; i--)
 			{
-				Run run = (Run)runs.get(i);
-				if (
-					run.startIndex != run.endIndex 
-					&& run.attributes != null 
-					&& !run.attributes.isEmpty()
-					)
+				Run run = runs.get(i);
+				if (run.startIndex != run.endIndex && run.attributes != null)
 				{
-					for (Iterator it = run.attributes.entrySet().iterator(); it.hasNext();)
-					{
-						Map.Entry entry = (Map.Entry) it.next();
-						AttributedCharacterIterator.Attribute attribute = 
-							(AttributedCharacterIterator.Attribute) entry.getKey();
-						if (!(attribute instanceof JRTextAttribute))
-						{
-							Object value = entry.getValue();
-							awtAttributedString.addAttribute(attribute, value, run.startIndex, run.endIndex);
-						}
-					}
+					awtAttributedString.addAttributes(run.attributes, run.startIndex, run.endIndex);
 				}
+//				if (
+//					run.startIndex != run.endIndex 
+//					&& run.attributes != null 
+//					&& !run.attributes.isEmpty()
+//					)
+//				{
+//					for (Iterator it = run.attributes.entrySet().iterator(); it.hasNext();)
+//					{
+//						Map.Entry entry = (Map.Entry) it.next();
+//						AttributedCharacterIterator.Attribute attribute = 
+//							(AttributedCharacterIterator.Attribute) entry.getKey();
+//						if (!(attribute instanceof JRTextAttribute))
+//						{
+//							Object value = entry.getValue();
+//							awtAttributedString.addAttribute(attribute, value, run.startIndex, run.endIndex);
+//						}
+//					}
+//				}
 			}
 			
 			AttributedCharacterIterator iterator = awtAttributedString.getIterator();
@@ -206,7 +206,7 @@ public class JRStyledText implements Cloneable
 
 			while(runLimit < iterator.getEndIndex() && (runLimit = iterator.getRunLimit(FONT_ATTRS)) <= iterator.getEndIndex())
 			{
-				Map attrs = iterator.getAttributes();
+				Map<Attribute,Object> attrs = iterator.getAttributes();
 					
 				String familyName = (String)attrs.get(TextAttribute.FAMILY); 
 				
@@ -265,7 +265,7 @@ public class JRStyledText implements Cloneable
 	/**
 	 *
 	 */
-	public List getRuns()
+	public List<Run> getRuns()
 	{
 		return runs;
 	}
@@ -278,14 +278,14 @@ public class JRStyledText implements Cloneable
 		/**
 		 *
 		 */
-		public Map attributes;
+		public Map<Attribute,Object> attributes;
 		public int startIndex;
 		public int endIndex;
 
 		/**
 		 *
 		 */
-		public Run(Map attributes, int startIndex, int endIndex) 
+		public Run(Map<Attribute,Object> attributes, int startIndex, int endIndex) 
 		{
 			this.attributes = attributes;
 			this.startIndex = startIndex;
@@ -318,14 +318,14 @@ public class JRStyledText implements Cloneable
 		}
 	}
 
-	public void setGlobalAttributes(Map attributes)
+	public void setGlobalAttributes(Map<Attribute,Object> attributes)
 	{
 		this.globalAttributes = attributes;
 		addRun(new Run(attributes, 0, length()));
 	}
 	
 	
-	public Map getGlobalAttributes()
+	public Map<Attribute,Object> getGlobalAttributes()
 	{
 		return globalAttributes;
 	}
@@ -336,9 +336,9 @@ public class JRStyledText implements Cloneable
 		return super.clone();
 	}
 	
-	protected static Map cloneAttributesMap(Map attributes)
+	protected static Map<Attribute,Object> cloneAttributesMap(Map<Attribute,Object> attributes)
 	{
-		return attributes == null ? null : new HashMap(attributes);
+		return attributes == null ? null : new HashMap<Attribute,Object>(attributes);
 	}
 
 	
@@ -354,10 +354,10 @@ public class JRStyledText implements Cloneable
 			JRStyledText clone = (JRStyledText) super.clone();
 			clone.globalAttributes = cloneAttributesMap(globalAttributes);
 			
-			clone.runs = new ArrayList(runs.size());
-			for (Iterator it = runs.iterator(); it.hasNext();)
+			clone.runs = new ArrayList<Run>(runs.size());
+			for (Iterator<Run> it = runs.iterator(); it.hasNext();)
 			{
-				Run run = (Run) it.next();
+				Run run = it.next();
 				Run runClone = run.cloneRun();
 				clone.runs.add(runClone);
 			}
@@ -411,9 +411,9 @@ public class JRStyledText implements Cloneable
 			
 			//adjust runs
 			//TODO optimize this?
-			for (Iterator it = runs.iterator(); it.hasNext();)
+			for (Iterator<Run> it = runs.iterator(); it.hasNext();)
 			{
-				Run run = (Run) it.next();
+				Run run = it.next();
 				if (run.startIndex >= offset)
 				{
 					//inserted before run
