@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -30,6 +30,7 @@ import java.io.IOException;
 import java.io.StringReader;
 import java.lang.ref.SoftReference;
 import java.text.AttributedCharacterIterator;
+import java.text.AttributedCharacterIterator.Attribute;
 import java.text.AttributedString;
 import java.util.Arrays;
 import java.util.HashMap;
@@ -45,8 +46,14 @@ import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.parsers.ParserConfigurationException;
 
+import net.sf.jasperreports.engine.JRPrintHyperlink;
+import net.sf.jasperreports.engine.JRPrintHyperlinkParameter;
+import net.sf.jasperreports.engine.JRPrintHyperlinkParameters;
 import net.sf.jasperreports.engine.JRRuntimeException;
+import net.sf.jasperreports.engine.base.JRBasePrintHyperlink;
 import net.sf.jasperreports.engine.fonts.FontFamily;
+import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
+import net.sf.jasperreports.engine.util.JRStyledText.Run;
 import net.sf.jasperreports.extensions.ExtensionsEnvironment;
 
 import org.apache.commons.logging.Log;
@@ -63,20 +70,20 @@ import org.xml.sax.SAXParseException;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRStyledTextParser.java 3668 2010-03-31 15:23:49Z shertage $
+ * @version $Id: JRStyledTextParser.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRStyledTextParser implements ErrorHandler
 {
 	private static final Log log = LogFactory.getLog(JRStyledTextParser.class);
 
-	private static final Set AVAILABLE_FONT_FACE_NAMES = new HashSet();
+	private static final Set<String> AVAILABLE_FONT_FACE_NAMES = new HashSet<String>();
 	static
 	{
 		//FIXMEFONT do some cache
-		List families = ExtensionsEnvironment.getExtensionsRegistry().getExtensions(FontFamily.class);
-		for (Iterator itf = families.iterator(); itf.hasNext();)
+		List<FontFamily> families = ExtensionsEnvironment.getExtensionsRegistry().getExtensions(FontFamily.class);
+		for (Iterator<FontFamily> itf = families.iterator(); itf.hasNext();)
 		{
-			FontFamily family = (FontFamily)itf.next();
+			FontFamily family =itf.next();
 			AVAILABLE_FONT_FACE_NAMES.add(family.getName());
 		}
 			
@@ -99,6 +106,8 @@ public class JRStyledTextParser implements ErrorHandler
 	private static final String NODE_font = "font";
 	private static final String NODE_br = "br";
 	private static final String NODE_li = "li";
+	private static final String NODE_a = "a";
+	private static final String NODE_param = "param";
 	private static final String ATTRIBUTE_fontName = "fontName";
 	private static final String ATTRIBUTE_fontFace = "face";
 	private static final String ATTRIBUTE_color = "color";
@@ -112,6 +121,11 @@ public class JRStyledTextParser implements ErrorHandler
 	private static final String ATTRIBUTE_pdfFontName = "pdfFontName";
 	private static final String ATTRIBUTE_pdfEncoding = "pdfEncoding";
 	private static final String ATTRIBUTE_isPdfEmbedded = "isPdfEmbedded";
+	private static final String ATTRIBUTE_type = "type";
+	private static final String ATTRIBUTE_href = "href";
+	private static final String ATTRIBUTE_target = "target";
+	private static final String ATTRIBUTE_name = "name";
+	private static final String ATTRIBUTE_valueClass = "valueClass";
 
 	private static final String SPACE = " ";
 	private static final String EQUAL_QUOTE = "=\"";
@@ -124,12 +138,12 @@ public class JRStyledTextParser implements ErrorHandler
 	/**
 	 * Thread local soft cache of instances.
 	 */
-	private static final ThreadLocal threadInstances = new ThreadLocal();
+	private static final ThreadLocal<SoftReference<JRStyledTextParser>> threadInstances = new ThreadLocal<SoftReference<JRStyledTextParser>>();
 	
 	/**
 	 * 
 	 */
-	private static final ThreadLocal threadLocale = new ThreadLocal();
+	private static final ThreadLocal<Locale> threadLocale = new ThreadLocal<Locale>();
 	
 	/**
 	 * Return a cached instance.
@@ -139,15 +153,15 @@ public class JRStyledTextParser implements ErrorHandler
 	public static JRStyledTextParser getInstance()
 	{
 		JRStyledTextParser instance = null;
-		SoftReference instanceRef = (SoftReference) threadInstances.get();
+		SoftReference<JRStyledTextParser> instanceRef = threadInstances.get();
 		if (instanceRef != null)
 		{
-			instance = (JRStyledTextParser) instanceRef.get();
+			instance =  instanceRef.get();
 		}
 		if (instance == null)
 		{
 			instance = new JRStyledTextParser();
-			threadInstances.set(new SoftReference(instance));
+			threadInstances.set(new SoftReference<JRStyledTextParser>(instance));
 		}
 		return instance;
 	}
@@ -166,19 +180,24 @@ public class JRStyledTextParser implements ErrorHandler
 	 */
 	public static Locale getLocale()
 	{
-		return (Locale)threadLocale.get();
+		return threadLocale.get();
 	}
 	
 	/**
 	 *
 	 */
-	private DocumentBuilder documentBuilder = null;
+	private DocumentBuilder documentBuilder;
+	
+	/**
+	 *
+	 */
+	private JRBasePrintHyperlink hyperlink;
 
 
 	/**
-	 * @deprecated Replaced by {@link #getInstance()}.
+	 *
 	 */
-	public JRStyledTextParser()
+	private JRStyledTextParser()
 	{
 		try
 		{
@@ -193,18 +212,10 @@ public class JRStyledTextParser implements ErrorHandler
 	}
 
 
-	/**
-	 * @deprecated Replaced by {@link #parse(Map, String, Locale)}.
-	 */
-	public JRStyledText parse(Map attributes, String text) throws SAXException
-	{
-		return parse(attributes, text, null);
-	}
-	
 	/**
 	 *
 	 */
-	public JRStyledText parse(Map attributes, String text, Locale locale) throws SAXException
+	public JRStyledText parse(Map<Attribute,Object> attributes, String text, Locale locale) throws SAXException
 	{
 		JRStyledText styledText = new JRStyledText(locale);
 		
@@ -219,6 +230,8 @@ public class JRStyledTextParser implements ErrorHandler
 			throw new JRRuntimeException(e);
 		}
 		
+		hyperlink = null;
+		
 		parseStyle(styledText, document.getDocumentElement());
 		
 		styledText.setGlobalAttributes(attributes);
@@ -226,14 +239,6 @@ public class JRStyledTextParser implements ErrorHandler
 		return styledText;
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #getStyledText(Map, String, boolean, Locale)}.
-	 */
-	public JRStyledText getStyledText(Map parentAttributes, String text, boolean isStyledText)
-	{
-		return getStyledText(parentAttributes, text, isStyledText, null);
-	}
-	
 	/**
 	 * Creates a styled text object by either parsing a styled text String or
 	 * by wrapping an unstyled String.
@@ -244,7 +249,7 @@ public class JRStyledTextParser implements ErrorHandler
 	 * @param locale the locale for the text
 	 * @return a styled text object
 	 */
-	public JRStyledText getStyledText(Map parentAttributes, String text, boolean isStyledText, Locale locale)
+	public JRStyledText getStyledText(Map<Attribute,Object> parentAttributes, String text, boolean isStyledText, Locale locale)
 	{
 		JRStyledText styledText = null;
 		if (isStyledText)
@@ -292,7 +297,7 @@ public class JRStyledTextParser implements ErrorHandler
 	 * @param text the text
 	 * @return the String styled text representation
 	 */
-	public String write(Map parentAttrs, AttributedCharacterIterator iterator, String text)
+	public String write(Map<Attribute,Object> parentAttrs, AttributedCharacterIterator iterator, String text)
 	{
 		StringBuffer sbuffer = new StringBuffer();
 		
@@ -301,7 +306,7 @@ public class JRStyledTextParser implements ErrorHandler
 		while(runLimit < iterator.getEndIndex() && (runLimit = iterator.getRunLimit()) <= iterator.getEndIndex())
 		{
 			String chunk = text.substring(iterator.getIndex(), runLimit);
-			Map attrs = iterator.getAttributes();
+			Map<Attribute,Object> attrs = iterator.getAttributes();
 			
 			StringBuffer styleBuffer = writeStyleAttributes(parentAttrs, attrs);
 			if (styleBuffer.length() > 0)
@@ -349,7 +354,7 @@ public class JRStyledTextParser implements ErrorHandler
 	/**
 	 *
 	 */
-	public void writeChunk(StringBuffer sbuffer, Map parentAttrs, Map attrs, String chunk)
+	public void writeChunk(StringBuffer sbuffer, Map<Attribute,Object> parentAttrs, Map<Attribute,Object> attrs, String chunk)
 	{
 		Object value = attrs.get(TextAttribute.SUPERSCRIPT);
 		Object oldValue = parentAttrs.get(TextAttribute.SUPERSCRIPT);
@@ -363,21 +368,94 @@ public class JRStyledTextParser implements ErrorHandler
 			isSub=TextAttribute.SUPERSCRIPT_SUB.equals(value);
 		}
 
+		String scriptNode = isSuper?NODE_sup:NODE_sub;
 
 		if (isSuper || isSub)
 		{
-			String node = isSuper?NODE_sup:NODE_sub;
 			sbuffer.append(LESS);
-			sbuffer.append(node);
-			sbuffer.append(GREATER);
-			sbuffer.append(JRStringUtil.xmlEncode(chunk));
-			sbuffer.append(LESS_SLASH);
-			sbuffer.append(node);
+			sbuffer.append(scriptNode);
 			sbuffer.append(GREATER);
 		}
-		else
+
+		JRPrintHyperlink hlink = (JRPrintHyperlink)attrs.get(JRTextAttribute.HYPERLINK);
+		if (hlink != null)
 		{
-			sbuffer.append(JRStringUtil.xmlEncode(chunk));
+			sbuffer.append(LESS);
+			sbuffer.append(NODE_a);
+
+			String href = hlink.getHyperlinkReference();
+			if (href != null && href.trim().length() > 0)
+			{
+				sbuffer.append(SPACE);
+				sbuffer.append(ATTRIBUTE_href);
+				sbuffer.append(EQUAL_QUOTE);
+				sbuffer.append(href);
+				sbuffer.append(QUOTE);
+			}
+			
+			String type = hlink.getLinkType();
+			if (type != null && type.trim().length() > 0)
+			{
+				sbuffer.append(SPACE);
+				sbuffer.append(ATTRIBUTE_type);
+				sbuffer.append(EQUAL_QUOTE);
+				sbuffer.append(type);
+				sbuffer.append(QUOTE);
+			}
+			
+			String target = hlink.getLinkTarget();
+			if (target != null && target.trim().length() > 0)
+			{
+				sbuffer.append(SPACE);
+				sbuffer.append(ATTRIBUTE_target);
+				sbuffer.append(EQUAL_QUOTE);
+				sbuffer.append(target);
+				sbuffer.append(QUOTE);
+			}
+			
+			sbuffer.append(GREATER);
+			
+			JRPrintHyperlinkParameters parameters = hlink.getHyperlinkParameters();
+			if (parameters != null && parameters.getParameters() != null)
+			{
+				for (JRPrintHyperlinkParameter parameter : parameters.getParameters())
+				{
+					sbuffer.append(LESS);
+					sbuffer.append(NODE_param);
+					sbuffer.append(SPACE);
+					sbuffer.append(ATTRIBUTE_name);
+					sbuffer.append(EQUAL_QUOTE);
+					sbuffer.append(parameter.getName());
+					sbuffer.append(QUOTE);
+					sbuffer.append(GREATER);
+					
+					if (parameter.getValue() != null)
+					{
+						String strValue = JRValueStringUtils.serialize(parameter.getValueClass(), parameter.getValue());
+						sbuffer.append(JRStringUtil.xmlEncode(strValue));
+					}
+
+					sbuffer.append(LESS_SLASH);
+					sbuffer.append(NODE_param);
+					sbuffer.append(GREATER);
+				}
+			}
+		}
+
+		sbuffer.append(JRStringUtil.xmlEncode(chunk));
+
+		if (hlink != null)
+		{
+			sbuffer.append(LESS_SLASH);
+			sbuffer.append(NODE_a);
+			sbuffer.append(GREATER);
+		}
+
+		if (isSuper || isSub)
+		{
+			sbuffer.append(LESS_SLASH);
+			sbuffer.append(scriptNode);
+			sbuffer.append(GREATER);
 		}
 	}
 
@@ -401,7 +479,7 @@ public class JRStyledTextParser implements ErrorHandler
 			{
 				NamedNodeMap nodeAttrs = node.getAttributes();
 
-				Map styleAttrs = new HashMap();
+				Map<Attribute,Object> styleAttrs = new HashMap<Attribute,Object>();
 
 				if (nodeAttrs.getNamedItem(ATTRIBUTE_fontName) != null)
 				{
@@ -513,7 +591,7 @@ public class JRStyledTextParser implements ErrorHandler
 			}
 			else if (node.getNodeType() == Node.ELEMENT_NODE && NODE_bold.equalsIgnoreCase(node.getNodeName()))
 			{
-				Map styleAttrs = new HashMap();
+				Map<Attribute,Object> styleAttrs = new HashMap<Attribute,Object>();
 				styleAttrs.put(TextAttribute.WEIGHT, TextAttribute.WEIGHT_BOLD);
 
 				int startIndex = styledText.length();
@@ -524,7 +602,7 @@ public class JRStyledTextParser implements ErrorHandler
 			}
 			else if (node.getNodeType() == Node.ELEMENT_NODE && NODE_italic.equalsIgnoreCase(node.getNodeName()))
 			{
-				Map styleAttrs = new HashMap();
+				Map<Attribute,Object> styleAttrs = new HashMap<Attribute,Object>();
 				styleAttrs.put(TextAttribute.POSTURE, TextAttribute.POSTURE_OBLIQUE);
 
 				int startIndex = styledText.length();
@@ -535,7 +613,7 @@ public class JRStyledTextParser implements ErrorHandler
 			}
 			else if (node.getNodeType() == Node.ELEMENT_NODE && NODE_underline.equalsIgnoreCase(node.getNodeName()))
 			{
-				Map styleAttrs = new HashMap();
+				Map<Attribute,Object> styleAttrs = new HashMap<Attribute,Object>();
 				styleAttrs.put(TextAttribute.UNDERLINE, TextAttribute.UNDERLINE_ON);
 
 				int startIndex = styledText.length();
@@ -546,7 +624,7 @@ public class JRStyledTextParser implements ErrorHandler
 			}
 			else if (node.getNodeType() == Node.ELEMENT_NODE && NODE_sup.equalsIgnoreCase(node.getNodeName()))
 			{
-				Map styleAttrs = new HashMap();
+				Map<Attribute,Object> styleAttrs = new HashMap<Attribute,Object>();
 				styleAttrs.put(TextAttribute.SUPERSCRIPT, TextAttribute.SUPERSCRIPT_SUPER);
 
 				int startIndex = styledText.length();
@@ -557,7 +635,7 @@ public class JRStyledTextParser implements ErrorHandler
 			}
 			else if (node.getNodeType() == Node.ELEMENT_NODE && NODE_sub.equalsIgnoreCase(node.getNodeName()))
 			{
-				Map styleAttrs = new HashMap();
+				Map<Attribute,Object> styleAttrs = new HashMap<Attribute,Object>();
 				styleAttrs.put(TextAttribute.SUPERSCRIPT, TextAttribute.SUPERSCRIPT_SUB);
 
 				int startIndex = styledText.length();
@@ -570,7 +648,7 @@ public class JRStyledTextParser implements ErrorHandler
 			{
 				NamedNodeMap nodeAttrs = node.getAttributes();
 
-				Map styleAttrs = new HashMap();
+				Map<Attribute,Object> styleAttrs = new HashMap<Attribute,Object>();
 
 				if (nodeAttrs.getNamedItem(ATTRIBUTE_size) != null)
 				{
@@ -624,7 +702,7 @@ public class JRStyledTextParser implements ErrorHandler
 				resizeRuns(styledText.getRuns(), startIndex, 1);
 
 				parseStyle(styledText, node);
-				styledText.addRun(new JRStyledText.Run(new HashMap(), startIndex, styledText.length()));
+				styledText.addRun(new JRStyledText.Run(new HashMap<Attribute,Object>(), startIndex, styledText.length()));
 
 				if (startIndex < styledText.length()) {
 					styledText.append("\n");
@@ -643,7 +721,7 @@ public class JRStyledTextParser implements ErrorHandler
 				int startIndex = styledText.length();
 				resizeRuns(styledText.getRuns(), startIndex, 1);
 				parseStyle(styledText, node);
-				styledText.addRun(new JRStyledText.Run(new HashMap(), startIndex, styledText.length()));
+				styledText.addRun(new JRStyledText.Run(new HashMap<Attribute,Object>(), startIndex, styledText.length()));
 				
 				// if the text in the next node does not start with a '\n', or 
 				// if the next node is not a <li /> one, we have to append a new line
@@ -659,6 +737,78 @@ public class JRStyledTextParser implements ErrorHandler
 					resizeRuns(styledText.getRuns(), startIndex, 1);
 				}
 			}
+			else if (node.getNodeType() == Node.ELEMENT_NODE && NODE_a.equalsIgnoreCase(node.getNodeName()))
+			{
+				if (hyperlink == null)
+				{
+					NamedNodeMap nodeAttrs = node.getAttributes();
+
+					Map<Attribute,Object> styleAttrs = new HashMap<Attribute,Object>();
+
+					hyperlink = new JRBasePrintHyperlink();
+					hyperlink.setHyperlinkType(HyperlinkTypeEnum.REFERENCE);
+					styleAttrs.put(JRTextAttribute.HYPERLINK, hyperlink);
+					
+					if (nodeAttrs.getNamedItem(ATTRIBUTE_href) != null)
+					{
+						hyperlink.setHyperlinkReference( nodeAttrs.getNamedItem(ATTRIBUTE_href).getNodeValue());
+					}
+
+					if (nodeAttrs.getNamedItem(ATTRIBUTE_type) != null)
+					{
+						hyperlink.setLinkType(nodeAttrs.getNamedItem(ATTRIBUTE_type).getNodeValue());
+					}
+
+					if (nodeAttrs.getNamedItem(ATTRIBUTE_target) != null)
+					{
+						hyperlink.setLinkTarget(nodeAttrs.getNamedItem(ATTRIBUTE_target).getNodeValue());
+					}
+
+					int startIndex = styledText.length();
+
+					parseStyle(styledText, node);
+
+					styledText.addRun(new JRStyledText.Run(styleAttrs, startIndex, styledText.length()));
+					
+					hyperlink = null;
+				}
+				else
+				{
+					throw new SAXException("Hyperlink <a> tags cannot be nested.");
+				}
+			}
+			else if (node.getNodeType() == Node.ELEMENT_NODE && NODE_param.equalsIgnoreCase(node.getNodeName()))
+			{
+				if (hyperlink == null)
+				{
+					throw new SAXException("Hyperlink <param> tags must appear inside an <a> tag only.");
+				}
+				else
+				{
+					NamedNodeMap nodeAttrs = node.getAttributes();
+
+					JRPrintHyperlinkParameter parameter = new JRPrintHyperlinkParameter();
+					
+					if (nodeAttrs.getNamedItem(ATTRIBUTE_name) != null)
+					{
+						parameter.setName(nodeAttrs.getNamedItem(ATTRIBUTE_name).getNodeValue());
+					}
+
+					if (nodeAttrs.getNamedItem(ATTRIBUTE_valueClass) != null)
+					{
+						parameter.setValueClass(nodeAttrs.getNamedItem(ATTRIBUTE_valueClass).getNodeValue());
+					}
+
+					String strValue = node.getTextContent();
+					if (strValue != null)
+					{
+						Object value = JRValueStringUtils.deserialize(parameter.getValueClass(), strValue);
+						parameter.setValue(value);
+					}
+						
+					hyperlink.addHyperlinkParameter(parameter);
+				}
+			}
 			else if (node.getNodeType() == Node.ELEMENT_NODE)
 			{
 				String nodeName = "<" + node.getNodeName() + ">";
@@ -670,11 +820,11 @@ public class JRStyledTextParser implements ErrorHandler
 	/**
 	 *
 	 */
-	private void resizeRuns(List runs, int startIndex, int count)
+	private void resizeRuns(List<Run> runs, int startIndex, int count)
 	{
 		for (int j = 0; j < runs.size(); j++)
 		{
-			JRStyledText.Run run = (JRStyledText.Run) runs.get(j);
+			JRStyledText.Run run = runs.get(j);
 			if (run.startIndex <= startIndex && run.endIndex > startIndex - count)
 			{
 				run.endIndex += count;
@@ -686,7 +836,7 @@ public class JRStyledTextParser implements ErrorHandler
 	/**
 	 *
 	 */
-	private StringBuffer writeStyleAttributes(Map parentAttrs,  Map attrs)
+	private StringBuffer writeStyleAttributes(Map<Attribute,Object> parentAttrs,  Map<Attribute,Object> attrs)
 	{
 		StringBuffer sbuffer = new StringBuffer();
 		
@@ -834,7 +984,7 @@ public class JRStyledTextParser implements ErrorHandler
 	}
 	
 	/**
-	 * The method returns the first text occurence in a given node element
+	 * The method returns the first text occurrence in a given node element
 	 * @param node
 	 * @return String
 	 */
