@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -38,7 +38,7 @@ import net.sf.jasperreports.engine.util.JRSingletonCache;
  * are used.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRXPathExecuterUtils.java 3712 2010-04-08 09:53:09Z teodord $
+ * @version $Id: JRXPathExecuterUtils.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public final class JRXPathExecuterUtils
 {
@@ -48,7 +48,8 @@ public final class JRXPathExecuterUtils
 	 */
 	public static final String PROPERTY_XPATH_EXECUTER_FACTORY = JRProperties.PROPERTY_PREFIX + "xpath.executer.factory";
 	
-	private static final JRSingletonCache cache = new JRSingletonCache(JRXPathExecuterFactory.class);
+	private static final JRSingletonCache<JRXPathExecuterFactory> cache = 
+			new JRSingletonCache<JRXPathExecuterFactory>(JRXPathExecuterFactory.class);
 	
 	
 	/**
@@ -67,7 +68,7 @@ public final class JRXPathExecuterUtils
 					"Create a propery named " + PROPERTY_XPATH_EXECUTER_FACTORY + ".");
 		}
 		
-		return (JRXPathExecuterFactory) cache.getCachedInstance(factoryClassName);
+		return cache.getCachedInstance(factoryClassName);
 	}
 	
 	
