@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -45,7 +45,7 @@ import org.xml.sax.Attributes;
 
 /**
  * @author Ionut Nedelcu (ionutned@users.sourceforge.net)
- * @version $Id: JRAbstractStyleFactory.java 3794 2010-05-13 07:47:16Z teodord $
+ * @version $Id: JRAbstractStyleFactory.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public abstract class JRAbstractStyleFactory extends JRBaseFactory
 {
@@ -296,7 +296,6 @@ public abstract class JRAbstractStyleFactory extends JRBaseFactory
 		}
 
 
-
 		RotationEnum rotation = RotationEnum.getByName(atts.getValue(JRXmlConstants.ATTRIBUTE_rotation));
 		if (rotation != null)
 		{
@@ -306,7 +305,11 @@ public abstract class JRAbstractStyleFactory extends JRBaseFactory
 		LineSpacingEnum lineSpacing = LineSpacingEnum.getByName(atts.getValue(JRXmlConstants.ATTRIBUTE_lineSpacing));
 		if (lineSpacing != null)
 		{
-			style.setLineSpacing(lineSpacing);
+			if (log.isWarnEnabled())
+			{
+				log.warn("The 'lineSpacing' attribute is deprecated. Use the <paragraph> tag instead.");
+			}
+			style.getParagraph().setLineSpacing(lineSpacing);
 		}
 
 		style.setMarkup(atts.getValue(JRXmlConstants.ATTRIBUTE_markup));
