@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -25,6 +25,7 @@ package net.sf.jasperreports.engine.xml;
 
 import java.util.Set;
 
+import net.sf.jasperreports.engine.JRElementDataset;
 import net.sf.jasperreports.engine.design.JRDesignElementDataset;
 import net.sf.jasperreports.engine.design.JRDesignGroup;
 import net.sf.jasperreports.engine.type.IncrementTypeEnum;
@@ -35,7 +36,7 @@ import org.xml.sax.Attributes;
 
 /**
  * @author Ionut Nedelcu (ionutned@users.sourceforge.net)
- * @version $Id: JRElementDatasetFactory.java 3616 2010-03-24 14:20:41Z teodord $
+ * @version $Id: JRElementDatasetFactory.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRElementDatasetFactory extends JRBaseFactory
 {
@@ -53,7 +54,7 @@ public class JRElementDatasetFactory extends JRBaseFactory
 	protected void setDatasetAtts(Attributes atts, JRDesignElementDataset dataset)
 	{
 		JRXmlLoader xmlLoader = (JRXmlLoader)digester.peek(digester.getCount() - 1);
-		Set groupBoundDatasets = xmlLoader.getGroupBoundDatasets();
+		Set<JRElementDataset> groupBoundDatasets = xmlLoader.getGroupBoundDatasets();
 		
 		ResetTypeEnum resetType = ResetTypeEnum.getByName(atts.getValue(JRXmlConstants.ATTRIBUTE_resetType));
 		if (resetType != null)
