@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -25,7 +25,6 @@ package net.sf.jasperreports.engine.xml;
 
 import java.util.Map;
 
-import net.sf.jasperreports.engine.JROrigin;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.JasperPrint;
@@ -38,7 +37,7 @@ import org.xml.sax.Attributes;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRPrintElementFactory.java 3717 2010-04-09 10:01:33Z teodord $
+ * @version $Id: JRPrintElementFactory.java 4672 2011-10-11 08:36:43Z lucianc $
  */
 public class JRPrintElementFactory extends JRBaseFactory
 {
@@ -100,22 +99,29 @@ public class JRPrintElementFactory extends JRBaseFactory
 			element.setBackcolor(JRColorUtil.getColor(backcolor, null));
 		}
 
-		if (atts.getValue(JRXmlConstants.ATTRIBUTE_style) != null)
+		String styleName = atts.getValue(JRXmlConstants.ATTRIBUTE_style);
+		if (styleName != null)
 		{
-			Map stylesMap = jasperPrint.getStylesMap();
+			Map<String,JRStyle> stylesMap = jasperPrint.getStylesMap();
 
-			if ( !stylesMap.containsKey(atts.getValue(JRXmlConstants.ATTRIBUTE_style)) )
+			if ( !stylesMap.containsKey(styleName) )
 			{
-				printXmlLoader.addError(new JRRuntimeException("Unknown report style : " + atts.getValue(JRXmlConstants.ATTRIBUTE_style)));
+				printXmlLoader.addError(new JRRuntimeException("Unknown report style : " + styleName));
 			}
 
-			element.setStyle((JRStyle) stylesMap.get(atts.getValue(JRXmlConstants.ATTRIBUTE_style)));
+			element.setStyle(stylesMap.get(styleName));
 		}
 
 		String origin = atts.getValue(JRXmlConstants.ATTRIBUTE_origin); 
 		if (origin != null && origin.length() > 0)
 		{
-			element.setOrigin((JROrigin)jasperPrint.getOriginsList().get(Integer.parseInt(origin)));
+			element.setOrigin(jasperPrint.getOriginsList().get(Integer.parseInt(origin)));
+		}
+		
+		String elementId = atts.getValue(JRXmlConstants.ATTRIBUTE_srcId);
+		if (elementId != null && elementId.length() > 0)
+		{
+			element.setSourceElementId(Integer.parseInt(elementId));
 		}
 
 		return element;
