@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,7 +35,7 @@ import org.w3c.tools.codec.Base64Decoder;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRPrintImageSourceObject.java 3034 2009-08-27 11:58:04Z teodord $
+ * @version $Id: JRPrintImageSourceObject.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRPrintImageSourceObject
 {
@@ -44,12 +44,12 @@ public class JRPrintImageSourceObject
 	/**
 	 *
 	 */
-	private JRPrintImage printImage = null;
+	private JRPrintImage printImage;
 
 	/**
 	 *
 	 */
-	private boolean isEmbedded = false;
+	private boolean isEmbedded;
 
 
 	/**
