@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -31,7 +31,6 @@ import java.util.List;
 
 import javax.xml.parsers.ParserConfigurationException;
 import javax.xml.parsers.SAXParser;
-import javax.xml.parsers.SAXParserFactory;
 
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRFont;
@@ -39,31 +38,40 @@ import net.sf.jasperreports.engine.JROrigin;
 import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRPrintHyperlinkParameter;
 import net.sf.jasperreports.engine.JRPrintPage;
-import net.sf.jasperreports.engine.JRReportFont;
+import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.JasperPrint;
+import net.sf.jasperreports.engine.TabStop;
+import net.sf.jasperreports.engine.util.CompositeClassloader;
 import net.sf.jasperreports.engine.util.JRProperties;
+import net.sf.jasperreports.engine.util.JRSingletonCache;
 
 import org.apache.commons.digester.SetNestedPropertiesRule;
 import org.apache.commons.digester.SetPropertiesRule;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.xml.sax.ErrorHandler;
 import org.xml.sax.SAXException;
 import org.xml.sax.SAXParseException;
-import org.xml.sax.XMLReader;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRPrintXmlLoader.java 3616 2010-03-24 14:20:41Z teodord $
+ * @version $Id: JRPrintXmlLoader.java 4617 2011-09-26 11:25:43Z lucianc $
  */
 public class JRPrintXmlLoader implements ErrorHandler
 {
+	
+	private static final Log log = LogFactory.getLog(JRPrintXmlLoader.class);
+	
+	protected static final JRSingletonCache<JRSaxParserFactory> printParserFactories = 
+		new JRSingletonCache<JRSaxParserFactory>(JRSaxParserFactory.class);
 
 	/**
 	 *
 	 */
-	private JasperPrint jasperPrint = null;
-	private List errors = new ArrayList();
+	private JasperPrint jasperPrint;
+	private List<Exception> errors = new ArrayList<Exception>();
 
 
 	/**
@@ -86,7 +94,7 @@ public class JRPrintXmlLoader implements ErrorHandler
 	/**
 	 *
 	 */
-	public static JasperPrint load(String sourceFileName) throws JRException
+	public static JasperPrint load(String sourceFileName) throws JRException//FIXMEREPO consider rename to loadFromFile
 	{
 		JasperPrint jasperPrint = null;
 
@@ -161,7 +169,7 @@ public class JRPrintXmlLoader implements ErrorHandler
 		
 		if (errors.size() > 0)
 		{
-			Exception e = (Exception)errors.get(0);
+			Exception e = errors.get(0);
 			if (e instanceof JRException)
 			{
 				throw (JRException)e;
@@ -176,20 +184,19 @@ public class JRPrintXmlLoader implements ErrorHandler
 	/**
 	 *
 	 */
-	private JRXmlDigester prepareDigester() throws ParserConfigurationException, SAXException
+	protected JRXmlDigester prepareDigester() throws ParserConfigurationException, SAXException
 	{
-		SAXParserFactory saxParserFactory = SAXParserFactory.newInstance();
+		JRXmlDigester digester = new JRXmlDigester(createParser());
+		
+		// use a classloader that resolves both JR classes and classes from the context classloader
+		CompositeClassloader digesterClassLoader = new CompositeClassloader(
+				JRXmlDigesterFactory.class.getClassLoader(), 
+				Thread.currentThread().getContextClassLoader());
+		digester.setClassLoader(digesterClassLoader);
+		digester.setNamespaceAware(true);
+		
+		digester.setRuleNamespaceURI(JRXmlConstants.JASPERPRINT_NAMESPACE);
 		
-		boolean validating = JRProperties.getBooleanProperty(JRProperties.EXPORT_XML_VALIDATION);		
-		saxParserFactory.setValidating(validating);
-
-		SAXParser saxParser = saxParserFactory.newSAXParser();
-		//XMLReader xmlReader = XMLReaderFactory.createXMLReader();
-		XMLReader xmlReader = saxParser.getXMLReader();
-
-		xmlReader.setFeature("http://xml.org/sax/features/validation", validating);
-
-		JRXmlDigester digester = new JRXmlDigester(xmlReader);
 		digester.push(this);
 		//digester.setDebug(3);
 		digester.setErrorHandler(this);
@@ -207,8 +214,8 @@ public class JRPrintXmlLoader implements ErrorHandler
 		digester.addSetNext("jasperPrint/origin", "addOrigin", JROrigin.class.getName());
 
 		/*   */
-		digester.addFactoryCreate("jasperPrint/reportFont", JRReportFontFactory.class.getName());
-		digester.addSetNext("jasperPrint/reportFont", "addFont", JRReportFont.class.getName());
+		digester.addFactoryCreate("jasperPrint/reportFont", JRStyleFactory.class.getName());
+		digester.addSetNext("jasperPrint/reportFont", "addStyle", JRStyle.class.getName());
 
 		/*   */
 		digester.addFactoryCreate("jasperPrint/style", JRPrintStyleFactory.class.getName());
@@ -256,6 +263,11 @@ public class JRPrintXmlLoader implements ErrorHandler
 		digester.addFactoryCreate("*/box/bottomPen", JRPenFactory.Bottom.class.getName());
 		digester.addFactoryCreate("*/box/rightPen", JRPenFactory.Right.class.getName());
 
+		/*   */
+		digester.addFactoryCreate("*/paragraph", JRParagraphFactory.class.getName());
+		digester.addFactoryCreate("*/paragraph/tabStop", TabStopFactory.class.getName());
+		digester.addSetNext("*/paragraph/tabStop", "addTabStop", TabStop.class.getName());
+
 		/*   */
 		digester.addFactoryCreate("*/image/imageSource", JRPrintImageSourceFactory.class.getName());
 		digester.addCallMethod("*/image/imageSource", "setImageSource", 0);
@@ -291,6 +303,28 @@ public class JRPrintXmlLoader implements ErrorHandler
 	}
 
 
+	protected SAXParser createParser()
+	{
+		try
+		{
+			String parserFactoryClass = JRProperties.getProperty(
+					JRSaxParserFactory.PROPERTY_PRINT_PARSER_FACTORY);
+			
+			if (log.isDebugEnabled())
+			{
+				log.debug("Using SAX parser factory class " + parserFactoryClass);
+			}
+			
+			JRSaxParserFactory factory = printParserFactories.getCachedInstance(parserFactoryClass);
+			return factory.createParser();
+		}
+		catch (JRException e)
+		{
+			throw new JRRuntimeException(e);
+		}
+	}
+
+
 	private void addFrameRules(JRXmlDigester digester)
 	{
 		digester.addFactoryCreate("*/frame", JRPrintFrameFactory.class.getName());
@@ -329,13 +363,46 @@ public class JRPrintXmlLoader implements ErrorHandler
 		digester.addFactoryCreate(elementParameterPattern, 
 				JRGenericPrintElementParameterFactory.class);
 		digester.addCallMethod(elementParameterPattern, "addParameter");
+		digester.addRule(elementParameterPattern, new JRGenericPrintElementParameterFactory.ArbitraryValueSetter());
 		
 		String elementParameterValuePattern = elementParameterPattern + "/"
 				+ JRXmlConstants.ELEMENT_genericElementParameterValue;
 		digester.addFactoryCreate(elementParameterValuePattern, 
 				JRGenericPrintElementParameterFactory.ParameterValueFactory.class);
-		digester.addSetNext(elementParameterValuePattern, "setValue");
 		digester.addCallMethod(elementParameterValuePattern, "setData", 0);
+		
+		addValueHandlerRules(digester, elementParameterPattern);
+	}
+
+	protected void addValueHandlerRules(JRXmlDigester digester, String elementParameterPattern)
+	{
+		List<XmlValueHandler> handlers = XmlValueHandlerUtils.instance().getHandlers();
+		for (XmlValueHandler handler : handlers)
+		{
+			XmlHandlerNamespace namespace = handler.getNamespace();
+			if (namespace != null)
+			{
+				String namespaceURI = namespace.getNamespaceURI();
+				
+				if (log.isDebugEnabled())
+				{
+					log.debug("Configuring the digester for handler " + handler 
+							+ " and namespace " + namespaceURI);
+				}
+				
+				digester.setRuleNamespaceURI(namespaceURI);
+				handler.configureDigester(digester);
+				
+				String schemaResource = namespace.getInternalSchemaResource();
+				if (schemaResource != null)
+				{
+					digester.addInternalEntityResource(namespace.getPublicSchemaLocation(), 
+							schemaResource);
+				}
+			}
+		}
+		
+		digester.setRuleNamespaceURI(JRXmlConstants.JASPERPRINT_NAMESPACE);
 	}
 
 
