@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -36,7 +36,7 @@ import org.xml.sax.Attributes;
  * creation.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRSubreportReturnValueFactory.java 3616 2010-03-24 14:20:41Z teodord $
+ * @version $Id: JRSubreportReturnValueFactory.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRSubreportReturnValueFactory extends JRBaseFactory
 {
@@ -55,7 +55,7 @@ public class JRSubreportReturnValueFactory extends JRBaseFactory
 		JRDesignSubreportReturnValue returnValue = new JRDesignSubreportReturnValue();
 
 		String variableName = atts.getValue(JRXmlConstants.ATTRIBUTE_toVariable);
-		JRVariable variable = (JRVariable) design.getVariablesMap().get(variableName);
+		JRVariable variable = design.getVariablesMap().get(variableName);
 		if (variable == null)
 		{
 			xmlLoader.addError(new JRValidationException("Unknown variable " + variableName, returnValue));
