@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -27,9 +27,11 @@ import java.io.IOException;
 
 import net.sf.jasperreports.engine.JRConditionalStyle;
 import net.sf.jasperreports.engine.JRLineBox;
+import net.sf.jasperreports.engine.JRParagraph;
 import net.sf.jasperreports.engine.JRPen;
 import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.JRStyleContainer;
+import net.sf.jasperreports.engine.TabStop;
 import net.sf.jasperreports.engine.util.JRXmlWriteHelper;
 import net.sf.jasperreports.engine.util.XmlNamespace;
 
@@ -38,7 +40,7 @@ import net.sf.jasperreports.engine.util.XmlNamespace;
  * Base XML writer.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRXmlBaseWriter.java 3794 2010-05-13 07:47:16Z teodord $
+ * @version $Id: JRXmlBaseWriter.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public abstract class JRXmlBaseWriter
 {
@@ -76,7 +78,6 @@ public abstract class JRXmlBaseWriter
 		writer.addAttribute(JRXmlConstants.ATTRIBUTE_hAlign, style.getOwnHorizontalAlignmentValue());
 		writer.addAttribute(JRXmlConstants.ATTRIBUTE_vAlign, style.getOwnVerticalAlignmentValue());
 		writer.addAttribute(JRXmlConstants.ATTRIBUTE_rotation, style.getOwnRotationValue());
-		writer.addAttribute(JRXmlConstants.ATTRIBUTE_lineSpacing, style.getOwnLineSpacingValue());
 		writer.addAttribute(JRXmlConstants.ATTRIBUTE_markup, style.getOwnMarkup());
 		writer.addEncodedAttribute(JRXmlConstants.ATTRIBUTE_pattern, style.getOwnPattern());
 		writer.addAttribute(JRXmlConstants.ATTRIBUTE_isBlankWhenNull, style.isOwnBlankWhenNull());
@@ -93,6 +94,7 @@ public abstract class JRXmlBaseWriter
 
 		writePen(style.getLinePen());
 		writeBox(style.getLineBox());
+		writeParagraph(style.getParagraph());
 		
 		if (toWriteConditionalStyles())
 		{
@@ -140,7 +142,7 @@ public abstract class JRXmlBaseWriter
 	protected void writeConditionalStyle(JRConditionalStyle style) throws IOException
 	{
 		writer.startElement(JRXmlConstants.ELEMENT_conditionalStyle);
-		writer.writeExpression(JRXmlConstants.ELEMENT_conditionExpression, style.getConditionExpression(), false);
+		writer.writeExpression(JRXmlConstants.ELEMENT_conditionExpression, style.getConditionExpression());
 		writeStyle(style);
 		writer.closeElement();
 	}
@@ -195,4 +197,58 @@ public abstract class JRXmlBaseWriter
 		}
 	}
 
+	public void writeParagraph(JRParagraph paragraph) throws IOException
+	{
+		writeParagraph(paragraph, null);
+	}
+	
+	/**
+	 *
+	 */
+	public void writeParagraph(JRParagraph paragraph, XmlNamespace namespace) throws IOException
+	{
+		if (paragraph != null)
+		{
+			writer.startElement(JRXmlConstants.ELEMENT_paragraph, namespace);
+			
+			writer.addAttribute(JRXmlConstants.ATTRIBUTE_lineSpacing, paragraph.getOwnLineSpacing());
+			writer.addAttribute(JRXmlConstants.ATTRIBUTE_lineSpacingSize, paragraph.getOwnLineSpacingSize());
+			writer.addAttribute(JRXmlConstants.ATTRIBUTE_firstLineIndent, paragraph.getOwnFirstLineIndent());
+			writer.addAttribute(JRXmlConstants.ATTRIBUTE_leftIndent, paragraph.getOwnLeftIndent());
+			writer.addAttribute(JRXmlConstants.ATTRIBUTE_rightIndent, paragraph.getOwnRightIndent());
+			writer.addAttribute(JRXmlConstants.ATTRIBUTE_spacingBefore, paragraph.getOwnSpacingBefore());
+			writer.addAttribute(JRXmlConstants.ATTRIBUTE_spacingAfter, paragraph.getOwnSpacingAfter());
+			writer.addAttribute(JRXmlConstants.ATTRIBUTE_tabStopWidth, paragraph.getOwnTabStopWidth());
+
+			/*   */
+			TabStop[] tabStops = paragraph.getTabStops();
+			if (tabStops != null && tabStops.length > 0)
+			{
+				for(int i = 0; i < tabStops.length; i++)
+				{
+					writeTabStop(tabStops[i]);
+				}
+			}
+
+			writer.closeElement(true);
+		}
+	}
+
+	
+	/**
+	 *
+	 */
+	public void writeTabStop(TabStop tabStop) throws IOException
+	{
+		if (tabStop != null)
+		{
+			writer.startElement(JRXmlConstants.ELEMENT_tabStop);
+			
+			writer.addAttribute(JRXmlConstants.ATTRIBUTE_position, tabStop.getPosition());
+			writer.addAttribute(JRXmlConstants.ATTRIBUTE_alignment, tabStop.getAlignment());
+
+			writer.closeElement(true);
+		}
+	}
+
 }
