@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -131,7 +131,6 @@ import net.sf.jasperreports.engine.JRHyperlink;
 import net.sf.jasperreports.engine.JRHyperlinkParameter;
 import net.sf.jasperreports.engine.JRParameter;
 import net.sf.jasperreports.engine.JRPropertyExpression;
-import net.sf.jasperreports.engine.JRReportFont;
 import net.sf.jasperreports.engine.JRReportTemplate;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRScriptlet;
@@ -139,6 +138,7 @@ import net.sf.jasperreports.engine.JRSortField;
 import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.JRSubreportParameter;
 import net.sf.jasperreports.engine.JRSubreportReturnValue;
+import net.sf.jasperreports.engine.TabStop;
 import net.sf.jasperreports.engine.component.ComponentsBundle;
 import net.sf.jasperreports.engine.component.ComponentsEnvironment;
 import net.sf.jasperreports.engine.component.ComponentsXmlParser;
@@ -171,15 +171,15 @@ import org.xml.sax.SAXParseException;
  * a digester in order to prepare it for parsing JasperReports xml definition files.
  *
  * @author Peter Severin (peter_p_s@users.sourceforge.net)
- * @version $Id: JRXmlDigesterFactory.java 3690 2010-04-06 12:23:17Z shertage $
+ * @version $Id: JRXmlDigesterFactory.java 4622 2011-09-27 12:08:19Z narcism $
  */
 public final class JRXmlDigesterFactory
 {
 
 	private static final Log log = LogFactory.getLog(JRXmlDigesterFactory.class);
 	
-	protected static final JRSingletonCache reportParserFactories = 
-		new JRSingletonCache(JRSaxParserFactory.class);
+	protected static final JRSingletonCache<JRSaxParserFactory> reportParserFactories = 
+		new JRSingletonCache<JRSaxParserFactory>(JRSaxParserFactory.class);
 
 	/**
 	 *
@@ -229,8 +229,8 @@ public final class JRXmlDigesterFactory
 		addTemplateRules(digester);
 
 		/*   */
-		digester.addFactoryCreate("jasperReport/reportFont", JRReportFontFactory.class.getName());
-		digester.addSetNext("jasperReport/reportFont", "addFont", JRReportFont.class.getName());
+		digester.addFactoryCreate("jasperReport/reportFont", JRStyleFactory.class.getName());
+		digester.addSetNext("jasperReport/reportFont", "addStyle", JRStyle.class.getName());
 
 		/*   */
 		digester.addFactoryCreate("jasperReport/style", JRStyleFactory.class.getName());
@@ -381,6 +381,11 @@ public final class JRXmlDigesterFactory
 		digester.addFactoryCreate("*/box/bottomPen", JRPenFactory.Bottom.class.getName());
 		digester.addFactoryCreate("*/box/rightPen", JRPenFactory.Right.class.getName());
 
+		/*   */
+		digester.addFactoryCreate("*/paragraph", JRParagraphFactory.class.getName());
+		digester.addFactoryCreate("*/paragraph/tabStop", TabStopFactory.class.getName());
+		digester.addSetNext("*/paragraph/tabStop", "addTabStop", TabStop.class.getName());
+
 		/*   */
 		digester.addFactoryCreate("*/image/imageExpression", JRStringExpressionFactory.class.getName());
 		digester.addSetNext("*/image/imageExpression", "setExpression", JRExpression.class.getName());
@@ -410,6 +415,11 @@ public final class JRXmlDigesterFactory
 		digester.addSetNext("*/textField/textFieldExpression", "setExpression", JRExpression.class.getName());
 		digester.addCallMethod("*/textField/textFieldExpression", "setText", 0);
 
+		/*   */
+		digester.addFactoryCreate("*/textField/patternExpression", JRExpressionFactory.class.getName());
+		digester.addSetNext("*/textField/patternExpression", "setPatternExpression", JRExpression.class.getName());
+		digester.addCallMethod("*/textField/patternExpression", "setText", 0);
+
 		/*   */
 		digester.addFactoryCreate("*/anchorNameExpression", JRExpressionFactory.StringExpressionFactory.class.getName());
 		digester.addSetNext("*/anchorNameExpression", "setAnchorNameExpression", JRExpression.class.getName());
@@ -491,10 +501,10 @@ public final class JRXmlDigesterFactory
 		digester.addFactoryCreate("*/componentElement", JRComponentElementFactory.class.getName());
 		digester.addSetNext("*/componentElement", "addElement", JRDesignElement.class.getName());
 		
-		Collection components = ComponentsEnvironment.getComponentBundles();
-		for (Iterator it = components.iterator(); it.hasNext();)
+		Collection<ComponentsBundle> components = ComponentsEnvironment.getComponentBundles();
+		for (Iterator<ComponentsBundle> it = components.iterator(); it.hasNext();)
 		{
-			ComponentsBundle componentsBundle = (ComponentsBundle) it.next();
+			ComponentsBundle componentsBundle = it.next();
 			ComponentsXmlParser xmlParser = componentsBundle.getXmlParser();
 			digester.setRuleNamespaceURI(xmlParser.getNamespace());
 			
@@ -504,10 +514,11 @@ public final class JRXmlDigesterFactory
 				configurer.configureDigester(digester);
 			}
 			
-			for (Iterator namesIt = componentsBundle.getComponentNames().iterator(); 
+			digester.setRuleNamespaceURI(xmlParser.getNamespace());
+			for (Iterator<String> namesIt = componentsBundle.getComponentNames().iterator(); 
 					namesIt.hasNext();)
 			{
-				String componentName = (String) namesIt.next();
+				String componentName = namesIt.next();
 				digester.addRule("*/componentElement/" + componentName, 
 						JRComponentRule.newInstance());
 			}
@@ -1327,8 +1338,7 @@ public final class JRXmlDigesterFactory
 				log.debug("Using SAX parser factory class " + parserFactoryClass);
 			}
 			
-			JRSaxParserFactory factory = (JRSaxParserFactory) reportParserFactories
-					.getCachedInstance(parserFactoryClass);
+			JRSaxParserFactory factory = reportParserFactories.getCachedInstance(parserFactoryClass);
 			return factory.createParser();
 		}
 		catch (JRException e)
@@ -1339,10 +1349,10 @@ public final class JRXmlDigesterFactory
 	
 	protected static void setComponentsInternalEntityResources(JRXmlDigester digester)
 	{
-		Collection components = ComponentsEnvironment.getComponentBundles();
-		for (Iterator it = components.iterator(); it.hasNext();)
+		Collection<ComponentsBundle> components = ComponentsEnvironment.getComponentBundles();
+		for (Iterator<ComponentsBundle> it = components.iterator(); it.hasNext();)
 		{
-			ComponentsBundle componentManager = (ComponentsBundle) it.next();
+			ComponentsBundle componentManager = it.next();
 			ComponentsXmlParser xmlParser = componentManager.getXmlParser();
 			String schemaResource = xmlParser.getInternalSchemaResource();
 			if (schemaResource != null)
