@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,7 +35,7 @@ import org.apache.commons.logging.LogFactory;
  * {@link ExtensionsRegistry} instances.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: ExtensionsEnvironment.java 3659 2010-03-31 10:20:49Z shertage $
+ * @version $Id: ExtensionsEnvironment.java 4595 2011-09-08 15:55:10Z teodord $
  * @see #getExtensionsRegistry()
  */
 public final class ExtensionsEnvironment
@@ -61,7 +61,7 @@ public final class ExtensionsEnvironment
 		JRProperties.PROPERTY_PREFIX + "extensions.registry.class";
 	
 	private static ExtensionsRegistry systemRegistry;
-	private static final ThreadLocal threadRegistry = new InheritableThreadLocal();
+	private static final ThreadLocal<ExtensionsRegistry> threadRegistry = new InheritableThreadLocal<ExtensionsRegistry>();
 	
 	static
 	{
@@ -118,7 +118,7 @@ public final class ExtensionsEnvironment
 	 */
 	public static ExtensionsRegistry getThreadExtensionsRegistry()
 	{
-		return (ExtensionsRegistry) threadRegistry.get();
+		return threadRegistry.get();
 	}
 
 	/**
