@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -32,7 +32,7 @@ import net.sf.jasperreports.engine.util.JRProperties;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: TimeoutGovernor.java 3279 2010-01-19 16:55:42Z lucianc $
+ * @version $Id: TimeoutGovernor.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class TimeoutGovernor extends JRDefaultScriptlet
 {
@@ -46,8 +46,8 @@ public class TimeoutGovernor extends JRDefaultScriptlet
 	/**
 	 *
 	 */
-	private long startTime = 0;
-	private long timeout = 0;
+	private long startTime;
+	private long timeout;
 
 	
 	/**
