@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,7 +35,7 @@ import net.sf.jasperreports.engine.JasperPrint;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: BaseHttpServlet.java 3439 2010-02-18 14:57:42Z teodord $
+ * @version $Id: BaseHttpServlet.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public abstract class BaseHttpServlet extends HttpServlet
 {
@@ -57,7 +57,7 @@ public abstract class BaseHttpServlet extends HttpServlet
 	/**
 	 *
 	 */
-	public static List getJasperPrintList(HttpServletRequest request)
+	public static List<JasperPrint> getJasperPrintList(HttpServletRequest request)
 	{
 		String jasperPrintListSessionAttr = request.getParameter(JASPER_PRINT_LIST_REQUEST_PARAMETER);
 		if (jasperPrintListSessionAttr == null)
@@ -71,13 +71,13 @@ public abstract class BaseHttpServlet extends HttpServlet
 			jasperPrintSessionAttr = DEFAULT_JASPER_PRINT_SESSION_ATTRIBUTE;
 		}
 		
-		List jasperPrintList = (List)request.getSession().getAttribute(jasperPrintListSessionAttr);
+		List<JasperPrint> jasperPrintList = (List<JasperPrint>)request.getSession().getAttribute(jasperPrintListSessionAttr);
 		if (jasperPrintList == null)
 		{
 			JasperPrint jasperPrint = (JasperPrint)request.getSession().getAttribute(jasperPrintSessionAttr);
 			if (jasperPrint != null)
 			{
-				jasperPrintList = new ArrayList();
+				jasperPrintList = new ArrayList<JasperPrint>();
 				jasperPrintList.add(jasperPrint);
 			}
 		}
