@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -38,6 +38,7 @@ import net.sf.jasperreports.engine.JRImageRenderer;
 import net.sf.jasperreports.engine.JRPrintImage;
 import net.sf.jasperreports.engine.JRRenderable;
 import net.sf.jasperreports.engine.JRWrappingSvgRenderer;
+import net.sf.jasperreports.engine.JasperPrint;
 import net.sf.jasperreports.engine.export.JRHtmlExporter;
 import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.util.JRTypeSniffer;
@@ -45,7 +46,7 @@ import net.sf.jasperreports.engine.util.JRTypeSniffer;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: ImageServlet.java 3420 2010-02-18 09:17:47Z teodord $
+ * @version $Id: ImageServlet.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class ImageServlet extends BaseHttpServlet
 {
@@ -86,7 +87,7 @@ public class ImageServlet extends BaseHttpServlet
 		}
 		else
 		{
-			List jasperPrintList = BaseHttpServlet.getJasperPrintList(request);
+			List<JasperPrint> jasperPrintList = BaseHttpServlet.getJasperPrintList(request);
 			
 			if (jasperPrintList == null)
 			{
