@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,12 +35,13 @@ import javax.servlet.http.HttpServletResponse;
 import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRExporterParameter;
+import net.sf.jasperreports.engine.JasperPrint;
 import net.sf.jasperreports.engine.export.JRXmlExporter;
 import net.sf.jasperreports.engine.util.FileBufferedOutputStream;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: XmlServlet.java 3659 2010-03-31 10:20:49Z shertage $
+ * @version $Id: XmlServlet.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class XmlServlet extends BaseHttpServlet
 {
@@ -62,7 +63,7 @@ public class XmlServlet extends BaseHttpServlet
 		HttpServletResponse response
 		) throws IOException, ServletException
 	{
-		List jasperPrintList = BaseHttpServlet.getJasperPrintList(request);
+		List<JasperPrint> jasperPrintList = BaseHttpServlet.getJasperPrintList(request);
 
 		if (jasperPrintList == null)
 		{
