@@ -2,7 +2,7 @@
 
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -19,7 +19,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -41,7 +41,7 @@ import antlr.collections.impl.BitSet;
 
 /**
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: MappingParser.java 3740 2010-04-16 15:03:17Z lucianc $
+ * @version $Id: MappingParser.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class MappingParser extends antlr.LLkParser implements MappingParserTokenTypes
  {
@@ -190,7 +190,9 @@ public MappingParser(ParserSharedInputState state) {
 	public final DataMapping  dataMapping() throws RecognitionException, TokenStreamException {
 		DataMapping mapping = null;
 		
-		boolean formatted = false; List filter = null; List positions = null;
+		boolean formatted = false; 
+		List<Member> filter = null; 
+		List<AxisPosition> positions = null;
 		
 		try {      // for error handling
 			{
@@ -506,8 +508,8 @@ public MappingParser(ParserSharedInputState state) {
 		return name;
 	}
 	
-	public final List  memberFilter() throws RecognitionException, TokenStreamException {
-		List filter = new ArrayList();
+	public final List<Member>  memberFilter() throws RecognitionException, TokenStreamException {
+		List<Member> filter = new ArrayList<Member>();
 		
 		Member member;
 		
@@ -538,8 +540,8 @@ public MappingParser(ParserSharedInputState state) {
 		return filter;
 	}
 	
-	public final List  axisPositions() throws RecognitionException, TokenStreamException {
-		List positions = new ArrayList();
+	public final List<AxisPosition> axisPositions() throws RecognitionException, TokenStreamException {
+		List<AxisPosition> positions = new ArrayList<AxisPosition>();
 		
 		AxisPosition pos; int axis = 0;
 		
