@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -36,7 +36,7 @@ import net.sf.jasperreports.olap.result.JROlapResultAxis;
 
 /**
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRMondrianAxis.java 3659 2010-03-31 10:20:49Z shertage $
+ * @version $Id: JRMondrianAxis.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRMondrianAxis implements JROlapResultAxis
 {
@@ -46,13 +46,13 @@ public class JRMondrianAxis implements JROlapResultAxis
 	
 	public JRMondrianAxis(Axis axis, Hierarchy[] axisHierarchies, JRMondrianFactory factory)
 	{
-		List positions = axis.getPositions();
+		List<Position> positions = axis.getPositions();
 		tuples = new JRMondrianTuple[positions.size()];
 		
 		int idx = 0;
-		for (Iterator it = positions.iterator(); it.hasNext(); ++idx)
+		for (Iterator<Position> it = positions.iterator(); it.hasNext(); ++idx)
 		{
-			Position position = (Position) it.next();
+			Position position = it.next();
 			tuples[idx] = new JRMondrianTuple(position, factory);
 		}
 		
