@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,7 +35,7 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRXmlaHierarchy.java 3659 2010-03-31 10:20:49Z shertage $
+ * @version $Id: JRXmlaHierarchy.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRXmlaHierarchy implements JROlapHierarchy
 {
@@ -43,13 +43,13 @@ public class JRXmlaHierarchy implements JROlapHierarchy
 	private final static Log log = LogFactory.getLog(JRXmlaHierarchy.class);
 
 	private final String dimensionName;
-	private final List levels;
+	private final List<JRXmlaHierarchyLevel> levels;
 	private JRXmlaHierarchyLevel[] levelArray;
 
 	public JRXmlaHierarchy(String dimensionName)
 	{
 		this.dimensionName = dimensionName;
-		this.levels = new ArrayList();
+		this.levels = new ArrayList<JRXmlaHierarchyLevel>();
 	}
 
 	public String getDimensionName()
@@ -73,7 +73,7 @@ public class JRXmlaHierarchy implements JROlapHierarchy
 			}
 		}
 		
-		JRXmlaHierarchyLevel level = (JRXmlaHierarchyLevel) levels.get(depth);
+		JRXmlaHierarchyLevel level = levels.get(depth);
 		if (level == null)
 		{
 			level = new JRXmlaHierarchyLevel(levelName, depth);
@@ -89,18 +89,19 @@ public class JRXmlaHierarchy implements JROlapHierarchy
 		
 		resetLevelArray();
 	}
-    // MPenningroth 21-April-2009 deal with case when dimension is <dimension>.<hierarchy> form
-    public String getHierarchyUniqueName()
-    {
-        return dimensionName;
-    }
+	
+	// MPenningroth 21-April-2009 deal with case when dimension is <dimension>.<hierarchy> form
+	public String getHierarchyUniqueName()
+	{
+		return dimensionName;
+	}
 
 	protected JRXmlaHierarchyLevel[] ensureLevelArray()
 	{
 		if (levelArray == null)
 		{
 			levelArray = new JRXmlaHierarchyLevel[levels.size()];
-			levelArray = (JRXmlaHierarchyLevel[]) levels.toArray(levelArray);
+			levelArray = levels.toArray(levelArray);
 		}
 		return levelArray;
 	}
