@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -38,17 +38,17 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRXmlaResult.java 3659 2010-03-31 10:20:49Z shertage $
+ * @version $Id: JRXmlaResult.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRXmlaResult implements JROlapResult
 {
 
 	private final static Log log = LogFactory.getLog(JRXmlaResult.class);
 	
-	private List axesList = new ArrayList();
+	private List<JRXmlaResultAxis> axesList = new ArrayList<JRXmlaResultAxis>();
 	private JRXmlaResultAxis[] axes;
 	private int[] cellOrdinalFactors;
-	private final List cells = new ArrayList();
+	private final List<JRXmlaCell> cells = new ArrayList<JRXmlaCell>();
 
 	public JROlapResultAxis[] getAxes()
 	{
@@ -58,16 +58,16 @@ public class JRXmlaResult implements JROlapResult
 	public JROlapCell getCell(int[] axisPositions)
 	{
 		int cellOrdinal = getCellOrdinal(axisPositions);
-                // Mpenningroth Nov 14th 2008
-                // Modified to check size of array.  Was throwing index exception
-                // for queries that return fewer cells than expected.
-                // The xmla spec (version 1.1 CellData section page 26) indicates that cell elements
-                // can be missing.
-                if (cellOrdinal < cells.size()) {
-                    return (JROlapCell) cells.get(cellOrdinal);
+				// Mpenningroth Nov 14th 2008
+				// Modified to check size of array.  Was throwing index exception
+				// for queries that return fewer cells than expected.
+				// The xmla spec (version 1.1 CellData section page 26) indicates that cell elements
+				// can be missing.
+				if (cellOrdinal < cells.size()) {
+					return cells.get(cellOrdinal);
 		}
-                else {
-                    return null;
+				else {
+					return null;
 		}
 	}
 	
@@ -98,9 +98,9 @@ public class JRXmlaResult implements JROlapResult
 	public JRXmlaResultAxis getAxisByName(String name)
 	{
 		JRXmlaResultAxis axis = null;
-		for (Iterator iter = axesList.iterator(); axis == null && iter.hasNext();)
+		for (Iterator<JRXmlaResultAxis> iter = axesList.iterator(); axis == null && iter.hasNext();)
 		{
-			JRXmlaResultAxis ax = (JRXmlaResultAxis) iter.next();
+			JRXmlaResultAxis ax = iter.next();
 			if (ax.getAxisName().equals(name))
 			{
 				axis = ax;
@@ -114,7 +114,7 @@ public class JRXmlaResult implements JROlapResult
 		if (axes == null)
 		{
 			axes = new JRXmlaResultAxis[axesList.size()];
-			axes = (JRXmlaResultAxis[]) axesList.toArray(axes);
+			axes = axesList.toArray(axes);
 		}
 		return axes;
 	}
