@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -41,7 +41,7 @@ import org.jfree.chart.entity.ChartEntity;
  * @deprecated
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRCategoryChartImageMapRenderer.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRCategoryChartImageMapRenderer.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRCategoryChartImageMapRenderer extends JRAbstractChartImageMapRenderer
 {
@@ -49,7 +49,7 @@ public class JRCategoryChartImageMapRenderer extends JRAbstractChartImageMapRend
 	
 	private CategoryChartHyperlinkProvider categoryChartHyperlinkProvider;
 	
-	public JRCategoryChartImageMapRenderer(JFreeChart chart, Map itemHyperlinks)
+	public JRCategoryChartImageMapRenderer(JFreeChart chart, Map<Comparable<?>,Map<Comparable<?>,JRPrintHyperlink>> itemHyperlinks)
 	{
 		super(chart);
 		
@@ -73,7 +73,7 @@ public class JRCategoryChartImageMapRenderer extends JRAbstractChartImageMapRend
 	/**
 	 * @deprecated
 	 */
-	private Map itemHyperlinks;
+	private Map<Comparable<?>,Map<Comparable<?>,JRPrintHyperlink>> itemHyperlinks;
 
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
