@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -33,6 +33,7 @@ import net.sf.jasperreports.engine.JRPrintHyperlink;
 
 import org.jfree.chart.JFreeChart;
 import org.jfree.chart.entity.ChartEntity;
+import org.jfree.data.time.RegularTimePeriod;
 
 
 /**
@@ -41,16 +42,16 @@ import org.jfree.chart.entity.ChartEntity;
  * @deprecated
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRTimeSeriesChartImageMapRenderer.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRTimeSeriesChartImageMapRenderer.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRTimeSeriesChartImageMapRenderer extends JRAbstractChartImageMapRenderer
 {
 	
 	private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 	
-	private TimeSeriesChartHyperlinkProvider timeSeriesChartHyperlinkProvider = null;
+	private TimeSeriesChartHyperlinkProvider timeSeriesChartHyperlinkProvider;
 	
-	public JRTimeSeriesChartImageMapRenderer(JFreeChart chart, Map itemHyperlinks)
+	public JRTimeSeriesChartImageMapRenderer(JFreeChart chart, Map<Comparable<?>, Map<RegularTimePeriod, JRPrintHyperlink>> itemHyperlinks)
 	{
 		super(chart);
 		
@@ -75,7 +76,7 @@ public class JRTimeSeriesChartImageMapRenderer extends JRAbstractChartImageMapRe
 	/**
 	 * @deprecated
 	 */
-	private Map itemHyperlinks;
+	private Map<Comparable<?>, Map<RegularTimePeriod, JRPrintHyperlink>> itemHyperlinks;
 
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
