@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -44,7 +44,7 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRViewerController.java 3674 2010-04-02 08:18:15Z shertage $
+ * @version $Id: JRViewerController.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRViewerController
 {
@@ -54,19 +54,19 @@ public class JRViewerController
 	protected static final int TYPE_INPUT_STREAM = 2;
 	protected static final int TYPE_OBJECT = 3;
 	
-	private ResourceBundle resourceBundle = null;
-	private Locale locale = null;
-	private final List listeners = new ArrayList();
+	private ResourceBundle resourceBundle;
+	private Locale locale;
+	private final List<JRViewerListener> listeners = new ArrayList<JRViewerListener>();
 	
 	protected int type = TYPE_FILE_NAME;
-	protected boolean isXML = false;
-	protected String reportFileName = null;
-	protected SimpleFileResolver fileResolver = null;
+	protected boolean isXML;
+	protected String reportFileName;
+	protected SimpleFileResolver fileResolver;
 	protected boolean reloadSupported;
 	
-	private JasperPrint jasperPrint = null;
-	private int pageIndex = 0;
-	private float zoom = 0f;
+	private JasperPrint jasperPrint;
+	private int pageIndex;
+	private float zoom;
 	private boolean fitPage;
 	private boolean fitWidth;
 
@@ -106,9 +106,9 @@ public class JRViewerController
 		if (!listeners.isEmpty())
 		{
 			JRViewerEvent event = new JRViewerEvent(this, eventCode);
-			for (Iterator it = listeners.iterator(); it.hasNext();)
+			for (Iterator<JRViewerListener> it = listeners.iterator(); it.hasNext();)
 			{
-				JRViewerListener listener = (JRViewerListener) it.next();
+				JRViewerListener listener = it.next();
 				listener.viewerEvent(event);
 			}
 		}
@@ -122,7 +122,7 @@ public class JRViewerController
 		}
 		else
 		{
-			jasperPrint = (JasperPrint)JRLoader.loadObject(fileName);
+			jasperPrint = (JasperPrint)JRLoader.loadObjectFromFile(fileName);
 		}
 
 		type = TYPE_FILE_NAME;
