@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -58,7 +58,6 @@ import javax.swing.SwingUtilities;
 import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRExporterParameter;
-import net.sf.jasperreports.engine.JRHyperlink;
 import net.sf.jasperreports.engine.JRImageMapRenderer;
 import net.sf.jasperreports.engine.JRPrintAnchorIndex;
 import net.sf.jasperreports.engine.JRPrintElement;
@@ -73,6 +72,7 @@ import net.sf.jasperreports.engine.JasperPrintManager;
 import net.sf.jasperreports.engine.export.JRGraphics2DExporter;
 import net.sf.jasperreports.engine.export.JRGraphics2DExporterParameter;
 import net.sf.jasperreports.engine.print.JRPrinterAWT;
+import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
 import net.sf.jasperreports.engine.util.JRProperties;
 import net.sf.jasperreports.view.JRHyperlinkListener;
 
@@ -81,7 +81,7 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRViewerPanel.java 3035 2009-08-27 12:05:03Z teodord $
+ * @version $Id: JRViewerPanel.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRViewerListener
 {
@@ -108,14 +108,14 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 	private javax.swing.JScrollPane scrollPane;
 
 	private final JRViewerController viewerContext;
-	private JRGraphics2DExporter exporter = null;
+	private JRGraphics2DExporter exporter;
 	private boolean pageError;
 
-	private int downX = 0;
-	private int downY = 0;
+	private int downX;
+	private int downY;
 	
-	private java.util.List hyperlinkListeners = new ArrayList();
-	private Map linksMap = new HashMap();
+	private List<JRHyperlinkListener> hyperlinkListeners = new ArrayList<JRHyperlinkListener>();
+	private Map<JPanel, JRPrintHyperlink> linksMap = new HashMap<JPanel, JRPrintHyperlink>();
 
 	/**
 	 * the screen resolution.
@@ -125,7 +125,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 	/**
 	 * the zoom ratio adjusted to the screen resolution.
 	 */
-	protected float realZoom = 0f;
+	protected float realZoom;
 
 	private MouseListener mouseListener =
 		new java.awt.event.MouseAdapter()
@@ -316,7 +316,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 
 	public JRHyperlinkListener[] getHyperlinkListeners()
 	{
-		return (JRHyperlinkListener[])hyperlinkListeners.toArray(new JRHyperlinkListener[hyperlinkListeners.size()]);
+		return hyperlinkListeners.toArray(new JRHyperlinkListener[hyperlinkListeners.size()]);
 	}
 
 
@@ -325,9 +325,9 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 	 */
 	public void gotoHyperlink(JRPrintHyperlink hyperlink)
 	{
-		switch(hyperlink.getHyperlinkType())
+		switch(hyperlink.getHyperlinkTypeValue())
 		{
-			case JRHyperlink.HYPERLINK_TYPE_REFERENCE :
+			case REFERENCE :
 			{
 				if (isOnlyHyperlinkListener())
 				{
@@ -336,12 +336,12 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 				}
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_LOCAL_ANCHOR :
+			case LOCAL_ANCHOR :
 			{
 				if (hyperlink.getHyperlinkAnchor() != null)
 				{
-					Map anchorIndexes = viewerContext.getJasperPrint().getAnchorIndexes();
-					JRPrintAnchorIndex anchorIndex = (JRPrintAnchorIndex)anchorIndexes.get(hyperlink.getHyperlinkAnchor());
+					Map<String, JRPrintAnchorIndex> anchorIndexes = viewerContext.getJasperPrint().getAnchorIndexes();
+					JRPrintAnchorIndex anchorIndex = anchorIndexes.get(hyperlink.getHyperlinkAnchor());
 					if (anchorIndex.getPageIndex() != viewerContext.getPageIndex())
 					{
 						viewerContext.setPageIndex(anchorIndex.getPageIndex());
@@ -381,7 +381,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_LOCAL_PAGE :
+			case LOCAL_PAGE :
 			{
 				int page = viewerContext.getPageIndex() + 1;
 				if (hyperlink.getHyperlinkPage() != null)
@@ -403,7 +403,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_REMOTE_ANCHOR :
+			case REMOTE_ANCHOR :
 			{
 				if (isOnlyHyperlinkListener())
 				{
@@ -413,7 +413,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 				}
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_REMOTE_PAGE :
+			case REMOTE_PAGE :
 			{
 				if (isOnlyHyperlinkListener())
 				{
@@ -423,7 +423,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 				}
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_CUSTOM:
+			case CUSTOM:
 			{
 				if (isOnlyHyperlinkListener())
 				{
@@ -432,7 +432,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 				}
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_NONE :
+			case NONE :
 			default :
 			{
 				break;
@@ -480,17 +480,19 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 
 			exporter.setParameter(JRExporterParameter.JASPER_PRINT, viewerContext.getJasperPrint());
 			exporter.setParameter(JRGraphics2DExporterParameter.GRAPHICS_2D, grx.create());
-			exporter.setParameter(JRExporterParameter.PAGE_INDEX, new Integer(viewerContext.getPageIndex()));
+			exporter.setParameter(JRExporterParameter.PAGE_INDEX, Integer.valueOf(viewerContext.getPageIndex()));
 			exporter.setParameter(JRGraphics2DExporterParameter.ZOOM_RATIO, new Float(realZoom));
-			exporter.setParameter(JRExporterParameter.OFFSET_X, new Integer(1)); //lblPage border
-			exporter.setParameter(JRExporterParameter.OFFSET_Y, new Integer(1));
+			exporter.setParameter(JRExporterParameter.OFFSET_X, Integer.valueOf(1)); //lblPage border
+			exporter.setParameter(JRExporterParameter.OFFSET_Y, Integer.valueOf(1));
 			exporter.setParameter(JRExporterParameter.FILE_RESOLVER, viewerContext.getFileResolver());
 			exporter.exportReport();
 		}
 		catch(Exception e)
 		{
 			if (log.isErrorEnabled())
+			{
 				log.error("Page paint error.", e);
+			}
 
 			pageError = true;
 			
@@ -704,7 +706,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 		}
 
 		pnlLinks.removeAll();
-		linksMap = new HashMap();
+		linksMap = new HashMap<JPanel, JRPrintHyperlink>();
 
 		createHyperlinks();
 
@@ -733,7 +735,9 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 			catch (Exception e)
 			{
 				if (log.isErrorEnabled())
+				{
 					log.error("Print page to image error.", e);
+				}
 
 				pageError = true;
 
@@ -758,7 +762,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 		transform.scale(realZoom, realZoom);
 		grx.transform(transform);
 
-		drawPageError((Graphics2D) grx);
+		drawPageError(grx);
 		
 		return image;
 	}
@@ -770,18 +774,18 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 
 	protected void createHyperlinks()
 	{
-		java.util.List pages = viewerContext.getJasperPrint().getPages();
-		JRPrintPage page = (JRPrintPage)pages.get(viewerContext.getPageIndex());
+		List<JRPrintPage> pages = viewerContext.getJasperPrint().getPages();
+		JRPrintPage page = pages.get(viewerContext.getPageIndex());
 		createHyperlinks(page.getElements(), 0, 0);
 	}
 
-	protected void createHyperlinks(List elements, int offsetX, int offsetY)
+	protected void createHyperlinks(List<JRPrintElement> elements, int offsetX, int offsetY)
 	{
 		if(elements != null && elements.size() > 0)
 		{
-			for(Iterator it = elements.iterator(); it.hasNext();)
+			for(Iterator<JRPrintElement> it = elements.iterator(); it.hasNext();)
 			{
-				JRPrintElement element = (JRPrintElement)it.next();
+				JRPrintElement element = it.next();
 
 				JRImageMapRenderer imageMap = null;
 				if (element instanceof JRPrintImage)
@@ -804,7 +808,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 					hyperlink = (JRPrintHyperlink) element;
 				}
 				boolean hasHyperlink = !hasImageMap 
-					&& hyperlink != null && hyperlink.getHyperlinkType() != JRHyperlink.HYPERLINK_TYPE_NONE;
+					&& hyperlink != null && hyperlink.getHyperlinkTypeValue() != HyperlinkTypeEnum.NONE;
 				boolean hasTooltip = hyperlink != null && hyperlink.getHyperlinkTooltip() != null;
 
 				if (hasHyperlink || hasImageMap || hasTooltip)
@@ -847,7 +851,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 					link.setToolTipText(toolTip);
 
 					pnlLinks.add(link);
-					linksMap.put(link, element);
+					linksMap.put(link, hyperlink);
 				}
 
 				if (element instanceof JRPrintFrame)
@@ -866,7 +870,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 	{
 		private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 
-		protected final List imageAreaHyperlinks;
+		protected final List<JRPrintImageAreaHyperlink> imageAreaHyperlinks;
 
 		public ImageMapPanel(Rectangle renderingArea, JRImageMapRenderer imageMap)
 		{
@@ -909,7 +913,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 		{
 			JRPrintImageAreaHyperlink imageArea = getImageMapArea(e);
 			if (imageArea != null
-					&& imageArea.getHyperlink().getHyperlinkType() != JRHyperlink.HYPERLINK_TYPE_NONE)
+					&& imageArea.getHyperlink().getHyperlinkTypeValue() != HyperlinkTypeEnum.NONE)
 			{
 				e.getComponent().setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
 			}
@@ -929,9 +933,9 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 			JRPrintImageAreaHyperlink image = null;
 			if (imageAreaHyperlinks != null)
 			{
-				for (ListIterator it = imageAreaHyperlinks.listIterator(imageAreaHyperlinks.size()); image == null && it.hasPrevious();)
+				for (ListIterator<JRPrintImageAreaHyperlink> it = imageAreaHyperlinks.listIterator(imageAreaHyperlinks.size()); image == null && it.hasPrevious();)
 				{
-					JRPrintImageAreaHyperlink area = (JRPrintImageAreaHyperlink) it.previous();
+					JRPrintImageAreaHyperlink area = it.previous();
 					if (area.getArea().containsPoint(x, y))
 					{
 						image = area;
@@ -987,14 +991,14 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 	protected String getFallbackTooltip(JRPrintHyperlink hyperlink)
 	{
 		String toolTip = null;
-		switch(hyperlink.getHyperlinkType())
+		switch(hyperlink.getHyperlinkTypeValue())
 		{
-			case JRHyperlink.HYPERLINK_TYPE_REFERENCE :
+			case REFERENCE :
 			{
 				toolTip = hyperlink.getHyperlinkReference();
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_LOCAL_ANCHOR :
+			case LOCAL_ANCHOR :
 			{
 				if (hyperlink.getHyperlinkAnchor() != null)
 				{
@@ -1002,7 +1006,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 				}
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_LOCAL_PAGE :
+			case LOCAL_PAGE :
 			{
 				if (hyperlink.getHyperlinkPage() != null)
 				{
@@ -1010,7 +1014,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 				}
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_REMOTE_ANCHOR :
+			case REMOTE_ANCHOR :
 			{
 				toolTip = "";
 				if (hyperlink.getHyperlinkReference() != null)
@@ -1023,7 +1027,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 				}
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_REMOTE_PAGE :
+			case REMOTE_PAGE :
 			{
 				toolTip = "";
 				if (hyperlink.getHyperlinkReference() != null)
@@ -1047,7 +1051,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 	void hyperlinkClicked(MouseEvent evt)
 	{
 		JPanel link = (JPanel)evt.getSource();
-		JRPrintHyperlink element = (JRPrintHyperlink)linksMap.get(link);
+		JRPrintHyperlink element = linksMap.get(link);
 		hyperlinkClicked(element);
 	}
 
@@ -1058,14 +1062,16 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 			JRHyperlinkListener listener = null;
 			for(int i = 0; i < hyperlinkListeners.size(); i++)
 			{
-				listener = (JRHyperlinkListener)hyperlinkListeners.get(i);
+				listener = hyperlinkListeners.get(i);
 				listener.gotoHyperlink(hyperlink);
 			}
 		}
 		catch(JRException e)
 		{
 			if (log.isErrorEnabled())
+			{
 				log.error("Hyperlink click error.", e);
+			}
 
 			JOptionPane.showMessageDialog(this, viewerContext.getBundleString("error.hyperlink"));
 		}
@@ -1129,7 +1135,9 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 		{
 			viewerContext.setPageIndex(viewerContext.getPageIndex() + 1);
 			if(scrollPane.isEnabled())
+			{
 				scrollPane.getVerticalScrollBar().setValue(0);
+			}
 		}
 	}
 
@@ -1141,7 +1149,9 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 		{
 			viewerContext.setPageIndex(viewerContext.getPageIndex() - 1);
 			if(scrollPane.isEnabled())
+			{
 				scrollPane.getVerticalScrollBar().setValue(scrollPane.getVerticalScrollBar().getMaximum());
+			}
 		}
 		else
 		{
@@ -1153,7 +1163,9 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 	{
 		viewerContext.setPageIndex(pageNumber);
 		if(scrollPane.isEnabled())
+		{
 			scrollPane.getVerticalScrollBar().setValue(0);
+		}
 	}
 
 	public void viewerEvent(JRViewerEvent event)
