@@ -1,6 +1,6 @@
 /*
  * JasperReports - Free Java Reporting Library.
- * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
+ * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
  * http://www.jaspersoft.com
  *
  * Unless you have purchased a commercial license agreement from Jaspersoft,
@@ -17,7 +17,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
  */
@@ -52,7 +52,7 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRViewerToolbar.java 3035 2009-08-27 12:05:03Z teodord $
+ * @version $Id: JRViewerToolbar.java 4595 2011-09-08 15:55:10Z teodord $
  */
 public class JRViewerToolbar extends JPanel implements JRViewerListener
 {
@@ -62,13 +62,13 @@ public class JRViewerToolbar extends JPanel implements JRViewerListener
 
 	protected final JRViewerController viewerContext;
 	
-	protected float MIN_ZOOM = 0.5f;
-	protected float MAX_ZOOM = 10f;
+	protected final float MIN_ZOOM = 0.5f;
+	protected final float MAX_ZOOM = 10f;
 	protected int zooms[] = {50, 75, 100, 125, 150, 175, 200, 250, 400, 800};
 	protected int defaultZoomIndex = 2;
-	protected List saveContributors = new ArrayList();
-	protected File lastFolder = null;
-	protected JRSaveContributor lastSaveContributor = null;
+	protected List<JRSaveContributor> saveContributors = new ArrayList<JRSaveContributor>();
+	protected File lastFolder;
+	protected JRSaveContributor lastSaveContributor;
 	protected DecimalFormat zoomDecimalFormat = new DecimalFormat("#.##");
 	
 	protected javax.swing.JToggleButton btnActualSize;
@@ -351,7 +351,7 @@ public class JRViewerToolbar extends JPanel implements JRViewerListener
 		fileChooser.updateUI();
 		for(int i = 0; i < saveContributors.size(); i++)
 		{
-			fileChooser.addChoosableFileFilter((JRSaveContributor)saveContributors.get(i));
+			fileChooser.addChoosableFileFilter(saveContributors.get(i));
 		}
 
 		if (saveContributors.contains(lastSaveContributor))
@@ -360,7 +360,7 @@ public class JRViewerToolbar extends JPanel implements JRViewerListener
 		}
 		else if (saveContributors.size() > 0)
 		{
-			fileChooser.setFileFilter((JRSaveContributor)saveContributors.get(0));
+			fileChooser.setFileFilter(saveContributors.get(0));
 		}
 		
 		if (lastFolder != null)
@@ -387,7 +387,7 @@ public class JRViewerToolbar extends JPanel implements JRViewerListener
 				int i = 0;
 				while(contributor == null && i < saveContributors.size())
 				{
-					contributor = (JRSaveContributor)saveContributors.get(i++);
+					contributor = saveContributors.get(i++);
 					if (!contributor.accept(file))
 					{
 						contributor = null;
@@ -409,8 +409,9 @@ public class JRViewerToolbar extends JPanel implements JRViewerListener
 			catch (JRException e)
 			{
 				if (log.isErrorEnabled())
+				{
 					log.error("Save error.", e);
-
+				}
 				JOptionPane.showMessageDialog(this, viewerContext.getBundleString("error.saving"));
 			}
 		}
@@ -434,8 +435,9 @@ public class JRViewerToolbar extends JPanel implements JRViewerListener
 						catch (Exception ex)
 						{
 							if (log.isErrorEnabled())
+							{
 								log.error("Print error.", ex);
-
+							}
 							JOptionPane.showMessageDialog(JRViewerToolbar.this, 
 									viewerContext.getBundleString("error.printing"));
 						}
@@ -646,7 +648,7 @@ public class JRViewerToolbar extends JPanel implements JRViewerListener
 	 */
 	public JRSaveContributor[] getSaveContributors()
 	{
-		return (JRSaveContributor[])saveContributors.toArray(new JRSaveContributor[saveContributors.size()]);
+		return saveContributors.toArray(new JRSaveContributor[saveContributors.size()]);
 	}
 
 
@@ -655,7 +657,7 @@ public class JRViewerToolbar extends JPanel implements JRViewerListener
 	 */
 	public void setSaveContributors(JRSaveContributor[] saveContributors)
 	{
-		this.saveContributors = new ArrayList();
+		this.saveContributors = new ArrayList<JRSaveContributor>();
 		if (saveContributors != null)
 		{
 			this.saveContributors.addAll(Arrays.asList(saveContributors));
@@ -687,8 +689,8 @@ public class JRViewerToolbar extends JPanel implements JRViewerListener
 		{
 			try
 			{
-				Class saveContribClass = JRClassLoader.loadClassForName(DEFAULT_CONTRIBUTORS[i]);
-				Constructor constructor = saveContribClass.getConstructor(new Class[]{Locale.class, ResourceBundle.class});
+				Class<?> saveContribClass = JRClassLoader.loadClassForName(DEFAULT_CONTRIBUTORS[i]);
+				Constructor<?> constructor = saveContribClass.getConstructor(new Class[]{Locale.class, ResourceBundle.class});
 				JRSaveContributor saveContrib = (JRSaveContributor)constructor.newInstance(new Object[]{getLocale(), viewerContext.getResourceBundle()});
 				saveContributors.add(saveContrib);
 			}
